Class: LaunchDarklyApi::AIConfigPatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIConfigPatch
- Defined in:
- lib/launchdarkly_api/models/ai_config_patch.rb
Instance Attribute Summary collapse
-
#description ⇒ Object
Returns the value of attribute description.
-
#evaluation_metric_key ⇒ Object
Evaluation metric key for this config.
-
#is_inverted ⇒ Object
Whether the evaluation metric is inverted, meaning a lower value is better if set as true.
-
#maintainer_id ⇒ Object
Returns the value of attribute maintainer_id.
-
#maintainer_team_key ⇒ Object
Returns the value of attribute maintainer_team_key.
-
#name ⇒ Object
Returns the value of attribute name.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIConfigPatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIConfigPatch
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigPatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'maintainer_team_key') self.maintainer_team_key = attributes[:'maintainer_team_key'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'evaluation_metric_key') self.evaluation_metric_key = attributes[:'evaluation_metric_key'] end if attributes.key?(:'is_inverted') self.is_inverted = attributes[:'is_inverted'] end end |
Instance Attribute Details
#description ⇒ Object
Returns the value of attribute description.
18 19 20 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 18 def description @description end |
#evaluation_metric_key ⇒ Object
Evaluation metric key for this config
29 30 31 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 29 def evaluation_metric_key @evaluation_metric_key end |
#is_inverted ⇒ Object
Whether the evaluation metric is inverted, meaning a lower value is better if set as true
32 33 34 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 32 def is_inverted @is_inverted end |
#maintainer_id ⇒ Object
Returns the value of attribute maintainer_id.
20 21 22 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 20 def maintainer_id @maintainer_id end |
#maintainer_team_key ⇒ Object
Returns the value of attribute maintainer_team_key.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 22 def maintainer_team_key @maintainer_team_key end |
#name ⇒ Object
Returns the value of attribute name.
24 25 26 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 24 def name @name end |
#tags ⇒ Object
Returns the value of attribute tags.
26 27 28 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 26 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 45 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 35 def self.attribute_map { :'description' => :'description', :'maintainer_id' => :'maintainerId', :'maintainer_team_key' => :'maintainerTeamKey', :'name' => :'name', :'tags' => :'tags', :'evaluation_metric_key' => :'evaluationMetricKey', :'is_inverted' => :'isInverted' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 58 def self.openapi_types { :'description' => :'String', :'maintainer_id' => :'String', :'maintainer_team_key' => :'String', :'name' => :'String', :'tags' => :'Array<String>', :'evaluation_metric_key' => :'String', :'is_inverted' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 140 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && maintainer_id == o.maintainer_id && maintainer_team_key == o.maintainer_team_key && name == o.name && == o. && evaluation_metric_key == o.evaluation_metric_key && is_inverted == o.is_inverted end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 160 def hash [description, maintainer_id, maintainer_team_key, name, , evaluation_metric_key, is_inverted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
133 134 135 136 |
# File 'lib/launchdarkly_api/models/ai_config_patch.rb', line 133 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |