Class: LaunchDarklyApi::AIConfigTargetingEnvironment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIConfigTargetingEnvironment
- Defined in:
- lib/launchdarkly_api/models/ai_config_targeting_environment.rb
Instance Attribute Summary collapse
-
#_environment_name ⇒ Object
Returns the value of attribute _environment_name.
-
#_version ⇒ Object
Returns the value of attribute _version.
-
#context_targets ⇒ Object
Returns the value of attribute context_targets.
-
#enabled ⇒ Object
Returns the value of attribute enabled.
-
#fallthrough ⇒ Object
Returns the value of attribute fallthrough.
-
#last_modified ⇒ Object
Returns the value of attribute last_modified.
-
#off_variation ⇒ Object
Returns the value of attribute off_variation.
-
#rules ⇒ Object
Returns the value of attribute rules.
-
#targets ⇒ Object
Returns the value of attribute targets.
-
#track_events ⇒ Object
Returns the value of attribute track_events.
-
#track_events_fallthrough ⇒ Object
Returns the value of attribute track_events_fallthrough.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIConfigTargetingEnvironment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIConfigTargetingEnvironment
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigTargetingEnvironment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigTargetingEnvironment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'context_targets') if (value = attributes[:'context_targets']).is_a?(Array) self.context_targets = value end else self.context_targets = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'fallthrough') self.fallthrough = attributes[:'fallthrough'] else self.fallthrough = nil end if attributes.key?(:'last_modified') self.last_modified = attributes[:'last_modified'] else self.last_modified = nil end if attributes.key?(:'off_variation') self.off_variation = attributes[:'off_variation'] end if attributes.key?(:'rules') if (value = attributes[:'rules']).is_a?(Array) self.rules = value end else self.rules = nil end if attributes.key?(:'targets') if (value = attributes[:'targets']).is_a?(Array) self.targets = value end else self.targets = nil end if attributes.key?(:'track_events') self.track_events = attributes[:'track_events'] else self.track_events = nil end if attributes.key?(:'track_events_fallthrough') self.track_events_fallthrough = attributes[:'track_events_fallthrough'] else self.track_events_fallthrough = nil end if attributes.key?(:'_environment_name') self._environment_name = attributes[:'_environment_name'] else self._environment_name = nil end if attributes.key?(:'_version') self._version = attributes[:'_version'] else self._version = nil end end |
Instance Attribute Details
#_environment_name ⇒ Object
Returns the value of attribute _environment_name.
36 37 38 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 36 def _environment_name @_environment_name end |
#_version ⇒ Object
Returns the value of attribute _version.
38 39 40 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 38 def _version @_version end |
#context_targets ⇒ Object
Returns the value of attribute context_targets.
18 19 20 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 18 def context_targets @context_targets end |
#enabled ⇒ Object
Returns the value of attribute enabled.
20 21 22 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 20 def enabled @enabled end |
#fallthrough ⇒ Object
Returns the value of attribute fallthrough.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 22 def fallthrough @fallthrough end |
#last_modified ⇒ Object
Returns the value of attribute last_modified.
24 25 26 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 24 def last_modified @last_modified end |
#off_variation ⇒ Object
Returns the value of attribute off_variation.
26 27 28 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 26 def off_variation @off_variation end |
#rules ⇒ Object
Returns the value of attribute rules.
28 29 30 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 28 def rules @rules end |
#targets ⇒ Object
Returns the value of attribute targets.
30 31 32 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 30 def targets @targets end |
#track_events ⇒ Object
Returns the value of attribute track_events.
32 33 34 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 32 def track_events @track_events end |
#track_events_fallthrough ⇒ Object
Returns the value of attribute track_events_fallthrough.
34 35 36 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 34 def track_events_fallthrough @track_events_fallthrough end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
58 59 60 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 58 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 63 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 41 def self.attribute_map { :'context_targets' => :'contextTargets', :'enabled' => :'enabled', :'fallthrough' => :'fallthrough', :'last_modified' => :'lastModified', :'off_variation' => :'offVariation', :'rules' => :'rules', :'targets' => :'targets', :'track_events' => :'trackEvents', :'track_events_fallthrough' => :'trackEventsFallthrough', :'_environment_name' => :'_environmentName', :'_version' => :'_version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 375 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 68 def self.openapi_types { :'context_targets' => :'Array<AIConfigTargetingEnvironmentTarget>', :'enabled' => :'Boolean', :'fallthrough' => :'AIConfigTargetingEnvironmentFallthrough', :'last_modified' => :'Integer', :'off_variation' => :'Integer', :'rules' => :'Array<AIConfigTargetingEnvironmentRule>', :'targets' => :'Array<AIConfigTargetingEnvironmentTarget>', :'track_events' => :'Boolean', :'track_events_fallthrough' => :'Boolean', :'_environment_name' => :'String', :'_version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 344 def ==(o) return true if self.equal?(o) self.class == o.class && context_targets == o.context_targets && enabled == o.enabled && fallthrough == o.fallthrough && last_modified == o.last_modified && off_variation == o.off_variation && rules == o.rules && targets == o.targets && track_events == o.track_events && track_events_fallthrough == o.track_events_fallthrough && _environment_name == o._environment_name && _version == o._version end |
#eql?(o) ⇒ Boolean
362 363 364 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 362 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
368 369 370 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 368 def hash [context_targets, enabled, fallthrough, last_modified, off_variation, rules, targets, track_events, track_events_fallthrough, _environment_name, _version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @context_targets.nil? invalid_properties.push('invalid value for "context_targets", context_targets cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @fallthrough.nil? invalid_properties.push('invalid value for "fallthrough", fallthrough cannot be nil.') end if @last_modified.nil? invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.') end if @rules.nil? invalid_properties.push('invalid value for "rules", rules cannot be nil.') end if @targets.nil? invalid_properties.push('invalid value for "targets", targets cannot be nil.') end if @track_events.nil? invalid_properties.push('invalid value for "track_events", track_events cannot be nil.') end if @track_events_fallthrough.nil? invalid_properties.push('invalid value for "track_events_fallthrough", track_events_fallthrough cannot be nil.') end if @_environment_name.nil? invalid_properties.push('invalid value for "_environment_name", _environment_name cannot be nil.') end if @_version.nil? invalid_properties.push('invalid value for "_version", _version cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 397 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/launchdarkly_api/models/ai_config_targeting_environment.rb', line 227 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @context_targets.nil? return false if @enabled.nil? return false if @fallthrough.nil? return false if @last_modified.nil? return false if @rules.nil? return false if @targets.nil? return false if @track_events.nil? return false if @track_events_fallthrough.nil? return false if @_environment_name.nil? return false if @_version.nil? true end |