Class: LaunchDarklyApi::AIConfigVariationPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIConfigVariationPost
- Defined in:
- lib/launchdarkly_api/models/ai_config_variation_post.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Human-readable description of this variation.
-
#description ⇒ Object
Returns the description for the agent.
-
#instructions ⇒ Object
Returns the instructions for the agent.
-
#judge_configuration ⇒ Object
Returns the value of attribute judge_configuration.
-
#key ⇒ Object
Returns the value of attribute key.
-
#messages ⇒ Object
Returns the value of attribute messages.
-
#model ⇒ Object
Returns the value of attribute model.
-
#model_config_key ⇒ Object
Returns the value of attribute model_config_key.
-
#name ⇒ Object
Returns the value of attribute name.
-
#output_format ⇒ Object
JSON Schema defining the structured output format for the variation.
-
#skills ⇒ Object
List of agent skills to attach to this variation.
-
#tool_keys ⇒ Object
List of tool keys to use for this variation.
-
#tools ⇒ Object
List of tools to use for this variation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIConfigVariationPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIConfigVariationPost
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigVariationPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigVariationPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'instructions') self.instructions = attributes[:'instructions'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'messages') if (value = attributes[:'messages']).is_a?(Array) self. = value end end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'model_config_key') self.model_config_key = attributes[:'model_config_key'] end if attributes.key?(:'output_format') if (value = attributes[:'output_format']).is_a?(Hash) self.output_format = value end end if attributes.key?(:'tools') if (value = attributes[:'tools']).is_a?(Array) self.tools = value end end if attributes.key?(:'tool_keys') if (value = attributes[:'tool_keys']).is_a?(Array) self.tool_keys = value end end if attributes.key?(:'skills') if (value = attributes[:'skills']).is_a?(Array) self.skills = value end end if attributes.key?(:'judge_configuration') self.judge_configuration = attributes[:'judge_configuration'] end end |
Instance Attribute Details
#comment ⇒ Object
Human-readable description of this variation
19 20 21 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 19 def comment @comment end |
#description ⇒ Object
Returns the description for the agent. This is only returned for agent variations.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 22 def description @description end |
#instructions ⇒ Object
Returns the instructions for the agent. This is only returned for agent variations.
25 26 27 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 25 def instructions @instructions end |
#judge_configuration ⇒ Object
Returns the value of attribute judge_configuration.
49 50 51 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 49 def judge_configuration @judge_configuration end |
#key ⇒ Object
Returns the value of attribute key.
27 28 29 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 27 def key @key end |
#messages ⇒ Object
Returns the value of attribute messages.
29 30 31 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 29 def @messages end |
#model ⇒ Object
Returns the value of attribute model.
31 32 33 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 31 def model @model end |
#model_config_key ⇒ Object
Returns the value of attribute model_config_key.
35 36 37 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 35 def model_config_key @model_config_key end |
#name ⇒ Object
Returns the value of attribute name.
33 34 35 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 33 def name @name end |
#output_format ⇒ Object
JSON Schema defining the structured output format for the variation.
38 39 40 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 38 def output_format @output_format end |
#skills ⇒ Object
List of agent skills to attach to this variation.
47 48 49 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 47 def skills @skills end |
#tool_keys ⇒ Object
List of tool keys to use for this variation. The latest version of the tool will be used.
44 45 46 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 44 def tool_keys @tool_keys end |
#tools ⇒ Object
List of tools to use for this variation. The latest version of the tool will be used.
41 42 43 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 41 def tools @tools end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 52 def self.attribute_map { :'comment' => :'comment', :'description' => :'description', :'instructions' => :'instructions', :'key' => :'key', :'messages' => :'messages', :'model' => :'model', :'name' => :'name', :'model_config_key' => :'modelConfigKey', :'output_format' => :'outputFormat', :'tools' => :'tools', :'tool_keys' => :'toolKeys', :'skills' => :'skills', :'judge_configuration' => :'judgeConfiguration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 268 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 81 def self.openapi_types { :'comment' => :'String', :'description' => :'String', :'instructions' => :'String', :'key' => :'String', :'messages' => :'Array<Message>', :'model' => :'Object', :'name' => :'String', :'model_config_key' => :'String', :'output_format' => :'Hash<String, Object>', :'tools' => :'Array<VariationToolPost>', :'tool_keys' => :'Array<String>', :'skills' => :'Array<VariationSkillPost>', :'judge_configuration' => :'JudgeConfiguration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 235 def ==(o) return true if self.equal?(o) self.class == o.class && comment == o.comment && description == o.description && instructions == o.instructions && key == o.key && == o. && model == o.model && name == o.name && model_config_key == o.model_config_key && output_format == o.output_format && tools == o.tools && tool_keys == o.tool_keys && skills == o.skills && judge_configuration == o.judge_configuration end |
#eql?(o) ⇒ Boolean
255 256 257 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 255 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
261 262 263 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 261 def hash [comment, description, instructions, key, , model, name, model_config_key, output_format, tools, tool_keys, skills, judge_configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 190 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 290 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
206 207 208 209 210 211 |
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 206 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? true end |