Class: LaunchDarklyApi::AITool
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AITool
- Defined in:
- lib/launchdarkly_api/models/ai_tool.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#custom_parameters ⇒ Object
Custom metadata and configuration for application-level use (not sent to LLM).
-
#description ⇒ Object
Returns the value of attribute description.
-
#key ⇒ Object
Returns the value of attribute key.
-
#schema ⇒ Object
JSON Schema defining the tool's parameters for LLM consumption.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AITool
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AITool
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AITool` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AITool`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_links') self._links = attributes[:'_links'] end if attributes.key?(:'_maintainer') self._maintainer = attributes[:'_maintainer'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'schema') self.schema = attributes[:'schema'] else self.schema = nil end if attributes.key?(:'custom_parameters') self.custom_parameters = attributes[:'custom_parameters'] end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
20 21 22 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 20 def _access @_access end |
#_links ⇒ Object
Returns the value of attribute _links.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 22 def _links @_links end |
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
24 25 26 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 24 def _maintainer @_maintainer end |
#created_at ⇒ Object
Returns the value of attribute created_at.
36 37 38 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 36 def created_at @created_at end |
#custom_parameters ⇒ Object
Custom metadata and configuration for application-level use (not sent to LLM)
32 33 34 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 32 def custom_parameters @custom_parameters end |
#description ⇒ Object
Returns the value of attribute description.
26 27 28 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 26 def description @description end |
#key ⇒ Object
Returns the value of attribute key.
18 19 20 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 18 def key @key end |
#schema ⇒ Object
JSON Schema defining the tool's parameters for LLM consumption
29 30 31 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 29 def schema @schema end |
#version ⇒ Object
Returns the value of attribute version.
34 35 36 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 34 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 39 def self.attribute_map { :'key' => :'key', :'_access' => :'_access', :'_links' => :'_links', :'_maintainer' => :'_maintainer', :'description' => :'description', :'schema' => :'schema', :'custom_parameters' => :'customParameters', :'version' => :'version', :'created_at' => :'createdAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 251 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 64 def self.openapi_types { :'key' => :'String', :'_access' => :'AiConfigsAccess', :'_links' => :'ParentAndSelfLinks', :'_maintainer' => :'AIConfigMaintainer', :'description' => :'String', :'schema' => :'Object', :'custom_parameters' => :'Object', :'version' => :'Integer', :'created_at' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 222 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && _access == o._access && _links == o._links && _maintainer == o._maintainer && description == o.description && schema == o.schema && custom_parameters == o.custom_parameters && version == o.version && created_at == o.created_at end |
#eql?(o) ⇒ Boolean
238 239 240 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 238 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
244 245 246 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 244 def hash [key, _access, _links, _maintainer, description, schema, custom_parameters, version, created_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @schema.nil? invalid_properties.push('invalid value for "schema", schema cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 273 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
171 172 173 174 175 176 177 178 |
# File 'lib/launchdarkly_api/models/ai_tool.rb', line 171 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @schema.nil? return false if @version.nil? return false if @created_at.nil? true end |