Class: LaunchDarklyApi::AIToolPatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIToolPatch
- Defined in:
- lib/launchdarkly_api/models/ai_tool_patch.rb
Instance Attribute Summary collapse
-
#custom_parameters ⇒ Object
Custom metadata and configuration for application-level use (not sent to LLM).
-
#description ⇒ Object
Returns the value of attribute description.
-
#maintainer_id ⇒ Object
Returns the value of attribute maintainer_id.
-
#maintainer_team_key ⇒ Object
Returns the value of attribute maintainer_team_key.
-
#schema ⇒ Object
JSON Schema defining the tool's parameters for LLM consumption.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIToolPatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIToolPatch
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIToolPatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIToolPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'maintainer_team_key') self.maintainer_team_key = attributes[:'maintainer_team_key'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'schema') self.schema = attributes[:'schema'] end if attributes.key?(:'custom_parameters') self.custom_parameters = attributes[:'custom_parameters'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#custom_parameters ⇒ Object
Custom metadata and configuration for application-level use (not sent to LLM)
28 29 30 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 28 def custom_parameters @custom_parameters end |
#description ⇒ Object
Returns the value of attribute description.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 22 def description @description end |
#maintainer_id ⇒ Object
Returns the value of attribute maintainer_id.
18 19 20 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 18 def maintainer_id @maintainer_id end |
#maintainer_team_key ⇒ Object
Returns the value of attribute maintainer_team_key.
20 21 22 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 20 def maintainer_team_key @maintainer_team_key end |
#schema ⇒ Object
JSON Schema defining the tool's parameters for LLM consumption
25 26 27 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 25 def schema @schema end |
#tags ⇒ Object
Returns the value of attribute tags.
30 31 32 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 30 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 33 def self.attribute_map { :'maintainer_id' => :'maintainerId', :'maintainer_team_key' => :'maintainerTeamKey', :'description' => :'description', :'schema' => :'schema', :'custom_parameters' => :'customParameters', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 158 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 55 def self.openapi_types { :'maintainer_id' => :'String', :'maintainer_team_key' => :'String', :'description' => :'String', :'schema' => :'Object', :'custom_parameters' => :'Object', :'tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
132 133 134 135 136 137 138 139 140 141 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 132 def ==(o) return true if self.equal?(o) self.class == o.class && maintainer_id == o.maintainer_id && maintainer_team_key == o.maintainer_team_key && description == o.description && schema == o.schema && custom_parameters == o.custom_parameters && == o. end |
#eql?(o) ⇒ Boolean
145 146 147 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 145 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
151 152 153 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 151 def hash [maintainer_id, maintainer_team_key, description, schema, custom_parameters, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
117 118 119 120 121 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 117 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 180 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
125 126 127 128 |
# File 'lib/launchdarkly_api/models/ai_tool_patch.rb', line 125 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |