Class: LaunchDarklyApi::AccessAllowedReason

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/access_allowed_reason.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccessAllowedReason

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AccessAllowedReason` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AccessAllowedReason`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'resources')
    if (value = attributes[:'resources']).is_a?(Array)
      self.resources = value
    end
  end

  if attributes.key?(:'not_resources')
    if (value = attributes[:'not_resources']).is_a?(Array)
      self.not_resources = value
    end
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'not_actions')
    if (value = attributes[:'not_actions']).is_a?(Array)
      self.not_actions = value
    end
  end

  if attributes.key?(:'effect')
    self.effect = attributes[:'effect']
  else
    self.effect = nil
  end

  if attributes.key?(:'role_name')
    self.role_name = attributes[:'role_name']
  end
end

Instance Attribute Details

#actionsObject

Actions to perform on a resource



25
26
27
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 25

def actions
  @actions
end

#effectObject

Whether this statement should allow or deny actions on the resources.



31
32
33
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 31

def effect
  @effect
end

#not_actionsObject

Targeted actions are the actions NOT in this list. The actions and notResources fields must be empty to use this field.



28
29
30
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 28

def not_actions
  @not_actions
end

#not_resourcesObject

Targeted resources are the resources NOT in this list. The resources and notActions fields must be empty to use this field.



22
23
24
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 22

def not_resources
  @not_resources
end

#resourcesObject

Resource specifier strings



19
20
21
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 19

def resources
  @resources
end

#role_nameObject

Returns the value of attribute role_name.



33
34
35
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 33

def role_name
  @role_name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 58

def self.attribute_map
  {
    :'resources' => :'resources',
    :'not_resources' => :'notResources',
    :'actions' => :'actions',
    :'not_actions' => :'notActions',
    :'effect' => :'effect',
    :'role_name' => :'role_name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 80

def self.openapi_types
  {
    :'resources' => :'Array<String>',
    :'not_resources' => :'Array<String>',
    :'actions' => :'Array<String>',
    :'not_actions' => :'Array<String>',
    :'effect' => :'String',
    :'role_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



182
183
184
185
186
187
188
189
190
191
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 182

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      resources == o.resources &&
      not_resources == o.not_resources &&
      actions == o.actions &&
      not_actions == o.not_actions &&
      effect == o.effect &&
      role_name == o.role_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 201

def hash
  [resources, not_resources, actions, not_actions, effect, role_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @effect.nil?
    invalid_properties.push('invalid value for "effect", effect cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
168
# File 'lib/launchdarkly_api/models/access_allowed_reason.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @effect.nil?
  effect_validator = EnumAttributeValidator.new('String', ["allow", "deny"])
  return false unless effect_validator.valid?(@effect)
  true
end