Class: LaunchDarklyApi::AccessTokenPost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/access_token_post.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AccessTokenPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 105

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AccessTokenPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AccessTokenPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'custom_role_ids')
    if (value = attributes[:'custom_role_ids']).is_a?(Array)
      self.custom_role_ids = value
    end
  end

  if attributes.key?(:'inline_role')
    if (value = attributes[:'inline_role']).is_a?(Array)
      self.inline_role = value
    end
  end

  if attributes.key?(:'service_token')
    self.service_token = attributes[:'service_token']
  end

  if attributes.key?(:'default_api_version')
    self.default_api_version = attributes[:'default_api_version']
  end
end

Instance Attribute Details

#custom_role_idsObject

A list of custom role IDs to use as access limits for the access token



28
29
30
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 28

def custom_role_ids
  @custom_role_ids
end

#default_api_versionObject

The default API version for this token



37
38
39
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 37

def default_api_version
  @default_api_version
end

#descriptionObject

A description for the access token



22
23
24
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 22

def description
  @description
end

#inline_roleObject

A JSON array of statements represented as JSON objects with three attributes: effect, resources, actions. May be used in place of a role.



31
32
33
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 31

def inline_role
  @inline_role
end

#nameObject

A human-friendly name for the access token



19
20
21
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 19

def name
  @name
end

#roleObject

Base role for the token



25
26
27
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 25

def role
  @role
end

#service_tokenObject

Whether the token is a service token



34
35
36
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 34

def service_token
  @service_token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



75
76
77
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 75

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



80
81
82
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 80

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 62

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'role' => :'role',
    :'custom_role_ids' => :'customRoleIds',
    :'inline_role' => :'inlineRole',
    :'service_token' => :'serviceToken',
    :'default_api_version' => :'defaultApiVersion'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 208

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



98
99
100
101
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 98

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



85
86
87
88
89
90
91
92
93
94
95
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 85

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'role' => :'String',
    :'custom_role_ids' => :'Array<String>',
    :'inline_role' => :'Array<StatementPost>',
    :'service_token' => :'Boolean',
    :'default_api_version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



181
182
183
184
185
186
187
188
189
190
191
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 181

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      role == o.role &&
      custom_role_ids == o.custom_role_ids &&
      inline_role == o.inline_role &&
      service_token == o.service_token &&
      default_api_version == o.default_api_version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


195
196
197
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 195

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



201
202
203
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 201

def hash
  [name, description, role, custom_role_ids, inline_role, service_token, default_api_version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 230

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



162
163
164
165
166
167
# File 'lib/launchdarkly_api/models/access_token_post.rb', line 162

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  role_validator = EnumAttributeValidator.new('String', ["reader", "writer", "admin"])
  return false unless role_validator.valid?(@role)
  true
end