Class: LaunchDarklyApi::AgentGraphEdgePost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/agent_graph_edge_post.rb

Overview

An edge in an agent graph connecting two AI Configs

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentGraphEdgePost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 69

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AgentGraphEdgePost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AgentGraphEdgePost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'source_config')
    self.source_config = attributes[:'source_config']
  else
    self.source_config = nil
  end

  if attributes.key?(:'target_config')
    self.target_config = attributes[:'target_config']
  else
    self.target_config = nil
  end

  if attributes.key?(:'handoff')
    self.handoff = attributes[:'handoff']
  end
end

Instance Attribute Details

#handoffObject

The handoff options from the source AI Config to the target AI Config



29
30
31
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 29

def handoff
  @handoff
end

#keyObject

A unique key for this edge within the graph



20
21
22
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 20

def key
  @key
end

#source_configObject

The AI Config key that is the source of this edge



23
24
25
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 23

def source_config
  @source_config
end

#target_configObject

The AI Config key that is the target of this edge



26
27
28
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 26

def target_config
  @target_config
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



42
43
44
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 42

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



47
48
49
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 47

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 32

def self.attribute_map
  {
    :'key' => :'key',
    :'source_config' => :'sourceConfig',
    :'target_config' => :'targetConfig',
    :'handoff' => :'handoff'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 192

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



62
63
64
65
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 62

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



52
53
54
55
56
57
58
59
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 52

def self.openapi_types
  {
    :'key' => :'String',
    :'source_config' => :'String',
    :'target_config' => :'String',
    :'handoff' => :'Object'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



168
169
170
171
172
173
174
175
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 168

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      source_config == o.source_config &&
      target_config == o.target_config &&
      handoff == o.handoff
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


179
180
181
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 179

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



185
186
187
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 185

def hash
  [key, source_config, target_config, handoff].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 108

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @source_config.nil?
    invalid_properties.push('invalid value for "source_config", source_config cannot be nil.')
  end

  if @target_config.nil?
    invalid_properties.push('invalid value for "target_config", target_config cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



214
215
216
217
218
219
220
221
222
223
224
225
226
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 214

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



128
129
130
131
132
133
134
# File 'lib/launchdarkly_api/models/agent_graph_edge_post.rb', line 128

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @source_config.nil?
  return false if @target_config.nil?
  true
end