Class: LaunchDarklyApi::AgentGraphPatch

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/agent_graph_patch.rb

Overview

Request body for updating an agent graph. If rootConfigKey or edges are present, both must be present.

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AgentGraphPatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 79

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AgentGraphPatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AgentGraphPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end

  if attributes.key?(:'root_config_key')
    self.root_config_key = attributes[:'root_config_key']
  end

  if attributes.key?(:'edges')
    if (value = attributes[:'edges']).is_a?(Array)
      self.edges = value
    end
  end
end

Instance Attribute Details

#descriptionObject

A description of the agent graph



23
24
25
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 23

def description
  @description
end

#edgesObject

The edges in the graph. If present, rootConfigKey must also be present. Replaces all existing edges.



35
36
37
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 35

def edges
  @edges
end

#maintainer_idObject

The ID of the member who maintains this agent graph. Pass an empty string to remove maintainer.



26
27
28
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 26

def maintainer_id
  @maintainer_id
end

#maintainer_team_keyObject

The key of the team that maintains this agent graph. Pass an empty string to remove maintainer.



29
30
31
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 29

def maintainer_team_key
  @maintainer_team_key
end

#nameObject

A human-readable name for the agent graph



20
21
22
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 20

def name
  @name
end

#root_config_keyObject

The AI Config key of the root node. If present, edges must also be present.



32
33
34
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 32

def root_config_key
  @root_config_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



50
51
52
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 50

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



55
56
57
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 55

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 38

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey',
    :'root_config_key' => :'rootConfigKey',
    :'edges' => :'edges'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 163

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 72

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



60
61
62
63
64
65
66
67
68
69
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 60

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String',
    :'root_config_key' => :'String',
    :'edges' => :'Array<AgentGraphEdge>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key &&
      root_config_key == o.root_config_key &&
      edges == o.edges
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


150
151
152
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 150

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



156
157
158
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 156

def hash
  [name, description, maintainer_id, maintainer_team_key, root_config_key, edges].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



122
123
124
125
126
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 122

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 185

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



130
131
132
133
# File 'lib/launchdarkly_api/models/agent_graph_patch.rb', line 130

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end