Class: LaunchDarklyApi::AgentOptimizationResultPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AgentOptimizationResultPost
- Defined in:
- lib/launchdarkly_api/models/agent_optimization_result_post.rb
Instance Attribute Summary collapse
-
#agent_optimization_version ⇒ Object
Returns the value of attribute agent_optimization_version.
-
#instructions ⇒ Object
Returns the value of attribute instructions.
-
#iteration ⇒ Object
Returns the value of attribute iteration.
-
#parameters ⇒ Object
Returns the value of attribute parameters.
-
#run_id ⇒ Object
Returns the value of attribute run_id.
-
#user_input ⇒ Object
Returns the value of attribute user_input.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentOptimizationResultPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AgentOptimizationResultPost
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AgentOptimizationResultPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AgentOptimizationResultPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'run_id') self.run_id = attributes[:'run_id'] else self.run_id = nil end if attributes.key?(:'agent_optimization_version') self.agent_optimization_version = attributes[:'agent_optimization_version'] else self.agent_optimization_version = nil end if attributes.key?(:'iteration') self.iteration = attributes[:'iteration'] else self.iteration = nil end if attributes.key?(:'instructions') self.instructions = attributes[:'instructions'] else self.instructions = nil end if attributes.key?(:'user_input') self.user_input = attributes[:'user_input'] else self.user_input = nil end if attributes.key?(:'parameters') if (value = attributes[:'parameters']).is_a?(Hash) self.parameters = value end end end |
Instance Attribute Details
#agent_optimization_version ⇒ Object
Returns the value of attribute agent_optimization_version.
20 21 22 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 20 def agent_optimization_version @agent_optimization_version end |
#instructions ⇒ Object
Returns the value of attribute instructions.
24 25 26 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 24 def instructions @instructions end |
#iteration ⇒ Object
Returns the value of attribute iteration.
22 23 24 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 22 def iteration @iteration end |
#parameters ⇒ Object
Returns the value of attribute parameters.
28 29 30 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 28 def parameters @parameters end |
#run_id ⇒ Object
Returns the value of attribute run_id.
18 19 20 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 18 def run_id @run_id end |
#user_input ⇒ Object
Returns the value of attribute user_input.
26 27 28 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 26 def user_input @user_input end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 40 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 31 def self.attribute_map { :'run_id' => :'runId', :'agent_optimization_version' => :'agentOptimizationVersion', :'iteration' => :'iteration', :'instructions' => :'instructions', :'user_input' => :'userInput', :'parameters' => :'parameters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 241 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 62 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 53 def self.openapi_types { :'run_id' => :'String', :'agent_optimization_version' => :'Integer', :'iteration' => :'Integer', :'instructions' => :'String', :'user_input' => :'String', :'parameters' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
215 216 217 218 219 220 221 222 223 224 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 215 def ==(o) return true if self.equal?(o) self.class == o.class && run_id == o.run_id && agent_optimization_version == o.agent_optimization_version && iteration == o.iteration && instructions == o.instructions && user_input == o.user_input && parameters == o.parameters end |
#eql?(o) ⇒ Boolean
228 229 230 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 228 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
234 235 236 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 234 def hash [run_id, agent_optimization_version, iteration, instructions, user_input, parameters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @run_id.nil? invalid_properties.push('invalid value for "run_id", run_id cannot be nil.') end if @agent_optimization_version.nil? invalid_properties.push('invalid value for "agent_optimization_version", agent_optimization_version cannot be nil.') end if @iteration.nil? invalid_properties.push('invalid value for "iteration", iteration cannot be nil.') end if @instructions.nil? invalid_properties.push('invalid value for "instructions", instructions cannot be nil.') end if @user_input.nil? invalid_properties.push('invalid value for "user_input", user_input cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
263 264 265 266 267 268 269 270 271 272 273 274 275 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 263 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 159 160 161 |
# File 'lib/launchdarkly_api/models/agent_optimization_result_post.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @run_id.nil? return false if @agent_optimization_version.nil? return false if @iteration.nil? return false if @instructions.nil? return false if @user_input.nil? true end |