Class: LaunchDarklyApi::AgentOptimizationRun
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AgentOptimizationRun
- Defined in:
- lib/launchdarkly_api/models/agent_optimization_run.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#activity ⇒ Object
Returns the value of attribute activity.
-
#agent_optimization_id ⇒ Object
Returns the value of attribute agent_optimization_id.
-
#agent_optimization_version ⇒ Object
Returns the value of attribute agent_optimization_version.
-
#completed_at ⇒ Object
Returns the value of attribute completed_at.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#optimization_key ⇒ Object
Returns the value of attribute optimization_key.
-
#run_id ⇒ Object
Returns the value of attribute run_id.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentOptimizationRun
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AgentOptimizationRun
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AgentOptimizationRun` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AgentOptimizationRun`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'run_id') self.run_id = attributes[:'run_id'] else self.run_id = nil end if attributes.key?(:'optimization_key') self.optimization_key = attributes[:'optimization_key'] else self.optimization_key = nil end if attributes.key?(:'agent_optimization_id') self.agent_optimization_id = attributes[:'agent_optimization_id'] else self.agent_optimization_id = nil end if attributes.key?(:'agent_optimization_version') self.agent_optimization_version = attributes[:'agent_optimization_version'] else self.agent_optimization_version = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'activity') self.activity = attributes[:'activity'] else self.activity = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'completed_at') self.completed_at = attributes[:'completed_at'] end end |
Instance Attribute Details
#activity ⇒ Object
Returns the value of attribute activity.
28 29 30 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 28 def activity @activity end |
#agent_optimization_id ⇒ Object
Returns the value of attribute agent_optimization_id.
22 23 24 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 22 def agent_optimization_id @agent_optimization_id end |
#agent_optimization_version ⇒ Object
Returns the value of attribute agent_optimization_version.
24 25 26 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 24 def agent_optimization_version @agent_optimization_version end |
#completed_at ⇒ Object
Returns the value of attribute completed_at.
32 33 34 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 32 def completed_at @completed_at end |
#created_at ⇒ Object
Returns the value of attribute created_at.
30 31 32 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 30 def created_at @created_at end |
#optimization_key ⇒ Object
Returns the value of attribute optimization_key.
20 21 22 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 20 def optimization_key @optimization_key end |
#run_id ⇒ Object
Returns the value of attribute run_id.
18 19 20 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 18 def run_id @run_id end |
#status ⇒ Object
Returns the value of attribute status.
26 27 28 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 26 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 57 def self.attribute_map { :'run_id' => :'runId', :'optimization_key' => :'optimizationKey', :'agent_optimization_id' => :'agentOptimizationId', :'agent_optimization_version' => :'agentOptimizationVersion', :'status' => :'status', :'activity' => :'activity', :'created_at' => :'createdAt', :'completed_at' => :'completedAt' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 314 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 99 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 95 def self.openapi_nullable Set.new([ :'completed_at' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 81 def self.openapi_types { :'run_id' => :'String', :'optimization_key' => :'String', :'agent_optimization_id' => :'String', :'agent_optimization_version' => :'Integer', :'status' => :'AgentOptimizationResultStatus', :'activity' => :'AgentOptimizationResultActivity', :'created_at' => :'Integer', :'completed_at' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 286 def ==(o) return true if self.equal?(o) self.class == o.class && run_id == o.run_id && optimization_key == o.optimization_key && agent_optimization_id == o.agent_optimization_id && agent_optimization_version == o.agent_optimization_version && status == o.status && activity == o.activity && created_at == o.created_at && completed_at == o.completed_at end |
#eql?(o) ⇒ Boolean
301 302 303 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 301 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
307 308 309 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 307 def hash [run_id, optimization_key, agent_optimization_id, agent_optimization_version, status, activity, created_at, completed_at].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @run_id.nil? invalid_properties.push('invalid value for "run_id", run_id cannot be nil.') end if @optimization_key.nil? invalid_properties.push('invalid value for "optimization_key", optimization_key cannot be nil.') end if @agent_optimization_id.nil? invalid_properties.push('invalid value for "agent_optimization_id", agent_optimization_id cannot be nil.') end if @agent_optimization_version.nil? invalid_properties.push('invalid value for "agent_optimization_version", agent_optimization_version cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @activity.nil? invalid_properties.push('invalid value for "activity", activity cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
336 337 338 339 340 341 342 343 344 345 346 347 348 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 336 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/launchdarkly_api/models/agent_optimization_run.rb', line 202 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @run_id.nil? return false if @optimization_key.nil? return false if @agent_optimization_id.nil? return false if @agent_optimization_version.nil? return false if @status.nil? return false if @activity.nil? return false if @created_at.nil? true end |