Class: LaunchDarklyApi::AiConfigsFilter
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AiConfigsFilter
- Defined in:
- lib/launchdarkly_api/models/ai_configs_filter.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#attribute ⇒ Object
If not a group node, the context attribute name or event property name to filter on.
-
#context_kind ⇒ Object
For context attribute filters, the context kind.
-
#negate ⇒ Object
If set, then take the inverse of the operator.
-
#op ⇒ Object
Returns the value of attribute op.
-
#type ⇒ Object
Filter type.
-
#values ⇒ Object
The context attribute / event property values or group member nodes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AiConfigsFilter
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AiConfigsFilter
Initializes the object
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 99 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AiConfigsFilter` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AiConfigsFilter`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'attribute') self.attribute = attributes[:'attribute'] end if attributes.key?(:'op') self.op = attributes[:'op'] else self.op = nil end if attributes.key?(:'values') if (value = attributes[:'values']).is_a?(Array) self.values = value end else self.values = nil end if attributes.key?(:'context_kind') self.context_kind = attributes[:'context_kind'] end if attributes.key?(:'negate') self.negate = attributes[:'negate'] else self.negate = nil end end |
Instance Attribute Details
#attribute ⇒ Object
If not a group node, the context attribute name or event property name to filter on
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 22 def attribute @attribute end |
#context_kind ⇒ Object
For context attribute filters, the context kind.
30 31 32 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 30 def context_kind @context_kind end |
#negate ⇒ Object
If set, then take the inverse of the operator. 'in' becomes 'not in'.
33 34 35 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 33 def negate @negate end |
#op ⇒ Object
Returns the value of attribute op.
24 25 26 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 24 def op @op end |
#type ⇒ Object
Filter type. One of [contextAttribute, eventProperty, group]
19 20 21 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 19 def type @type end |
#values ⇒ Object
The context attribute / event property values or group member nodes
27 28 29 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 27 def values @values end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
70 71 72 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 70 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
75 76 77 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 75 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 58 def self.attribute_map { :'type' => :'type', :'attribute' => :'attribute', :'op' => :'op', :'values' => :'values', :'context_kind' => :'contextKind', :'negate' => :'negate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 253 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 92 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
80 81 82 83 84 85 86 87 88 89 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 80 def self.openapi_types { :'type' => :'String', :'attribute' => :'String', :'op' => :'String', :'values' => :'Array<Object>', :'context_kind' => :'String', :'negate' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
227 228 229 230 231 232 233 234 235 236 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 227 def ==(o) return true if self.equal?(o) self.class == o.class && type == o.type && attribute == o.attribute && op == o.op && values == o.values && context_kind == o.context_kind && negate == o.negate end |
#eql?(o) ⇒ Boolean
240 241 242 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 240 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
246 247 248 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 246 def hash [type, attribute, op, values, context_kind, negate].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 150 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @op.nil? invalid_properties.push('invalid value for "op", op cannot be nil.') end if @values.nil? invalid_properties.push('invalid value for "values", values cannot be nil.') end if @negate.nil? invalid_properties.push('invalid value for "negate", negate cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 275 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
174 175 176 177 178 179 180 181 182 183 |
# File 'lib/launchdarkly_api/models/ai_configs_filter.rb', line 174 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["group", "contextAttribute", "eventProperty"]) return false unless type_validator.valid?(@type) return false if @op.nil? return false if @values.nil? return false if @negate.nil? true end |