Class: LaunchDarklyApi::AnalysisConfigRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AnalysisConfigRep
- Defined in:
- lib/launchdarkly_api/models/analysis_config_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#bayesian_threshold ⇒ Object
The threshold for the Probability to Beat Baseline (PBBL) and Probability to Be Best (PBB) comparisons for the Bayesian results analysis approach.
-
#multiple_comparison_correction_method ⇒ Object
The method for multiple comparison correction.
-
#multiple_comparison_correction_scope ⇒ Object
The scope for multiple comparison correction.
-
#sequential_testing_enabled ⇒ Object
Whether sequential testing is enabled for Frequentist analysis.
-
#significance_threshold ⇒ Object
The significance threshold for the frequentist results analysis approach.
-
#test_direction ⇒ Object
The test sided direction for the frequentist results analysis approach.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AnalysisConfigRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AnalysisConfigRep
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AnalysisConfigRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AnalysisConfigRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'bayesian_threshold') self.bayesian_threshold = attributes[:'bayesian_threshold'] end if attributes.key?(:'significance_threshold') self.significance_threshold = attributes[:'significance_threshold'] end if attributes.key?(:'test_direction') self.test_direction = attributes[:'test_direction'] end if attributes.key?(:'multiple_comparison_correction_method') self.multiple_comparison_correction_method = attributes[:'multiple_comparison_correction_method'] end if attributes.key?(:'multiple_comparison_correction_scope') self.multiple_comparison_correction_scope = attributes[:'multiple_comparison_correction_scope'] end if attributes.key?(:'sequential_testing_enabled') self.sequential_testing_enabled = attributes[:'sequential_testing_enabled'] end end |
Instance Attribute Details
#bayesian_threshold ⇒ Object
The threshold for the Probability to Beat Baseline (PBBL) and Probability to Be Best (PBB) comparisons for the Bayesian results analysis approach. Value should be between 0-100 inclusive.
19 20 21 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 19 def bayesian_threshold @bayesian_threshold end |
#multiple_comparison_correction_method ⇒ Object
The method for multiple comparison correction.
28 29 30 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 28 def multiple_comparison_correction_method @multiple_comparison_correction_method end |
#multiple_comparison_correction_scope ⇒ Object
The scope for multiple comparison correction.
31 32 33 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 31 def multiple_comparison_correction_scope @multiple_comparison_correction_scope end |
#sequential_testing_enabled ⇒ Object
Whether sequential testing is enabled for Frequentist analysis
34 35 36 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 34 def sequential_testing_enabled @sequential_testing_enabled end |
#significance_threshold ⇒ Object
The significance threshold for the frequentist results analysis approach. Value should be between 0.0-1.0 inclusive.
22 23 24 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 22 def significance_threshold @significance_threshold end |
#test_direction ⇒ Object
The test sided direction for the frequentist results analysis approach.
25 26 27 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 25 def test_direction @test_direction end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 59 def self.attribute_map { :'bayesian_threshold' => :'bayesianThreshold', :'significance_threshold' => :'significanceThreshold', :'test_direction' => :'testDirection', :'multiple_comparison_correction_method' => :'multipleComparisonCorrectionMethod', :'multiple_comparison_correction_scope' => :'multipleComparisonCorrectionScope', :'sequential_testing_enabled' => :'sequentialTestingEnabled' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 206 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 81 def self.openapi_types { :'bayesian_threshold' => :'String', :'significance_threshold' => :'String', :'test_direction' => :'String', :'multiple_comparison_correction_method' => :'String', :'multiple_comparison_correction_scope' => :'String', :'sequential_testing_enabled' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && bayesian_threshold == o.bayesian_threshold && significance_threshold == o.significance_threshold && test_direction == o.test_direction && multiple_comparison_correction_method == o.multiple_comparison_correction_method && multiple_comparison_correction_scope == o.multiple_comparison_correction_scope && sequential_testing_enabled == o.sequential_testing_enabled end |
#eql?(o) ⇒ Boolean
193 194 195 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 193 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
199 200 201 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 199 def hash [bayesian_threshold, significance_threshold, test_direction, multiple_comparison_correction_method, multiple_comparison_correction_scope, sequential_testing_enabled].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
228 229 230 231 232 233 234 235 236 237 238 239 240 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 228 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
149 150 151 152 153 154 155 156 |
# File 'lib/launchdarkly_api/models/analysis_config_rep.rb', line 149 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' multiple_comparison_correction_method_validator = EnumAttributeValidator.new('String', ["bonferroni", "benjamini-hochberg"]) return false unless multiple_comparison_correction_method_validator.valid?(@multiple_comparison_correction_method) multiple_comparison_correction_scope_validator = EnumAttributeValidator.new('String', ["variations", "variations-and-metrics", "metrics"]) return false unless multiple_comparison_correction_scope_validator.valid?(@multiple_comparison_correction_scope) true end |