Class: LaunchDarklyApi::AnnouncementResponse

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/announcement_response.rb

Overview

Announcement response

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AnnouncementResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 119

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AnnouncementResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AnnouncementResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'is_dismissible')
    self.is_dismissible = attributes[:'is_dismissible']
  else
    self.is_dismissible = nil
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  else
    self.title = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  else
    self.start_time = nil
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  else
    self.severity = nil
  end

  if attributes.key?(:'_status')
    self._status = attributes[:'_status']
  else
    self._status = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  else
    self._links = nil
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



43
44
45
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 43

def _access
  @_access
end

#_idObject

The ID of the announcement



20
21
22
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 20

def _id
  @_id
end

Returns the value of attribute _links.



45
46
47
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 45

def _links
  @_links
end

#_statusObject

The status of the announcement



41
42
43
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 41

def _status
  @_status
end

#end_timeObject

The end time of the announcement. This is a Unix timestamp in milliseconds.



35
36
37
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 35

def end_time
  @end_time
end

#is_dismissibleObject

true if the announcement is dismissible



23
24
25
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 23

def is_dismissible
  @is_dismissible
end

#messageObject

The message of the announcement



29
30
31
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 29

def message
  @message
end

#severityObject

The severity of the announcement



38
39
40
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 38

def severity
  @severity
end

#start_timeObject

The start time of the announcement. This is a Unix timestamp in milliseconds.



32
33
34
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 32

def start_time
  @start_time
end

#titleObject

The title of the announcement



26
27
28
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 26

def title
  @title
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



86
87
88
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 86

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



91
92
93
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 91

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 70

def self.attribute_map
  {
    :'_id' => :'_id',
    :'is_dismissible' => :'isDismissible',
    :'title' => :'title',
    :'message' => :'message',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'severity' => :'severity',
    :'_status' => :'_status',
    :'_access' => :'_access',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 361

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



112
113
114
115
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 112

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



96
97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 96

def self.openapi_types
  {
    :'_id' => :'String',
    :'is_dismissible' => :'Boolean',
    :'title' => :'String',
    :'message' => :'String',
    :'start_time' => :'Integer',
    :'end_time' => :'Integer',
    :'severity' => :'String',
    :'_status' => :'String',
    :'_access' => :'AnnouncementAccessRep',
    :'_links' => :'AnnouncementResponseLinks'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 331

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      is_dismissible == o.is_dismissible &&
      title == o.title &&
      message == o.message &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      severity == o.severity &&
      _status == o._status &&
      _access == o._access &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


348
349
350
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 348

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



354
355
356
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 354

def hash
  [_id, is_dismissible, title, message, start_time, end_time, severity, _status, _access, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 192

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @is_dismissible.nil?
    invalid_properties.push('invalid value for "is_dismissible", is_dismissible cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @start_time.nil?
    invalid_properties.push('invalid value for "start_time", start_time cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  if @_status.nil?
    invalid_properties.push('invalid value for "_status", _status cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 383

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 232

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @is_dismissible.nil?
  return false if @title.nil?
  return false if @message.nil?
  return false if @start_time.nil?
  return false if @severity.nil?
  severity_validator = EnumAttributeValidator.new('String', ["info", "warning", "critical"])
  return false unless severity_validator.valid?(@severity)
  return false if @_status.nil?
  _status_validator = EnumAttributeValidator.new('String', ["active", "inactive", "scheduled"])
  return false unless _status_validator.valid?(@_status)
  return false if @_links.nil?
  true
end