Class: LaunchDarklyApi::ApplicationsBetaApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/applications_beta_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ApplicationsBetaApi

Returns a new instance of ApplicationsBetaApi.



19
20
21
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_application(create_application_input, opts = {}) ⇒ ApplicationRep

Post application Create a new application

Parameters:

Returns:



27
28
29
30
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 27

def create_application(create_application_input, opts = {})
  data, _status_code, _headers = create_application_with_http_info(create_application_input, opts)
  data
end

#create_application_with_http_info(create_application_input, opts = {}) ⇒ Array<(ApplicationRep, Integer, Hash)>

Post application Create a new application

Parameters:

Returns:

  • (Array<(ApplicationRep, Integer, Hash)>)

    ApplicationRep data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 37

def create_application_with_http_info(create_application_input, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.create_application ...'
  end
  # verify the required parameter 'create_application_input' is set
  if @api_client.config.client_side_validation && create_application_input.nil?
    fail ArgumentError, "Missing the required parameter 'create_application_input' when calling ApplicationsBetaApi.create_application"
  end
  # resource path
  local_var_path = '/api/v2/applications'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_application_input)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.create_application",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#create_application\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_application(application_key, opts = {}) ⇒ nil

Delete application Delete an application.

Parameters:

  • application_key (String)

    The application key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


95
96
97
98
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 95

def delete_application(application_key, opts = {})
  delete_application_with_http_info(application_key, opts)
  nil
end

#delete_application_version(application_key, version_key, opts = {}) ⇒ nil

Delete application version Delete an application version.

Parameters:

  • application_key (String)

    The application key

  • version_key (String)

    The application version key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


159
160
161
162
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 159

def delete_application_version(application_key, version_key, opts = {})
  delete_application_version_with_http_info(application_key, version_key, opts)
  nil
end

#delete_application_version_with_http_info(application_key, version_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete application version Delete an application version.

Parameters:

  • application_key (String)

    The application key

  • version_key (String)

    The application version key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 170

def delete_application_version_with_http_info(application_key, version_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.delete_application_version ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.delete_application_version"
  end
  # verify the required parameter 'version_key' is set
  if @api_client.config.client_side_validation && version_key.nil?
    fail ArgumentError, "Missing the required parameter 'version_key' when calling ApplicationsBetaApi.delete_application_version"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}/versions/{versionKey}'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s)).sub('{' + 'versionKey' + '}', CGI.escape(version_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.delete_application_version",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#delete_application_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_application_with_http_info(application_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete application Delete an application.

Parameters:

  • application_key (String)

    The application key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 105

def delete_application_with_http_info(application_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.delete_application ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.delete_application"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.delete_application",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#delete_application\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_application(application_key, opts = {}) ⇒ ApplicationRep

Get application by key

Retrieve an application by the application key.  ### Expanding the application response  LaunchDarkly supports expanding the \"Get application\" response to include additional fields.  To expand the response, append the `expand` query parameter and include the following:  * `flags` includes details on the flags that have been evaluated by the application  For example, use `?expand=flags` to include the `flags` field in the response. By default, this field is **not** included in the response.

Parameters:

  • application_key (String)

    The application key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :expand (String)

    A comma-separated list of properties that can reveal additional information in the response. Options: &#x60;flags&#x60;.

Returns:



228
229
230
231
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 228

def get_application(application_key, opts = {})
  data, _status_code, _headers = get_application_with_http_info(application_key, opts)
  data
end

#get_application_versions(application_key, opts = {}) ⇒ ApplicationVersionsCollectionRep

Get application versions by application key Get a list of versions for a specific application in an account.

Parameters:

  • application_key (String)

    The application key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Accepts filter by &#x60;key&#x60;, &#x60;name&#x60;, &#x60;supported&#x60;, and &#x60;autoAdded&#x60;. Example: &#x60;filter&#x3D;key equals &#39;test-key&#39;&#x60;. To learn more about the filter syntax, read [Filtering applications and application versions](/tag/Applications-(beta)#filtering-contexts-and-context-instances).

  • :limit (Integer)

    The number of versions to return. Defaults to 50.

  • :offset (Integer)

    Where to start in the list. Use this with pagination. For example, an offset of 10 skips the first ten items and then returns the next items in the list, up to the query &#x60;limit&#x60;.

  • :sort (String)

    Accepts sorting order and fields. Fields can be comma separated. Possible fields are &#x60;creationDate&#x60;, &#x60;name&#x60;. Examples: &#x60;sort&#x3D;name&#x60; sort by names ascending, &#x60;sort&#x3D;-name,creationDate&#x60; sort by names descending and creationDate ascending.

Returns:



297
298
299
300
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 297

def get_application_versions(application_key, opts = {})
  data, _status_code, _headers = get_application_versions_with_http_info(application_key, opts)
  data
end

#get_application_versions_with_http_info(application_key, opts = {}) ⇒ Array<(ApplicationVersionsCollectionRep, Integer, Hash)>

Get application versions by application key Get a list of versions for a specific application in an account.

Parameters:

  • application_key (String)

    The application key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Accepts filter by &#x60;key&#x60;, &#x60;name&#x60;, &#x60;supported&#x60;, and &#x60;autoAdded&#x60;. Example: &#x60;filter&#x3D;key equals &#39;test-key&#39;&#x60;. To learn more about the filter syntax, read [Filtering applications and application versions](/tag/Applications-(beta)#filtering-contexts-and-context-instances).

  • :limit (Integer)

    The number of versions to return. Defaults to 50.

  • :offset (Integer)

    Where to start in the list. Use this with pagination. For example, an offset of 10 skips the first ten items and then returns the next items in the list, up to the query &#x60;limit&#x60;.

  • :sort (String)

    Accepts sorting order and fields. Fields can be comma separated. Possible fields are &#x60;creationDate&#x60;, &#x60;name&#x60;. Examples: &#x60;sort&#x3D;name&#x60; sort by names ascending, &#x60;sort&#x3D;-name,creationDate&#x60; sort by names descending and creationDate ascending.

Returns:



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 311

def get_application_versions_with_http_info(application_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.get_application_versions ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.get_application_versions"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}/versions'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationVersionsCollectionRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.get_application_versions",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#get_application_versions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_application_with_http_info(application_key, opts = {}) ⇒ Array<(ApplicationRep, Integer, Hash)>

Get application by key

Retrieve an application by the application key.  ### Expanding the application response  LaunchDarkly supports expanding the \&quot;Get application\&quot; response to include additional fields.  To expand the response, append the &#x60;expand&#x60; query parameter and include the following:  * &#x60;flags&#x60; includes details on the flags that have been evaluated by the application  For example, use &#x60;?expand&#x3D;flags&#x60; to include the &#x60;flags&#x60; field in the response. By default, this field is **not** included in the response.

Parameters:

  • application_key (String)

    The application key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :expand (String)

    A comma-separated list of properties that can reveal additional information in the response. Options: &#x60;flags&#x60;.

Returns:

  • (Array<(ApplicationRep, Integer, Hash)>)

    ApplicationRep data, response status code and response headers



239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 239

def get_application_with_http_info(application_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.get_application ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.get_application"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.get_application",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#get_application\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_applications(opts = {}) ⇒ ApplicationCollectionRep

Get applications

Get a list of applications.  ### Expanding the applications response  LaunchDarkly supports expanding the \"Get applications\" response to include additional fields.  To expand the response, append the `expand` query parameter and include the following:  * `flags` includes details on the flags that have been evaluated by the application  For example, use `?expand=flags` to include the `flags` field in the response. By default, this field is **not** included in the response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Accepts filter by &#x60;key&#x60;, &#x60;name&#x60;, &#x60;kind&#x60;, and &#x60;autoAdded&#x60;. Example: &#x60;filter&#x3D;kind anyOf [&#39;mobile&#39;, &#39;server&#39;],key equals &#39;test-key&#39;&#x60;. To learn more about the filter syntax, read [Filtering applications and application versions](/tag/Applications-(beta)#filtering-contexts-and-context-instances).

  • :limit (Integer)

    The number of applications to return. Defaults to 10.

  • :offset (Integer)

    Where to start in the list. Use this with pagination. For example, an offset of 10 skips the first ten items and then returns the next items in the list, up to the query &#x60;limit&#x60;.

  • :sort (String)

    Accepts sorting order and fields. Fields can be comma separated. Possible fields are &#x60;creationDate&#x60;, &#x60;name&#x60;. Examples: &#x60;sort&#x3D;name&#x60; sort by names ascending, &#x60;sort&#x3D;-name,creationDate&#x60; sort by names descending and creationDate ascending.

  • :expand (String)

    A comma-separated list of properties that can reveal additional information in the response. Options: &#x60;flags&#x60;.

Returns:



372
373
374
375
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 372

def get_applications(opts = {})
  data, _status_code, _headers = get_applications_with_http_info(opts)
  data
end

#get_applications_with_http_info(opts = {}) ⇒ Array<(ApplicationCollectionRep, Integer, Hash)>

Get applications

Get a list of applications.  ### Expanding the applications response  LaunchDarkly supports expanding the \&quot;Get applications\&quot; response to include additional fields.  To expand the response, append the &#x60;expand&#x60; query parameter and include the following:  * &#x60;flags&#x60; includes details on the flags that have been evaluated by the application  For example, use &#x60;?expand&#x3D;flags&#x60; to include the &#x60;flags&#x60; field in the response. By default, this field is **not** included in the response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :filter (String)

    Accepts filter by &#x60;key&#x60;, &#x60;name&#x60;, &#x60;kind&#x60;, and &#x60;autoAdded&#x60;. Example: &#x60;filter&#x3D;kind anyOf [&#39;mobile&#39;, &#39;server&#39;],key equals &#39;test-key&#39;&#x60;. To learn more about the filter syntax, read [Filtering applications and application versions](/tag/Applications-(beta)#filtering-contexts-and-context-instances).

  • :limit (Integer)

    The number of applications to return. Defaults to 10.

  • :offset (Integer)

    Where to start in the list. Use this with pagination. For example, an offset of 10 skips the first ten items and then returns the next items in the list, up to the query &#x60;limit&#x60;.

  • :sort (String)

    Accepts sorting order and fields. Fields can be comma separated. Possible fields are &#x60;creationDate&#x60;, &#x60;name&#x60;. Examples: &#x60;sort&#x3D;name&#x60; sort by names ascending, &#x60;sort&#x3D;-name,creationDate&#x60; sort by names descending and creationDate ascending.

  • :expand (String)

    A comma-separated list of properties that can reveal additional information in the response. Options: &#x60;flags&#x60;.

Returns:

  • (Array<(ApplicationCollectionRep, Integer, Hash)>)

    ApplicationCollectionRep data, response status code and response headers



386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 386

def get_applications_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.get_applications ...'
  end
  # resource path
  local_var_path = '/api/v2/applications'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationCollectionRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.get_applications",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#get_applications\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_application(application_key, patch_operation, opts = {}) ⇒ ApplicationRep

Update application Update an application. You can update the ‘description` and `kind` fields. Requires a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes to the application. To learn more, read [Updates](/#section/Overview/Updates).

Parameters:

  • application_key (String)

    The application key

  • patch_operation (Array<PatchOperation>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



441
442
443
444
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 441

def patch_application(application_key, patch_operation, opts = {})
  data, _status_code, _headers = patch_application_with_http_info(application_key, patch_operation, opts)
  data
end

#patch_application_version(application_key, version_key, patch_operation, opts = {}) ⇒ ApplicationVersionRep

Update application version Update an application version. You can update the ‘supported` field. Requires a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes to the application version. To learn more, read [Updates](/#section/Overview/Updates).

Parameters:

  • application_key (String)

    The application key

  • version_key (String)

    The application version key

  • patch_operation (Array<PatchOperation>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



516
517
518
519
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 516

def patch_application_version(application_key, version_key, patch_operation, opts = {})
  data, _status_code, _headers = patch_application_version_with_http_info(application_key, version_key, patch_operation, opts)
  data
end

#patch_application_version_with_http_info(application_key, version_key, patch_operation, opts = {}) ⇒ Array<(ApplicationVersionRep, Integer, Hash)>

Update application version Update an application version. You can update the &#x60;supported&#x60; field. Requires a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes to the application version. To learn more, read [Updates](/#section/Overview/Updates).

Parameters:

  • application_key (String)

    The application key

  • version_key (String)

    The application version key

  • patch_operation (Array<PatchOperation>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ApplicationVersionRep, Integer, Hash)>)

    ApplicationVersionRep data, response status code and response headers



528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
567
568
569
570
571
572
573
574
575
576
577
578
579
580
581
582
583
584
585
586
587
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 528

def patch_application_version_with_http_info(application_key, version_key, patch_operation, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.patch_application_version ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.patch_application_version"
  end
  # verify the required parameter 'version_key' is set
  if @api_client.config.client_side_validation && version_key.nil?
    fail ArgumentError, "Missing the required parameter 'version_key' when calling ApplicationsBetaApi.patch_application_version"
  end
  # verify the required parameter 'patch_operation' is set
  if @api_client.config.client_side_validation && patch_operation.nil?
    fail ArgumentError, "Missing the required parameter 'patch_operation' when calling ApplicationsBetaApi.patch_application_version"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}/versions/{versionKey}'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s)).sub('{' + 'versionKey' + '}', CGI.escape(version_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_operation)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationVersionRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.patch_application_version",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#patch_application_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_application_with_http_info(application_key, patch_operation, opts = {}) ⇒ Array<(ApplicationRep, Integer, Hash)>

Update application Update an application. You can update the &#x60;description&#x60; and &#x60;kind&#x60; fields. Requires a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes to the application. To learn more, read [Updates](/#section/Overview/Updates).

Parameters:

  • application_key (String)

    The application key

  • patch_operation (Array<PatchOperation>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ApplicationRep, Integer, Hash)>)

    ApplicationRep data, response status code and response headers



452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 452

def patch_application_with_http_info(application_key, patch_operation, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.patch_application ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.patch_application"
  end
  # verify the required parameter 'patch_operation' is set
  if @api_client.config.client_side_validation && patch_operation.nil?
    fail ArgumentError, "Missing the required parameter 'patch_operation' when calling ApplicationsBetaApi.patch_application"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_operation)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.patch_application",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#patch_application\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_application_version(application_key, create_application_version_input, opts = {}) ⇒ ApplicationVersionRep

Post application version Create an application version

Parameters:

  • application_key (String)

    The application key

  • create_application_version_input (CreateApplicationVersionInput)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



595
596
597
598
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 595

def post_application_version(application_key, create_application_version_input, opts = {})
  data, _status_code, _headers = post_application_version_with_http_info(application_key, create_application_version_input, opts)
  data
end

#post_application_version_with_http_info(application_key, create_application_version_input, opts = {}) ⇒ Array<(ApplicationVersionRep, Integer, Hash)>

Post application version Create an application version

Parameters:

  • application_key (String)

    The application key

  • create_application_version_input (CreateApplicationVersionInput)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ApplicationVersionRep, Integer, Hash)>)

    ApplicationVersionRep data, response status code and response headers



606
607
608
609
610
611
612
613
614
615
616
617
618
619
620
621
622
623
624
625
626
627
628
629
630
631
632
633
634
635
636
637
638
639
640
641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
# File 'lib/launchdarkly_api/api/applications_beta_api.rb', line 606

def post_application_version_with_http_info(application_key, create_application_version_input, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ApplicationsBetaApi.post_application_version ...'
  end
  # verify the required parameter 'application_key' is set
  if @api_client.config.client_side_validation && application_key.nil?
    fail ArgumentError, "Missing the required parameter 'application_key' when calling ApplicationsBetaApi.post_application_version"
  end
  # verify the required parameter 'create_application_version_input' is set
  if @api_client.config.client_side_validation && create_application_version_input.nil?
    fail ArgumentError, "Missing the required parameter 'create_application_version_input' when calling ApplicationsBetaApi.post_application_version"
  end
  # resource path
  local_var_path = '/api/v2/applications/{applicationKey}/versions'.sub('{' + 'applicationKey' + '}', CGI.escape(application_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_application_version_input)

  # return_type
  return_type = opts[:debug_return_type] || 'ApplicationVersionRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ApplicationsBetaApi.post_application_version",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ApplicationsBetaApi#post_application_version\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end