Class: LaunchDarklyApi::ApprovalRequestResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/approval_request_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ApprovalRequestResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 166

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApprovalRequestResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApprovalRequestResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'service_kind')
    self.service_kind = attributes[:'service_kind']
  end

  if attributes.key?(:'requestor_id')
    self.requestor_id = attributes[:'requestor_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'review_status')
    self.review_status = attributes[:'review_status']
  end

  if attributes.key?(:'all_reviews')
    if (value = attributes[:'all_reviews']).is_a?(Array)
      self.all_reviews = value
    end
  end

  if attributes.key?(:'notify_member_ids')
    if (value = attributes[:'notify_member_ids']).is_a?(Array)
      self.notify_member_ids = value
    end
  end

  if attributes.key?(:'applied_date')
    self.applied_date = attributes[:'applied_date']
  end

  if attributes.key?(:'applied_by_member_id')
    self.applied_by_member_id = attributes[:'applied_by_member_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'instructions')
    if (value = attributes[:'instructions']).is_a?(Array)
      self.instructions = value
    end
  end

  if attributes.key?(:'conflicts')
    if (value = attributes[:'conflicts']).is_a?(Array)
      self.conflicts = value
    end
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'execution_date')
    self.execution_date = attributes[:'execution_date']
  end

  if attributes.key?(:'operating_on_id')
    self.operating_on_id = attributes[:'operating_on_id']
  end

  if attributes.key?(:'integration_metadata')
    self. = attributes[:'integration_metadata']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'custom_workflow_metadata')
    self. = attributes[:'custom_workflow_metadata']
  end

  if attributes.key?(:'resource_id')
    self.resource_id = attributes[:'resource_id']
  end

  if attributes.key?(:'approval_settings')
    self.approval_settings = attributes[:'approval_settings']
  end
end

Instance Attribute Details

#_idObject

The ID of this approval request



19
20
21
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 19

def _id
  @_id
end

The location and content type of related resources



57
58
59
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 57

def _links
  @_links
end

#_versionObject

Version of the approval request



22
23
24
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 22

def _version
  @_version
end

#all_reviewsObject

An array of individual reviews of this approval request



38
39
40
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 38

def all_reviews
  @all_reviews
end

#applied_by_member_idObject

The member ID of the member who applied the approval request



46
47
48
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 46

def applied_by_member_id
  @applied_by_member_id
end

#applied_dateObject

Returns the value of attribute applied_date.



43
44
45
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 43

def applied_date
  @applied_date
end

#approval_settingsObject

Returns the value of attribute approval_settings.



73
74
75
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 73

def approval_settings
  @approval_settings
end

#conflictsObject

Details on any conflicting approval requests



54
55
56
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 54

def conflicts
  @conflicts
end

#creation_dateObject

Returns the value of attribute creation_date.



24
25
26
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 24

def creation_date
  @creation_date
end

#custom_workflow_metadataObject

Returns the value of attribute custom_workflow_metadata.



68
69
70
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 68

def 
  @custom_workflow_metadata
end

#descriptionObject

A human-friendly name for the approval request



32
33
34
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 32

def description
  @description
end

#execution_dateObject

Returns the value of attribute execution_date.



59
60
61
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 59

def execution_date
  @execution_date
end

#instructionsObject

Returns the value of attribute instructions.



51
52
53
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 51

def instructions
  @instructions
end

#integration_metadataObject

Returns the value of attribute integration_metadata.



64
65
66
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 64

def 
  @integration_metadata
end

#notify_member_idsObject

An array of member IDs. These members are notified to review the approval request.



41
42
43
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 41

def notify_member_ids
  @notify_member_ids
end

#operating_on_idObject

ID of scheduled change to edit or delete



62
63
64
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 62

def operating_on_id
  @operating_on_id
end

#requestor_idObject

The ID of the member who requested the approval



29
30
31
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 29

def requestor_id
  @requestor_id
end

#resource_idObject

String representation of a resource



71
72
73
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 71

def resource_id
  @resource_id
end

#review_statusObject

Current status of the review of this approval request



35
36
37
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 35

def review_status
  @review_status
end

#service_kindObject

Returns the value of attribute service_kind.



26
27
28
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 26

def service_kind
  @service_kind
end

#sourceObject

Returns the value of attribute source.



66
67
68
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 66

def source
  @source
end

#statusObject

Current status of the approval request



49
50
51
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 49

def status
  @status
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



126
127
128
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 126

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 98

def self.attribute_map
  {
    :'_id' => :'_id',
    :'_version' => :'_version',
    :'creation_date' => :'creationDate',
    :'service_kind' => :'serviceKind',
    :'requestor_id' => :'requestorId',
    :'description' => :'description',
    :'review_status' => :'reviewStatus',
    :'all_reviews' => :'allReviews',
    :'notify_member_ids' => :'notifyMemberIds',
    :'applied_date' => :'appliedDate',
    :'applied_by_member_id' => :'appliedByMemberId',
    :'status' => :'status',
    :'instructions' => :'instructions',
    :'conflicts' => :'conflicts',
    :'_links' => :'_links',
    :'execution_date' => :'executionDate',
    :'operating_on_id' => :'operatingOnId',
    :'integration_metadata' => :'integrationMetadata',
    :'source' => :'source',
    :'custom_workflow_metadata' => :'customWorkflowMetadata',
    :'resource_id' => :'resourceId',
    :'approval_settings' => :'approvalSettings'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



414
415
416
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 414

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



159
160
161
162
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 159

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 131

def self.openapi_types
  {
    :'_id' => :'String',
    :'_version' => :'Integer',
    :'creation_date' => :'Integer',
    :'service_kind' => :'String',
    :'requestor_id' => :'String',
    :'description' => :'String',
    :'review_status' => :'String',
    :'all_reviews' => :'Array<ReviewResponse>',
    :'notify_member_ids' => :'Array<String>',
    :'applied_date' => :'Integer',
    :'applied_by_member_id' => :'String',
    :'status' => :'String',
    :'instructions' => :'Array<Hash>',
    :'conflicts' => :'Array<Conflict>',
    :'_links' => :'Hash<String, Object>',
    :'execution_date' => :'Integer',
    :'operating_on_id' => :'String',
    :'integration_metadata' => :'IntegrationMetadata',
    :'source' => :'CopiedFromEnv',
    :'custom_workflow_metadata' => :'CustomWorkflowMeta',
    :'resource_id' => :'String',
    :'approval_settings' => :'ApprovalSettings'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 372

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      _version == o._version &&
      creation_date == o.creation_date &&
      service_kind == o.service_kind &&
      requestor_id == o.requestor_id &&
      description == o.description &&
      review_status == o.review_status &&
      all_reviews == o.all_reviews &&
      notify_member_ids == o.notify_member_ids &&
      applied_date == o.applied_date &&
      applied_by_member_id == o.applied_by_member_id &&
      status == o.status &&
      instructions == o.instructions &&
      conflicts == o.conflicts &&
      _links == o._links &&
      execution_date == o.execution_date &&
      operating_on_id == o.operating_on_id &&
       == o. &&
      source == o.source &&
       == o. &&
      resource_id == o.resource_id &&
      approval_settings == o.approval_settings
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 445

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 516

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 421

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


401
402
403
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 401

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



407
408
409
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 407

def hash
  [_id, _version, creation_date, service_kind, requestor_id, description, review_status, all_reviews, notify_member_ids, applied_date, applied_by_member_id, status, instructions, conflicts, _links, execution_date, operating_on_id, , source, , resource_id, approval_settings].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 280

def list_invalid_properties
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @service_kind.nil?
    invalid_properties.push('invalid value for "service_kind", service_kind cannot be nil.')
  end

  if @review_status.nil?
    invalid_properties.push('invalid value for "review_status", review_status cannot be nil.')
  end

  if @all_reviews.nil?
    invalid_properties.push('invalid value for "all_reviews", all_reviews cannot be nil.')
  end

  if @notify_member_ids.nil?
    invalid_properties.push('invalid value for "notify_member_ids", notify_member_ids cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @instructions.nil?
    invalid_properties.push('invalid value for "instructions", instructions cannot be nil.')
  end

  if @conflicts.nil?
    invalid_properties.push('invalid value for "conflicts", conflicts cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



492
493
494
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 492

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



498
499
500
501
502
503
504
505
506
507
508
509
510
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 498

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



486
487
488
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 486

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/launchdarkly_api/models/approval_request_response.rb', line 331

def valid?
  return false if @_id.nil?
  return false if @_version.nil?
  return false if @creation_date.nil?
  return false if @service_kind.nil?
  return false if @review_status.nil?
  review_status_validator = EnumAttributeValidator.new('String', ["approved", "declined", "pending"])
  return false unless review_status_validator.valid?(@review_status)
  return false if @all_reviews.nil?
  return false if @notify_member_ids.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "completed", "failed", "scheduled"])
  return false unless status_validator.valid?(@status)
  return false if @instructions.nil?
  return false if @conflicts.nil?
  return false if @_links.nil?
  true
end