Class: LaunchDarklyApi::ApprovalRequestSettingsPatch

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/approval_request_settings_patch.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApprovalRequestSettingsPatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApprovalRequestSettingsPatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApprovalRequestSettingsPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'auto_apply_approved_changes')
    self.auto_apply_approved_changes = attributes[:'auto_apply_approved_changes']
  end

  if attributes.key?(:'bypass_approvals_for_pending_changes')
    self.bypass_approvals_for_pending_changes = attributes[:'bypass_approvals_for_pending_changes']
  end

  if attributes.key?(:'can_apply_declined_changes')
    self.can_apply_declined_changes = attributes[:'can_apply_declined_changes']
  end

  if attributes.key?(:'can_review_own_request')
    self.can_review_own_request = attributes[:'can_review_own_request']
  end

  if attributes.key?(:'environment_key')
    self.environment_key = attributes[:'environment_key']
  else
    self.environment_key = nil
  end

  if attributes.key?(:'min_num_approvals')
    self.min_num_approvals = attributes[:'min_num_approvals']
  end

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  end

  if attributes.key?(:'required_approval_tags')
    if (value = attributes[:'required_approval_tags']).is_a?(Array)
      self.required_approval_tags = value
    end
  end

  if attributes.key?(:'resource_kind')
    self.resource_kind = attributes[:'resource_kind']
  else
    self.resource_kind = nil
  end

  if attributes.key?(:'service_config')
    if (value = attributes[:'service_config']).is_a?(Hash)
      self.service_config = value
    end
  end

  if attributes.key?(:'service_kind')
    self.service_kind = attributes[:'service_kind']
  end

  if attributes.key?(:'service_kind_configuration_id')
    self.service_kind_configuration_id = attributes[:'service_kind_configuration_id']
  end
end

Instance Attribute Details

#auto_apply_approved_changesObject

Automatically apply changes that have been approved by all reviewers. This field is only applicable for approval services other than LaunchDarkly.



19
20
21
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 19

def auto_apply_approved_changes
  @auto_apply_approved_changes
end

#bypass_approvals_for_pending_changesObject

Whether to skip approvals for pending changes



22
23
24
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 22

def bypass_approvals_for_pending_changes
  @bypass_approvals_for_pending_changes
end

#can_apply_declined_changesObject

Allow applying the change as long as at least one person has approved



25
26
27
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 25

def can_apply_declined_changes
  @can_apply_declined_changes
end

#can_review_own_requestObject

Allow someone who makes an approval request to apply their own change



28
29
30
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 28

def can_review_own_request
  @can_review_own_request
end

#environment_keyObject

Returns the value of attribute environment_key.



30
31
32
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 30

def environment_key
  @environment_key
end

#min_num_approvalsObject

Sets the amount of approvals required before a member can apply a change. The minimum is one and the maximum is five.



33
34
35
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 33

def min_num_approvals
  @min_num_approvals
end

#requiredObject

If approvals are required for this environment



36
37
38
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 36

def required
  @required
end

#required_approval_tagsObject

Require approval only on flags with the provided tags. Otherwise all flags will require approval.



39
40
41
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 39

def required_approval_tags
  @required_approval_tags
end

#resource_kindObject

Returns the value of attribute resource_kind.



41
42
43
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 41

def resource_kind
  @resource_kind
end

#service_configObject

Arbitrary service-specific configuration



44
45
46
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 44

def service_config
  @service_config
end

#service_kindObject

Which service to use for managing approvals



47
48
49
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 47

def service_kind
  @service_kind
end

#service_kind_configuration_idObject

Optional integration configuration ID of a custom approval integration. This is an Enterprise-only feature.



50
51
52
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 50

def service_kind_configuration_id
  @service_kind_configuration_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



71
72
73
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 71

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



76
77
78
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 76

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 53

def self.attribute_map
  {
    :'auto_apply_approved_changes' => :'autoApplyApprovedChanges',
    :'bypass_approvals_for_pending_changes' => :'bypassApprovalsForPendingChanges',
    :'can_apply_declined_changes' => :'canApplyDeclinedChanges',
    :'can_review_own_request' => :'canReviewOwnRequest',
    :'environment_key' => :'environmentKey',
    :'min_num_approvals' => :'minNumApprovals',
    :'required' => :'required',
    :'required_approval_tags' => :'requiredApprovalTags',
    :'resource_kind' => :'resourceKind',
    :'service_config' => :'serviceConfig',
    :'service_kind' => :'serviceKind',
    :'service_kind_configuration_id' => :'serviceKindConfigurationId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 258

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



99
100
101
102
103
104
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 99

def self.openapi_nullable
  Set.new([
    :'auto_apply_approved_changes',
    :'service_kind_configuration_id'
  ])
end

.openapi_typesObject

Attribute type mapping.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 81

def self.openapi_types
  {
    :'auto_apply_approved_changes' => :'Boolean',
    :'bypass_approvals_for_pending_changes' => :'Boolean',
    :'can_apply_declined_changes' => :'Boolean',
    :'can_review_own_request' => :'Boolean',
    :'environment_key' => :'String',
    :'min_num_approvals' => :'Integer',
    :'required' => :'Boolean',
    :'required_approval_tags' => :'Array<String>',
    :'resource_kind' => :'String',
    :'service_config' => :'Hash<String, Object>',
    :'service_kind' => :'String',
    :'service_kind_configuration_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      auto_apply_approved_changes == o.auto_apply_approved_changes &&
      bypass_approvals_for_pending_changes == o.bypass_approvals_for_pending_changes &&
      can_apply_declined_changes == o.can_apply_declined_changes &&
      can_review_own_request == o.can_review_own_request &&
      environment_key == o.environment_key &&
      min_num_approvals == o.min_num_approvals &&
      required == o.required &&
      required_approval_tags == o.required_approval_tags &&
      resource_kind == o.resource_kind &&
      service_config == o.service_config &&
      service_kind == o.service_kind &&
      service_kind_configuration_id == o.service_kind_configuration_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


245
246
247
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 245

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



251
252
253
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 251

def hash
  [auto_apply_approved_changes, bypass_approvals_for_pending_changes, can_apply_declined_changes, can_review_own_request, environment_key, min_num_approvals, required, required_approval_tags, resource_kind, service_config, service_kind, service_kind_configuration_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @environment_key.nil?
    invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.')
  end

  if @resource_kind.nil?
    invalid_properties.push('invalid value for "resource_kind", resource_kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



280
281
282
283
284
285
286
287
288
289
290
291
292
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 280

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



197
198
199
200
201
202
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 197

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @environment_key.nil?
  return false if @resource_kind.nil?
  true
end