Class: LaunchDarklyApi::ApprovalSettings

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/approval_settings.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ApprovalSettings

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApprovalSettings` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApprovalSettings`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'required')
    self.required = attributes[:'required']
  else
    self.required = nil
  end

  if attributes.key?(:'bypass_approvals_for_pending_changes')
    self.bypass_approvals_for_pending_changes = attributes[:'bypass_approvals_for_pending_changes']
  else
    self.bypass_approvals_for_pending_changes = nil
  end

  if attributes.key?(:'min_num_approvals')
    self.min_num_approvals = attributes[:'min_num_approvals']
  else
    self.min_num_approvals = nil
  end

  if attributes.key?(:'can_review_own_request')
    self.can_review_own_request = attributes[:'can_review_own_request']
  else
    self.can_review_own_request = nil
  end

  if attributes.key?(:'can_apply_declined_changes')
    self.can_apply_declined_changes = attributes[:'can_apply_declined_changes']
  else
    self.can_apply_declined_changes = nil
  end

  if attributes.key?(:'auto_apply_approved_changes')
    self.auto_apply_approved_changes = attributes[:'auto_apply_approved_changes']
  end

  if attributes.key?(:'service_kind')
    self.service_kind = attributes[:'service_kind']
  else
    self.service_kind = nil
  end

  if attributes.key?(:'service_config')
    if (value = attributes[:'service_config']).is_a?(Hash)
      self.service_config = value
    end
  else
    self.service_config = nil
  end

  if attributes.key?(:'required_approval_tags')
    if (value = attributes[:'required_approval_tags']).is_a?(Array)
      self.required_approval_tags = value
    end
  else
    self.required_approval_tags = nil
  end

  if attributes.key?(:'service_kind_configuration_id')
    self.service_kind_configuration_id = attributes[:'service_kind_configuration_id']
  end
end

Instance Attribute Details

#auto_apply_approved_changesObject

Automatically apply changes that have been approved by all reviewers. This field is only applicable for approval services other than LaunchDarkly.



34
35
36
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 34

def auto_apply_approved_changes
  @auto_apply_approved_changes
end

#bypass_approvals_for_pending_changesObject

Whether to skip approvals for pending changes



22
23
24
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 22

def bypass_approvals_for_pending_changes
  @bypass_approvals_for_pending_changes
end

#can_apply_declined_changesObject

Allow applying the change as long as at least one person has approved



31
32
33
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 31

def can_apply_declined_changes
  @can_apply_declined_changes
end

#can_review_own_requestObject

Allow someone who makes an approval request to apply their own change



28
29
30
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 28

def can_review_own_request
  @can_review_own_request
end

#min_num_approvalsObject

Sets the amount of approvals required before a member can apply a change. The minimum is one and the maximum is five.



25
26
27
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 25

def min_num_approvals
  @min_num_approvals
end

#requiredObject

If approvals are required for this environment



19
20
21
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 19

def required
  @required
end

#required_approval_tagsObject

Require approval only on flags with the provided tags. Otherwise all flags will require approval.



42
43
44
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 42

def required_approval_tags
  @required_approval_tags
end

#service_configObject

Returns the value of attribute service_config.



39
40
41
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 39

def service_config
  @service_config
end

#service_kindObject

Which service to use for managing approvals



37
38
39
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 37

def service_kind
  @service_kind
end

#service_kind_configuration_idObject

Optional field for integration configuration ID of a custom approval integration. This is an Enterprise-only feature.



45
46
47
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 45

def service_kind_configuration_id
  @service_kind_configuration_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 48

def self.attribute_map
  {
    :'required' => :'required',
    :'bypass_approvals_for_pending_changes' => :'bypassApprovalsForPendingChanges',
    :'min_num_approvals' => :'minNumApprovals',
    :'can_review_own_request' => :'canReviewOwnRequest',
    :'can_apply_declined_changes' => :'canApplyDeclinedChanges',
    :'auto_apply_approved_changes' => :'autoApplyApprovedChanges',
    :'service_kind' => :'serviceKind',
    :'service_config' => :'serviceConfig',
    :'required_approval_tags' => :'requiredApprovalTags',
    :'service_kind_configuration_id' => :'serviceKindConfigurationId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 339

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 74

def self.openapi_types
  {
    :'required' => :'Boolean',
    :'bypass_approvals_for_pending_changes' => :'Boolean',
    :'min_num_approvals' => :'Integer',
    :'can_review_own_request' => :'Boolean',
    :'can_apply_declined_changes' => :'Boolean',
    :'auto_apply_approved_changes' => :'Boolean',
    :'service_kind' => :'String',
    :'service_config' => :'Hash<String, Object>',
    :'required_approval_tags' => :'Array<String>',
    :'service_kind_configuration_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



309
310
311
312
313
314
315
316
317
318
319
320
321
322
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 309

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      required == o.required &&
      bypass_approvals_for_pending_changes == o.bypass_approvals_for_pending_changes &&
      min_num_approvals == o.min_num_approvals &&
      can_review_own_request == o.can_review_own_request &&
      can_apply_declined_changes == o.can_apply_declined_changes &&
      auto_apply_approved_changes == o.auto_apply_approved_changes &&
      service_kind == o.service_kind &&
      service_config == o.service_config &&
      required_approval_tags == o.required_approval_tags &&
      service_kind_configuration_id == o.service_kind_configuration_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


326
327
328
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 326

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



332
333
334
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 332

def hash
  [required, bypass_approvals_for_pending_changes, min_num_approvals, can_review_own_request, can_apply_declined_changes, auto_apply_approved_changes, service_kind, service_config, required_approval_tags, service_kind_configuration_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 174

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @required.nil?
    invalid_properties.push('invalid value for "required", required cannot be nil.')
  end

  if @bypass_approvals_for_pending_changes.nil?
    invalid_properties.push('invalid value for "bypass_approvals_for_pending_changes", bypass_approvals_for_pending_changes cannot be nil.')
  end

  if @min_num_approvals.nil?
    invalid_properties.push('invalid value for "min_num_approvals", min_num_approvals cannot be nil.')
  end

  if @can_review_own_request.nil?
    invalid_properties.push('invalid value for "can_review_own_request", can_review_own_request cannot be nil.')
  end

  if @can_apply_declined_changes.nil?
    invalid_properties.push('invalid value for "can_apply_declined_changes", can_apply_declined_changes cannot be nil.')
  end

  if @service_kind.nil?
    invalid_properties.push('invalid value for "service_kind", service_kind cannot be nil.')
  end

  if @service_config.nil?
    invalid_properties.push('invalid value for "service_config", service_config cannot be nil.')
  end

  if @required_approval_tags.nil?
    invalid_properties.push('invalid value for "required_approval_tags", required_approval_tags cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/launchdarkly_api/models/approval_settings.rb', line 214

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @required.nil?
  return false if @bypass_approvals_for_pending_changes.nil?
  return false if @min_num_approvals.nil?
  return false if @can_review_own_request.nil?
  return false if @can_apply_declined_changes.nil?
  return false if @service_kind.nil?
  return false if @service_config.nil?
  return false if @required_approval_tags.nil?
  true
end