Class: LaunchDarklyApi::AuditLogEntryRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/audit_log_entry_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuditLogEntryRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 176

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AuditLogEntryRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AuditLogEntryRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'_account_id')
    self. = attributes[:'_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'date')
    self.date = attributes[:'date']
  else
    self.date = nil
  end

  if attributes.key?(:'accesses')
    if (value = attributes[:'accesses']).is_a?(Array)
      self.accesses = value
    end
  else
    self.accesses = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'short_description')
    self.short_description = attributes[:'short_description']
  else
    self.short_description = nil
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'related_flag')
    self.related_flag = attributes[:'related_flag']
  end

  if attributes.key?(:'related_experiment')
    self.related_experiment = attributes[:'related_experiment']
  end

  if attributes.key?(:'related_ai_config')
    self.related_ai_config = attributes[:'related_ai_config']
  end

  if attributes.key?(:'subject')
    self.subject = attributes[:'subject']
  end

  if attributes.key?(:'member')
    self.member = attributes[:'member']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'app')
    self.app = attributes[:'app']
  end

  if attributes.key?(:'title_verb')
    self.title_verb = attributes[:'title_verb']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'target')
    self.target = attributes[:'target']
  end

  if attributes.key?(:'parent')
    self.parent = attributes[:'parent']
  end

  if attributes.key?(:'delta')
    self.delta = attributes[:'delta']
  end

  if attributes.key?(:'trigger_body')
    self.trigger_body = attributes[:'trigger_body']
  end

  if attributes.key?(:'merge')
    self.merge = attributes[:'merge']
  end

  if attributes.key?(:'previous_version')
    self.previous_version = attributes[:'previous_version']
  end

  if attributes.key?(:'current_version')
    self.current_version = attributes[:'current_version']
  end

  if attributes.key?(:'subentries')
    if (value = attributes[:'subentries']).is_a?(Array)
      self.subentries = value
    end
  end
end

Instance Attribute Details

#_account_idObject

The ID of the account to which this audit log entry belongs



25
26
27
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 25

def 
  @_account_id
end

#_idObject

The ID of the audit log entry



22
23
24
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 22

def _id
  @_id
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 19

def _links
  @_links
end

#accessesObject

Details on the actions performed and resources acted on in this audit log entry



30
31
32
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 30

def accesses
  @accesses
end

#appObject

Returns the value of attribute app.



58
59
60
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 58

def app
  @app
end

#commentObject

Optional comment for the audit log entry



44
45
46
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 44

def comment
  @comment
end

#current_versionObject

If the audit log entry has been updated, this is a JSON representation of the current version of the entity



83
84
85
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 83

def current_version
  @current_version
end

#dateObject

Returns the value of attribute date.



27
28
29
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 27

def date
  @date
end

#deltaObject

If the audit log entry has been updated, this is the JSON patch body that was used in the request to update the entity



71
72
73
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 71

def delta
  @delta
end

#descriptionObject

Description of the change recorded in the audit log entry



38
39
40
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 38

def description
  @description
end

#kindObject

Returns the value of attribute kind.



32
33
34
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 32

def kind
  @kind
end

#memberObject

Returns the value of attribute member.



54
55
56
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 54

def member
  @member
end

#mergeObject

A JSON representation of the merge information for this audit log entry, if any



77
78
79
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 77

def merge
  @merge
end

#nameObject

The name of the resource this audit log entry refers to



35
36
37
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 35

def name
  @name
end

#parentObject

Returns the value of attribute parent.



68
69
70
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 68

def parent
  @parent
end

#previous_versionObject

If the audit log entry has been updated, this is a JSON representation of the previous version of the entity



80
81
82
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 80

def previous_version
  @previous_version
end

Returns the value of attribute related_ai_config.



50
51
52
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 50

def related_ai_config
  @related_ai_config
end

Returns the value of attribute related_experiment.



48
49
50
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 48

def related_experiment
  @related_experiment
end

Returns the value of attribute related_flag.



46
47
48
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 46

def related_flag
  @related_flag
end

#short_descriptionObject

Shorter version of the change recorded in the audit log entry



41
42
43
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 41

def short_description
  @short_description
end

#subentriesObject

Returns the value of attribute subentries.



85
86
87
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 85

def subentries
  @subentries
end

#subjectObject

Returns the value of attribute subject.



52
53
54
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 52

def subject
  @subject
end

#targetObject

Returns the value of attribute target.



66
67
68
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 66

def target
  @target
end

#titleObject

A description of what occurred, in the format member titleVerb target



64
65
66
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 64

def title
  @title
end

#title_verbObject

The action and resource recorded in this audit log entry



61
62
63
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 61

def title_verb
  @title_verb
end

#tokenObject

Returns the value of attribute token.



56
57
58
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 56

def token
  @token
end

#trigger_bodyObject

A JSON representation of the external trigger for this audit log entry, if any



74
75
76
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 74

def trigger_body
  @trigger_body
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



121
122
123
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 121

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



126
127
128
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 126

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 88

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'_account_id' => :'_accountId',
    :'date' => :'date',
    :'accesses' => :'accesses',
    :'kind' => :'kind',
    :'name' => :'name',
    :'description' => :'description',
    :'short_description' => :'shortDescription',
    :'comment' => :'comment',
    :'related_flag' => :'relatedFlag',
    :'related_experiment' => :'relatedExperiment',
    :'related_ai_config' => :'relatedAIConfig',
    :'subject' => :'subject',
    :'member' => :'member',
    :'token' => :'token',
    :'app' => :'app',
    :'title_verb' => :'titleVerb',
    :'title' => :'title',
    :'target' => :'target',
    :'parent' => :'parent',
    :'delta' => :'delta',
    :'trigger_body' => :'triggerBody',
    :'merge' => :'merge',
    :'previous_version' => :'previousVersion',
    :'current_version' => :'currentVersion',
    :'subentries' => :'subentries'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 522

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



164
165
166
167
168
169
170
171
172
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 164

def self.openapi_nullable
  Set.new([
    :'delta',
    :'trigger_body',
    :'merge',
    :'previous_version',
    :'current_version',
  ])
end

.openapi_typesObject

Attribute type mapping.



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 131

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'_account_id' => :'String',
    :'date' => :'Integer',
    :'accesses' => :'Array<ResourceAccess>',
    :'kind' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'short_description' => :'String',
    :'comment' => :'String',
    :'related_flag' => :'RelatedFlag',
    :'related_experiment' => :'RelatedExperiment',
    :'related_ai_config' => :'RelatedAIConfig',
    :'subject' => :'SubjectDataRep',
    :'member' => :'MemberDataRep',
    :'token' => :'TokenSummary',
    :'app' => :'AuthorizedAppDataRep',
    :'title_verb' => :'String',
    :'title' => :'String',
    :'target' => :'TargetResourceRep',
    :'parent' => :'ParentResourceRep',
    :'delta' => :'Object',
    :'trigger_body' => :'Object',
    :'merge' => :'Object',
    :'previous_version' => :'Object',
    :'current_version' => :'Object',
    :'subentries' => :'Array<AuditLogEntryListingRep>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
505
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 475

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
       == o. &&
      date == o.date &&
      accesses == o.accesses &&
      kind == o.kind &&
      name == o.name &&
      description == o.description &&
      short_description == o.short_description &&
      comment == o.comment &&
      related_flag == o.related_flag &&
      related_experiment == o.related_experiment &&
      related_ai_config == o.related_ai_config &&
      subject == o.subject &&
      member == o.member &&
      token == o.token &&
      app == o.app &&
      title_verb == o.title_verb &&
      title == o.title &&
      target == o.target &&
      parent == o.parent &&
      delta == o.delta &&
      trigger_body == o.trigger_body &&
      merge == o.merge &&
      previous_version == o.previous_version &&
      current_version == o.current_version &&
      subentries == o.subentries
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


509
510
511
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 509

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



515
516
517
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 515

def hash
  [_links, _id, , date, accesses, kind, name, description, short_description, comment, related_flag, related_experiment, related_ai_config, subject, member, token, app, title_verb, title, target, parent, delta, trigger_body, merge, previous_version, current_version, subentries].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 325

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_account_id.nil?
    invalid_properties.push('invalid value for "_account_id", _account_id cannot be nil.')
  end

  if @date.nil?
    invalid_properties.push('invalid value for "date", date cannot be nil.')
  end

  if @accesses.nil?
    invalid_properties.push('invalid value for "accesses", accesses cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @short_description.nil?
    invalid_properties.push('invalid value for "short_description", short_description cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



544
545
546
547
548
549
550
551
552
553
554
555
556
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 544

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



369
370
371
372
373
374
375
376
377
378
379
380
381
# File 'lib/launchdarkly_api/models/audit_log_entry_rep.rb', line 369

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @_account_id.nil?
  return false if @date.nil?
  return false if @accesses.nil?
  return false if @kind.nil?
  return false if @name.nil?
  return false if @description.nil?
  return false if @short_description.nil?
  true
end