Class: LaunchDarklyApi::AuthorizedAppDataRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/authorized_app_data_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AuthorizedAppDataRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AuthorizedAppDataRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AuthorizedAppDataRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'is_scim')
    self.is_scim = attributes[:'is_scim']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'maintainer_name')
    self.maintainer_name = attributes[:'maintainer_name']
  end
end

Instance Attribute Details

#_idObject

The ID of the authorized application



21
22
23
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 21

def _id
  @_id
end

Returns the value of attribute _links.



18
19
20
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 18

def _links
  @_links
end

#is_scimObject

Whether the application is authorized through SCIM



24
25
26
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 24

def is_scim
  @is_scim
end

#maintainer_nameObject

The name of the maintainer for this authorized application



30
31
32
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 30

def maintainer_name
  @maintainer_name
end

#nameObject

The authorized application name



27
28
29
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 27

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 33

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'is_scim' => :'isScim',
    :'name' => :'name',
    :'maintainer_name' => :'maintainerName'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 151

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 54

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'is_scim' => :'Boolean',
    :'name' => :'String',
    :'maintainer_name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



126
127
128
129
130
131
132
133
134
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 126

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      is_scim == o.is_scim &&
      name == o.name &&
      maintainer_name == o.maintainer_name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


138
139
140
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 138

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



144
145
146
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 144

def hash
  [_links, _id, is_scim, name, maintainer_name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



111
112
113
114
115
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 111

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 173

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
# File 'lib/launchdarkly_api/models/authorized_app_data_rep.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end