Class: LaunchDarklyApi::BigSegmentStoreStatus
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::BigSegmentStoreStatus
- Defined in:
- lib/launchdarkly_api/models/big_segment_store_status.rb
Instance Attribute Summary collapse
-
#available ⇒ Object
Whether the persistent store integration is fully synchronized with the LaunchDarkly environment, and the
lastSyncoccurred within a few minutes. -
#errors ⇒ Object
Returns the value of attribute errors.
-
#last_error ⇒ Object
Returns the value of attribute last_error.
-
#last_sync ⇒ Object
Returns the value of attribute last_sync.
-
#potentially_stale ⇒ Object
Whether the persistent store integration may not be fully synchronized with the LaunchDarkly environment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BigSegmentStoreStatus
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BigSegmentStoreStatus
Initializes the object
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 70 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::BigSegmentStoreStatus` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::BigSegmentStoreStatus`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'available') self.available = attributes[:'available'] end if attributes.key?(:'potentially_stale') self.potentially_stale = attributes[:'potentially_stale'] end if attributes.key?(:'last_sync') self.last_sync = attributes[:'last_sync'] end if attributes.key?(:'last_error') self.last_error = attributes[:'last_error'] end if attributes.key?(:'errors') if (value = attributes[:'errors']).is_a?(Array) self.errors = value end end end |
Instance Attribute Details
#available ⇒ Object
Whether the persistent store integration is fully synchronized with the LaunchDarkly environment, and the lastSync occurred within a few minutes
19 20 21 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 19 def available @available end |
#errors ⇒ Object
Returns the value of attribute errors.
28 29 30 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 28 def errors @errors end |
#last_error ⇒ Object
Returns the value of attribute last_error.
26 27 28 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 26 def last_error @last_error end |
#last_sync ⇒ Object
Returns the value of attribute last_sync.
24 25 26 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 24 def last_sync @last_sync end |
#potentially_stale ⇒ Object
Whether the persistent store integration may not be fully synchronized with the LaunchDarkly environment. true if the integration could be stale.
22 23 24 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 22 def potentially_stale @potentially_stale end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
42 43 44 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 42 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
47 48 49 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 47 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
31 32 33 34 35 36 37 38 39 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 31 def self.attribute_map { :'available' => :'available', :'potentially_stale' => :'potentiallyStale', :'last_sync' => :'lastSync', :'last_error' => :'lastError', :'errors' => :'errors' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 149 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
63 64 65 66 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 63 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
52 53 54 55 56 57 58 59 60 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 52 def self.openapi_types { :'available' => :'Boolean', :'potentially_stale' => :'Boolean', :'last_sync' => :'Integer', :'last_error' => :'Integer', :'errors' => :'Array<StoreIntegrationError>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
124 125 126 127 128 129 130 131 132 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 124 def ==(o) return true if self.equal?(o) self.class == o.class && available == o.available && potentially_stale == o.potentially_stale && last_sync == o.last_sync && last_error == o.last_error && errors == o.errors end |
#eql?(o) ⇒ Boolean
136 137 138 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 136 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
142 143 144 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 142 def hash [available, potentially_stale, last_sync, last_error, errors].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
109 110 111 112 113 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 109 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 171 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
117 118 119 120 |
# File 'lib/launchdarkly_api/models/big_segment_store_status.rb', line 117 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |