Class: LaunchDarklyApi::ConditionInput

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/condition_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConditionInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/launchdarkly_api/models/condition_input.rb', line 93

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ConditionInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ConditionInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'schedule_kind')
    self.schedule_kind = attributes[:'schedule_kind']
  end

  if attributes.key?(:'execution_date')
    self.execution_date = attributes[:'execution_date']
  end

  if attributes.key?(:'wait_duration')
    self.wait_duration = attributes[:'wait_duration']
  end

  if attributes.key?(:'wait_duration_unit')
    self.wait_duration_unit = attributes[:'wait_duration_unit']
  end

  if attributes.key?(:'execute_now')
    self.execute_now = attributes[:'execute_now']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'notify_member_ids')
    if (value = attributes[:'notify_member_ids']).is_a?(Array)
      self.notify_member_ids = value
    end
  end

  if attributes.key?(:'notify_team_keys')
    if (value = attributes[:'notify_team_keys']).is_a?(Array)
      self.notify_team_keys = value
    end
  end

  if attributes.key?(:'integration_config')
    if (value = attributes[:'integration_config']).is_a?(Hash)
      self.integration_config = value
    end
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end
end

Instance Attribute Details

#descriptionObject

A description of the approval required for this stage



31
32
33
# File 'lib/launchdarkly_api/models/condition_input.rb', line 31

def description
  @description
end

#execute_nowObject

Whether the workflow stage should be executed immediately



28
29
30
# File 'lib/launchdarkly_api/models/condition_input.rb', line 28

def execute_now
  @execute_now
end

#execution_dateObject

Returns the value of attribute execution_date.



20
21
22
# File 'lib/launchdarkly_api/models/condition_input.rb', line 20

def execution_date
  @execution_date
end

#integration_configObject

Returns the value of attribute integration_config.



39
40
41
# File 'lib/launchdarkly_api/models/condition_input.rb', line 39

def integration_config
  @integration_config
end

#kindObject

Returns the value of attribute kind.



41
42
43
# File 'lib/launchdarkly_api/models/condition_input.rb', line 41

def kind
  @kind
end

#notify_member_idsObject

A list of member IDs for the members to request approval from for this stage



34
35
36
# File 'lib/launchdarkly_api/models/condition_input.rb', line 34

def notify_member_ids
  @notify_member_ids
end

#notify_team_keysObject

A list of team keys for the teams to request approval from for this stage



37
38
39
# File 'lib/launchdarkly_api/models/condition_input.rb', line 37

def notify_team_keys
  @notify_team_keys
end

#schedule_kindObject

Returns the value of attribute schedule_kind.



18
19
20
# File 'lib/launchdarkly_api/models/condition_input.rb', line 18

def schedule_kind
  @schedule_kind
end

#wait_durationObject

For workflow stages whose scheduled execution is relative, how far in the future the stage should start.



23
24
25
# File 'lib/launchdarkly_api/models/condition_input.rb', line 23

def wait_duration
  @wait_duration
end

#wait_duration_unitObject

Returns the value of attribute wait_duration_unit.



25
26
27
# File 'lib/launchdarkly_api/models/condition_input.rb', line 25

def wait_duration_unit
  @wait_duration_unit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/launchdarkly_api/models/condition_input.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/launchdarkly_api/models/condition_input.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/launchdarkly_api/models/condition_input.rb', line 44

def self.attribute_map
  {
    :'schedule_kind' => :'scheduleKind',
    :'execution_date' => :'executionDate',
    :'wait_duration' => :'waitDuration',
    :'wait_duration_unit' => :'waitDurationUnit',
    :'execute_now' => :'executeNow',
    :'description' => :'description',
    :'notify_member_ids' => :'notifyMemberIds',
    :'notify_team_keys' => :'notifyTeamKeys',
    :'integration_config' => :'integrationConfig',
    :'kind' => :'kind'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/launchdarkly_api/models/condition_input.rb', line 201

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



86
87
88
89
# File 'lib/launchdarkly_api/models/condition_input.rb', line 86

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/launchdarkly_api/models/condition_input.rb', line 70

def self.openapi_types
  {
    :'schedule_kind' => :'String',
    :'execution_date' => :'Integer',
    :'wait_duration' => :'Integer',
    :'wait_duration_unit' => :'String',
    :'execute_now' => :'Boolean',
    :'description' => :'String',
    :'notify_member_ids' => :'Array<String>',
    :'notify_team_keys' => :'Array<String>',
    :'integration_config' => :'Hash<String, Object>',
    :'kind' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



171
172
173
174
175
176
177
178
179
180
181
182
183
184
# File 'lib/launchdarkly_api/models/condition_input.rb', line 171

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      schedule_kind == o.schedule_kind &&
      execution_date == o.execution_date &&
      wait_duration == o.wait_duration &&
      wait_duration_unit == o.wait_duration_unit &&
      execute_now == o.execute_now &&
      description == o.description &&
      notify_member_ids == o.notify_member_ids &&
      notify_team_keys == o.notify_team_keys &&
      integration_config == o.integration_config &&
      kind == o.kind
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


188
189
190
# File 'lib/launchdarkly_api/models/condition_input.rb', line 188

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



194
195
196
# File 'lib/launchdarkly_api/models/condition_input.rb', line 194

def hash
  [schedule_kind, execution_date, wait_duration, wait_duration_unit, execute_now, description, notify_member_ids, notify_team_keys, integration_config, kind].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



156
157
158
159
160
# File 'lib/launchdarkly_api/models/condition_input.rb', line 156

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/launchdarkly_api/models/condition_input.rb', line 223

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



164
165
166
167
# File 'lib/launchdarkly_api/models/condition_input.rb', line 164

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end