Class: LaunchDarklyApi::ConditionOutput

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/condition_output.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ConditionOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/launchdarkly_api/models/condition_output.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ConditionOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ConditionOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'_execution')
    self._execution = attributes[:'_execution']
  else
    self._execution = nil
  end

  if attributes.key?(:'schedule_kind')
    self.schedule_kind = attributes[:'schedule_kind']
  end

  if attributes.key?(:'execution_date')
    self.execution_date = attributes[:'execution_date']
  end

  if attributes.key?(:'wait_duration')
    self.wait_duration = attributes[:'wait_duration']
  end

  if attributes.key?(:'wait_duration_unit')
    self.wait_duration_unit = attributes[:'wait_duration_unit']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'notify_member_ids')
    if (value = attributes[:'notify_member_ids']).is_a?(Array)
      self.notify_member_ids = value
    end
  else
    self.notify_member_ids = nil
  end

  if attributes.key?(:'all_reviews')
    if (value = attributes[:'all_reviews']).is_a?(Array)
      self.all_reviews = value
    end
  else
    self.all_reviews = nil
  end

  if attributes.key?(:'review_status')
    self.review_status = attributes[:'review_status']
  else
    self.review_status = nil
  end

  if attributes.key?(:'applied_date')
    self.applied_date = attributes[:'applied_date']
  end

  if attributes.key?(:'creation_config')
    if (value = attributes[:'creation_config']).is_a?(Hash)
      self.creation_config = value
    end
  end
end

Instance Attribute Details

#_executionObject

Returns the value of attribute _execution.



22
23
24
# File 'lib/launchdarkly_api/models/condition_output.rb', line 22

def _execution
  @_execution
end

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/launchdarkly_api/models/condition_output.rb', line 18

def _id
  @_id
end

#all_reviewsObject

Returns the value of attribute all_reviews.



36
37
38
# File 'lib/launchdarkly_api/models/condition_output.rb', line 36

def all_reviews
  @all_reviews
end

#applied_dateObject

Returns the value of attribute applied_date.



40
41
42
# File 'lib/launchdarkly_api/models/condition_output.rb', line 40

def applied_date
  @applied_date
end

#creation_configObject

Returns the value of attribute creation_config.



42
43
44
# File 'lib/launchdarkly_api/models/condition_output.rb', line 42

def creation_config
  @creation_config
end

#descriptionObject

Returns the value of attribute description.



32
33
34
# File 'lib/launchdarkly_api/models/condition_output.rb', line 32

def description
  @description
end

#execution_dateObject

Returns the value of attribute execution_date.



26
27
28
# File 'lib/launchdarkly_api/models/condition_output.rb', line 26

def execution_date
  @execution_date
end

#kindObject

Returns the value of attribute kind.



20
21
22
# File 'lib/launchdarkly_api/models/condition_output.rb', line 20

def kind
  @kind
end

#notify_member_idsObject

Returns the value of attribute notify_member_ids.



34
35
36
# File 'lib/launchdarkly_api/models/condition_output.rb', line 34

def notify_member_ids
  @notify_member_ids
end

#review_statusObject

Returns the value of attribute review_status.



38
39
40
# File 'lib/launchdarkly_api/models/condition_output.rb', line 38

def review_status
  @review_status
end

#schedule_kindObject

Returns the value of attribute schedule_kind.



24
25
26
# File 'lib/launchdarkly_api/models/condition_output.rb', line 24

def schedule_kind
  @schedule_kind
end

#wait_durationObject

Returns the value of attribute wait_duration.



28
29
30
# File 'lib/launchdarkly_api/models/condition_output.rb', line 28

def wait_duration
  @wait_duration
end

#wait_duration_unitObject

Returns the value of attribute wait_duration_unit.



30
31
32
# File 'lib/launchdarkly_api/models/condition_output.rb', line 30

def wait_duration_unit
  @wait_duration_unit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/launchdarkly_api/models/condition_output.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/launchdarkly_api/models/condition_output.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/launchdarkly_api/models/condition_output.rb', line 45

def self.attribute_map
  {
    :'_id' => :'_id',
    :'kind' => :'kind',
    :'_execution' => :'_execution',
    :'schedule_kind' => :'scheduleKind',
    :'execution_date' => :'executionDate',
    :'wait_duration' => :'waitDuration',
    :'wait_duration_unit' => :'waitDurationUnit',
    :'description' => :'description',
    :'notify_member_ids' => :'notifyMemberIds',
    :'all_reviews' => :'allReviews',
    :'review_status' => :'reviewStatus',
    :'applied_date' => :'appliedDate',
    :'creation_config' => :'creationConfig'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
# File 'lib/launchdarkly_api/models/condition_output.rb', line 325

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/launchdarkly_api/models/condition_output.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/launchdarkly_api/models/condition_output.rb', line 74

def self.openapi_types
  {
    :'_id' => :'String',
    :'kind' => :'String',
    :'_execution' => :'ExecutionOutput',
    :'schedule_kind' => :'String',
    :'execution_date' => :'Integer',
    :'wait_duration' => :'Integer',
    :'wait_duration_unit' => :'String',
    :'description' => :'String',
    :'notify_member_ids' => :'Array<String>',
    :'all_reviews' => :'Array<ReviewOutput>',
    :'review_status' => :'String',
    :'applied_date' => :'Integer',
    :'creation_config' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
# File 'lib/launchdarkly_api/models/condition_output.rb', line 292

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      kind == o.kind &&
      _execution == o._execution &&
      schedule_kind == o.schedule_kind &&
      execution_date == o.execution_date &&
      wait_duration == o.wait_duration &&
      wait_duration_unit == o.wait_duration_unit &&
      description == o.description &&
      notify_member_ids == o.notify_member_ids &&
      all_reviews == o.all_reviews &&
      review_status == o.review_status &&
      applied_date == o.applied_date &&
      creation_config == o.creation_config
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


312
313
314
# File 'lib/launchdarkly_api/models/condition_output.rb', line 312

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



318
319
320
# File 'lib/launchdarkly_api/models/condition_output.rb', line 318

def hash
  [_id, kind, _execution, schedule_kind, execution_date, wait_duration, wait_duration_unit, description, notify_member_ids, all_reviews, review_status, applied_date, creation_config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/launchdarkly_api/models/condition_output.rb', line 187

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_execution.nil?
    invalid_properties.push('invalid value for "_execution", _execution cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @notify_member_ids.nil?
    invalid_properties.push('invalid value for "notify_member_ids", notify_member_ids cannot be nil.')
  end

  if @all_reviews.nil?
    invalid_properties.push('invalid value for "all_reviews", all_reviews cannot be nil.')
  end

  if @review_status.nil?
    invalid_properties.push('invalid value for "review_status", review_status cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



347
348
349
350
351
352
353
354
355
356
357
358
359
# File 'lib/launchdarkly_api/models/condition_output.rb', line 347

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



219
220
221
222
223
224
225
226
227
228
# File 'lib/launchdarkly_api/models/condition_output.rb', line 219

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @_execution.nil?
  return false if @description.nil?
  return false if @notify_member_ids.nil?
  return false if @all_reviews.nil?
  return false if @review_status.nil?
  true
end