Class: LaunchDarklyApi::ContextInstanceRecord

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/context_instance_record.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ContextInstanceRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ContextInstanceRecord` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ContextInstanceRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'application_id')
    self.application_id = attributes[:'application_id']
  end

  if attributes.key?(:'anonymous_kinds')
    if (value = attributes[:'anonymous_kinds']).is_a?(Array)
      self.anonymous_kinds = value
    end
  end

  if attributes.key?(:'context')
    self.context = attributes[:'context']
  else
    self.context = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



36
37
38
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 36

def _access
  @_access
end

The location and content type of related resources



34
35
36
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 34

def _links
  @_links
end

#anonymous_kindsObject

A list of the context kinds this context was associated with that the SDK removed because they were marked as anonymous at flag evaluation



28
29
30
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 28

def anonymous_kinds
  @anonymous_kinds
end

#application_idObject

An identifier representing the application where the LaunchDarkly SDK is running



25
26
27
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 25

def application_id
  @application_id
end

#contextObject

The context, including its kind and attributes



31
32
33
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 31

def context
  @context
end

#idObject

The context instance ID



22
23
24
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 22

def id
  @id
end

#last_seenObject

Timestamp of the last time an evaluation occurred for this context instance



19
20
21
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 19

def last_seen
  @last_seen
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 39

def self.attribute_map
  {
    :'last_seen' => :'lastSeen',
    :'id' => :'id',
    :'application_id' => :'applicationId',
    :'anonymous_kinds' => :'anonymousKinds',
    :'context' => :'context',
    :'_links' => :'_links',
    :'_access' => :'_access'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 193

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
79
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 75

def self.openapi_nullable
  Set.new([
    :'context',
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 62

def self.openapi_types
  {
    :'last_seen' => :'Time',
    :'id' => :'String',
    :'application_id' => :'String',
    :'anonymous_kinds' => :'Array<String>',
    :'context' => :'Object',
    :'_links' => :'Hash<String, Link>',
    :'_access' => :'Access'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



166
167
168
169
170
171
172
173
174
175
176
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 166

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      last_seen == o.last_seen &&
      id == o.id &&
      application_id == o.application_id &&
      anonymous_kinds == o.anonymous_kinds &&
      context == o.context &&
      _links == o._links &&
      _access == o._access
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


180
181
182
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 180

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



186
187
188
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 186

def hash
  [last_seen, id, application_id, anonymous_kinds, context, _links, _access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



136
137
138
139
140
141
142
143
144
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 136

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



215
216
217
218
219
220
221
222
223
224
225
226
227
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 215

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



148
149
150
151
152
# File 'lib/launchdarkly_api/models/context_instance_record.rb', line 148

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  true
end