Class: LaunchDarklyApi::ContextRecord
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ContextRecord
- Defined in:
- lib/launchdarkly_api/models/context_record.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_links ⇒ Object
The location and content type of related resources.
-
#application_id ⇒ Object
An identifier representing the application where the LaunchDarkly SDK is running.
-
#associated_contexts ⇒ Object
The total number of associated contexts.
-
#context ⇒ Object
The context, including its kind and attributes.
-
#last_seen ⇒ Object
Timestamp of the last time an evaluation occurred for this context.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContextRecord
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ContextRecord
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ContextRecord` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ContextRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'context') self.context = attributes[:'context'] else self.context = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'associated_contexts') self.associated_contexts = attributes[:'associated_contexts'] end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
30 31 32 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 30 def _access @_access end |
#_links ⇒ Object
The location and content type of related resources
28 29 30 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 28 def _links @_links end |
#application_id ⇒ Object
An identifier representing the application where the LaunchDarkly SDK is running
22 23 24 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 22 def application_id @application_id end |
#associated_contexts ⇒ Object
The total number of associated contexts. Associated contexts are contexts that have appeared in the same context instance, that is, they were part of the same flag evaluation.
33 34 35 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 33 def associated_contexts @associated_contexts end |
#context ⇒ Object
The context, including its kind and attributes
25 26 27 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 25 def context @context end |
#last_seen ⇒ Object
Timestamp of the last time an evaluation occurred for this context
19 20 21 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 19 def last_seen @last_seen end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 36 def self.attribute_map { :'last_seen' => :'lastSeen', :'application_id' => :'applicationId', :'context' => :'context', :'_links' => :'_links', :'_access' => :'_access', :'associated_contexts' => :'associatedContexts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 164 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 74 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 70 def self.openapi_nullable Set.new([ :'context', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 58 def self.openapi_types { :'last_seen' => :'Time', :'application_id' => :'String', :'context' => :'Object', :'_links' => :'Hash<String, Link>', :'_access' => :'Access', :'associated_contexts' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
138 139 140 141 142 143 144 145 146 147 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 138 def ==(o) return true if self.equal?(o) self.class == o.class && last_seen == o.last_seen && application_id == o.application_id && context == o.context && _links == o._links && _access == o._access && associated_contexts == o.associated_contexts end |
#eql?(o) ⇒ Boolean
151 152 153 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 151 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
157 158 159 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 157 def hash [last_seen, application_id, context, _links, _access, associated_contexts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
186 187 188 189 190 191 192 193 194 195 196 197 198 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 186 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
131 132 133 134 |
# File 'lib/launchdarkly_api/models/context_record.rb', line 131 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |