Class: LaunchDarklyApi::ContextsBetaApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ContextsBetaApi
- Defined in:
- lib/launchdarkly_api/api/contexts_beta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_context_kinds_by_project_key(project_key, opts = {}) ⇒ ContextKindsCollectionRep
Get context kinds Get all context kinds for a given project.
-
#get_context_kinds_by_project_key_with_http_info(project_key, opts = {}) ⇒ Array<(ContextKindsCollectionRep, Integer, Hash)>
Get context kinds Get all context kinds for a given project.
-
#initialize(api_client = ApiClient.default) ⇒ ContextsBetaApi
constructor
A new instance of ContextsBetaApi.
-
#put_context_kind(project_key, key, upsert_context_kind_payload, opts = {}) ⇒ UpsertResponseRep
Create or update context kind Create or update a context kind by key.
-
#put_context_kind_with_http_info(project_key, key, upsert_context_kind_payload, opts = {}) ⇒ Array<(UpsertResponseRep, Integer, Hash)>
Create or update context kind Create or update a context kind by key.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ContextsBetaApi
Returns a new instance of ContextsBetaApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/contexts_beta_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/contexts_beta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_context_kinds_by_project_key(project_key, opts = {}) ⇒ ContextKindsCollectionRep
Get context kinds Get all context kinds for a given project.
27 28 29 30 |
# File 'lib/launchdarkly_api/api/contexts_beta_api.rb', line 27 def get_context_kinds_by_project_key(project_key, opts = {}) data, _status_code, _headers = get_context_kinds_by_project_key_with_http_info(project_key, opts) data end |
#get_context_kinds_by_project_key_with_http_info(project_key, opts = {}) ⇒ Array<(ContextKindsCollectionRep, Integer, Hash)>
Get context kinds Get all context kinds for a given project.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/launchdarkly_api/api/contexts_beta_api.rb', line 37 def get_context_kinds_by_project_key_with_http_info(project_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsBetaApi.get_context_kinds_by_project_key ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ContextsBetaApi.get_context_kinds_by_project_key" end # resource path local_var_path = '/api/v2/projects/{projectKey}/context-kinds'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ContextKindsCollectionRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ContextsBetaApi.get_context_kinds_by_project_key", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsBetaApi#get_context_kinds_by_project_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_context_kind(project_key, key, upsert_context_kind_payload, opts = {}) ⇒ UpsertResponseRep
Create or update context kind Create or update a context kind by key. Only the included fields will be updated.
92 93 94 95 |
# File 'lib/launchdarkly_api/api/contexts_beta_api.rb', line 92 def put_context_kind(project_key, key, upsert_context_kind_payload, opts = {}) data, _status_code, _headers = put_context_kind_with_http_info(project_key, key, upsert_context_kind_payload, opts) data end |
#put_context_kind_with_http_info(project_key, key, upsert_context_kind_payload, opts = {}) ⇒ Array<(UpsertResponseRep, Integer, Hash)>
Create or update context kind Create or update a context kind by key. Only the included fields will be updated.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 |
# File 'lib/launchdarkly_api/api/contexts_beta_api.rb', line 104 def put_context_kind_with_http_info(project_key, key, upsert_context_kind_payload, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ContextsBetaApi.put_context_kind ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ContextsBetaApi.put_context_kind" end # verify the required parameter 'key' is set if @api_client.config.client_side_validation && key.nil? fail ArgumentError, "Missing the required parameter 'key' when calling ContextsBetaApi.put_context_kind" end # verify the required parameter 'upsert_context_kind_payload' is set if @api_client.config.client_side_validation && upsert_context_kind_payload.nil? fail ArgumentError, "Missing the required parameter 'upsert_context_kind_payload' when calling ContextsBetaApi.put_context_kind" end # resource path local_var_path = '/api/v2/projects/{projectKey}/context-kinds/{key}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'key' + '}', CGI.escape(key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(upsert_context_kind_payload) # return_type return_type = opts[:debug_return_type] || 'UpsertResponseRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ContextsBetaApi.put_context_kind", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ContextsBetaApi#put_context_kind\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |