Class: LaunchDarklyApi::CreateApprovalRequestRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::CreateApprovalRequestRequest
- Defined in:
- lib/launchdarkly_api/models/create_approval_request_request.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Optional comment describing the approval request.
-
#description ⇒ Object
A brief description of the changes you're requesting.
-
#instructions ⇒ Object
Returns the value of attribute instructions.
-
#integration_config ⇒ Object
Returns the value of attribute integration_config.
-
#notify_member_ids ⇒ Object
An array of member IDs.
-
#notify_team_keys ⇒ Object
An array of team keys.
-
#resource_id ⇒ Object
String representation of the resource specifier.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateApprovalRequestRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateApprovalRequestRequest
Initializes the object
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 81 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CreateApprovalRequestRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CreateApprovalRequestRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'resource_id') self.resource_id = attributes[:'resource_id'] else self.resource_id = nil end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'instructions') if (value = attributes[:'instructions']).is_a?(Array) self.instructions = value end else self.instructions = nil end if attributes.key?(:'notify_member_ids') if (value = attributes[:'notify_member_ids']).is_a?(Array) self.notify_member_ids = value end end if attributes.key?(:'notify_team_keys') if (value = attributes[:'notify_team_keys']).is_a?(Array) self.notify_team_keys = value end end if attributes.key?(:'integration_config') if (value = attributes[:'integration_config']).is_a?(Hash) self.integration_config = value end end end |
Instance Attribute Details
#comment ⇒ Object
Optional comment describing the approval request
22 23 24 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 22 def comment @comment end |
#description ⇒ Object
A brief description of the changes you're requesting
25 26 27 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 25 def description @description end |
#instructions ⇒ Object
Returns the value of attribute instructions.
27 28 29 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 27 def instructions @instructions end |
#integration_config ⇒ Object
Returns the value of attribute integration_config.
35 36 37 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 35 def integration_config @integration_config end |
#notify_member_ids ⇒ Object
An array of member IDs. These members are notified to review the approval request.
30 31 32 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 30 def notify_member_ids @notify_member_ids end |
#notify_team_keys ⇒ Object
An array of team keys. The members of these teams are notified to review the approval request.
33 34 35 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 33 def notify_team_keys @notify_team_keys end |
#resource_id ⇒ Object
String representation of the resource specifier
19 20 21 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 19 def resource_id @resource_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
51 52 53 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 51 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
56 57 58 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 56 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
38 39 40 41 42 43 44 45 46 47 48 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 38 def self.attribute_map { :'resource_id' => :'resourceId', :'comment' => :'comment', :'description' => :'description', :'instructions' => :'instructions', :'notify_member_ids' => :'notifyMemberIds', :'notify_team_keys' => :'notifyTeamKeys', :'integration_config' => :'integrationConfig' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 227 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
74 75 76 77 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 74 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 61 def self.openapi_types { :'resource_id' => :'String', :'comment' => :'String', :'description' => :'String', :'instructions' => :'Array<Hash>', :'notify_member_ids' => :'Array<String>', :'notify_team_keys' => :'Array<String>', :'integration_config' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 200 def ==(o) return true if self.equal?(o) self.class == o.class && resource_id == o.resource_id && comment == o.comment && description == o.description && instructions == o.instructions && notify_member_ids == o.notify_member_ids && notify_team_keys == o.notify_team_keys && integration_config == o.integration_config end |
#eql?(o) ⇒ Boolean
214 215 216 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 214 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
220 221 222 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 220 def hash [resource_id, comment, description, instructions, notify_member_ids, notify_team_keys, integration_config].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 140 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @resource_id.nil? invalid_properties.push('invalid value for "resource_id", resource_id cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @instructions.nil? invalid_properties.push('invalid value for "instructions", instructions cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 249 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
160 161 162 163 164 165 166 |
# File 'lib/launchdarkly_api/models/create_approval_request_request.rb', line 160 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @resource_id.nil? return false if @description.nil? return false if @instructions.nil? true end |