Class: LaunchDarklyApi::CreateCopyFlagConfigApprovalRequestRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::CreateCopyFlagConfigApprovalRequestRequest
- Defined in:
- lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comment ⇒ Object
Optional comment describing the approval request.
-
#description ⇒ Object
A brief description of your changes.
-
#excluded_actions ⇒ Object
Optional list of the flag changes NOT to copy from the source environment to the target environment.
-
#included_actions ⇒ Object
Optional list of the flag changes to copy from the source environment to the target environment.
-
#notify_member_ids ⇒ Object
An array of member IDs.
-
#notify_team_keys ⇒ Object
An array of team keys.
-
#source ⇒ Object
Returns the value of attribute source.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateCopyFlagConfigApprovalRequestRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateCopyFlagConfigApprovalRequestRequest
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CreateCopyFlagConfigApprovalRequestRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CreateCopyFlagConfigApprovalRequestRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'notify_member_ids') if (value = attributes[:'notify_member_ids']).is_a?(Array) self.notify_member_ids = value end end if attributes.key?(:'notify_team_keys') if (value = attributes[:'notify_team_keys']).is_a?(Array) self.notify_team_keys = value end end if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'included_actions') if (value = attributes[:'included_actions']).is_a?(Array) self.included_actions = value end end if attributes.key?(:'excluded_actions') if (value = attributes[:'excluded_actions']).is_a?(Array) self.excluded_actions = value end end end |
Instance Attribute Details
#comment ⇒ Object
Optional comment describing the approval request
19 20 21 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 19 def comment @comment end |
#description ⇒ Object
A brief description of your changes
22 23 24 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 22 def description @description end |
#excluded_actions ⇒ Object
Optional list of the flag changes NOT to copy from the source environment to the target environment. You may include either includedActions or excludedActions, but not both. If neither are included, then all flag changes will be copied.
36 37 38 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 36 def excluded_actions @excluded_actions end |
#included_actions ⇒ Object
Optional list of the flag changes to copy from the source environment to the target environment. You may include either includedActions or excludedActions, but not both. If neither are included, then all flag changes will be copied.
33 34 35 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 33 def included_actions @included_actions end |
#notify_member_ids ⇒ Object
An array of member IDs. These members are notified to review the approval request.
25 26 27 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 25 def notify_member_ids @notify_member_ids end |
#notify_team_keys ⇒ Object
An array of team keys. The members of these teams are notified to review the approval request.
28 29 30 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 28 def notify_team_keys @notify_team_keys end |
#source ⇒ Object
Returns the value of attribute source.
30 31 32 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 30 def source @source end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 61 def self.attribute_map { :'comment' => :'comment', :'description' => :'description', :'notify_member_ids' => :'notifyMemberIds', :'notify_team_keys' => :'notifyTeamKeys', :'source' => :'source', :'included_actions' => :'includedActions', :'excluded_actions' => :'excludedActions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 84 def self.openapi_types { :'comment' => :'String', :'description' => :'String', :'notify_member_ids' => :'Array<String>', :'notify_team_keys' => :'Array<String>', :'source' => :'SourceFlag', :'included_actions' => :'Array<String>', :'excluded_actions' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 206 def ==(o) return true if self.equal?(o) self.class == o.class && comment == o.comment && description == o.description && notify_member_ids == o.notify_member_ids && notify_team_keys == o.notify_team_keys && source == o.source && included_actions == o.included_actions && excluded_actions == o.excluded_actions end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 226 def hash [comment, description, notify_member_ids, notify_team_keys, source, included_actions, excluded_actions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 161 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 255 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
177 178 179 180 181 182 |
# File 'lib/launchdarkly_api/models/create_copy_flag_config_approval_request_request.rb', line 177 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @description.nil? return false if @source.nil? true end |