Class: LaunchDarklyApi::CreateReleasePipelineInput

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/create_release_pipeline_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ CreateReleasePipelineInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CreateReleasePipelineInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CreateReleasePipelineInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'phases')
    if (value = attributes[:'phases']).is_a?(Array)
      self.phases = value
    end
  else
    self.phases = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'is_project_default')
    self.is_project_default = attributes[:'is_project_default']
  end

  if attributes.key?(:'is_legacy')
    self.is_legacy = attributes[:'is_legacy']
  end
end

Instance Attribute Details

#descriptionObject

The release pipeline description



19
20
21
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 19

def description
  @description
end

#is_legacyObject

Whether or not the pipeline is enabled for Release Automation.



37
38
39
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 37

def is_legacy
  @is_legacy
end

#is_project_defaultObject

Whether or not the newly created pipeline should be set as the default pipeline for this project



34
35
36
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 34

def is_project_default
  @is_project_default
end

#keyObject

The unique identifier of this release pipeline



22
23
24
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 22

def key
  @key
end

#nameObject

The name of the release pipeline



25
26
27
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 25

def name
  @name
end

#phasesObject

A logical grouping of one or more environments that share attributes for rolling out changes



28
29
30
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 28

def phases
  @phases
end

#tagsObject

A list of tags for this release pipeline



31
32
33
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 31

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 40

def self.attribute_map
  {
    :'description' => :'description',
    :'key' => :'key',
    :'name' => :'name',
    :'phases' => :'phases',
    :'tags' => :'tags',
    :'is_project_default' => :'isProjectDefault',
    :'is_legacy' => :'isLegacy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 225

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 63

def self.openapi_types
  {
    :'description' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'phases' => :'Array<CreatePhaseInput>',
    :'tags' => :'Array<String>',
    :'is_project_default' => :'Boolean',
    :'is_legacy' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      description == o.description &&
      key == o.key &&
      name == o.name &&
      phases == o.phases &&
      tags == o.tags &&
      is_project_default == o.is_project_default &&
      is_legacy == o.is_legacy
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


212
213
214
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 212

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



218
219
220
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 218

def hash
  [description, key, name, phases, tags, is_project_default, is_legacy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @phases.nil?
    invalid_properties.push('invalid value for "phases", phases cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



247
248
249
250
251
252
253
254
255
256
257
258
259
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 247

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
# File 'lib/launchdarkly_api/models/create_release_pipeline_input.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @phases.nil?
  true
end