Class: LaunchDarklyApi::DependentExperimentRep

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/dependent_experiment_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DependentExperimentRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::DependentExperimentRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::DependentExperimentRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'environment_id')
    self.environment_id = attributes[:'environment_id']
  else
    self.environment_id = nil
  end

  if attributes.key?(:'environment_key')
    self.environment_key = attributes[:'environment_key']
  else
    self.environment_key = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'archived_date')
    self.archived_date = attributes[:'archived_date']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end
end

Instance Attribute Details

The location and content type of related resources



35
36
37
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 35

def _links
  @_links
end

#archived_dateObject

Returns the value of attribute archived_date.



32
33
34
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 32

def archived_date
  @archived_date
end

#creation_dateObject

Returns the value of attribute creation_date.



30
31
32
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 30

def creation_date
  @creation_date
end

#environment_idObject

The environment ID



25
26
27
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 25

def environment_id
  @environment_id
end

#environment_keyObject

The environment key



28
29
30
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 28

def environment_key
  @environment_key
end

#keyObject

The experiment key



19
20
21
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 19

def key
  @key
end

#nameObject

The experiment name



22
23
24
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 22

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 38

def self.attribute_map
  {
    :'key' => :'key',
    :'name' => :'name',
    :'environment_id' => :'environmentId',
    :'environment_key' => :'environmentKey',
    :'creation_date' => :'creationDate',
    :'archived_date' => :'archivedDate',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 272

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 61

def self.openapi_types
  {
    :'key' => :'String',
    :'name' => :'String',
    :'environment_id' => :'String',
    :'environment_key' => :'String',
    :'creation_date' => :'Integer',
    :'archived_date' => :'Integer',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      name == o.name &&
      environment_id == o.environment_id &&
      environment_key == o.environment_key &&
      creation_date == o.creation_date &&
      archived_date == o.archived_date &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


259
260
261
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 259

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



265
266
267
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 265

def hash
  [key, name, environment_id, environment_key, creation_date, archived_date, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 140

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @environment_id.nil?
    invalid_properties.push('invalid value for "environment_id", environment_id cannot be nil.')
  end

  if @environment_key.nil?
    invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 294

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



172
173
174
175
176
177
178
179
180
181
# File 'lib/launchdarkly_api/models/dependent_experiment_rep.rb', line 172

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @environment_id.nil?
  return false if @environment_key.nil?
  return false if @creation_date.nil?
  return false if @_links.nil?
  true
end