Class: LaunchDarklyApi::DependentMetricOrMetricGroupRep

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ DependentMetricOrMetricGroupRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 125

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::DependentMetricOrMetricGroupRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::DependentMetricOrMetricGroupRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'_version_id')
    self._version_id = attributes[:'_version_id']
  else
    self._version_id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'is_numeric')
    self.is_numeric = attributes[:'is_numeric']
  end

  if attributes.key?(:'event_key')
    self.event_key = attributes[:'event_key']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'is_group')
    self.is_group = attributes[:'is_group']
  else
    self.is_group = nil
  end

  if attributes.key?(:'metrics')
    if (value = attributes[:'metrics']).is_a?(Array)
      self.metrics = value
    end
  end

  if attributes.key?(:'analysis_type')
    self.analysis_type = attributes[:'analysis_type']
  end

  if attributes.key?(:'analysis_unit')
    self.analysis_unit = attributes[:'analysis_unit']
  end
end

Instance Attribute Details

The location and content type of related resources



37
38
39
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 37

def _links
  @_links
end

#_version_idObject

The version ID of the metric or metric group



22
23
24
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 22

def _version_id
  @_version_id
end

#analysis_typeObject

The method for analyzing metric events. Only set for individual metrics, not metric groups.



46
47
48
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 46

def analysis_type
  @analysis_type
end

#analysis_unitObject

The context kind chosen as the analysis unit for this metric in the iteration. If null, analysis uses the iteration's randomization unit.



49
50
51
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 49

def analysis_unit
  @analysis_unit
end

#event_keyObject

The event key sent with the metric. Only relevant for custom metrics.



34
35
36
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 34

def event_key
  @event_key
end

#is_groupObject

Whether this is a metric group or a metric



40
41
42
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 40

def is_group
  @is_group
end

#is_numericObject

For custom and trace metrics, whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false).



31
32
33
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 31

def is_numeric
  @is_numeric
end

#keyObject

A unique key to reference the metric or metric group



19
20
21
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 19

def key
  @key
end

#kindObject

If this is a metric, then it represents the kind of event the metric tracks. If this is a metric group, then it represents the group type



28
29
30
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 28

def kind
  @kind
end

#metricsObject

An ordered list of the metrics in this metric group



43
44
45
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 43

def metrics
  @metrics
end

#nameObject

A human-friendly name for the metric or metric group



25
26
27
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 25

def name
  @name
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



91
92
93
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 91

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



96
97
98
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 96

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 74

def self.attribute_map
  {
    :'key' => :'key',
    :'_version_id' => :'_versionId',
    :'name' => :'name',
    :'kind' => :'kind',
    :'is_numeric' => :'isNumeric',
    :'event_key' => :'eventKey',
    :'_links' => :'_links',
    :'is_group' => :'isGroup',
    :'metrics' => :'metrics',
    :'analysis_type' => :'analysisType',
    :'analysis_unit' => :'analysisUnit'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 352

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



118
119
120
121
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 118

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 101

def self.openapi_types
  {
    :'key' => :'String',
    :'_version_id' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'is_numeric' => :'Boolean',
    :'event_key' => :'String',
    :'_links' => :'Hash<String, Link>',
    :'is_group' => :'Boolean',
    :'metrics' => :'Array<MetricInGroupRep>',
    :'analysis_type' => :'String',
    :'analysis_unit' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 321

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      _version_id == o._version_id &&
      name == o.name &&
      kind == o.kind &&
      is_numeric == o.is_numeric &&
      event_key == o.event_key &&
      _links == o._links &&
      is_group == o.is_group &&
      metrics == o.metrics &&
      analysis_type == o.analysis_type &&
      analysis_unit == o.analysis_unit
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


339
340
341
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 339

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



345
346
347
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 345

def hash
  [key, _version_id, name, kind, is_numeric, event_key, _links, is_group, metrics, analysis_type, analysis_unit].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 202

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @_version_id.nil?
    invalid_properties.push('invalid value for "_version_id", _version_id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @is_group.nil?
    invalid_properties.push('invalid value for "is_group", is_group cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



374
375
376
377
378
379
380
381
382
383
384
385
386
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 374

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



234
235
236
237
238
239
240
241
242
243
244
245
246
247
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 234

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @_version_id.nil?
  return false if @name.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom", "trace", "funnel", "standard"])
  return false unless kind_validator.valid?(@kind)
  return false if @_links.nil?
  return false if @is_group.nil?
  analysis_type_validator = EnumAttributeValidator.new('String', ["mean", "percentile"])
  return false unless analysis_type_validator.valid?(@analysis_type)
  true
end