Class: LaunchDarklyApi::Destination
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::Destination
- Defined in:
- lib/launchdarkly_api/models/destination.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_id ⇒ Object
The ID of this Data Export destination.
-
#_links ⇒ Object
The location and content type of related resources.
-
#completed_artifacts ⇒ Object
Returns the value of attribute completed_artifacts.
-
#config ⇒ Object
An object with the configuration parameters required for the destination type.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#kind ⇒ Object
The type of Data Export destination.
-
#maintainer_id ⇒ Object
The ID of the member who maintains this Data Export destination.
-
#name ⇒ Object
A human-readable name for your Data Export destination.
-
#on ⇒ Object
Whether the export is on, that is, the status of the integration.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Destination
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Destination
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/launchdarkly_api/models/destination.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Destination` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Destination`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'config') self.config = attributes[:'config'] end if attributes.key?(:'on') self.on = attributes[:'on'] end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'completed_artifacts') self.completed_artifacts = attributes[:'completed_artifacts'] end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
43 44 45 |
# File 'lib/launchdarkly_api/models/destination.rb', line 43 def _access @_access end |
#_id ⇒ Object
The ID of this Data Export destination
19 20 21 |
# File 'lib/launchdarkly_api/models/destination.rb', line 19 def _id @_id end |
#_links ⇒ Object
The location and content type of related resources
22 23 24 |
# File 'lib/launchdarkly_api/models/destination.rb', line 22 def _links @_links end |
#completed_artifacts ⇒ Object
Returns the value of attribute completed_artifacts.
45 46 47 |
# File 'lib/launchdarkly_api/models/destination.rb', line 45 def completed_artifacts @completed_artifacts end |
#config ⇒ Object
An object with the configuration parameters required for the destination type
33 34 35 |
# File 'lib/launchdarkly_api/models/destination.rb', line 33 def config @config end |
#created_at ⇒ Object
Returns the value of attribute created_at.
38 39 40 |
# File 'lib/launchdarkly_api/models/destination.rb', line 38 def created_at @created_at end |
#kind ⇒ Object
The type of Data Export destination
28 29 30 |
# File 'lib/launchdarkly_api/models/destination.rb', line 28 def kind @kind end |
#maintainer_id ⇒ Object
The ID of the member who maintains this Data Export destination
41 42 43 |
# File 'lib/launchdarkly_api/models/destination.rb', line 41 def maintainer_id @maintainer_id end |
#name ⇒ Object
A human-readable name for your Data Export destination
25 26 27 |
# File 'lib/launchdarkly_api/models/destination.rb', line 25 def name @name end |
#on ⇒ Object
Whether the export is on, that is, the status of the integration
36 37 38 |
# File 'lib/launchdarkly_api/models/destination.rb', line 36 def on @on end |
#version ⇒ Object
Returns the value of attribute version.
30 31 32 |
# File 'lib/launchdarkly_api/models/destination.rb', line 30 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/launchdarkly_api/models/destination.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/launchdarkly_api/models/destination.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/launchdarkly_api/models/destination.rb', line 70 def self.attribute_map { :'_id' => :'_id', :'_links' => :'_links', :'name' => :'name', :'kind' => :'kind', :'version' => :'version', :'config' => :'config', :'on' => :'on', :'created_at' => :'createdAt', :'maintainer_id' => :'maintainerId', :'_access' => :'_access', :'completed_artifacts' => :'completedArtifacts' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/launchdarkly_api/models/destination.rb', line 243 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 118 |
# File 'lib/launchdarkly_api/models/destination.rb', line 114 def self.openapi_nullable Set.new([ :'config', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/launchdarkly_api/models/destination.rb', line 97 def self.openapi_types { :'_id' => :'String', :'_links' => :'Hash<String, Link>', :'name' => :'String', :'kind' => :'String', :'version' => :'Float', :'config' => :'Object', :'on' => :'Boolean', :'created_at' => :'Integer', :'maintainer_id' => :'String', :'_access' => :'Access', :'completed_artifacts' => :'RedshiftDataExportCompletedArtifactsRep' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/launchdarkly_api/models/destination.rb', line 212 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _links == o._links && name == o.name && kind == o.kind && version == o.version && config == o.config && on == o.on && created_at == o.created_at && maintainer_id == o.maintainer_id && _access == o._access && completed_artifacts == o.completed_artifacts end |
#eql?(o) ⇒ Boolean
230 231 232 |
# File 'lib/launchdarkly_api/models/destination.rb', line 230 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
236 237 238 |
# File 'lib/launchdarkly_api/models/destination.rb', line 236 def hash [_id, _links, name, kind, version, config, on, created_at, maintainer_id, _access, completed_artifacts].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
185 186 187 188 189 |
# File 'lib/launchdarkly_api/models/destination.rb', line 185 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/launchdarkly_api/models/destination.rb', line 265 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 |
# File 'lib/launchdarkly_api/models/destination.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' kind_validator = EnumAttributeValidator.new('String', ["google-pubsub", "kinesis", "mparticle", "segment", "azure-event-hubs", "snowflake-v2", "databricks", "bigquery", "redshift"]) return false unless kind_validator.valid?(@kind) true end |