Class: LaunchDarklyApi::EnvironmentsApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/environments_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ EnvironmentsApi



19
20
21
# File 'lib/launchdarkly_api/api/environments_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_client ⇒ Object

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/environments_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_environment(project_key, environment_key, opts = {}) ⇒ nil

Delete an environment in a specific project.



27
28
29
30
# File 'lib/launchdarkly_api/api/environments_api.rb', line 27

def delete_environment(project_key, environment_key, opts = {})
  delete_environment_with_http_info(project_key, environment_key, opts)
  nil
end

#delete_environment_with_http_info(project_key, environment_key, opts = {}) ⇒ Array<(nil, Fixnum, Hash)>

Delete an environment in a specific project.



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/launchdarkly_api/api/environments_api.rb', line 37

def delete_environment_with_http_info(project_key, environment_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnvironmentsApi.delete_environment ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling EnvironmentsApi.delete_environment"
  end
  # verify the required parameter 'environment_key' is set
  if @api_client.config.client_side_validation && environment_key.nil?
    fail ArgumentError, "Missing the required parameter 'environment_key' when calling EnvironmentsApi.delete_environment"
  end
  # resource path
  local_var_path = '/projects/{projectKey}/environments/{environmentKey}'.sub('{' + 'projectKey' + '}', project_key.to_s).sub('{' + 'environmentKey' + '}', environment_key.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['Token']
  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnvironmentsApi#delete_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_environment(project_key, environment_key, opts = {}) ⇒ Environment

Get an environment given a project and key.



84
85
86
87
# File 'lib/launchdarkly_api/api/environments_api.rb', line 84

def get_environment(project_key, environment_key, opts = {})
  data, _status_code, _headers = get_environment_with_http_info(project_key, environment_key, opts)
  data
end

#get_environment_with_http_info(project_key, environment_key, opts = {}) ⇒ Array<(Environment, Fixnum, Hash)>

Get an environment given a project and key.



94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
# File 'lib/launchdarkly_api/api/environments_api.rb', line 94

def get_environment_with_http_info(project_key, environment_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnvironmentsApi.get_environment ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling EnvironmentsApi.get_environment"
  end
  # verify the required parameter 'environment_key' is set
  if @api_client.config.client_side_validation && environment_key.nil?
    fail ArgumentError, "Missing the required parameter 'environment_key' when calling EnvironmentsApi.get_environment"
  end
  # resource path
  local_var_path = '/projects/{projectKey}/environments/{environmentKey}'.sub('{' + 'projectKey' + '}', project_key.to_s).sub('{' + 'environmentKey' + '}', environment_key.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = nil
  auth_names = ['Token']
  data, status_code, headers = @api_client.call_api(:GET, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Environment')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnvironmentsApi#get_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_environment(project_key, environment_key, patch_delta, opts = {}) ⇒ Environment

Modify an environment by ID.



143
144
145
146
# File 'lib/launchdarkly_api/api/environments_api.rb', line 143

def patch_environment(project_key, environment_key, patch_delta, opts = {})
  data, _status_code, _headers = patch_environment_with_http_info(project_key, environment_key, patch_delta, opts)
  data
end

#patch_environment_with_http_info(project_key, environment_key, patch_delta, opts = {}) ⇒ Array<(Environment, Fixnum, Hash)>

Modify an environment by ID.



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/launchdarkly_api/api/environments_api.rb', line 154

def patch_environment_with_http_info(project_key, environment_key, patch_delta, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnvironmentsApi.patch_environment ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling EnvironmentsApi.patch_environment"
  end
  # verify the required parameter 'environment_key' is set
  if @api_client.config.client_side_validation && environment_key.nil?
    fail ArgumentError, "Missing the required parameter 'environment_key' when calling EnvironmentsApi.patch_environment"
  end
  # verify the required parameter 'patch_delta' is set
  if @api_client.config.client_side_validation && patch_delta.nil?
    fail ArgumentError, "Missing the required parameter 'patch_delta' when calling EnvironmentsApi.patch_environment"
  end
  # resource path
  local_var_path = '/projects/{projectKey}/environments/{environmentKey}'.sub('{' + 'projectKey' + '}', project_key.to_s).sub('{' + 'environmentKey' + '}', environment_key.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(patch_delta)
  auth_names = ['Token']
  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Environment')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnvironmentsApi#patch_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_environment(project_key, environment_body, opts = {}) ⇒ Environment

Create a new environment in a specified project with a given name, key, and swatch color.



206
207
208
209
# File 'lib/launchdarkly_api/api/environments_api.rb', line 206

def post_environment(project_key, environment_body, opts = {})
  data, _status_code, _headers = post_environment_with_http_info(project_key, environment_body, opts)
  data
end

#post_environment_with_http_info(project_key, environment_body, opts = {}) ⇒ Array<(Environment, Fixnum, Hash)>

Create a new environment in a specified project with a given name, key, and swatch color.



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/launchdarkly_api/api/environments_api.rb', line 216

def post_environment_with_http_info(project_key, environment_body, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: EnvironmentsApi.post_environment ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling EnvironmentsApi.post_environment"
  end
  # verify the required parameter 'environment_body' is set
  if @api_client.config.client_side_validation && environment_body.nil?
    fail ArgumentError, "Missing the required parameter 'environment_body' when calling EnvironmentsApi.post_environment"
  end
  # resource path
  local_var_path = '/projects/{projectKey}/environments'.sub('{' + 'projectKey' + '}', project_key.to_s)

  # query parameters
  query_params = {}

  # header parameters
  header_params = {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  header_params['Content-Type'] = @api_client.select_header_content_type(['application/json'])

  # form parameters
  form_params = {}

  # http body (model)
  post_body = @api_client.object_to_http_body(environment_body)
  auth_names = ['Token']
  data, status_code, headers = @api_client.call_api(:POST, local_var_path,
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => 'Environment')
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: EnvironmentsApi#post_environment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end