Class: LaunchDarklyApi::ExpandableApprovalRequestResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/expandable_approval_request_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpandableApprovalRequestResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 193

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandableApprovalRequestResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandableApprovalRequestResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  else
    self._version = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'service_kind')
    self.service_kind = attributes[:'service_kind']
  else
    self.service_kind = nil
  end

  if attributes.key?(:'requestor_id')
    self.requestor_id = attributes[:'requestor_id']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'review_status')
    self.review_status = attributes[:'review_status']
  else
    self.review_status = nil
  end

  if attributes.key?(:'all_reviews')
    if (value = attributes[:'all_reviews']).is_a?(Array)
      self.all_reviews = value
    end
  else
    self.all_reviews = nil
  end

  if attributes.key?(:'notify_member_ids')
    if (value = attributes[:'notify_member_ids']).is_a?(Array)
      self.notify_member_ids = value
    end
  else
    self.notify_member_ids = nil
  end

  if attributes.key?(:'applied_date')
    self.applied_date = attributes[:'applied_date']
  end

  if attributes.key?(:'applied_by_member_id')
    self.applied_by_member_id = attributes[:'applied_by_member_id']
  end

  if attributes.key?(:'applied_by_service_token_id')
    self.applied_by_service_token_id = attributes[:'applied_by_service_token_id']
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'instructions')
    if (value = attributes[:'instructions']).is_a?(Array)
      self.instructions = value
    end
  else
    self.instructions = nil
  end

  if attributes.key?(:'conflicts')
    if (value = attributes[:'conflicts']).is_a?(Array)
      self.conflicts = value
    end
  else
    self.conflicts = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'execution_date')
    self.execution_date = attributes[:'execution_date']
  end

  if attributes.key?(:'operating_on_id')
    self.operating_on_id = attributes[:'operating_on_id']
  end

  if attributes.key?(:'integration_metadata')
    self. = attributes[:'integration_metadata']
  end

  if attributes.key?(:'source')
    self.source = attributes[:'source']
  end

  if attributes.key?(:'custom_workflow_metadata')
    self. = attributes[:'custom_workflow_metadata']
  end

  if attributes.key?(:'resource_id')
    self.resource_id = attributes[:'resource_id']
  end

  if attributes.key?(:'approval_settings')
    self.approval_settings = attributes[:'approval_settings']
  end

  if attributes.key?(:'project')
    self.project = attributes[:'project']
  end

  if attributes.key?(:'environments')
    if (value = attributes[:'environments']).is_a?(Array)
      self.environments = value
    end
  end

  if attributes.key?(:'flag')
    self.flag = attributes[:'flag']
  end

  if attributes.key?(:'resource')
    self.resource = attributes[:'resource']
  end
end

Instance Attribute Details

#_idObject

The ID of this approval request



19
20
21
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 19

def _id
  @_id
end

The location and content type of related resources



60
61
62
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 60

def _links
  @_links
end

#_versionObject

Version of the approval request



22
23
24
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 22

def _version
  @_version
end

#all_reviewsObject

An array of individual reviews of this approval request



38
39
40
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 38

def all_reviews
  @all_reviews
end

#applied_by_member_idObject

The member ID of the member who applied the approval request



46
47
48
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 46

def applied_by_member_id
  @applied_by_member_id
end

#applied_by_service_token_idObject

The service token ID of the service token which applied the approval request



49
50
51
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 49

def applied_by_service_token_id
  @applied_by_service_token_id
end

#applied_dateObject

Returns the value of attribute applied_date.



43
44
45
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 43

def applied_date
  @applied_date
end

#approval_settingsObject

Returns the value of attribute approval_settings.



76
77
78
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 76

def approval_settings
  @approval_settings
end

#conflictsObject

Details on any conflicting approval requests



57
58
59
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 57

def conflicts
  @conflicts
end

#creation_dateObject

Returns the value of attribute creation_date.



24
25
26
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 24

def creation_date
  @creation_date
end

#custom_workflow_metadataObject

Returns the value of attribute custom_workflow_metadata.



71
72
73
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 71

def 
  @custom_workflow_metadata
end

#descriptionObject

A human-friendly name for the approval request



32
33
34
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 32

def description
  @description
end

#environmentsObject

List of environments the approval impacts



81
82
83
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 81

def environments
  @environments
end

#execution_dateObject

Returns the value of attribute execution_date.



62
63
64
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 62

def execution_date
  @execution_date
end

#flagObject

Returns the value of attribute flag.



83
84
85
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 83

def flag
  @flag
end

#instructionsObject

Returns the value of attribute instructions.



54
55
56
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 54

def instructions
  @instructions
end

#integration_metadataObject

Returns the value of attribute integration_metadata.



67
68
69
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 67

def 
  @integration_metadata
end

#notify_member_idsObject

An array of member IDs. These members are notified to review the approval request.



41
42
43
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 41

def notify_member_ids
  @notify_member_ids
end

#operating_on_idObject

ID of scheduled change to edit or delete



65
66
67
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 65

def operating_on_id
  @operating_on_id
end

#projectObject

Returns the value of attribute project.



78
79
80
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 78

def project
  @project
end

#requestor_idObject

The ID of the member who requested the approval



29
30
31
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 29

def requestor_id
  @requestor_id
end

#resourceObject

Returns the value of attribute resource.



85
86
87
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 85

def resource
  @resource
end

#resource_idObject

String representation of a resource



74
75
76
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 74

def resource_id
  @resource_id
end

#review_statusObject

Current status of the review of this approval request



35
36
37
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 35

def review_status
  @review_status
end

#service_kindObject

Returns the value of attribute service_kind.



26
27
28
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 26

def service_kind
  @service_kind
end

#sourceObject

Returns the value of attribute source.



69
70
71
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 69

def source
  @source
end

#statusObject

Current status of the approval request



52
53
54
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 52

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



143
144
145
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 143

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



148
149
150
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 148

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 110

def self.attribute_map
  {
    :'_id' => :'_id',
    :'_version' => :'_version',
    :'creation_date' => :'creationDate',
    :'service_kind' => :'serviceKind',
    :'requestor_id' => :'requestorId',
    :'description' => :'description',
    :'review_status' => :'reviewStatus',
    :'all_reviews' => :'allReviews',
    :'notify_member_ids' => :'notifyMemberIds',
    :'applied_date' => :'appliedDate',
    :'applied_by_member_id' => :'appliedByMemberId',
    :'applied_by_service_token_id' => :'appliedByServiceTokenId',
    :'status' => :'status',
    :'instructions' => :'instructions',
    :'conflicts' => :'conflicts',
    :'_links' => :'_links',
    :'execution_date' => :'executionDate',
    :'operating_on_id' => :'operatingOnId',
    :'integration_metadata' => :'integrationMetadata',
    :'source' => :'source',
    :'custom_workflow_metadata' => :'customWorkflowMetadata',
    :'resource_id' => :'resourceId',
    :'approval_settings' => :'approvalSettings',
    :'project' => :'project',
    :'environments' => :'environments',
    :'flag' => :'flag',
    :'resource' => :'resource'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



583
584
585
586
587
588
589
590
591
592
593
594
595
596
597
598
599
600
601
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 583

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



186
187
188
189
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 186

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 153

def self.openapi_types
  {
    :'_id' => :'String',
    :'_version' => :'Integer',
    :'creation_date' => :'Integer',
    :'service_kind' => :'String',
    :'requestor_id' => :'String',
    :'description' => :'String',
    :'review_status' => :'String',
    :'all_reviews' => :'Array<ReviewResponse>',
    :'notify_member_ids' => :'Array<String>',
    :'applied_date' => :'Integer',
    :'applied_by_member_id' => :'String',
    :'applied_by_service_token_id' => :'String',
    :'status' => :'String',
    :'instructions' => :'Array<Hash>',
    :'conflicts' => :'Array<Conflict>',
    :'_links' => :'Hash<String, Object>',
    :'execution_date' => :'Integer',
    :'operating_on_id' => :'String',
    :'integration_metadata' => :'IntegrationMetadata',
    :'source' => :'CopiedFromEnv',
    :'custom_workflow_metadata' => :'CustomWorkflowMeta',
    :'resource_id' => :'String',
    :'approval_settings' => :'ApprovalSettings',
    :'project' => :'Project',
    :'environments' => :'Array<Environment>',
    :'flag' => :'ExpandedFlagRep',
    :'resource' => :'ExpandedResourceRep'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
565
566
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 536

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      _version == o._version &&
      creation_date == o.creation_date &&
      service_kind == o.service_kind &&
      requestor_id == o.requestor_id &&
      description == o.description &&
      review_status == o.review_status &&
      all_reviews == o.all_reviews &&
      notify_member_ids == o.notify_member_ids &&
      applied_date == o.applied_date &&
      applied_by_member_id == o.applied_by_member_id &&
      applied_by_service_token_id == o.applied_by_service_token_id &&
      status == o.status &&
      instructions == o.instructions &&
      conflicts == o.conflicts &&
      _links == o._links &&
      execution_date == o.execution_date &&
      operating_on_id == o.operating_on_id &&
       == o. &&
      source == o.source &&
       == o. &&
      resource_id == o.resource_id &&
      approval_settings == o.approval_settings &&
      project == o.project &&
      environments == o.environments &&
      flag == o.flag &&
      resource == o.resource
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


570
571
572
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 570

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



576
577
578
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 576

def hash
  [_id, _version, creation_date, service_kind, requestor_id, description, review_status, all_reviews, notify_member_ids, applied_date, applied_by_member_id, applied_by_service_token_id, status, instructions, conflicts, _links, execution_date, operating_on_id, , source, , resource_id, approval_settings, project, environments, flag, resource].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 352

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @service_kind.nil?
    invalid_properties.push('invalid value for "service_kind", service_kind cannot be nil.')
  end

  if @review_status.nil?
    invalid_properties.push('invalid value for "review_status", review_status cannot be nil.')
  end

  if @all_reviews.nil?
    invalid_properties.push('invalid value for "all_reviews", all_reviews cannot be nil.')
  end

  if @notify_member_ids.nil?
    invalid_properties.push('invalid value for "notify_member_ids", notify_member_ids cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @instructions.nil?
    invalid_properties.push('invalid value for "instructions", instructions cannot be nil.')
  end

  if @conflicts.nil?
    invalid_properties.push('invalid value for "conflicts", conflicts cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



605
606
607
608
609
610
611
612
613
614
615
616
617
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 605

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
# File 'lib/launchdarkly_api/models/expandable_approval_request_response.rb', line 404

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @_version.nil?
  return false if @creation_date.nil?
  return false if @service_kind.nil?
  return false if @review_status.nil?
  review_status_validator = EnumAttributeValidator.new('String', ["approved", "declined", "pending"])
  return false unless review_status_validator.valid?(@review_status)
  return false if @all_reviews.nil?
  return false if @notify_member_ids.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["pending", "completed", "failed", "scheduled"])
  return false unless status_validator.valid?(@status)
  return false if @instructions.nil?
  return false if @conflicts.nil?
  return false if @_links.nil?
  true
end