Class: LaunchDarklyApi::ExpandedFlag
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ExpandedFlag
- Defined in:
- lib/launchdarkly_api/models/expanded_flag.rb
Overview
Flag representation for Views API - contains only fields actually used by the Views service
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_version ⇒ Object
Version of the flag.
-
#archived ⇒ Object
Whether the flag is archived.
-
#creation_date ⇒ Object
Creation date in milliseconds.
-
#description ⇒ Object
Description of the flag.
-
#include_in_snippet ⇒ Object
Whether to include in snippet.
-
#key ⇒ Object
A unique key used to reference the flag.
-
#maintainer ⇒ Object
Returns the value of attribute maintainer.
-
#name ⇒ Object
A human-friendly name for the flag.
-
#tags ⇒ Object
Tags for the flag.
-
#temporary ⇒ Object
Whether the flag is temporary.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpandedFlag
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExpandedFlag
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandedFlag` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandedFlag`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'_version') self._version = attributes[:'_version'] end if attributes.key?(:'archived') self.archived = attributes[:'archived'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'temporary') self.temporary = attributes[:'temporary'] end if attributes.key?(:'include_in_snippet') self.include_in_snippet = attributes[:'include_in_snippet'] end if attributes.key?(:'maintainer') self.maintainer = attributes[:'maintainer'] end if attributes.key?(:'_links') self._links = attributes[:'_links'] end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
48 49 50 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 48 def _links @_links end |
#_version ⇒ Object
Version of the flag
32 33 34 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 32 def _version @_version end |
#archived ⇒ Object
Whether the flag is archived
35 36 37 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 35 def archived @archived end |
#creation_date ⇒ Object
Creation date in milliseconds
29 30 31 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 29 def creation_date @creation_date end |
#description ⇒ Object
Description of the flag
26 27 28 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 26 def description @description end |
#include_in_snippet ⇒ Object
Whether to include in snippet
44 45 46 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 44 def include_in_snippet @include_in_snippet end |
#key ⇒ Object
A unique key used to reference the flag
20 21 22 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 20 def key @key end |
#maintainer ⇒ Object
Returns the value of attribute maintainer.
46 47 48 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 46 def maintainer @maintainer end |
#name ⇒ Object
A human-friendly name for the flag
23 24 25 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 23 def name @name end |
#tags ⇒ Object
Tags for the flag
38 39 40 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 38 def @tags end |
#temporary ⇒ Object
Whether the flag is temporary
41 42 43 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 41 def temporary @temporary end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 51 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'description' => :'description', :'creation_date' => :'creationDate', :'_version' => :'_version', :'archived' => :'archived', :'tags' => :'tags', :'temporary' => :'temporary', :'include_in_snippet' => :'includeInSnippet', :'maintainer' => :'maintainer', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 245 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 78 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'description' => :'String', :'creation_date' => :'Integer', :'_version' => :'Integer', :'archived' => :'Boolean', :'tags' => :'Array<String>', :'temporary' => :'Boolean', :'include_in_snippet' => :'Boolean', :'maintainer' => :'ExpandedFlagMaintainer', :'_links' => :'ParentAndSelfLinks' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 214 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && description == o.description && creation_date == o.creation_date && _version == o._version && archived == o.archived && == o. && temporary == o.temporary && include_in_snippet == o.include_in_snippet && maintainer == o.maintainer && _links == o._links end |
#eql?(o) ⇒ Boolean
232 233 234 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 232 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
238 239 240 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 238 def hash [key, name, description, creation_date, _version, archived, , temporary, include_in_snippet, maintainer, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 267 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 189 190 |
# File 'lib/launchdarkly_api/models/expanded_flag.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? true end |