Class: LaunchDarklyApi::ExpandedFlagMaintainer

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/expanded_flag_maintainer.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpandedFlagMaintainer

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandedFlagMaintainer` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandedFlagMaintainer`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'_member')
    self._member = attributes[:'_member']
  end

  if attributes.key?(:'_team')
    self._team = attributes[:'_team']
  end
end

Instance Attribute Details

#_memberObject

Returns the value of attribute _member.



24
25
26
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 24

def _member
  @_member
end

#_teamObject

Returns the value of attribute _team.



26
27
28
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 26

def _team
  @_team
end

#keyObject

The ID of the maintainer member, or the key of the maintainer team



19
20
21
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 19

def key
  @key
end

#kindObject

The type of the maintainer



22
23
24
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 22

def kind
  @kind
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



61
62
63
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 61

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



66
67
68
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 66

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



51
52
53
54
55
56
57
58
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 51

def self.attribute_map
  {
    :'key' => :'key',
    :'kind' => :'kind',
    :'_member' => :'_member',
    :'_team' => :'_team'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



71
72
73
74
75
76
77
78
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 71

def self.openapi_types
  {
    :'key' => :'String',
    :'kind' => :'String',
    :'_member' => :'ViewsMemberSummary',
    :'_team' => :'ViewsMemberTeamSummaryRep'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



172
173
174
175
176
177
178
179
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 172

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      kind == o.kind &&
      _member == o._member &&
      _team == o._team
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 189

def hash
  [key, kind, _member, _team].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
147
148
# File 'lib/launchdarkly_api/models/expanded_flag_maintainer.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["member", "team"])
  return false unless kind_validator.valid?(@kind)
  true
end