Class: LaunchDarklyApi::ExpandedResourceRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ExpandedResourceRep
- Defined in:
- lib/launchdarkly_api/models/expanded_resource_rep.rb
Instance Attribute Summary collapse
-
#ai_config ⇒ Object
Returns the value of attribute ai_config.
-
#flag ⇒ Object
Returns the value of attribute flag.
-
#kind ⇒ Object
The type of resource.
-
#segment ⇒ Object
Returns the value of attribute segment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpandedResourceRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExpandedResourceRep
Initializes the object
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 65 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandedResourceRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandedResourceRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'ai_config') self.ai_config = attributes[:'ai_config'] end if attributes.key?(:'flag') self.flag = attributes[:'flag'] end if attributes.key?(:'segment') self.segment = attributes[:'segment'] end end |
Instance Attribute Details
#ai_config ⇒ Object
Returns the value of attribute ai_config.
21 22 23 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 21 def ai_config @ai_config end |
#flag ⇒ Object
Returns the value of attribute flag.
23 24 25 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 23 def flag @flag end |
#kind ⇒ Object
The type of resource
19 20 21 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 19 def kind @kind end |
#segment ⇒ Object
Returns the value of attribute segment.
25 26 27 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 25 def segment @segment end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
38 39 40 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 38 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
43 44 45 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 43 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
28 29 30 31 32 33 34 35 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 28 def self.attribute_map { :'kind' => :'kind', :'ai_config' => :'aiConfig', :'flag' => :'flag', :'segment' => :'segment' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 154 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
58 59 60 61 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 58 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
48 49 50 51 52 53 54 55 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 48 def self.openapi_types { :'kind' => :'String', :'ai_config' => :'AIConfigRep', :'flag' => :'ExpandedFlagRep', :'segment' => :'UserSegment' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
130 131 132 133 134 135 136 137 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 130 def ==(o) return true if self.equal?(o) self.class == o.class && kind == o.kind && ai_config == o.ai_config && flag == o.flag && segment == o.segment end |
#eql?(o) ⇒ Boolean
141 142 143 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 141 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
147 148 149 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 147 def hash [kind, ai_config, flag, segment].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
100 101 102 103 104 105 106 107 108 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 100 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 176 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 116 |
# File 'lib/launchdarkly_api/models/expanded_resource_rep.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kind.nil? true end |