Class: LaunchDarklyApi::ExperimentsBetaApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ExperimentsBetaApi
- Defined in:
- lib/launchdarkly_api/api/experiments_beta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_experiment(project_key, environment_key, experiment_post, opts = {}) ⇒ Experiment
Create experiment Create an experiment.
-
#create_experiment_with_http_info(project_key, environment_key, experiment_post, opts = {}) ⇒ Array<(Experiment, Integer, Hash)>
Create experiment Create an experiment.
-
#create_iteration(project_key, environment_key, experiment_key, iteration_input, opts = {}) ⇒ IterationRep
Create iteration Create an experiment iteration.
-
#create_iteration_with_http_info(project_key, environment_key, experiment_key, iteration_input, opts = {}) ⇒ Array<(IterationRep, Integer, Hash)>
Create iteration Create an experiment iteration.
-
#get_experiment(project_key, environment_key, experiment_key, opts = {}) ⇒ Experiment
Get experiment Get details about an experiment.
-
#get_experiment_results(project_key, environment_key, experiment_key, metric_key, opts = {}) ⇒ ExperimentBayesianResultsRep
Get experiment results Get results from an experiment for a particular metric.
-
#get_experiment_results_for_metric_group(project_key, environment_key, experiment_key, metric_group_key, opts = {}) ⇒ MetricGroupResultsRep
Get experiment results for metric group Get results from an experiment for a particular metric group.
-
#get_experiment_results_for_metric_group_with_http_info(project_key, environment_key, experiment_key, metric_group_key, opts = {}) ⇒ Array<(MetricGroupResultsRep, Integer, Hash)>
Get experiment results for metric group Get results from an experiment for a particular metric group.
-
#get_experiment_results_with_http_info(project_key, environment_key, experiment_key, metric_key, opts = {}) ⇒ Array<(ExperimentBayesianResultsRep, Integer, Hash)>
Get experiment results Get results from an experiment for a particular metric.
-
#get_experiment_with_http_info(project_key, environment_key, experiment_key, opts = {}) ⇒ Array<(Experiment, Integer, Hash)>
Get experiment Get details about an experiment.
-
#get_experimentation_settings(project_key, opts = {}) ⇒ RandomizationSettingsRep
Get experimentation settings Get current experimentation settings for the given project.
-
#get_experimentation_settings_with_http_info(project_key, opts = {}) ⇒ Array<(RandomizationSettingsRep, Integer, Hash)>
Get experimentation settings Get current experimentation settings for the given project.
-
#get_experiments(project_key, environment_key, opts = {}) ⇒ ExperimentCollectionRep
Get experiments Get details about all experiments in an environment.
-
#get_experiments_with_http_info(project_key, environment_key, opts = {}) ⇒ Array<(ExperimentCollectionRep, Integer, Hash)>
Get experiments Get details about all experiments in an environment.
-
#get_legacy_experiment_results(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ ExperimentResults
Get legacy experiment results (deprecated) Get detailed experiment result data for legacy experiments.
-
#get_legacy_experiment_results_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ Array<(ExperimentResults, Integer, Hash)>
Get legacy experiment results (deprecated) Get detailed experiment result data for legacy experiments.
-
#initialize(api_client = ApiClient.default) ⇒ ExperimentsBetaApi
constructor
A new instance of ExperimentsBetaApi.
-
#patch_experiment(project_key, environment_key, experiment_key, experiment_patch_input, opts = {}) ⇒ Experiment
Patch experiment Update an experiment.
-
#patch_experiment_with_http_info(project_key, environment_key, experiment_key, experiment_patch_input, opts = {}) ⇒ Array<(Experiment, Integer, Hash)>
Patch experiment Update an experiment.
-
#put_experimentation_settings(project_key, randomization_settings_put, opts = {}) ⇒ RandomizationSettingsRep
Update experimentation settings Update experimentation settings for the given project.
-
#put_experimentation_settings_with_http_info(project_key, randomization_settings_put, opts = {}) ⇒ Array<(RandomizationSettingsRep, Integer, Hash)>
Update experimentation settings Update experimentation settings for the given project.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ExperimentsBetaApi
Returns a new instance of ExperimentsBetaApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_experiment(project_key, environment_key, experiment_post, opts = {}) ⇒ Experiment
Create experiment Create an experiment. To run this experiment, you’ll need to [create an iteration](/tag/Experiments-(beta)#operation/createIteration) and then [update the experiment](/tag/Experiments-(beta)#operation/patchExperiment) with the ‘startIteration` instruction. To learn more, read [Creating experiments](docs.launchdarkly.com/home/creating-experiments).
29 30 31 32 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 29 def create_experiment(project_key, environment_key, experiment_post, opts = {}) data, _status_code, _headers = create_experiment_with_http_info(project_key, environment_key, experiment_post, opts) data end |
#create_experiment_with_http_info(project_key, environment_key, experiment_post, opts = {}) ⇒ Array<(Experiment, Integer, Hash)>
Create experiment Create an experiment. To run this experiment, you'll need to [create an iteration](/tag/Experiments-(beta)#operation/createIteration) and then [update the experiment](/tag/Experiments-(beta)#operation/patchExperiment) with the `startIteration` instruction. To learn more, read [Creating experiments](docs.launchdarkly.com/home/creating-experiments).
41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 41 def create_experiment_with_http_info(project_key, environment_key, experiment_post, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.create_experiment ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.create_experiment" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.create_experiment" end # verify the required parameter 'experiment_post' is set if @api_client.config.client_side_validation && experiment_post.nil? fail ArgumentError, "Missing the required parameter 'experiment_post' when calling ExperimentsBetaApi.create_experiment" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(experiment_post) # return_type return_type = opts[:debug_return_type] || 'Experiment' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.create_experiment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#create_experiment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_iteration(project_key, environment_key, experiment_key, iteration_input, opts = {}) ⇒ IterationRep
Create iteration Create an experiment iteration. Experiment iterations let you record experiments in individual blocks of time. Initially, iterations are created with a status of ‘not_started` and appear in the `draftIteration` field of an experiment. To start or stop an iteration, [update the experiment](/tag/Experiments-(beta)#operation/patchExperiment) with the `startIteration` or `stopIteration` instruction. To learn more, read [Starting experiment iterations](docs.launchdarkly.com/home/creating-experiments#starting-experiment-iterations).
110 111 112 113 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 110 def create_iteration(project_key, environment_key, experiment_key, iteration_input, opts = {}) data, _status_code, _headers = create_iteration_with_http_info(project_key, environment_key, experiment_key, iteration_input, opts) data end |
#create_iteration_with_http_info(project_key, environment_key, experiment_key, iteration_input, opts = {}) ⇒ Array<(IterationRep, Integer, Hash)>
Create iteration Create an experiment iteration. Experiment iterations let you record experiments in individual blocks of time. Initially, iterations are created with a status of `not_started` and appear in the `draftIteration` field of an experiment. To start or stop an iteration, [update the experiment](/tag/Experiments-(beta)#operation/patchExperiment) with the `startIteration` or `stopIteration` instruction. To learn more, read [Starting experiment iterations](docs.launchdarkly.com/home/creating-experiments#starting-experiment-iterations).
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 123 def create_iteration_with_http_info(project_key, environment_key, experiment_key, iteration_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.create_iteration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.create_iteration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.create_iteration" end # verify the required parameter 'experiment_key' is set if @api_client.config.client_side_validation && experiment_key.nil? fail ArgumentError, "Missing the required parameter 'experiment_key' when calling ExperimentsBetaApi.create_iteration" end # verify the required parameter 'iteration_input' is set if @api_client.config.client_side_validation && iteration_input.nil? fail ArgumentError, "Missing the required parameter 'iteration_input' when calling ExperimentsBetaApi.create_iteration" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments/{experimentKey}/iterations'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'experimentKey' + '}', CGI.escape(experiment_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(iteration_input) # return_type return_type = opts[:debug_return_type] || 'IterationRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.create_iteration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#create_iteration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_experiment(project_key, environment_key, experiment_key, opts = {}) ⇒ Experiment
Get experiment Get details about an experiment. ### Expanding the experiment response LaunchDarkly supports four fields for expanding the "Get experiment" response. By default, these fields are not included in the response. To expand the response, append the ‘expand` query parameter and add a comma-separated list with any of the following fields: - `previousIterations` includes all iterations prior to the current iteration. By default only the current iteration is included in the response. - `draftIteration` includes the iteration which has not been started yet, if any. - `secondaryMetrics` includes secondary metrics. By default only the primary metric is included in the response. - `treatments` includes all treatment and parameter details. By default treatment data is not included in the response. For example, `expand=draftIteration,treatments` includes the `draftIteration` and `treatments` fields in the response. If fields that you request with the `expand` query parameter are empty, they are not included in the response.
196 197 198 199 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 196 def get_experiment(project_key, environment_key, experiment_key, opts = {}) data, _status_code, _headers = get_experiment_with_http_info(project_key, environment_key, experiment_key, opts) data end |
#get_experiment_results(project_key, environment_key, experiment_key, metric_key, opts = {}) ⇒ ExperimentBayesianResultsRep
Get experiment results Get results from an experiment for a particular metric. LaunchDarkly supports one field for expanding the "Get experiment results" response. By default, this field is not included in the response. To expand the response, append the ‘expand` query parameter with the following field: * `traffic` includes the total count of units for each treatment. For example, `expand=traffic` includes the `traffic` field for the project in the response.
276 277 278 279 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 276 def get_experiment_results(project_key, environment_key, experiment_key, metric_key, opts = {}) data, _status_code, _headers = get_experiment_results_with_http_info(project_key, environment_key, experiment_key, metric_key, opts) data end |
#get_experiment_results_for_metric_group(project_key, environment_key, experiment_key, metric_group_key, opts = {}) ⇒ MetricGroupResultsRep
Get experiment results for metric group Get results from an experiment for a particular metric group.
362 363 364 365 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 362 def get_experiment_results_for_metric_group(project_key, environment_key, experiment_key, metric_group_key, opts = {}) data, _status_code, _headers = get_experiment_results_for_metric_group_with_http_info(project_key, environment_key, experiment_key, metric_group_key, opts) data end |
#get_experiment_results_for_metric_group_with_http_info(project_key, environment_key, experiment_key, metric_group_key, opts = {}) ⇒ Array<(MetricGroupResultsRep, Integer, Hash)>
Get experiment results for metric group Get results from an experiment for a particular metric group.
376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 376 def get_experiment_results_for_metric_group_with_http_info(project_key, environment_key, experiment_key, metric_group_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_experiment_results_for_metric_group ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_experiment_results_for_metric_group" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.get_experiment_results_for_metric_group" end # verify the required parameter 'experiment_key' is set if @api_client.config.client_side_validation && experiment_key.nil? fail ArgumentError, "Missing the required parameter 'experiment_key' when calling ExperimentsBetaApi.get_experiment_results_for_metric_group" end # verify the required parameter 'metric_group_key' is set if @api_client.config.client_side_validation && metric_group_key.nil? fail ArgumentError, "Missing the required parameter 'metric_group_key' when calling ExperimentsBetaApi.get_experiment_results_for_metric_group" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments/{experimentKey}/metric-groups/{metricGroupKey}/results'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'experimentKey' + '}', CGI.escape(experiment_key.to_s)).sub('{' + 'metricGroupKey' + '}', CGI.escape(metric_group_key.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'iterationId'] = opts[:'iteration_id'] if !opts[:'iteration_id'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'MetricGroupResultsRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.get_experiment_results_for_metric_group", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_experiment_results_for_metric_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_experiment_results_with_http_info(project_key, environment_key, experiment_key, metric_key, opts = {}) ⇒ Array<(ExperimentBayesianResultsRep, Integer, Hash)>
Get experiment results Get results from an experiment for a particular metric. LaunchDarkly supports one field for expanding the "Get experiment results" response. By default, this field is not included in the response. To expand the response, append the `expand` query parameter with the following field: * `traffic` includes the total count of units for each treatment. For example, `expand=traffic` includes the `traffic` field for the project in the response.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 291 def get_experiment_results_with_http_info(project_key, environment_key, experiment_key, metric_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_experiment_results ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_experiment_results" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.get_experiment_results" end # verify the required parameter 'experiment_key' is set if @api_client.config.client_side_validation && experiment_key.nil? fail ArgumentError, "Missing the required parameter 'experiment_key' when calling ExperimentsBetaApi.get_experiment_results" end # verify the required parameter 'metric_key' is set if @api_client.config.client_side_validation && metric_key.nil? fail ArgumentError, "Missing the required parameter 'metric_key' when calling ExperimentsBetaApi.get_experiment_results" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments/{experimentKey}/metrics/{metricKey}/results'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'experimentKey' + '}', CGI.escape(experiment_key.to_s)).sub('{' + 'metricKey' + '}', CGI.escape(metric_key.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'iterationId'] = opts[:'iteration_id'] if !opts[:'iteration_id'].nil? query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExperimentBayesianResultsRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.get_experiment_results", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_experiment_results\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_experiment_with_http_info(project_key, environment_key, experiment_key, opts = {}) ⇒ Array<(Experiment, Integer, Hash)>
Get experiment Get details about an experiment. ### Expanding the experiment response LaunchDarkly supports four fields for expanding the "Get experiment" response. By default, these fields are not included in the response. To expand the response, append the `expand` query parameter and add a comma-separated list with any of the following fields: - `previousIterations` includes all iterations prior to the current iteration. By default only the current iteration is included in the response. - `draftIteration` includes the iteration which has not been started yet, if any. - `secondaryMetrics` includes secondary metrics. By default only the primary metric is included in the response. - `treatments` includes all treatment and parameter details. By default treatment data is not included in the response. For example, `expand=draftIteration,treatments` includes the `draftIteration` and `treatments` fields in the response. If fields that you request with the `expand` query parameter are empty, they are not included in the response.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 209 def get_experiment_with_http_info(project_key, environment_key, experiment_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_experiment ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_experiment" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.get_experiment" end # verify the required parameter 'experiment_key' is set if @api_client.config.client_side_validation && experiment_key.nil? fail ArgumentError, "Missing the required parameter 'experiment_key' when calling ExperimentsBetaApi.get_experiment" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments/{experimentKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'experimentKey' + '}', CGI.escape(experiment_key.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Experiment' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.get_experiment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_experiment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_experimentation_settings(project_key, opts = {}) ⇒ RandomizationSettingsRep
Get experimentation settings Get current experimentation settings for the given project
442 443 444 445 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 442 def get_experimentation_settings(project_key, opts = {}) data, _status_code, _headers = get_experimentation_settings_with_http_info(project_key, opts) data end |
#get_experimentation_settings_with_http_info(project_key, opts = {}) ⇒ Array<(RandomizationSettingsRep, Integer, Hash)>
Get experimentation settings Get current experimentation settings for the given project
452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 491 492 493 494 495 496 497 498 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 452 def get_experimentation_settings_with_http_info(project_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_experimentation_settings ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_experimentation_settings" end # resource path local_var_path = '/api/v2/projects/{projectKey}/experimentation-settings'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RandomizationSettingsRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.get_experimentation_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_experimentation_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_experiments(project_key, environment_key, opts = {}) ⇒ ExperimentCollectionRep
Get experiments Get details about all experiments in an environment. ### Filtering experiments LaunchDarkly supports the ‘filter` query param for filtering, with the following fields: - `flagKey` filters for only experiments that use the flag with the given key. - `metricKey` filters for only experiments that use the metric with the given key. - `status` filters for only experiments with an iteration with the given status. An iteration can have the status `not_started`, `running` or `stopped`. For example, `filter=flagKey:my-flag,status:running,metricKey:page-load-ms` filters for experiments for the given flag key and the given metric key which have a currently running iteration. ### Expanding the experiments response LaunchDarkly supports four fields for expanding the "Get experiments" response. By default, these fields are not included in the response. To expand the response, append the `expand` query parameter and add a comma-separated list with any of the following fields: - `previousIterations` includes all iterations prior to the current iteration. By default only the current iteration is included in the response. - `draftIteration` includes the iteration which has not been started yet, if any. - `secondaryMetrics` includes secondary metrics. By default only the primary metric is included in the response. - `treatments` includes all treatment and parameter details. By default treatment data is not included in the response. For example, `expand=draftIteration,treatments` includes the `draftIteration` and `treatments` fields in the response. If fields that you request with the `expand` query parameter are empty, they are not included in the response.
511 512 513 514 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 511 def get_experiments(project_key, environment_key, opts = {}) data, _status_code, _headers = get_experiments_with_http_info(project_key, environment_key, opts) data end |
#get_experiments_with_http_info(project_key, environment_key, opts = {}) ⇒ Array<(ExperimentCollectionRep, Integer, Hash)>
Get experiments Get details about all experiments in an environment. ### Filtering experiments LaunchDarkly supports the `filter` query param for filtering, with the following fields: - `flagKey` filters for only experiments that use the flag with the given key. - `metricKey` filters for only experiments that use the metric with the given key. - `status` filters for only experiments with an iteration with the given status. An iteration can have the status `not_started`, `running` or `stopped`. For example, `filter=flagKey:my-flag,status:running,metricKey:page-load-ms` filters for experiments for the given flag key and the given metric key which have a currently running iteration. ### Expanding the experiments response LaunchDarkly supports four fields for expanding the "Get experiments" response. By default, these fields are not included in the response. To expand the response, append the `expand` query parameter and add a comma-separated list with any of the following fields: - `previousIterations` includes all iterations prior to the current iteration. By default only the current iteration is included in the response. - `draftIteration` includes the iteration which has not been started yet, if any. - `secondaryMetrics` includes secondary metrics. By default only the primary metric is included in the response. - `treatments` includes all treatment and parameter details. By default treatment data is not included in the response. For example, `expand=draftIteration,treatments` includes the `draftIteration` and `treatments` fields in the response. If fields that you request with the `expand` query parameter are empty, they are not included in the response.
527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 527 def get_experiments_with_http_info(project_key, environment_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_experiments ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_experiments" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.get_experiments" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil? query_params[:'lifecycleState'] = opts[:'lifecycle_state'] if !opts[:'lifecycle_state'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExperimentCollectionRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.get_experiments", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_experiments\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_legacy_experiment_results(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ ExperimentResults
Get legacy experiment results (deprecated) Get detailed experiment result data for legacy experiments.
594 595 596 597 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 594 def get_legacy_experiment_results(project_key, feature_flag_key, environment_key, metric_key, opts = {}) data, _status_code, _headers = get_legacy_experiment_results_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts) data end |
#get_legacy_experiment_results_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ Array<(ExperimentResults, Integer, Hash)>
Get legacy experiment results (deprecated) Get detailed experiment result data for legacy experiments.
609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 627 628 629 630 631 632 633 634 635 636 637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 609 def get_legacy_experiment_results_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_legacy_experiment_results ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_legacy_experiment_results" end # verify the required parameter 'feature_flag_key' is set if @api_client.config.client_side_validation && feature_flag_key.nil? fail ArgumentError, "Missing the required parameter 'feature_flag_key' when calling ExperimentsBetaApi.get_legacy_experiment_results" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.get_legacy_experiment_results" end # verify the required parameter 'metric_key' is set if @api_client.config.client_side_validation && metric_key.nil? fail ArgumentError, "Missing the required parameter 'metric_key' when calling ExperimentsBetaApi.get_legacy_experiment_results" end # resource path local_var_path = '/api/v2/flags/{projectKey}/{featureFlagKey}/experiments/{environmentKey}/{metricKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'featureFlagKey' + '}', CGI.escape(feature_flag_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'metricKey' + '}', CGI.escape(metric_key.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil? query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExperimentResults' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.get_legacy_experiment_results", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_legacy_experiment_results\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_experiment(project_key, environment_key, experiment_key, experiment_patch_input, opts = {}) ⇒ Experiment
Patch experiment Update an experiment. Updating an experiment uses the semantic patch format. To make a semantic patch request, you must append ‘domain-model=launchdarkly.semanticpatch` to your `Content-Type` header. To learn more, read [Updates using semantic patch](/reference#updates-using-semantic-patch). ### Instructions Semantic patch requests support the following `kind` instructions for updating experiments. #### updateName Updates the experiment name. ##### Parameters - `value`: The new name. Here’s an example: “‘json { "instructions": [{ "kind": "updateName", "value": "Example updated experiment name" }] } “` #### updateDescription Updates the experiment description. ##### Parameters - `value`: The new description. Here’s an example: “‘json { "instructions": [{ "kind": "updateDescription", "value": "Example updated description" }] } “` #### startIteration Starts a new iteration for this experiment. You must [create a new iteration](/tag/Experiments-(beta)#operation/createIteration) before calling this instruction. An iteration may not be started until it meets the following criteria: * Its associated flag is toggled on and is not archived * Its `randomizationUnit` is set * At least one of its `treatments` has a non-zero `allocationPercent` ##### Parameters - `changeJustification`: The reason for starting a new iteration. Required when you call `startIteration` on an already running experiment, otherwise optional. Here’s an example: “‘json { "instructions": [{ "kind": "startIteration", "changeJustification": "It’s time to start a new iteration" }] } “‘ #### stopIteration Stops the current iteration for this experiment. ##### Parameters - `winningTreatmentId`: The ID of the winning treatment. Treatment IDs are returned as part of the [Get experiment](/tag/Experiments-(beta)#operation/getExperiment) response. They are the `_id` of each element in the `treatments` array. - `winningReason`: The reason for the winner Here’s an example: “‘json { "instructions": [{ "kind": "stopIteration", "winningTreatmentId": "3a548ec2-72ac-4e59-8518-5c24f5609ccf", "winningReason": "Example reason to stop the iteration" }] } “` #### archiveExperiment Archives this experiment. Archived experiments are hidden by default in the LaunchDarkly user interface. You cannot start new iterations for archived experiments. Here’s an example: “‘json { "instructions": [{ "kind": "archiveExperiment" }] } “` #### restoreExperiment Restores an archived experiment. After restoring an experiment, you can start new iterations for it again. Here’s an example: “‘json { "instructions": [{ "kind": "restoreExperiment" }] } “`
679 680 681 682 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 679 def patch_experiment(project_key, environment_key, experiment_key, experiment_patch_input, opts = {}) data, _status_code, _headers = patch_experiment_with_http_info(project_key, environment_key, experiment_key, experiment_patch_input, opts) data end |
#patch_experiment_with_http_info(project_key, environment_key, experiment_key, experiment_patch_input, opts = {}) ⇒ Array<(Experiment, Integer, Hash)>
Patch experiment Update an experiment. Updating an experiment uses the semantic patch format. To make a semantic patch request, you must append `domain-model=launchdarkly.semanticpatch` to your `Content-Type` header. To learn more, read [Updates using semantic patch](/reference#updates-using-semantic-patch). ### Instructions Semantic patch requests support the following `kind` instructions for updating experiments. #### updateName Updates the experiment name. ##### Parameters - `value`: The new name. Here's an example: ```json { "instructions": [{ "kind": "updateName", "value": "Example updated experiment name" }] } ``` #### updateDescription Updates the experiment description. ##### Parameters - `value`: The new description. Here's an example: ```json { "instructions": [{ "kind": "updateDescription", "value": "Example updated description" }] } ``` #### startIteration Starts a new iteration for this experiment. You must [create a new iteration](/tag/Experiments-(beta)#operation/createIteration) before calling this instruction. An iteration may not be started until it meets the following criteria: * Its associated flag is toggled on and is not archived * Its `randomizationUnit` is set * At least one of its `treatments` has a non-zero `allocationPercent` ##### Parameters - `changeJustification`: The reason for starting a new iteration. Required when you call `startIteration` on an already running experiment, otherwise optional. Here's an example: ```json { "instructions": [{ "kind": "startIteration", "changeJustification": "It's time to start a new iteration" }] } ``` #### stopIteration Stops the current iteration for this experiment. ##### Parameters - `winningTreatmentId`: The ID of the winning treatment. Treatment IDs are returned as part of the [Get experiment](/tag/Experiments-(beta)#operation/getExperiment) response. They are the `_id` of each element in the `treatments` array. - `winningReason`: The reason for the winner Here's an example: ```json { "instructions": [{ "kind": "stopIteration", "winningTreatmentId": "3a548ec2-72ac-4e59-8518-5c24f5609ccf", "winningReason": "Example reason to stop the iteration" }] } ``` #### archiveExperiment Archives this experiment. Archived experiments are hidden by default in the LaunchDarkly user interface. You cannot start new iterations for archived experiments. Here's an example: ```json { "instructions": [{ "kind": "archiveExperiment" }] } ``` #### restoreExperiment Restores an archived experiment. After restoring an experiment, you can start new iterations for it again. Here's an example: ```json { "instructions": [{ "kind": "restoreExperiment" }] } ```
692 693 694 695 696 697 698 699 700 701 702 703 704 705 706 707 708 709 710 711 712 713 714 715 716 717 718 719 720 721 722 723 724 725 726 727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 692 def patch_experiment_with_http_info(project_key, environment_key, experiment_key, experiment_patch_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.patch_experiment ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.patch_experiment" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.patch_experiment" end # verify the required parameter 'experiment_key' is set if @api_client.config.client_side_validation && experiment_key.nil? fail ArgumentError, "Missing the required parameter 'experiment_key' when calling ExperimentsBetaApi.patch_experiment" end # verify the required parameter 'experiment_patch_input' is set if @api_client.config.client_side_validation && experiment_patch_input.nil? fail ArgumentError, "Missing the required parameter 'experiment_patch_input' when calling ExperimentsBetaApi.patch_experiment" end # resource path local_var_path = '/api/v2/projects/{projectKey}/environments/{environmentKey}/experiments/{experimentKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'experimentKey' + '}', CGI.escape(experiment_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(experiment_patch_input) # return_type return_type = opts[:debug_return_type] || 'Experiment' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.patch_experiment", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#patch_experiment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#put_experimentation_settings(project_key, randomization_settings_put, opts = {}) ⇒ RandomizationSettingsRep
Update experimentation settings Update experimentation settings for the given project
763 764 765 766 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 763 def put_experimentation_settings(project_key, randomization_settings_put, opts = {}) data, _status_code, _headers = put_experimentation_settings_with_http_info(project_key, randomization_settings_put, opts) data end |
#put_experimentation_settings_with_http_info(project_key, randomization_settings_put, opts = {}) ⇒ Array<(RandomizationSettingsRep, Integer, Hash)>
Update experimentation settings Update experimentation settings for the given project
774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 791 792 793 794 795 796 797 798 799 800 801 802 803 804 805 806 807 808 809 810 811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 |
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 774 def put_experimentation_settings_with_http_info(project_key, randomization_settings_put, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.put_experimentation_settings ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.put_experimentation_settings" end # verify the required parameter 'randomization_settings_put' is set if @api_client.config.client_side_validation && randomization_settings_put.nil? fail ArgumentError, "Missing the required parameter 'randomization_settings_put' when calling ExperimentsBetaApi.put_experimentation_settings" end # resource path local_var_path = '/api/v2/projects/{projectKey}/experimentation-settings'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(randomization_settings_put) # return_type return_type = opts[:debug_return_type] || 'RandomizationSettingsRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ExperimentsBetaApi.put_experimentation_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PUT, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ExperimentsBetaApi#put_experimentation_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |