Class: LaunchDarklyApi::ExpiringTarget
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ExpiringTarget
- Defined in:
- lib/launchdarkly_api/models/expiring_target.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
The ID of this expiring target.
-
#_resource_id ⇒ Object
Returns the value of attribute _resource_id.
-
#_version ⇒ Object
The version of this expiring target.
-
#context_key ⇒ Object
A unique key used to represent the context to be removed.
-
#context_kind ⇒ Object
The context kind of the context to be removed.
-
#expiration_date ⇒ Object
Returns the value of attribute expiration_date.
-
#target_type ⇒ Object
A segment's target type,
includedorexcluded. -
#variation_id ⇒ Object
A unique ID used to represent the flag variation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpiringTarget
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExpiringTarget
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpiringTarget` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpiringTarget`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_version') self._version = attributes[:'_version'] else self._version = nil end if attributes.key?(:'expiration_date') self.expiration_date = attributes[:'expiration_date'] else self.expiration_date = nil end if attributes.key?(:'context_kind') self.context_kind = attributes[:'context_kind'] else self.context_kind = nil end if attributes.key?(:'context_key') self.context_key = attributes[:'context_key'] else self.context_key = nil end if attributes.key?(:'target_type') self.target_type = attributes[:'target_type'] end if attributes.key?(:'variation_id') self.variation_id = attributes[:'variation_id'] end if attributes.key?(:'_resource_id') self._resource_id = attributes[:'_resource_id'] else self._resource_id = nil end end |
Instance Attribute Details
#_id ⇒ Object
The ID of this expiring target
19 20 21 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 19 def _id @_id end |
#_resource_id ⇒ Object
Returns the value of attribute _resource_id.
38 39 40 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 38 def _resource_id @_resource_id end |
#_version ⇒ Object
The version of this expiring target
22 23 24 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 22 def _version @_version end |
#context_key ⇒ Object
A unique key used to represent the context to be removed
30 31 32 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 30 def context_key @context_key end |
#context_kind ⇒ Object
The context kind of the context to be removed
27 28 29 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 27 def context_kind @context_kind end |
#expiration_date ⇒ Object
Returns the value of attribute expiration_date.
24 25 26 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 24 def expiration_date @expiration_date end |
#target_type ⇒ Object
A segment's target type, included or excluded. Included when expiring targets are updated on a segment.
33 34 35 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 33 def target_type @target_type end |
#variation_id ⇒ Object
A unique ID used to represent the flag variation. Included when expiring targets are updated on a feature flag.
36 37 38 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 36 def variation_id @variation_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 41 def self.attribute_map { :'_id' => :'_id', :'_version' => :'_version', :'expiration_date' => :'expirationDate', :'context_kind' => :'contextKind', :'context_key' => :'contextKey', :'target_type' => :'targetType', :'variation_id' => :'variationId', :'_resource_id' => :'_resourceId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 280 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 65 def self.openapi_types { :'_id' => :'String', :'_version' => :'Integer', :'expiration_date' => :'Integer', :'context_kind' => :'String', :'context_key' => :'String', :'target_type' => :'String', :'variation_id' => :'String', :'_resource_id' => :'ResourceId' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 252 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _version == o._version && expiration_date == o.expiration_date && context_kind == o.context_kind && context_key == o.context_key && target_type == o.target_type && variation_id == o.variation_id && _resource_id == o._resource_id end |
#eql?(o) ⇒ Boolean
267 268 269 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 267 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
273 274 275 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 273 def hash [_id, _version, expiration_date, context_kind, context_key, target_type, variation_id, _resource_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 147 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_version.nil? invalid_properties.push('invalid value for "_version", _version cannot be nil.') end if @expiration_date.nil? invalid_properties.push('invalid value for "expiration_date", expiration_date cannot be nil.') end if @context_kind.nil? invalid_properties.push('invalid value for "context_kind", context_kind cannot be nil.') end if @context_key.nil? invalid_properties.push('invalid value for "context_key", context_key cannot be nil.') end if @_resource_id.nil? invalid_properties.push('invalid value for "_resource_id", _resource_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 302 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/expiring_target.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @_version.nil? return false if @expiration_date.nil? return false if @context_kind.nil? return false if @context_key.nil? return false if @_resource_id.nil? true end |