Class: LaunchDarklyApi::ExpiringTargetPatchResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/expiring_target_patch_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpiringTargetPatchResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 74

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpiringTargetPatchResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpiringTargetPatchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'total_instructions')
    self.total_instructions = attributes[:'total_instructions']
  end

  if attributes.key?(:'successful_instructions')
    self.successful_instructions = attributes[:'successful_instructions']
  end

  if attributes.key?(:'failed_instructions')
    self.failed_instructions = attributes[:'failed_instructions']
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end
end

Instance Attribute Details

The location and content type of related resources



22
23
24
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 22

def _links
  @_links
end

#errorsObject

Returns the value of attribute errors.



30
31
32
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 30

def errors
  @errors
end

#failed_instructionsObject

Returns the value of attribute failed_instructions.



28
29
30
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 28

def failed_instructions
  @failed_instructions
end

#itemsObject

A list of the results from each instruction



19
20
21
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 19

def items
  @items
end

#successful_instructionsObject

Returns the value of attribute successful_instructions.



26
27
28
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 26

def successful_instructions
  @successful_instructions
end

#total_instructionsObject

Returns the value of attribute total_instructions.



24
25
26
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 24

def total_instructions
  @total_instructions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
42
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 33

def self.attribute_map
  {
    :'items' => :'items',
    :'_links' => :'_links',
    :'total_instructions' => :'totalInstructions',
    :'successful_instructions' => :'successfulInstructions',
    :'failed_instructions' => :'failedInstructions',
    :'errors' => :'errors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 179

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



67
68
69
70
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 67

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
64
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 55

def self.openapi_types
  {
    :'items' => :'Array<ExpiringTarget>',
    :'_links' => :'Hash<String, Link>',
    :'total_instructions' => :'Integer',
    :'successful_instructions' => :'Integer',
    :'failed_instructions' => :'Integer',
    :'errors' => :'Array<ExpiringTargetError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



153
154
155
156
157
158
159
160
161
162
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 153

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      items == o.items &&
      _links == o._links &&
      total_instructions == o.total_instructions &&
      successful_instructions == o.successful_instructions &&
      failed_instructions == o.failed_instructions &&
      errors == o.errors
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


166
167
168
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 166

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



172
173
174
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 172

def hash
  [items, _links, total_instructions, successful_instructions, failed_instructions, errors].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



123
124
125
126
127
128
129
130
131
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 123

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



201
202
203
204
205
206
207
208
209
210
211
212
213
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 201

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
139
# File 'lib/launchdarkly_api/models/expiring_target_patch_response.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @items.nil?
  true
end