Class: LaunchDarklyApi::ExpiringUserTargetPatchResponse

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/expiring_user_target_patch_response.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ExpiringUserTargetPatchResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpiringUserTargetPatchResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpiringUserTargetPatchResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'total_instructions')
    self.total_instructions = attributes[:'total_instructions']
  end

  if attributes.key?(:'successful_instructions')
    self.successful_instructions = attributes[:'successful_instructions']
  end

  if attributes.key?(:'failed_instructions')
    self.failed_instructions = attributes[:'failed_instructions']
  end

  if attributes.key?(:'errors')
    if (value = attributes[:'errors']).is_a?(Array)
      self.errors = value
    end
  end
end

Instance Attribute Details

The location and content type of related resources



22
23
24
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 22

def _links
  @_links
end

#errorsObject

An array of error messages for the failed instructions



34
35
36
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 34

def errors
  @errors
end

#failed_instructionsObject

The total count of the failed instructions sent in the PATCH request



31
32
33
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 31

def failed_instructions
  @failed_instructions
end

#itemsObject

An array of expiring user targets



19
20
21
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 19

def items
  @items
end

#successful_instructionsObject

The total count of successful instructions sent in the PATCH request



28
29
30
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 28

def successful_instructions
  @successful_instructions
end

#total_instructionsObject

The total count of instructions sent in the PATCH request



25
26
27
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 25

def total_instructions
  @total_instructions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 37

def self.attribute_map
  {
    :'items' => :'items',
    :'_links' => :'_links',
    :'total_instructions' => :'totalInstructions',
    :'successful_instructions' => :'successfulInstructions',
    :'failed_instructions' => :'failedInstructions',
    :'errors' => :'errors'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 183

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 59

def self.openapi_types
  {
    :'items' => :'Array<ExpiringUserTargetItem>',
    :'_links' => :'Hash<String, Link>',
    :'total_instructions' => :'Integer',
    :'successful_instructions' => :'Integer',
    :'failed_instructions' => :'Integer',
    :'errors' => :'Array<ExpiringTargetError>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



157
158
159
160
161
162
163
164
165
166
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 157

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      items == o.items &&
      _links == o._links &&
      total_instructions == o.total_instructions &&
      successful_instructions == o.successful_instructions &&
      failed_instructions == o.failed_instructions &&
      errors == o.errors
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


170
171
172
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 170

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



176
177
178
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 176

def hash
  [items, _links, total_instructions, successful_instructions, failed_instructions, errors].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
132
133
134
135
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 205

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



139
140
141
142
143
# File 'lib/launchdarkly_api/models/expiring_user_target_patch_response.rb', line 139

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @items.nil?
  true
end