Class: LaunchDarklyApi::Extinction

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/extinction.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Extinction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
# File 'lib/launchdarkly_api/models/extinction.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Extinction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Extinction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'revision')
    self.revision = attributes[:'revision']
  else
    self.revision = nil
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  else
    self.message = nil
  end

  if attributes.key?(:'time')
    self.time = attributes[:'time']
  else
    self.time = nil
  end

  if attributes.key?(:'flag_key')
    self.flag_key = attributes[:'flag_key']
  else
    self.flag_key = nil
  end

  if attributes.key?(:'proj_key')
    self.proj_key = attributes[:'proj_key']
  else
    self.proj_key = nil
  end
end

Instance Attribute Details

#flag_keyObject

The feature flag key



27
28
29
# File 'lib/launchdarkly_api/models/extinction.rb', line 27

def flag_key
  @flag_key
end

#messageObject

Description of the extinction. For example, the commit message for the revision.



22
23
24
# File 'lib/launchdarkly_api/models/extinction.rb', line 22

def message
  @message
end

#proj_keyObject

The project key



30
31
32
# File 'lib/launchdarkly_api/models/extinction.rb', line 30

def proj_key
  @proj_key
end

#revisionObject

The identifier for the revision where flag became extinct. For example, a commit SHA.



19
20
21
# File 'lib/launchdarkly_api/models/extinction.rb', line 19

def revision
  @revision
end

#timeObject

Returns the value of attribute time.



24
25
26
# File 'lib/launchdarkly_api/models/extinction.rb', line 24

def time
  @time
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/launchdarkly_api/models/extinction.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/extinction.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/launchdarkly_api/models/extinction.rb', line 33

def self.attribute_map
  {
    :'revision' => :'revision',
    :'message' => :'message',
    :'time' => :'time',
    :'flag_key' => :'flagKey',
    :'proj_key' => :'projKey'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
# File 'lib/launchdarkly_api/models/extinction.rb', line 234

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/launchdarkly_api/models/extinction.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/launchdarkly_api/models/extinction.rb', line 54

def self.openapi_types
  {
    :'revision' => :'String',
    :'message' => :'String',
    :'time' => :'Integer',
    :'flag_key' => :'String',
    :'proj_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



209
210
211
212
213
214
215
216
217
# File 'lib/launchdarkly_api/models/extinction.rb', line 209

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      revision == o.revision &&
      message == o.message &&
      time == o.time &&
      flag_key == o.flag_key &&
      proj_key == o.proj_key
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


221
222
223
# File 'lib/launchdarkly_api/models/extinction.rb', line 221

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



227
228
229
# File 'lib/launchdarkly_api/models/extinction.rb', line 227

def hash
  [revision, message, time, flag_key, proj_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
# File 'lib/launchdarkly_api/models/extinction.rb', line 119

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @revision.nil?
    invalid_properties.push('invalid value for "revision", revision cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @time.nil?
    invalid_properties.push('invalid value for "time", time cannot be nil.')
  end

  if @flag_key.nil?
    invalid_properties.push('invalid value for "flag_key", flag_key cannot be nil.')
  end

  if @proj_key.nil?
    invalid_properties.push('invalid value for "proj_key", proj_key cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/launchdarkly_api/models/extinction.rb', line 256

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



147
148
149
150
151
152
153
154
155
# File 'lib/launchdarkly_api/models/extinction.rb', line 147

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @revision.nil?
  return false if @message.nil?
  return false if @time.nil?
  return false if @flag_key.nil?
  return false if @proj_key.nil?
  true
end