Class: LaunchDarklyApi::FeatureFlag
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::FeatureFlag
- Defined in:
- lib/launchdarkly_api/models/feature_flag.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
-
#_maintainer_team ⇒ Object
Returns the value of attribute _maintainer_team.
-
#_purpose ⇒ Object
Returns the value of attribute _purpose.
-
#_version ⇒ Object
Version of the feature flag.
-
#archived ⇒ Object
Boolean indicating if the feature flag is archived.
-
#archived_date ⇒ Object
Returns the value of attribute archived_date.
-
#client_side_availability ⇒ Object
Returns the value of attribute client_side_availability.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#custom_properties ⇒ Object
Returns the value of attribute custom_properties.
-
#defaults ⇒ Object
Returns the value of attribute defaults.
-
#deprecated ⇒ Object
Boolean indicating if the feature flag is deprecated.
-
#deprecated_date ⇒ Object
Returns the value of attribute deprecated_date.
-
#description ⇒ Object
Description of the feature flag.
-
#environments ⇒ Object
Details on the environments for this flag.
-
#experiments ⇒ Object
Returns the value of attribute experiments.
-
#goal_ids ⇒ Object
Deprecated, use
experimentsinstead. -
#include_in_snippet ⇒ Object
Deprecated, use
clientSideAvailability. -
#key ⇒ Object
A unique key used to reference the flag in your code.
-
#kind ⇒ Object
Kind of feature flag.
-
#maintainer_id ⇒ Object
Associated maintainerId for the feature flag.
-
#maintainer_team_key ⇒ Object
The key of the associated team that maintains this feature flag.
-
#migration_settings ⇒ Object
Returns the value of attribute migration_settings.
-
#name ⇒ Object
A human-friendly name for the feature flag.
-
#stale ⇒ Object
Returns the value of attribute stale.
-
#tags ⇒ Object
Tags for the feature flag.
-
#temporary ⇒ Object
Whether the flag is a temporary flag.
-
#variations ⇒ Object
An array of possible variations for the flag.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FeatureFlag
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FeatureFlag
Initializes the object
198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 198 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FeatureFlag` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FeatureFlag`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'_version') self._version = attributes[:'_version'] else self._version = nil end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'include_in_snippet') self.include_in_snippet = attributes[:'include_in_snippet'] end if attributes.key?(:'client_side_availability') self.client_side_availability = attributes[:'client_side_availability'] end if attributes.key?(:'variations') if (value = attributes[:'variations']).is_a?(Array) self.variations = value end else self.variations = nil end if attributes.key?(:'temporary') self.temporary = attributes[:'temporary'] else self.temporary = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'_maintainer') self._maintainer = attributes[:'_maintainer'] end if attributes.key?(:'maintainer_team_key') self.maintainer_team_key = attributes[:'maintainer_team_key'] end if attributes.key?(:'_maintainer_team') self._maintainer_team = attributes[:'_maintainer_team'] end if attributes.key?(:'goal_ids') if (value = attributes[:'goal_ids']).is_a?(Array) self.goal_ids = value end end if attributes.key?(:'experiments') self.experiments = attributes[:'experiments'] else self.experiments = nil end if attributes.key?(:'custom_properties') if (value = attributes[:'custom_properties']).is_a?(Hash) self.custom_properties = value end else self.custom_properties = nil end if attributes.key?(:'archived') self.archived = attributes[:'archived'] else self.archived = nil end if attributes.key?(:'archived_date') self.archived_date = attributes[:'archived_date'] end if attributes.key?(:'deprecated') self.deprecated = attributes[:'deprecated'] end if attributes.key?(:'deprecated_date') self.deprecated_date = attributes[:'deprecated_date'] end if attributes.key?(:'defaults') self.defaults = attributes[:'defaults'] end if attributes.key?(:'_purpose') self._purpose = attributes[:'_purpose'] end if attributes.key?(:'migration_settings') self.migration_settings = attributes[:'migration_settings'] end if attributes.key?(:'stale') self.stale = attributes[:'stale'] end if attributes.key?(:'environments') if (value = attributes[:'environments']).is_a?(Hash) self.environments = value end end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
50 51 52 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 50 def _links @_links end |
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
55 56 57 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 55 def _maintainer @_maintainer end |
#_maintainer_team ⇒ Object
Returns the value of attribute _maintainer_team.
60 61 62 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 60 def _maintainer_team @_maintainer_team end |
#_purpose ⇒ Object
Returns the value of attribute _purpose.
81 82 83 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 81 def _purpose @_purpose end |
#_version ⇒ Object
Version of the feature flag
31 32 33 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 31 def _version @_version end |
#archived ⇒ Object
Boolean indicating if the feature flag is archived
70 71 72 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 70 def archived @archived end |
#archived_date ⇒ Object
Returns the value of attribute archived_date.
72 73 74 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 72 def archived_date @archived_date end |
#client_side_availability ⇒ Object
Returns the value of attribute client_side_availability.
38 39 40 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 38 def client_side_availability @client_side_availability end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
33 34 35 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 33 def creation_date @creation_date end |
#custom_properties ⇒ Object
Returns the value of attribute custom_properties.
67 68 69 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 67 def custom_properties @custom_properties end |
#defaults ⇒ Object
Returns the value of attribute defaults.
79 80 81 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 79 def defaults @defaults end |
#deprecated ⇒ Object
Boolean indicating if the feature flag is deprecated
75 76 77 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 75 def deprecated @deprecated end |
#deprecated_date ⇒ Object
Returns the value of attribute deprecated_date.
77 78 79 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 77 def deprecated_date @deprecated_date end |
#description ⇒ Object
Description of the feature flag
25 26 27 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 25 def description @description end |
#environments ⇒ Object
Details on the environments for this flag. Only returned if the request is filtered by environment, using the filterEnv query parameter.
88 89 90 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 88 def environments @environments end |
#experiments ⇒ Object
Returns the value of attribute experiments.
65 66 67 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 65 def experiments @experiments end |
#goal_ids ⇒ Object
Deprecated, use experiments instead
63 64 65 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 63 def goal_ids @goal_ids end |
#include_in_snippet ⇒ Object
Deprecated, use clientSideAvailability. Whether this flag should be made available to the client-side JavaScript SDK
36 37 38 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 36 def include_in_snippet @include_in_snippet end |
#key ⇒ Object
A unique key used to reference the flag in your code
28 29 30 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 28 def key @key end |
#kind ⇒ Object
Kind of feature flag
22 23 24 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 22 def kind @kind end |
#maintainer_id ⇒ Object
Associated maintainerId for the feature flag
53 54 55 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 53 def maintainer_id @maintainer_id end |
#maintainer_team_key ⇒ Object
The key of the associated team that maintains this feature flag
58 59 60 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 58 def maintainer_team_key @maintainer_team_key end |
#migration_settings ⇒ Object
Returns the value of attribute migration_settings.
83 84 85 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 83 def migration_settings @migration_settings end |
#name ⇒ Object
A human-friendly name for the feature flag
19 20 21 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 19 def name @name end |
#stale ⇒ Object
Returns the value of attribute stale.
85 86 87 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 85 def stale @stale end |
#tags ⇒ Object
Tags for the feature flag
47 48 49 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 47 def @tags end |
#temporary ⇒ Object
Whether the flag is a temporary flag
44 45 46 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 44 def temporary @temporary end |
#variations ⇒ Object
An array of possible variations for the flag
41 42 43 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 41 def variations @variations end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
147 148 149 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 147 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
152 153 154 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 152 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 113 def self.attribute_map { :'name' => :'name', :'kind' => :'kind', :'description' => :'description', :'key' => :'key', :'_version' => :'_version', :'creation_date' => :'creationDate', :'include_in_snippet' => :'includeInSnippet', :'client_side_availability' => :'clientSideAvailability', :'variations' => :'variations', :'temporary' => :'temporary', :'tags' => :'tags', :'_links' => :'_links', :'maintainer_id' => :'maintainerId', :'_maintainer' => :'_maintainer', :'maintainer_team_key' => :'maintainerTeamKey', :'_maintainer_team' => :'_maintainerTeam', :'goal_ids' => :'goalIds', :'experiments' => :'experiments', :'custom_properties' => :'customProperties', :'archived' => :'archived', :'archived_date' => :'archivedDate', :'deprecated' => :'deprecated', :'deprecated_date' => :'deprecatedDate', :'defaults' => :'defaults', :'_purpose' => :'_purpose', :'migration_settings' => :'migrationSettings', :'stale' => :'stale', :'environments' => :'environments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
608 609 610 611 612 613 614 615 616 617 618 619 620 621 622 623 624 625 626 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 608 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
191 192 193 194 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 191 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 157 def self.openapi_types { :'name' => :'String', :'kind' => :'String', :'description' => :'String', :'key' => :'String', :'_version' => :'Integer', :'creation_date' => :'Integer', :'include_in_snippet' => :'Boolean', :'client_side_availability' => :'ClientSideAvailability', :'variations' => :'Array<Variation>', :'temporary' => :'Boolean', :'tags' => :'Array<String>', :'_links' => :'Hash<String, Link>', :'maintainer_id' => :'String', :'_maintainer' => :'MemberSummary', :'maintainer_team_key' => :'String', :'_maintainer_team' => :'MaintainerTeam', :'goal_ids' => :'Array<String>', :'experiments' => :'ExperimentInfoRep', :'custom_properties' => :'Hash<String, CustomProperty>', :'archived' => :'Boolean', :'archived_date' => :'Integer', :'deprecated' => :'Boolean', :'deprecated_date' => :'Integer', :'defaults' => :'Defaults', :'_purpose' => :'String', :'migration_settings' => :'FlagMigrationSettingsRep', :'stale' => :'StaleFlagData', :'environments' => :'Hash<String, FeatureFlagConfig>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
560 561 562 563 564 565 566 567 568 569 570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 560 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && kind == o.kind && description == o.description && key == o.key && _version == o._version && creation_date == o.creation_date && include_in_snippet == o.include_in_snippet && client_side_availability == o.client_side_availability && variations == o.variations && temporary == o.temporary && == o. && _links == o._links && maintainer_id == o.maintainer_id && _maintainer == o._maintainer && maintainer_team_key == o.maintainer_team_key && _maintainer_team == o._maintainer_team && goal_ids == o.goal_ids && experiments == o.experiments && custom_properties == o.custom_properties && archived == o.archived && archived_date == o.archived_date && deprecated == o.deprecated && deprecated_date == o.deprecated_date && defaults == o.defaults && _purpose == o._purpose && migration_settings == o.migration_settings && stale == o.stale && environments == o.environments end |
#eql?(o) ⇒ Boolean
595 596 597 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 595 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
601 602 603 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 601 def hash [name, kind, description, key, _version, creation_date, include_in_snippet, client_side_availability, variations, temporary, , _links, maintainer_id, _maintainer, maintainer_team_key, _maintainer_team, goal_ids, experiments, custom_properties, archived, archived_date, deprecated, deprecated_date, defaults, _purpose, migration_settings, stale, environments].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 363 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @_version.nil? invalid_properties.push('invalid value for "_version", _version cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @variations.nil? invalid_properties.push('invalid value for "variations", variations cannot be nil.') end if @temporary.nil? invalid_properties.push('invalid value for "temporary", temporary cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @experiments.nil? invalid_properties.push('invalid value for "experiments", experiments cannot be nil.') end if @custom_properties.nil? invalid_properties.push('invalid value for "custom_properties", custom_properties cannot be nil.') end if @archived.nil? invalid_properties.push('invalid value for "archived", archived cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
630 631 632 633 634 635 636 637 638 639 640 641 642 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 630 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 |
# File 'lib/launchdarkly_api/models/feature_flag.rb', line 419 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["boolean", "multivariate"]) return false unless kind_validator.valid?(@kind) return false if @key.nil? return false if @_version.nil? return false if @creation_date.nil? return false if @variations.nil? return false if @temporary.nil? return false if @tags.nil? return false if @_links.nil? return false if @experiments.nil? return false if @custom_properties.nil? return false if @archived.nil? true end |