Class: LaunchDarklyApi::FeatureFlagConfig

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/feature_flag_config.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FeatureFlagConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 143

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FeatureFlagConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FeatureFlagConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'on')
    self.on = attributes[:'on']
  else
    self.on = nil
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  else
    self.archived = nil
  end

  if attributes.key?(:'salt')
    self.salt = attributes[:'salt']
  else
    self.salt = nil
  end

  if attributes.key?(:'sel')
    self.sel = attributes[:'sel']
  else
    self.sel = nil
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  else
    self.last_modified = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'targets')
    if (value = attributes[:'targets']).is_a?(Array)
      self.targets = value
    end
  end

  if attributes.key?(:'context_targets')
    if (value = attributes[:'context_targets']).is_a?(Array)
      self.context_targets = value
    end
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  end

  if attributes.key?(:'fallthrough')
    self.fallthrough = attributes[:'fallthrough']
  end

  if attributes.key?(:'off_variation')
    self.off_variation = attributes[:'off_variation']
  end

  if attributes.key?(:'prerequisites')
    if (value = attributes[:'prerequisites']).is_a?(Array)
      self.prerequisites = value
    end
  end

  if attributes.key?(:'_site')
    self._site = attributes[:'_site']
  else
    self._site = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_environment_name')
    self._environment_name = attributes[:'_environment_name']
  else
    self._environment_name = nil
  end

  if attributes.key?(:'track_events')
    self.track_events = attributes[:'track_events']
  else
    self.track_events = nil
  end

  if attributes.key?(:'track_events_fallthrough')
    self.track_events_fallthrough = attributes[:'track_events_fallthrough']
  else
    self.track_events_fallthrough = nil
  end

  if attributes.key?(:'_debug_events_until_date')
    self._debug_events_until_date = attributes[:'_debug_events_until_date']
  end

  if attributes.key?(:'_summary')
    self._summary = attributes[:'_summary']
  end

  if attributes.key?(:'evaluation')
    self.evaluation = attributes[:'evaluation']
  end

  if attributes.key?(:'migration_settings')
    self.migration_settings = attributes[:'migration_settings']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



52
53
54
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 52

def _access
  @_access
end

#_debug_events_until_dateObject

Returns the value of attribute _debug_events_until_date.



63
64
65
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 63

def _debug_events_until_date
  @_debug_events_until_date
end

#_environment_nameObject

The environment name



55
56
57
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 55

def _environment_name
  @_environment_name
end

#_siteObject

Returns the value of attribute _site.



50
51
52
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 50

def _site
  @_site
end

#_summaryObject

Returns the value of attribute _summary.



65
66
67
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 65

def _summary
  @_summary
end

#archivedObject

Boolean indicating if the feature flag is archived



22
23
24
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 22

def archived
  @archived
end

#context_targetsObject

An array of the individual targets that will receive a specific variation based on their key. Individual targets with context kinds other than 'user' are included here.



37
38
39
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 37

def context_targets
  @context_targets
end

#evaluationObject

Returns the value of attribute evaluation.



67
68
69
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 67

def evaluation
  @evaluation
end

#fallthroughObject

Returns the value of attribute fallthrough.



42
43
44
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 42

def fallthrough
  @fallthrough
end

#last_modifiedObject

Returns the value of attribute last_modified.



28
29
30
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 28

def last_modified
  @last_modified
end

#migration_settingsObject

Returns the value of attribute migration_settings.



69
70
71
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 69

def migration_settings
  @migration_settings
end

#off_variationObject

The ID of the variation to serve when the flag is off



45
46
47
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 45

def off_variation
  @off_variation
end

#onObject

Whether the flag is on



19
20
21
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 19

def on
  @on
end

#prerequisitesObject

An array of the prerequisite flags and their variations that are required before this flag takes effect



48
49
50
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 48

def prerequisites
  @prerequisites
end

#rulesObject

An array of the rules for how to serve a variation to specific targets based on their attributes



40
41
42
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 40

def rules
  @rules
end

#saltObject

Returns the value of attribute salt.



24
25
26
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 24

def salt
  @salt
end

#selObject

Returns the value of attribute sel.



26
27
28
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 26

def sel
  @sel
end

#targetsObject

An array of the individual targets that will receive a specific variation based on their key. Individual targets with a context kind of 'user' are included here.



34
35
36
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 34

def targets
  @targets
end

#track_eventsObject

Whether LaunchDarkly tracks events for the feature flag, for all rules



58
59
60
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 58

def track_events
  @track_events
end

#track_events_fallthroughObject

Whether LaunchDarkly tracks events for the feature flag, for the default rule



61
62
63
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 61

def track_events_fallthrough
  @track_events_fallthrough
end

#versionObject

Version of the feature flag



31
32
33
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 31

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



99
100
101
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 99

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



104
105
106
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 104

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 72

def self.attribute_map
  {
    :'on' => :'on',
    :'archived' => :'archived',
    :'salt' => :'salt',
    :'sel' => :'sel',
    :'last_modified' => :'lastModified',
    :'version' => :'version',
    :'targets' => :'targets',
    :'context_targets' => :'contextTargets',
    :'rules' => :'rules',
    :'fallthrough' => :'fallthrough',
    :'off_variation' => :'offVariation',
    :'prerequisites' => :'prerequisites',
    :'_site' => :'_site',
    :'_access' => :'_access',
    :'_environment_name' => :'_environmentName',
    :'track_events' => :'trackEvents',
    :'track_events_fallthrough' => :'trackEventsFallthrough',
    :'_debug_events_until_date' => :'_debugEventsUntilDate',
    :'_summary' => :'_summary',
    :'evaluation' => :'evaluation',
    :'migration_settings' => :'migrationSettings'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 478

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



136
137
138
139
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 136

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 109

def self.openapi_types
  {
    :'on' => :'Boolean',
    :'archived' => :'Boolean',
    :'salt' => :'String',
    :'sel' => :'String',
    :'last_modified' => :'Integer',
    :'version' => :'Integer',
    :'targets' => :'Array<Target>',
    :'context_targets' => :'Array<Target>',
    :'rules' => :'Array<Rule>',
    :'fallthrough' => :'VariationOrRolloutRep',
    :'off_variation' => :'Integer',
    :'prerequisites' => :'Array<Prerequisite>',
    :'_site' => :'Link',
    :'_access' => :'Access',
    :'_environment_name' => :'String',
    :'track_events' => :'Boolean',
    :'track_events_fallthrough' => :'Boolean',
    :'_debug_events_until_date' => :'Integer',
    :'_summary' => :'FlagSummary',
    :'evaluation' => :'FlagConfigEvaluation',
    :'migration_settings' => :'FlagConfigMigrationSettingsRep'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 437

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      on == o.on &&
      archived == o.archived &&
      salt == o.salt &&
      sel == o.sel &&
      last_modified == o.last_modified &&
      version == o.version &&
      targets == o.targets &&
      context_targets == o.context_targets &&
      rules == o.rules &&
      fallthrough == o.fallthrough &&
      off_variation == o.off_variation &&
      prerequisites == o.prerequisites &&
      _site == o._site &&
      _access == o._access &&
      _environment_name == o._environment_name &&
      track_events == o.track_events &&
      track_events_fallthrough == o.track_events_fallthrough &&
      _debug_events_until_date == o._debug_events_until_date &&
      _summary == o._summary &&
      evaluation == o.evaluation &&
      migration_settings == o.migration_settings
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


465
466
467
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 465

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



471
472
473
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 471

def hash
  [on, archived, salt, sel, last_modified, version, targets, context_targets, rules, fallthrough, off_variation, prerequisites, _site, _access, _environment_name, track_events, track_events_fallthrough, _debug_events_until_date, _summary, evaluation, migration_settings].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 272

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @on.nil?
    invalid_properties.push('invalid value for "on", on cannot be nil.')
  end

  if @archived.nil?
    invalid_properties.push('invalid value for "archived", archived cannot be nil.')
  end

  if @salt.nil?
    invalid_properties.push('invalid value for "salt", salt cannot be nil.')
  end

  if @sel.nil?
    invalid_properties.push('invalid value for "sel", sel cannot be nil.')
  end

  if @last_modified.nil?
    invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @_site.nil?
    invalid_properties.push('invalid value for "_site", _site cannot be nil.')
  end

  if @_environment_name.nil?
    invalid_properties.push('invalid value for "_environment_name", _environment_name cannot be nil.')
  end

  if @track_events.nil?
    invalid_properties.push('invalid value for "track_events", track_events cannot be nil.')
  end

  if @track_events_fallthrough.nil?
    invalid_properties.push('invalid value for "track_events_fallthrough", track_events_fallthrough cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



500
501
502
503
504
505
506
507
508
509
510
511
512
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 500

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/launchdarkly_api/models/feature_flag_config.rb', line 320

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @on.nil?
  return false if @archived.nil?
  return false if @salt.nil?
  return false if @sel.nil?
  return false if @last_modified.nil?
  return false if @version.nil?
  return false if @_site.nil?
  return false if @_environment_name.nil?
  return false if @track_events.nil?
  return false if @track_events_fallthrough.nil?
  true
end