Class: LaunchDarklyApi::FeatureFlagScheduledChange

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/feature_flag_scheduled_change.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FeatureFlagScheduledChange

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 90

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FeatureFlagScheduledChange` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FeatureFlagScheduledChange`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  else
    self._creation_date = nil
  end

  if attributes.key?(:'_maintainer_id')
    self._maintainer_id = attributes[:'_maintainer_id']
  else
    self._maintainer_id = nil
  end

  if attributes.key?(:'_maintainer_service_token_id')
    self._maintainer_service_token_id = attributes[:'_maintainer_service_token_id']
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  else
    self._version = nil
  end

  if attributes.key?(:'execution_date')
    self.execution_date = attributes[:'execution_date']
  else
    self.execution_date = nil
  end

  if attributes.key?(:'instructions')
    if (value = attributes[:'instructions']).is_a?(Array)
      self.instructions = value
    end
  else
    self.instructions = nil
  end

  if attributes.key?(:'conflicts')
    self.conflicts = attributes[:'conflicts']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end
end

Instance Attribute Details

#_creation_dateObject

Returns the value of attribute _creation_date.



20
21
22
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 20

def _creation_date
  @_creation_date
end

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 18

def _id
  @_id
end

The location and content type of related resources



39
40
41
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 39

def _links
  @_links
end

#_maintainer_idObject

The ID of the scheduled change maintainer



23
24
25
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 23

def _maintainer_id
  @_maintainer_id
end

#_maintainer_service_token_idObject

The ID of the service token that created or updated this scheduled change



26
27
28
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 26

def _maintainer_service_token_id
  @_maintainer_service_token_id
end

#_versionObject

Version of the scheduled change



29
30
31
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 29

def _version
  @_version
end

#conflictsObject

Details on any conflicting scheduled changes



36
37
38
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 36

def conflicts
  @conflicts
end

#execution_dateObject

Returns the value of attribute execution_date.



31
32
33
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 31

def execution_date
  @execution_date
end

#instructionsObject

Returns the value of attribute instructions.



33
34
35
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 33

def instructions
  @instructions
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 42

def self.attribute_map
  {
    :'_id' => :'_id',
    :'_creation_date' => :'_creationDate',
    :'_maintainer_id' => :'_maintainerId',
    :'_maintainer_service_token_id' => :'_maintainerServiceTokenId',
    :'_version' => :'_version',
    :'execution_date' => :'executionDate',
    :'instructions' => :'instructions',
    :'conflicts' => :'conflicts',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 293

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
86
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 82

def self.openapi_nullable
  Set.new([
    :'conflicts',
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 67

def self.openapi_types
  {
    :'_id' => :'String',
    :'_creation_date' => :'Integer',
    :'_maintainer_id' => :'String',
    :'_maintainer_service_token_id' => :'String',
    :'_version' => :'Integer',
    :'execution_date' => :'Integer',
    :'instructions' => :'Array<Hash>',
    :'conflicts' => :'Object',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 264

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      _creation_date == o._creation_date &&
      _maintainer_id == o._maintainer_id &&
      _maintainer_service_token_id == o._maintainer_service_token_id &&
      _version == o._version &&
      execution_date == o.execution_date &&
      instructions == o.instructions &&
      conflicts == o.conflicts &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


280
281
282
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 280

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



286
287
288
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 286

def hash
  [_id, _creation_date, _maintainer_id, _maintainer_service_token_id, _version, execution_date, instructions, conflicts, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_creation_date.nil?
    invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.')
  end

  if @_maintainer_id.nil?
    invalid_properties.push('invalid value for "_maintainer_id", _maintainer_id cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  if @execution_date.nil?
    invalid_properties.push('invalid value for "execution_date", execution_date cannot be nil.')
  end

  if @instructions.nil?
    invalid_properties.push('invalid value for "instructions", instructions cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



315
316
317
318
319
320
321
322
323
324
325
326
327
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 315

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
195
196
197
198
199
200
# File 'lib/launchdarkly_api/models/feature_flag_scheduled_change.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @_creation_date.nil?
  return false if @_maintainer_id.nil?
  return false if @_version.nil?
  return false if @execution_date.nil?
  return false if @instructions.nil?
  true
end