Class: LaunchDarklyApi::FlagCopyConfigPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::FlagCopyConfigPost
- Defined in:
- lib/launchdarkly_api/models/flag_copy_config_post.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#comment ⇒ Object
Optional comment.
-
#excluded_actions ⇒ Object
Optional list of the flag changes NOT to copy from the source environment to the target environment.
-
#included_actions ⇒ Object
Optional list of the flag changes to copy from the source environment to the target environment.
-
#source ⇒ Object
Returns the value of attribute source.
-
#target ⇒ Object
Returns the value of attribute target.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlagCopyConfigPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FlagCopyConfigPost
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagCopyConfigPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagCopyConfigPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'source') self.source = attributes[:'source'] else self.source = nil end if attributes.key?(:'target') self.target = attributes[:'target'] else self.target = nil end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'included_actions') if (value = attributes[:'included_actions']).is_a?(Array) self.included_actions = value end end if attributes.key?(:'excluded_actions') if (value = attributes[:'excluded_actions']).is_a?(Array) self.excluded_actions = value end end end |
Instance Attribute Details
#comment ⇒ Object
Optional comment
23 24 25 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 23 def comment @comment end |
#excluded_actions ⇒ Object
Optional list of the flag changes NOT to copy from the source environment to the target environment. You may include either includedActions or excludedActions, but not both. If you include neither, then all flag changes will be copied.
29 30 31 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 29 def excluded_actions @excluded_actions end |
#included_actions ⇒ Object
Optional list of the flag changes to copy from the source environment to the target environment. You may include either includedActions or excludedActions, but not both. If you include neither, then all flag changes will be copied.
26 27 28 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 26 def included_actions @included_actions end |
#source ⇒ Object
Returns the value of attribute source.
18 19 20 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 18 def source @source end |
#target ⇒ Object
Returns the value of attribute target.
20 21 22 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 20 def target @target end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
65 66 67 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 65 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
70 71 72 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 70 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
54 55 56 57 58 59 60 61 62 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 54 def self.attribute_map { :'source' => :'source', :'target' => :'target', :'comment' => :'comment', :'included_actions' => :'includedActions', :'excluded_actions' => :'excludedActions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 208 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
75 76 77 78 79 80 81 82 83 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 75 def self.openapi_types { :'source' => :'FlagCopyConfigEnvironment', :'target' => :'FlagCopyConfigEnvironment', :'comment' => :'String', :'included_actions' => :'Array<String>', :'excluded_actions' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && source == o.source && target == o.target && comment == o.comment && included_actions == o.included_actions && excluded_actions == o.excluded_actions end |
#eql?(o) ⇒ Boolean
195 196 197 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 195 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
201 202 203 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 201 def hash [source, target, comment, included_actions, excluded_actions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @source.nil? invalid_properties.push('invalid value for "source", source cannot be nil.') end if @target.nil? invalid_properties.push('invalid value for "target", target cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 230 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
154 155 156 157 158 159 |
# File 'lib/launchdarkly_api/models/flag_copy_config_post.rb', line 154 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @source.nil? return false if @target.nil? true end |