Class: LaunchDarklyApi::FlagDefaultsRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/flag_defaults_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlagDefaultsRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 76

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagDefaultsRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagDefaultsRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'temporary')
    self.temporary = attributes[:'temporary']
  end

  if attributes.key?(:'default_client_side_availability')
    self.default_client_side_availability = attributes[:'default_client_side_availability']
  end

  if attributes.key?(:'boolean_defaults')
    self.boolean_defaults = attributes[:'boolean_defaults']
  end
end

Instance Attribute Details

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 19

def _links
  @_links
end

#boolean_defaultsObject

Returns the value of attribute boolean_defaults.



32
33
34
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 32

def boolean_defaults
  @boolean_defaults
end

#default_client_side_availabilityObject

Returns the value of attribute default_client_side_availability.



30
31
32
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 30

def default_client_side_availability
  @default_client_side_availability
end

#keyObject

A unique key for the flag default



22
23
24
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 22

def key
  @key
end

#tagsObject

A list of default tags for each flag



25
26
27
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 25

def tags
  @tags
end

#temporaryObject

Whether the flag should be temporary by default



28
29
30
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 28

def temporary
  @temporary
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 35

def self.attribute_map
  {
    :'_links' => :'_links',
    :'key' => :'key',
    :'tags' => :'tags',
    :'temporary' => :'temporary',
    :'default_client_side_availability' => :'defaultClientSideAvailability',
    :'boolean_defaults' => :'booleanDefaults'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 162

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



69
70
71
72
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 69

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 57

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'key' => :'String',
    :'tags' => :'Array<String>',
    :'temporary' => :'Boolean',
    :'default_client_side_availability' => :'ClientSideAvailability',
    :'boolean_defaults' => :'BooleanDefaults'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
143
144
145
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      key == o.key &&
      tags == o.tags &&
      temporary == o.temporary &&
      default_client_side_availability == o.default_client_side_availability &&
      boolean_defaults == o.boolean_defaults
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


149
150
151
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 149

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



155
156
157
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 155

def hash
  [_links, key, tags, temporary, default_client_side_availability, boolean_defaults].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



121
122
123
124
125
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 121

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 184

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



129
130
131
132
# File 'lib/launchdarkly_api/models/flag_defaults_rep.rb', line 129

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end