Class: LaunchDarklyApi::FlagEventRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/flag_event_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlagEventRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagEventRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagEventRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'project_id')
    self.project_id = attributes[:'project_id']
  else
    self.project_id = nil
  end

  if attributes.key?(:'project_key')
    self.project_key = attributes[:'project_key']
  else
    self.project_key = nil
  end

  if attributes.key?(:'environment_id')
    self.environment_id = attributes[:'environment_id']
  end

  if attributes.key?(:'environment_key')
    self.environment_key = attributes[:'environment_key']
  end

  if attributes.key?(:'flag_key')
    self.flag_key = attributes[:'flag_key']
  else
    self.flag_key = nil
  end

  if attributes.key?(:'event_type')
    self.event_type = attributes[:'event_type']
  else
    self.event_type = nil
  end

  if attributes.key?(:'event_time')
    self.event_time = attributes[:'event_time']
  else
    self.event_time = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'audit_log_entry_id')
    self.audit_log_entry_id = attributes[:'audit_log_entry_id']
  end

  if attributes.key?(:'member')
    self.member = attributes[:'member']
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'impact')
    self.impact = attributes[:'impact']
  else
    self.impact = nil
  end

  if attributes.key?(:'experiments')
    self.experiments = attributes[:'experiments']
  end
end

Instance Attribute Details

#actionsObject

The resource actions



49
50
51
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 49

def actions
  @actions
end

#audit_log_entry_idObject

The audit log entry ID



44
45
46
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 44

def audit_log_entry_id
  @audit_log_entry_id
end

#descriptionObject

The event description



41
42
43
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 41

def description
  @description
end

#environment_idObject

The environment ID



28
29
30
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 28

def environment_id
  @environment_id
end

#environment_keyObject

The environment key



31
32
33
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 31

def environment_key
  @environment_key
end

#event_timeObject

Returns the value of attribute event_time.



38
39
40
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 38

def event_time
  @event_time
end

#event_typeObject

Returns the value of attribute event_type.



36
37
38
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 36

def event_type
  @event_type
end

#experimentsObject

Returns the value of attribute experiments.



53
54
55
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 53

def experiments
  @experiments
end

#flag_keyObject

The flag key



34
35
36
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 34

def flag_key
  @flag_key
end

#idObject

The flag event ID



19
20
21
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 19

def id
  @id
end

#impactObject

Returns the value of attribute impact.



51
52
53
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 51

def impact
  @impact
end

#memberObject

Returns the value of attribute member.



46
47
48
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 46

def member
  @member
end

#project_idObject

The project ID



22
23
24
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 22

def project_id
  @project_id
end

#project_keyObject

The project key



25
26
27
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 25

def project_key
  @project_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 56

def self.attribute_map
  {
    :'id' => :'id',
    :'project_id' => :'projectId',
    :'project_key' => :'projectKey',
    :'environment_id' => :'environmentId',
    :'environment_key' => :'environmentKey',
    :'flag_key' => :'flagKey',
    :'event_type' => :'eventType',
    :'event_time' => :'eventTime',
    :'description' => :'description',
    :'audit_log_entry_id' => :'auditLogEntryId',
    :'member' => :'member',
    :'actions' => :'actions',
    :'impact' => :'impact',
    :'experiments' => :'experiments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 373

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 86

def self.openapi_types
  {
    :'id' => :'String',
    :'project_id' => :'String',
    :'project_key' => :'String',
    :'environment_id' => :'String',
    :'environment_key' => :'String',
    :'flag_key' => :'String',
    :'event_type' => :'String',
    :'event_time' => :'Integer',
    :'description' => :'String',
    :'audit_log_entry_id' => :'String',
    :'member' => :'FlagEventMemberRep',
    :'actions' => :'Array<String>',
    :'impact' => :'FlagEventImpactRep',
    :'experiments' => :'FlagEventExperimentCollection'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 339

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      project_id == o.project_id &&
      project_key == o.project_key &&
      environment_id == o.environment_id &&
      environment_key == o.environment_key &&
      flag_key == o.flag_key &&
      event_type == o.event_type &&
      event_time == o.event_time &&
      description == o.description &&
      audit_log_entry_id == o.audit_log_entry_id &&
      member == o.member &&
      actions == o.actions &&
      impact == o.impact &&
      experiments == o.experiments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


360
361
362
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 360

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



366
367
368
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 366

def hash
  [id, project_id, project_key, environment_id, environment_key, flag_key, event_type, event_time, description, audit_log_entry_id, member, actions, impact, experiments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 204

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @project_id.nil?
    invalid_properties.push('invalid value for "project_id", project_id cannot be nil.')
  end

  if @project_key.nil?
    invalid_properties.push('invalid value for "project_key", project_key cannot be nil.')
  end

  if @flag_key.nil?
    invalid_properties.push('invalid value for "flag_key", flag_key cannot be nil.')
  end

  if @event_type.nil?
    invalid_properties.push('invalid value for "event_type", event_type cannot be nil.')
  end

  if @event_time.nil?
    invalid_properties.push('invalid value for "event_time", event_time cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @impact.nil?
    invalid_properties.push('invalid value for "impact", impact cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



395
396
397
398
399
400
401
402
403
404
405
406
407
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 395

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 244

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @id.nil?
  return false if @project_id.nil?
  return false if @project_key.nil?
  return false if @flag_key.nil?
  return false if @event_type.nil?
  return false if @event_time.nil?
  return false if @description.nil?
  return false if @impact.nil?
  true
end