Class: LaunchDarklyApi::FlagRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/flag_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FlagRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'targeting_rule')
    self.targeting_rule = attributes[:'targeting_rule']
  end

  if attributes.key?(:'targeting_rule_description')
    self.targeting_rule_description = attributes[:'targeting_rule_description']
  end

  if attributes.key?(:'targeting_rule_clauses')
    if (value = attributes[:'targeting_rule_clauses']).is_a?(Array)
      self.targeting_rule_clauses = value
    end
  end

  if attributes.key?(:'flag_config_version')
    self.flag_config_version = attributes[:'flag_config_version']
  end

  if attributes.key?(:'not_in_experiment_variation_id')
    self.not_in_experiment_variation_id = attributes[:'not_in_experiment_variation_id']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end
end

Instance Attribute Details

The location and content type of related resources



34
35
36
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 34

def _links
  @_links
end

#flag_config_versionObject

The flag version



28
29
30
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 28

def flag_config_version
  @flag_config_version
end

#not_in_experiment_variation_idObject

The ID of the variation to route traffic not part of the experiment analysis to



31
32
33
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 31

def not_in_experiment_variation_id
  @not_in_experiment_variation_id
end

#targeting_ruleObject

The targeting rule



19
20
21
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 19

def targeting_rule
  @targeting_rule
end

#targeting_rule_clausesObject

An array of clauses used for individual targeting based on attributes



25
26
27
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 25

def targeting_rule_clauses
  @targeting_rule_clauses
end

#targeting_rule_descriptionObject

The rule description



22
23
24
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 22

def targeting_rule_description
  @targeting_rule_description
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 37

def self.attribute_map
  {
    :'targeting_rule' => :'targetingRule',
    :'targeting_rule_description' => :'targetingRuleDescription',
    :'targeting_rule_clauses' => :'targetingRuleClauses',
    :'flag_config_version' => :'flagConfigVersion',
    :'not_in_experiment_variation_id' => :'notInExperimentVariationId',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 181

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 59

def self.openapi_types
  {
    :'targeting_rule' => :'String',
    :'targeting_rule_description' => :'String',
    :'targeting_rule_clauses' => :'Array<Object>',
    :'flag_config_version' => :'Integer',
    :'not_in_experiment_variation_id' => :'String',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



155
156
157
158
159
160
161
162
163
164
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 155

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      targeting_rule == o.targeting_rule &&
      targeting_rule_description == o.targeting_rule_description &&
      targeting_rule_clauses == o.targeting_rule_clauses &&
      flag_config_version == o.flag_config_version &&
      not_in_experiment_variation_id == o.not_in_experiment_variation_id &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


168
169
170
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 168

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



174
175
176
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 174

def hash
  [targeting_rule, targeting_rule_description, targeting_rule_clauses, flag_config_version, not_in_experiment_variation_id, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 203

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



137
138
139
140
141
# File 'lib/launchdarkly_api/models/flag_rep.rb', line 137

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  true
end