Class: LaunchDarklyApi::FlagStatusRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::FlagStatusRep
- Defined in:
- lib/launchdarkly_api/models/flag_status_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#default ⇒ Object
Default value seen from code.
-
#last_requested ⇒ Object
Timestamp of last time flag was requested.
-
#name ⇒ Object
Status of the flag.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlagStatusRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FlagStatusRep
Initializes the object
90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 90 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagStatusRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagStatusRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'last_requested') self.last_requested = attributes[:'last_requested'] end if attributes.key?(:'default') self.default = attributes[:'default'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
27 28 29 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 27 def _links @_links end |
#default ⇒ Object
Default value seen from code
25 26 27 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 25 def default @default end |
#last_requested ⇒ Object
Timestamp of last time flag was requested
22 23 24 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 22 def last_requested @last_requested end |
#name ⇒ Object
Status of the flag
19 20 21 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 19 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 52 def self.attribute_map { :'name' => :'name', :'last_requested' => :'lastRequested', :'default' => :'default', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 200 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
82 83 84 85 86 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 82 def self.openapi_nullable Set.new([ :'default', ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 72 def self.openapi_types { :'name' => :'String', :'last_requested' => :'Time', :'default' => :'Object', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && last_requested == o.last_requested && default == o.default && _links == o._links end |
#eql?(o) ⇒ Boolean
187 188 189 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 187 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
193 194 195 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 193 def hash [name, last_requested, default, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
222 223 224 225 226 227 228 229 230 231 232 233 234 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 222 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 152 |
# File 'lib/launchdarkly_api/models/flag_status_rep.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? name_validator = EnumAttributeValidator.new('String', ["new", "inactive", "active", "launched"]) return false unless name_validator.valid?(@name) return false if @_links.nil? true end |