Class: LaunchDarklyApi::FollowFlagMember

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/follow_flag_member.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ FollowFlagMember

Initializes the object



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FollowFlagMember` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FollowFlagMember`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end
end

Instance Attribute Details

#_id ⇒ Object

The member's ID



22
23
24
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 22

def _id
  @_id
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 19

def _links
  @_links
end

#email ⇒ Object

The member's email address



34
35
36
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 34

def email
  @email
end

#first_name ⇒ Object

The member's first name



25
26
27
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 25

def first_name
  @first_name
end

#last_name ⇒ Object

The member's last name



28
29
30
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 28

def last_name
  @last_name
end

#role ⇒ Object

The member's base role. If the member has no additional roles, this role will be in effect.



31
32
33
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 31

def role
  @role
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 37

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'role' => :'role',
    :'email' => :'email'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 230

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



71
72
73
74
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 59

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'role' => :'String',
    :'email' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



204
205
206
207
208
209
210
211
212
213
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 204

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      role == o.role &&
      email == o.email
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


217
218
219
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 217

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



223
224
225
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 223

def hash
  [_links, _id, first_name, last_name, role, email].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 129

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



252
253
254
255
256
257
258
259
260
261
262
263
264
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 252

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



153
154
155
156
157
158
159
160
# File 'lib/launchdarkly_api/models/follow_flag_member.rb', line 153

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @role.nil?
  return false if @email.nil?
  true
end