Class: LaunchDarklyApi::HoldoutDetailRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/holdout_detail_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ HoldoutDetailRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::HoldoutDetailRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::HoldoutDetailRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'holdout_amount')
    self.holdout_amount = attributes[:'holdout_amount']
  else
    self.holdout_amount = nil
  end

  if attributes.key?(:'is_dirty')
    self.is_dirty = attributes[:'is_dirty']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'base_experiment')
    self.base_experiment = attributes[:'base_experiment']
  else
    self.base_experiment = nil
  end

  if attributes.key?(:'related_experiments')
    if (value = attributes[:'related_experiments']).is_a?(Array)
      self.related_experiments = value
    end
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 18

def _id
  @_id
end

#base_experimentObject

Returns the value of attribute base_experiment.



34
35
36
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 34

def base_experiment
  @base_experiment
end

#created_atObject

Returns the value of attribute created_at.



30
31
32
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 30

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 22

def description
  @description
end

#holdout_amountObject

The percentage of traffic allocated to this holdout.



25
26
27
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 25

def holdout_amount
  @holdout_amount
end

#is_dirtyObject

Indicates if the holdout experiment is running and if any related experiments are running.



28
29
30
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 28

def is_dirty
  @is_dirty
end

Returns the value of attribute related_experiments.



36
37
38
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 36

def related_experiments
  @related_experiments
end

#statusObject

Returns the value of attribute status.



20
21
22
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 20

def status
  @status
end

#updated_atObject

Returns the value of attribute updated_at.



32
33
34
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 32

def updated_at
  @updated_at
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 61

def self.attribute_map
  {
    :'_id' => :'_id',
    :'status' => :'status',
    :'description' => :'description',
    :'holdout_amount' => :'holdoutAmount',
    :'is_dirty' => :'isDirty',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'base_experiment' => :'baseExperiment',
    :'related_experiments' => :'relatedExperiments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 311

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 86

def self.openapi_types
  {
    :'_id' => :'String',
    :'status' => :'String',
    :'description' => :'String',
    :'holdout_amount' => :'String',
    :'is_dirty' => :'Boolean',
    :'created_at' => :'Integer',
    :'updated_at' => :'Integer',
    :'base_experiment' => :'Experiment',
    :'related_experiments' => :'Array<Experiment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 282

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      status == o.status &&
      description == o.description &&
      holdout_amount == o.holdout_amount &&
      is_dirty == o.is_dirty &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      base_experiment == o.base_experiment &&
      related_experiments == o.related_experiments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


298
299
300
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 298

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



304
305
306
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 304

def hash
  [_id, status, description, holdout_amount, is_dirty, created_at, updated_at, base_experiment, related_experiments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 175

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @holdout_amount.nil?
    invalid_properties.push('invalid value for "holdout_amount", holdout_amount cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  if @base_experiment.nil?
    invalid_properties.push('invalid value for "base_experiment", base_experiment cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 333

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



207
208
209
210
211
212
213
214
215
216
217
218
# File 'lib/launchdarkly_api/models/holdout_detail_rep.rb', line 207

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @status.nil?
  status_validator = EnumAttributeValidator.new('String', ["created", "enabled", "running", "ended"])
  return false unless status_validator.valid?(@status)
  return false if @holdout_amount.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  return false if @base_experiment.nil?
  true
end