Class: LaunchDarklyApi::HoldoutPostRequest

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/holdout_post_request.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ HoldoutPostRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::HoldoutPostRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::HoldoutPostRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'randomizationunit')
    self.randomizationunit = attributes[:'randomizationunit']
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Array)
      self.attributes = value
    end
  end

  if attributes.key?(:'holdoutamount')
    self.holdoutamount = attributes[:'holdoutamount']
  end

  if attributes.key?(:'primarymetrickey')
    self.primarymetrickey = attributes[:'primarymetrickey']
  end

  if attributes.key?(:'metrics')
    if (value = attributes[:'metrics']).is_a?(Array)
      self.metrics = value
    end
  end

  if attributes.key?(:'prerequisiteflagkey')
    self.prerequisiteflagkey = attributes[:'prerequisiteflagkey']
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end
end

Instance Attribute Details

#attributesObject

The attributes that the holdout iteration's results can be sliced by



31
32
33
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 31

def attributes
  @attributes
end

#descriptionObject

Description of the holdout



25
26
27
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 25

def description
  @description
end

#holdoutamountObject

Audience allocation for the holdout



34
35
36
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 34

def holdoutamount
  @holdoutamount
end

#keyObject

A key that identifies the holdout



22
23
24
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 22

def key
  @key
end

#maintainer_idObject

Maintainer id



46
47
48
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 46

def maintainer_id
  @maintainer_id
end

#metricsObject

Details on the metrics for this experiment



40
41
42
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 40

def metrics
  @metrics
end

#nameObject

A human-friendly name for the holdout



19
20
21
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 19

def name
  @name
end

#prerequisiteflagkeyObject

The key of the flag that the holdout is dependent on



43
44
45
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 43

def prerequisiteflagkey
  @prerequisiteflagkey
end

#primarymetrickeyObject

The key of the primary metric for this holdout



37
38
39
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 37

def primarymetrickey
  @primarymetrickey
end

#randomizationunitObject

The chosen randomization unit for the holdout base experiment



28
29
30
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 28

def randomizationunit
  @randomizationunit
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 49

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'description' => :'description',
    :'randomizationunit' => :'randomizationunit',
    :'attributes' => :'attributes',
    :'holdoutamount' => :'holdoutamount',
    :'primarymetrickey' => :'primarymetrickey',
    :'metrics' => :'metrics',
    :'prerequisiteflagkey' => :'prerequisiteflagkey',
    :'maintainer_id' => :'maintainerId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 204

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 75

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'description' => :'String',
    :'randomizationunit' => :'String',
    :'attributes' => :'Array<String>',
    :'holdoutamount' => :'String',
    :'primarymetrickey' => :'String',
    :'metrics' => :'Array<MetricInput>',
    :'prerequisiteflagkey' => :'String',
    :'maintainer_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      description == o.description &&
      randomizationunit == o.randomizationunit &&
      attributes == o.attributes &&
      holdoutamount == o.holdoutamount &&
      primarymetrickey == o.primarymetrickey &&
      metrics == o.metrics &&
      prerequisiteflagkey == o.prerequisiteflagkey &&
      maintainer_id == o.maintainer_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


191
192
193
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 191

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



197
198
199
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 197

def hash
  [name, key, description, randomizationunit, attributes, holdoutamount, primarymetrickey, metrics, prerequisiteflagkey, maintainer_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



159
160
161
162
163
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 159

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 226

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
# File 'lib/launchdarkly_api/models/holdout_post_request.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end