Class: LaunchDarklyApi::IPAllowlistBetaApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/ip_allowlist_beta_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ IPAllowlistBetaApi

Returns a new instance of IPAllowlistBetaApi.



19
20
21
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_ip_allowlist_entry(create_ip_allowlist_entry_request, opts = {}) ⇒ IpAllowlistEntryResponse

Create IP Allowlist Entry Create a new IP allowlist entry.

Parameters:

Returns:



27
28
29
30
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 27

def create_ip_allowlist_entry(create_ip_allowlist_entry_request, opts = {})
  data, _status_code, _headers = create_ip_allowlist_entry_with_http_info(create_ip_allowlist_entry_request, opts)
  data
end

#create_ip_allowlist_entry_with_http_info(create_ip_allowlist_entry_request, opts = {}) ⇒ Array<(IpAllowlistEntryResponse, Integer, Hash)>

Create IP Allowlist Entry Create a new IP allowlist entry.

Parameters:

Returns:

  • (Array<(IpAllowlistEntryResponse, Integer, Hash)>)

    IpAllowlistEntryResponse data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 37

def create_ip_allowlist_entry_with_http_info(create_ip_allowlist_entry_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IPAllowlistBetaApi.create_ip_allowlist_entry ...'
  end
  # verify the required parameter 'create_ip_allowlist_entry_request' is set
  if @api_client.config.client_side_validation && create_ip_allowlist_entry_request.nil?
    fail ArgumentError, "Missing the required parameter 'create_ip_allowlist_entry_request' when calling IPAllowlistBetaApi.create_ip_allowlist_entry"
  end
  # resource path
  local_var_path = '/api/v2/account/ip-allowlist'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_ip_allowlist_entry_request)

  # return_type
  return_type = opts[:debug_return_type] || 'IpAllowlistEntryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"IPAllowlistBetaApi.create_ip_allowlist_entry",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IPAllowlistBetaApi#create_ip_allowlist_entry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_ip_allowlist_entry(id, opts = {}) ⇒ nil

Delete IP Allowlist Entry Delete an IP allowlist entry by id.

Parameters:

  • id (String)

    Unique identifier for the allowlist entry

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


95
96
97
98
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 95

def delete_ip_allowlist_entry(id, opts = {})
  delete_ip_allowlist_entry_with_http_info(id, opts)
  nil
end

#delete_ip_allowlist_entry_with_http_info(id, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete IP Allowlist Entry Delete an IP allowlist entry by id.

Parameters:

  • id (String)

    Unique identifier for the allowlist entry

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 105

def delete_ip_allowlist_entry_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IPAllowlistBetaApi.delete_ip_allowlist_entry ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling IPAllowlistBetaApi.delete_ip_allowlist_entry"
  end
  # resource path
  local_var_path = '/api/v2/account/ip-allowlist/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"IPAllowlistBetaApi.delete_ip_allowlist_entry",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IPAllowlistBetaApi#delete_ip_allowlist_entry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_ip_allowlist(opts = {}) ⇒ IpAllowlistResponse

Get IP Allowlist Get the current IP allowlist configuration and entries.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



157
158
159
160
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 157

def get_ip_allowlist(opts = {})
  data, _status_code, _headers = get_ip_allowlist_with_http_info(opts)
  data
end

#get_ip_allowlist_with_http_info(opts = {}) ⇒ Array<(IpAllowlistResponse, Integer, Hash)>

Get IP Allowlist Get the current IP allowlist configuration and entries.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(IpAllowlistResponse, Integer, Hash)>)

    IpAllowlistResponse data, response status code and response headers



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 166

def get_ip_allowlist_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IPAllowlistBetaApi.get_ip_allowlist ...'
  end
  # resource path
  local_var_path = '/api/v2/account/ip-allowlist'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'IpAllowlistResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"IPAllowlistBetaApi.get_ip_allowlist",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IPAllowlistBetaApi#get_ip_allowlist\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_ip_allowlist_config(patch_ip_allowlist_config_request, opts = {}) ⇒ IpAllowlistResponse

Update IP Allowlist Configuration Update sessionAllowlistEnabled and apiTokenAllowlistEnabled settings.

Parameters:

Returns:



215
216
217
218
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 215

def patch_ip_allowlist_config(patch_ip_allowlist_config_request, opts = {})
  data, _status_code, _headers = patch_ip_allowlist_config_with_http_info(patch_ip_allowlist_config_request, opts)
  data
end

#patch_ip_allowlist_config_with_http_info(patch_ip_allowlist_config_request, opts = {}) ⇒ Array<(IpAllowlistResponse, Integer, Hash)>

Update IP Allowlist Configuration Update sessionAllowlistEnabled and apiTokenAllowlistEnabled settings.

Parameters:

Returns:

  • (Array<(IpAllowlistResponse, Integer, Hash)>)

    IpAllowlistResponse data, response status code and response headers



225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 225

def patch_ip_allowlist_config_with_http_info(patch_ip_allowlist_config_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IPAllowlistBetaApi.patch_ip_allowlist_config ...'
  end
  # verify the required parameter 'patch_ip_allowlist_config_request' is set
  if @api_client.config.client_side_validation && patch_ip_allowlist_config_request.nil?
    fail ArgumentError, "Missing the required parameter 'patch_ip_allowlist_config_request' when calling IPAllowlistBetaApi.patch_ip_allowlist_config"
  end
  # resource path
  local_var_path = '/api/v2/account/ip-allowlist'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_ip_allowlist_config_request)

  # return_type
  return_type = opts[:debug_return_type] || 'IpAllowlistResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"IPAllowlistBetaApi.patch_ip_allowlist_config",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IPAllowlistBetaApi#patch_ip_allowlist_config\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_ip_allowlist_entry(id, patch_ip_allowlist_entry_request, opts = {}) ⇒ IpAllowlistEntryResponse

Update IP Allowlist Entry Description Update the description of an IP allowlist entry.

Parameters:

  • id (String)

    Unique identifier for the allowlist entry

  • patch_ip_allowlist_entry_request (PatchIpAllowlistEntryRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



284
285
286
287
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 284

def patch_ip_allowlist_entry(id, patch_ip_allowlist_entry_request, opts = {})
  data, _status_code, _headers = patch_ip_allowlist_entry_with_http_info(id, patch_ip_allowlist_entry_request, opts)
  data
end

#patch_ip_allowlist_entry_with_http_info(id, patch_ip_allowlist_entry_request, opts = {}) ⇒ Array<(IpAllowlistEntryResponse, Integer, Hash)>

Update IP Allowlist Entry Description Update the description of an IP allowlist entry.

Parameters:

  • id (String)

    Unique identifier for the allowlist entry

  • patch_ip_allowlist_entry_request (PatchIpAllowlistEntryRequest)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(IpAllowlistEntryResponse, Integer, Hash)>)

    IpAllowlistEntryResponse data, response status code and response headers



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
# File 'lib/launchdarkly_api/api/ip_allowlist_beta_api.rb', line 295

def patch_ip_allowlist_entry_with_http_info(id, patch_ip_allowlist_entry_request, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: IPAllowlistBetaApi.patch_ip_allowlist_entry ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling IPAllowlistBetaApi.patch_ip_allowlist_entry"
  end
  # verify the required parameter 'patch_ip_allowlist_entry_request' is set
  if @api_client.config.client_side_validation && patch_ip_allowlist_entry_request.nil?
    fail ArgumentError, "Missing the required parameter 'patch_ip_allowlist_entry_request' when calling IPAllowlistBetaApi.patch_ip_allowlist_entry"
  end
  # resource path
  local_var_path = '/api/v2/account/ip-allowlist/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_ip_allowlist_entry_request)

  # return_type
  return_type = opts[:debug_return_type] || 'IpAllowlistEntryResponse'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"IPAllowlistBetaApi.patch_ip_allowlist_entry",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: IPAllowlistBetaApi#patch_ip_allowlist_entry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end