Class: LaunchDarklyApi::Import
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::Import
- Defined in:
- lib/launchdarkly_api/models/import.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#creation_time ⇒ Object
Returns the value of attribute creation_time.
-
#files ⇒ Object
The imported files and their status.
-
#id ⇒ Object
The import ID.
-
#mode ⇒ Object
The import mode used, either
mergeorreplace. -
#segment_key ⇒ Object
The segment key.
-
#status ⇒ Object
The import status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Import
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Import
Initializes the object
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/launchdarkly_api/models/import.rb', line 104 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Import` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Import`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'segment_key') self.segment_key = attributes[:'segment_key'] else self.segment_key = nil end if attributes.key?(:'creation_time') self.creation_time = attributes[:'creation_time'] else self.creation_time = nil end if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'files') if (value = attributes[:'files']).is_a?(Array) self.files = value end end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
36 37 38 |
# File 'lib/launchdarkly_api/models/import.rb', line 36 def _links @_links end |
#creation_time ⇒ Object
Returns the value of attribute creation_time.
24 25 26 |
# File 'lib/launchdarkly_api/models/import.rb', line 24 def creation_time @creation_time end |
#files ⇒ Object
The imported files and their status
33 34 35 |
# File 'lib/launchdarkly_api/models/import.rb', line 33 def files @files end |
#id ⇒ Object
The import ID
19 20 21 |
# File 'lib/launchdarkly_api/models/import.rb', line 19 def id @id end |
#mode ⇒ Object
The import mode used, either merge or replace
27 28 29 |
# File 'lib/launchdarkly_api/models/import.rb', line 27 def mode @mode end |
#segment_key ⇒ Object
The segment key
22 23 24 |
# File 'lib/launchdarkly_api/models/import.rb', line 22 def segment_key @segment_key end |
#status ⇒ Object
The import status
30 31 32 |
# File 'lib/launchdarkly_api/models/import.rb', line 30 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/launchdarkly_api/models/import.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/launchdarkly_api/models/import.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/launchdarkly_api/models/import.rb', line 61 def self.attribute_map { :'id' => :'id', :'segment_key' => :'segmentKey', :'creation_time' => :'creationTime', :'mode' => :'mode', :'status' => :'status', :'files' => :'files', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/launchdarkly_api/models/import.rb', line 299 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
97 98 99 100 |
# File 'lib/launchdarkly_api/models/import.rb', line 97 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 |
# File 'lib/launchdarkly_api/models/import.rb', line 84 def self.openapi_types { :'id' => :'String', :'segment_key' => :'String', :'creation_time' => :'Integer', :'mode' => :'String', :'status' => :'String', :'files' => :'Array<FileRep>', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/launchdarkly_api/models/import.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && segment_key == o.segment_key && creation_time == o.creation_time && mode == o.mode && status == o.status && files == o.files && _links == o._links end |
#eql?(o) ⇒ Boolean
286 287 288 |
# File 'lib/launchdarkly_api/models/import.rb', line 286 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
292 293 294 |
# File 'lib/launchdarkly_api/models/import.rb', line 292 def hash [id, segment_key, creation_time, mode, status, files, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 |
# File 'lib/launchdarkly_api/models/import.rb', line 165 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @segment_key.nil? invalid_properties.push('invalid value for "segment_key", segment_key cannot be nil.') end if @creation_time.nil? invalid_properties.push('invalid value for "creation_time", creation_time cannot be nil.') end if @mode.nil? invalid_properties.push('invalid value for "mode", mode cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
321 322 323 324 325 326 327 328 329 330 331 332 333 |
# File 'lib/launchdarkly_api/models/import.rb', line 321 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/launchdarkly_api/models/import.rb', line 197 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @segment_key.nil? return false if @creation_time.nil? return false if @mode.nil? return false if @status.nil? status_validator = EnumAttributeValidator.new('String', ["preparing", "pending_approval", "ready", "in_progress", "complete", "stopped"]) return false unless status_validator.valid?(@status) return false if @_links.nil? true end |