Class: LaunchDarklyApi::InsightGroup

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/insight_group.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InsightGroup

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/launchdarkly_api/models/insight_group.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightGroup` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightGroup`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'scores')
    self.scores = attributes[:'scores']
  end

  if attributes.key?(:'score_metadata')
    self. = attributes[:'score_metadata']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'project_key')
    self.project_key = attributes[:'project_key']
  else
    self.project_key = nil
  end

  if attributes.key?(:'environment_key')
    self.environment_key = attributes[:'environment_key']
  else
    self.environment_key = nil
  end

  if attributes.key?(:'application_keys')
    if (value = attributes[:'application_keys']).is_a?(Array)
      self.application_keys = value
    end
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#application_keysObject

The application keys



37
38
39
# File 'lib/launchdarkly_api/models/insight_group.rb', line 37

def application_keys
  @application_keys
end

#created_atObject

Returns the value of attribute created_at.



39
40
41
# File 'lib/launchdarkly_api/models/insight_group.rb', line 39

def created_at
  @created_at
end

#environmentObject

Returns the value of attribute environment.



18
19
20
# File 'lib/launchdarkly_api/models/insight_group.rb', line 18

def environment
  @environment
end

#environment_keyObject

The environment key



34
35
36
# File 'lib/launchdarkly_api/models/insight_group.rb', line 34

def environment_key
  @environment_key
end

#keyObject

The insight group key



25
26
27
# File 'lib/launchdarkly_api/models/insight_group.rb', line 25

def key
  @key
end

#nameObject

The insight group name



28
29
30
# File 'lib/launchdarkly_api/models/insight_group.rb', line 28

def name
  @name
end

#project_keyObject

The project key



31
32
33
# File 'lib/launchdarkly_api/models/insight_group.rb', line 31

def project_key
  @project_key
end

#score_metadataObject

Returns the value of attribute score_metadata.



22
23
24
# File 'lib/launchdarkly_api/models/insight_group.rb', line 22

def 
  @score_metadata
end

#scoresObject

Returns the value of attribute scores.



20
21
22
# File 'lib/launchdarkly_api/models/insight_group.rb', line 20

def scores
  @scores
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/launchdarkly_api/models/insight_group.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/launchdarkly_api/models/insight_group.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/launchdarkly_api/models/insight_group.rb', line 42

def self.attribute_map
  {
    :'environment' => :'environment',
    :'scores' => :'scores',
    :'score_metadata' => :'scoreMetadata',
    :'key' => :'key',
    :'name' => :'name',
    :'project_key' => :'projectKey',
    :'environment_key' => :'environmentKey',
    :'application_keys' => :'applicationKeys',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/launchdarkly_api/models/insight_group.rb', line 273

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/launchdarkly_api/models/insight_group.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/launchdarkly_api/models/insight_group.rb', line 67

def self.openapi_types
  {
    :'environment' => :'Environment',
    :'scores' => :'InsightGroupScores',
    :'score_metadata' => :'InsightGroupCollectionScoreMetadata',
    :'key' => :'String',
    :'name' => :'String',
    :'project_key' => :'String',
    :'environment_key' => :'String',
    :'application_keys' => :'Array<String>',
    :'created_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/launchdarkly_api/models/insight_group.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      environment == o.environment &&
      scores == o.scores &&
       == o. &&
      key == o.key &&
      name == o.name &&
      project_key == o.project_key &&
      environment_key == o.environment_key &&
      application_keys == o.application_keys &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/launchdarkly_api/models/insight_group.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/launchdarkly_api/models/insight_group.rb', line 266

def hash
  [environment, scores, , key, name, project_key, environment_key, application_keys, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/launchdarkly_api/models/insight_group.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @project_key.nil?
    invalid_properties.push('invalid value for "project_key", project_key cannot be nil.')
  end

  if @environment_key.nil?
    invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/launchdarkly_api/models/insight_group.rb', line 295

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
# File 'lib/launchdarkly_api/models/insight_group.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @project_key.nil?
  return false if @environment_key.nil?
  return false if @created_at.nil?
  true
end