Class: LaunchDarklyApi::InsightGroupsCountByIndicator

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InsightGroupsCountByIndicator

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightGroupsCountByIndicator` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightGroupsCountByIndicator`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'excellent')
    self.excellent = attributes[:'excellent']
  else
    self.excellent = nil
  end

  if attributes.key?(:'good')
    self.good = attributes[:'good']
  else
    self.good = nil
  end

  if attributes.key?(:'fair')
    self.fair = attributes[:'fair']
  else
    self.fair = nil
  end

  if attributes.key?(:'needs_attention')
    self.needs_attention = attributes[:'needs_attention']
  else
    self.needs_attention = nil
  end

  if attributes.key?(:'not_calculated')
    self.not_calculated = attributes[:'not_calculated']
  else
    self.not_calculated = nil
  end

  if attributes.key?(:'unknown')
    self.unknown = attributes[:'unknown']
  else
    self.unknown = nil
  end

  if attributes.key?(:'total')
    self.total = attributes[:'total']
  else
    self.total = nil
  end
end

Instance Attribute Details

#excellentObject

The number of insight groups with an excellent indicator



19
20
21
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 19

def excellent
  @excellent
end

#fairObject

The number of insight groups with a fair indicator



25
26
27
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 25

def fair
  @fair
end

#goodObject

The number of insight groups with a good indicator



22
23
24
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 22

def good
  @good
end

#needs_attentionObject

The number of insight groups with a needs attention indicator



28
29
30
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 28

def needs_attention
  @needs_attention
end

#not_calculatedObject

The number of insight groups with a not calculated indicator



31
32
33
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 31

def not_calculated
  @not_calculated
end

#totalObject

The total number of insight groups



37
38
39
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 37

def total
  @total
end

#unknownObject

The number of insight groups with an unknown indicator



34
35
36
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 34

def unknown
  @unknown
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 40

def self.attribute_map
  {
    :'excellent' => :'excellent',
    :'good' => :'good',
    :'fair' => :'fair',
    :'needs_attention' => :'needsAttention',
    :'not_calculated' => :'notCalculated',
    :'unknown' => :'unknown',
    :'total' => :'total'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 289

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 63

def self.openapi_types
  {
    :'excellent' => :'Integer',
    :'good' => :'Integer',
    :'fair' => :'Integer',
    :'needs_attention' => :'Integer',
    :'not_calculated' => :'Integer',
    :'unknown' => :'Integer',
    :'total' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



262
263
264
265
266
267
268
269
270
271
272
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 262

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      excellent == o.excellent &&
      good == o.good &&
      fair == o.fair &&
      needs_attention == o.needs_attention &&
      not_calculated == o.not_calculated &&
      unknown == o.unknown &&
      total == o.total
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


276
277
278
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 276

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



282
283
284
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 282

def hash
  [excellent, good, fair, needs_attention, not_calculated, unknown, total].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @excellent.nil?
    invalid_properties.push('invalid value for "excellent", excellent cannot be nil.')
  end

  if @good.nil?
    invalid_properties.push('invalid value for "good", good cannot be nil.')
  end

  if @fair.nil?
    invalid_properties.push('invalid value for "fair", fair cannot be nil.')
  end

  if @needs_attention.nil?
    invalid_properties.push('invalid value for "needs_attention", needs_attention cannot be nil.')
  end

  if @not_calculated.nil?
    invalid_properties.push('invalid value for "not_calculated", not_calculated cannot be nil.')
  end

  if @unknown.nil?
    invalid_properties.push('invalid value for "unknown", unknown cannot be nil.')
  end

  if @total.nil?
    invalid_properties.push('invalid value for "total", total cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 311

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
187
188
# File 'lib/launchdarkly_api/models/insight_groups_count_by_indicator.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @excellent.nil?
  return false if @good.nil?
  return false if @fair.nil?
  return false if @needs_attention.nil?
  return false if @not_calculated.nil?
  return false if @unknown.nil?
  return false if @total.nil?
  true
end