Class: LaunchDarklyApi::InsightsChartMetadata
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::InsightsChartMetadata
- Defined in:
- lib/launchdarkly_api/models/insights_chart_metadata.rb
Instance Attribute Summary collapse
-
#metrics ⇒ Object
Returns the value of attribute metrics.
-
#name ⇒ Object
Name of the chart.
-
#summary ⇒ Object
Returns the value of attribute summary.
-
#x_axis ⇒ Object
Returns the value of attribute x_axis.
-
#y_axis ⇒ Object
Returns the value of attribute y_axis.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InsightsChartMetadata
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InsightsChartMetadata
Initializes the object
69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 69 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightsChartMetadata` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightsChartMetadata`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'summary') if (value = attributes[:'summary']).is_a?(Hash) self.summary = value end else self.summary = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'metrics') if (value = attributes[:'metrics']).is_a?(Hash) self.metrics = value end end if attributes.key?(:'x_axis') self.x_axis = attributes[:'x_axis'] else self.x_axis = nil end if attributes.key?(:'y_axis') self.y_axis = attributes[:'y_axis'] else self.y_axis = nil end end |
Instance Attribute Details
#metrics ⇒ Object
Returns the value of attribute metrics.
23 24 25 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 23 def metrics @metrics end |
#name ⇒ Object
Name of the chart
21 22 23 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 21 def name @name end |
#summary ⇒ Object
Returns the value of attribute summary.
18 19 20 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 18 def summary @summary end |
#x_axis ⇒ Object
Returns the value of attribute x_axis.
25 26 27 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 25 def x_axis @x_axis end |
#y_axis ⇒ Object
Returns the value of attribute y_axis.
27 28 29 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 27 def y_axis @y_axis end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
41 42 43 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 41 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
46 47 48 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 46 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 38 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 30 def self.attribute_map { :'summary' => :'summary', :'name' => :'name', :'metrics' => :'metrics', :'x_axis' => :'xAxis', :'y_axis' => :'yAxis' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 201 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
62 63 64 65 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 62 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
51 52 53 54 55 56 57 58 59 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 51 def self.openapi_types { :'summary' => :'Hash<String, Object>', :'name' => :'String', :'metrics' => :'Hash<String, InsightsChartMetric>', :'x_axis' => :'InsightsChartSeriesMetadataAxis', :'y_axis' => :'InsightsChartSeriesMetadataAxis' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
176 177 178 179 180 181 182 183 184 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 176 def ==(o) return true if self.equal?(o) self.class == o.class && summary == o.summary && name == o.name && metrics == o.metrics && x_axis == o.x_axis && y_axis == o.y_axis end |
#eql?(o) ⇒ Boolean
188 189 190 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 188 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
194 195 196 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 194 def hash [summary, name, metrics, x_axis, y_axis].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @summary.nil? invalid_properties.push('invalid value for "summary", summary cannot be nil.') end if @x_axis.nil? invalid_properties.push('invalid value for "x_axis", x_axis cannot be nil.') end if @y_axis.nil? invalid_properties.push('invalid value for "y_axis", y_axis cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
223 224 225 226 227 228 229 230 231 232 233 234 235 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 223 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
136 137 138 139 140 141 142 |
# File 'lib/launchdarkly_api/models/insights_chart_metadata.rb', line 136 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @summary.nil? return false if @x_axis.nil? return false if @y_axis.nil? true end |