Class: LaunchDarklyApi::InsightsMetricScore
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::InsightsMetricScore
- Defined in:
- lib/launchdarkly_api/models/insights_metric_score.rb
Instance Attribute Summary collapse
-
#aggregate_of ⇒ Object
The keys of the metrics that were aggregated to calculate this score.
-
#diff_vs_last_period ⇒ Object
Returns the value of attribute diff_vs_last_period.
-
#indicator ⇒ Object
Returns the value of attribute indicator.
-
#indicator_range ⇒ Object
Returns the value of attribute indicator_range.
-
#last_period ⇒ Object
Returns the value of attribute last_period.
-
#score ⇒ Object
The score for the metric.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InsightsMetricScore
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InsightsMetricScore
Initializes the object
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 74 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightsMetricScore` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightsMetricScore`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'score') self.score = attributes[:'score'] else self.score = nil end if attributes.key?(:'aggregate_of') if (value = attributes[:'aggregate_of']).is_a?(Array) self.aggregate_of = value end end if attributes.key?(:'diff_vs_last_period') self.diff_vs_last_period = attributes[:'diff_vs_last_period'] end if attributes.key?(:'indicator') self.indicator = attributes[:'indicator'] else self.indicator = nil end if attributes.key?(:'indicator_range') self.indicator_range = attributes[:'indicator_range'] else self.indicator_range = nil end if attributes.key?(:'last_period') self.last_period = attributes[:'last_period'] end end |
Instance Attribute Details
#aggregate_of ⇒ Object
The keys of the metrics that were aggregated to calculate this score
22 23 24 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 22 def aggregate_of @aggregate_of end |
#diff_vs_last_period ⇒ Object
Returns the value of attribute diff_vs_last_period.
24 25 26 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 24 def diff_vs_last_period @diff_vs_last_period end |
#indicator ⇒ Object
Returns the value of attribute indicator.
26 27 28 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 26 def indicator @indicator end |
#indicator_range ⇒ Object
Returns the value of attribute indicator_range.
28 29 30 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 28 def indicator_range @indicator_range end |
#last_period ⇒ Object
Returns the value of attribute last_period.
30 31 32 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 30 def last_period @last_period end |
#score ⇒ Object
The score for the metric
19 20 21 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 19 def score @score end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 42 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 33 def self.attribute_map { :'score' => :'score', :'aggregate_of' => :'aggregateOf', :'diff_vs_last_period' => :'diffVsLastPeriod', :'indicator' => :'indicator', :'indicator_range' => :'indicatorRange', :'last_period' => :'lastPeriod' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
67 68 69 70 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 67 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 64 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 55 def self.openapi_types { :'score' => :'Integer', :'aggregate_of' => :'Array<String>', :'diff_vs_last_period' => :'Integer', :'indicator' => :'String', :'indicator_range' => :'InsightsMetricIndicatorRange', :'last_period' => :'InsightsMetricScore' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
183 184 185 186 187 188 189 190 191 192 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 183 def ==(o) return true if self.equal?(o) self.class == o.class && score == o.score && aggregate_of == o.aggregate_of && diff_vs_last_period == o.diff_vs_last_period && indicator == o.indicator && indicator_range == o.indicator_range && last_period == o.last_period end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 202 def hash [score, aggregate_of, diff_vs_last_period, indicator, indicator_range, last_period].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 123 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @score.nil? invalid_properties.push('invalid value for "score", score cannot be nil.') end if @indicator.nil? invalid_properties.push('invalid value for "indicator", indicator cannot be nil.') end if @indicator_range.nil? invalid_properties.push('invalid value for "indicator_range", indicator_range cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
143 144 145 146 147 148 149 |
# File 'lib/launchdarkly_api/models/insights_metric_score.rb', line 143 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @score.nil? return false if @indicator.nil? return false if @indicator_range.nil? true end |