Class: LaunchDarklyApi::InsightsRepository

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/insights_repository.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ InsightsRepository

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 82

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightsRepository` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightsRepository`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'main_branch')
    self.main_branch = attributes[:'main_branch']
  else
    self.main_branch = nil
  end

  if attributes.key?(:'projects')
    self.projects = attributes[:'projects']
  end
end

Instance Attribute Details

#_idObject

The repository ID



19
20
21
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 19

def _id
  @_id
end

#keyObject

The repository key



25
26
27
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 25

def key
  @key
end

#main_branchObject

The repository main branch



34
35
36
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 34

def main_branch
  @main_branch
end

#projectsObject

Returns the value of attribute projects.



36
37
38
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 36

def projects
  @projects
end

#typeObject

The repository type



28
29
30
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 28

def type
  @type
end

#urlObject

The repository URL



31
32
33
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 31

def url
  @url
end

#versionObject

The repository version



22
23
24
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 22

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



52
53
54
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 52

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



57
58
59
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 57

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



39
40
41
42
43
44
45
46
47
48
49
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 39

def self.attribute_map
  {
    :'_id' => :'_id',
    :'version' => :'version',
    :'key' => :'key',
    :'type' => :'type',
    :'url' => :'url',
    :'main_branch' => :'mainBranch',
    :'projects' => :'projects'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 271

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



75
76
77
78
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 75

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



62
63
64
65
66
67
68
69
70
71
72
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 62

def self.openapi_types
  {
    :'_id' => :'String',
    :'version' => :'Integer',
    :'key' => :'String',
    :'type' => :'String',
    :'url' => :'String',
    :'main_branch' => :'String',
    :'projects' => :'ProjectSummaryCollection'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      version == o.version &&
      key == o.key &&
      type == o.type &&
      url == o.url &&
      main_branch == o.main_branch &&
      projects == o.projects
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


258
259
260
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 258

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



264
265
266
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 264

def hash
  [_id, version, key, type, url, main_branch, projects].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @main_branch.nil?
    invalid_properties.push('invalid value for "main_branch", main_branch cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



171
172
173
174
175
176
177
178
179
180
# File 'lib/launchdarkly_api/models/insights_repository.rb', line 171

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @version.nil?
  return false if @key.nil?
  return false if @type.nil?
  return false if @url.nil?
  return false if @main_branch.nil?
  true
end