Class: LaunchDarklyApi::InsightsScoresBetaApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/insights_scores_beta_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ InsightsScoresBetaApi

Returns a new instance of InsightsScoresBetaApi.



19
20
21
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#create_insight_group(post_insight_group_params, opts = {}) ⇒ InsightGroup

Create insight group Create insight group

Parameters:

  • post_insight_group_params (PostInsightGroupParams)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



27
28
29
30
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 27

def create_insight_group(post_insight_group_params, opts = {})
  data, _status_code, _headers = create_insight_group_with_http_info(post_insight_group_params, opts)
  data
end

#create_insight_group_with_http_info(post_insight_group_params, opts = {}) ⇒ Array<(InsightGroup, Integer, Hash)>

Create insight group Create insight group

Parameters:

  • post_insight_group_params (PostInsightGroupParams)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(InsightGroup, Integer, Hash)>)

    InsightGroup data, response status code and response headers



37
38
39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 37

def create_insight_group_with_http_info(post_insight_group_params, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InsightsScoresBetaApi.create_insight_group ...'
  end
  # verify the required parameter 'post_insight_group_params' is set
  if @api_client.config.client_side_validation && post_insight_group_params.nil?
    fail ArgumentError, "Missing the required parameter 'post_insight_group_params' when calling InsightsScoresBetaApi.create_insight_group"
  end
  # resource path
  local_var_path = '/api/v2/engineering-insights/insights/group'

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(post_insight_group_params)

  # return_type
  return_type = opts[:debug_return_type] || 'InsightGroup'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"InsightsScoresBetaApi.create_insight_group",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InsightsScoresBetaApi#create_insight_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#delete_insight_group(insight_group_key, opts = {}) ⇒ nil

Delete insight group Delete insight group

Parameters:

  • insight_group_key (String)

    The insight group key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


95
96
97
98
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 95

def delete_insight_group(insight_group_key, opts = {})
  delete_insight_group_with_http_info(insight_group_key, opts)
  nil
end

#delete_insight_group_with_http_info(insight_group_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete insight group Delete insight group

Parameters:

  • insight_group_key (String)

    The insight group key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 105

def delete_insight_group_with_http_info(insight_group_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InsightsScoresBetaApi.delete_insight_group ...'
  end
  # verify the required parameter 'insight_group_key' is set
  if @api_client.config.client_side_validation && insight_group_key.nil?
    fail ArgumentError, "Missing the required parameter 'insight_group_key' when calling InsightsScoresBetaApi.delete_insight_group"
  end
  # resource path
  local_var_path = '/api/v2/engineering-insights/insights/groups/{insightGroupKey}'.sub('{' + 'insightGroupKey' + '}', CGI.escape(insight_group_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"InsightsScoresBetaApi.delete_insight_group",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InsightsScoresBetaApi#delete_insight_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_insight_group(insight_group_key, opts = {}) ⇒ InsightGroup

Get insight group Get insight group ### Expanding the insight group response LaunchDarkly supports expanding the insight group response to include additional fields. To expand the response, append the expand query parameter and include the following: * scores includes details on all of the scores used in the engineering insights metrics views for this group * environment includes details on each environment associated with this group For example, use ?expand=scores to include the scores field in the response. By default, this field is not included in the response.

Parameters:

  • insight_group_key (String)

    The insight group key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :expand (String)

    Options: `scores`, `environment`

Returns:



159
160
161
162
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 159

def get_insight_group(insight_group_key, opts = {})
  data, _status_code, _headers = get_insight_group_with_http_info(insight_group_key, opts)
  data
end

#get_insight_group_with_http_info(insight_group_key, opts = {}) ⇒ Array<(InsightGroup, Integer, Hash)>

Get insight group Get insight group ### Expanding the insight group response LaunchDarkly supports expanding the insight group response to include additional fields. To expand the response, append the `expand` query parameter and include the following: * `scores` includes details on all of the scores used in the engineering insights metrics views for this group * `environment` includes details on each environment associated with this group For example, use `?expand=scores` to include the `scores` field in the response. By default, this field is not included in the response.

Parameters:

  • insight_group_key (String)

    The insight group key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :expand (String)

    Options: `scores`, `environment`

Returns:

  • (Array<(InsightGroup, Integer, Hash)>)

    InsightGroup data, response status code and response headers



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 170

def get_insight_group_with_http_info(insight_group_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InsightsScoresBetaApi.get_insight_group ...'
  end
  # verify the required parameter 'insight_group_key' is set
  if @api_client.config.client_side_validation && insight_group_key.nil?
    fail ArgumentError, "Missing the required parameter 'insight_group_key' when calling InsightsScoresBetaApi.get_insight_group"
  end
  # resource path
  local_var_path = '/api/v2/engineering-insights/insights/groups/{insightGroupKey}'.sub('{' + 'insightGroupKey' + '}', CGI.escape(insight_group_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InsightGroup'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"InsightsScoresBetaApi.get_insight_group",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InsightsScoresBetaApi#get_insight_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_insight_groups(opts = {}) ⇒ InsightGroupCollection

List insight groups List groups for which you are collecting insights ### Expanding the insight groups collection response LaunchDarkly supports expanding the insight groups collection response to include additional fields. To expand the response, append the expand query parameter and include the following: * scores includes details on all of the scores used in the engineering insights metrics views for each group * environment includes details on each environment associated with each group * metadata includes counts of the number of insight groups with particular indicators, such as "excellent," "good," "fair," and so on. For example, use ?expand=scores to include the scores field in the response. By default, this field is not included in the response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The number of insight groups to return. Default is 20. Must be between 1 and 20 inclusive.

  • :offset (Integer)

    Where to start in the list. Use this with pagination. For example, an offset of 10 skips the first ten items and then returns the next items in the list, up to the query `limit`.

  • :sort (String)

    Sort flag list by field. Prefix field with <code>-</code> to sort in descending order. Allowed fields: name

  • :query (String)

    Filter list of insights groups by name.

  • :expand (String)

    Options: `scores`, `environment`, `metadata`

Returns:



228
229
230
231
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 228

def get_insight_groups(opts = {})
  data, _status_code, _headers = get_insight_groups_with_http_info(opts)
  data
end

#get_insight_groups_with_http_info(opts = {}) ⇒ Array<(InsightGroupCollection, Integer, Hash)>

List insight groups List groups for which you are collecting insights ### Expanding the insight groups collection response LaunchDarkly supports expanding the insight groups collection response to include additional fields. To expand the response, append the `expand` query parameter and include the following: * `scores` includes details on all of the scores used in the engineering insights metrics views for each group * `environment` includes details on each environment associated with each group * `metadata` includes counts of the number of insight groups with particular indicators, such as &quot;excellent,&quot; &quot;good,&quot; &quot;fair,&quot; and so on. For example, use `?expand=scores` to include the `scores` field in the response. By default, this field is not included in the response.

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :limit (Integer)

    The number of insight groups to return. Default is 20. Must be between 1 and 20 inclusive.

  • :offset (Integer)

    Where to start in the list. Use this with pagination. For example, an offset of 10 skips the first ten items and then returns the next items in the list, up to the query `limit`.

  • :sort (String)

    Sort flag list by field. Prefix field with <code>-</code> to sort in descending order. Allowed fields: name

  • :query (String)

    Filter list of insights groups by name.

  • :expand (String)

    Options: `scores`, `environment`, `metadata`

Returns:

  • (Array<(InsightGroupCollection, Integer, Hash)>)

    InsightGroupCollection data, response status code and response headers



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 242

def get_insight_groups_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InsightsScoresBetaApi.get_insight_groups ...'
  end
  # resource path
  local_var_path = '/api/v2/engineering-insights/insights/groups'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil?
  query_params[:'sort'] = opts[:'sort'] if !opts[:'sort'].nil?
  query_params[:'query'] = opts[:'query'] if !opts[:'query'].nil?
  query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InsightGroupCollection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"InsightsScoresBetaApi.get_insight_groups",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InsightsScoresBetaApi#get_insight_groups\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_insights_scores(project_key, environment_key, opts = {}) ⇒ InsightScores

Get insight scores Return insights scores, based on the given parameters. This data is also used in engineering insights metrics views.

Parameters:

  • project_key (String)

    The project key

  • environment_key (String)

    The environment key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :application_key (String)

    Comma separated list of application keys

Returns:



298
299
300
301
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 298

def get_insights_scores(project_key, environment_key, opts = {})
  data, _status_code, _headers = get_insights_scores_with_http_info(project_key, environment_key, opts)
  data
end

#get_insights_scores_with_http_info(project_key, environment_key, opts = {}) ⇒ Array<(InsightScores, Integer, Hash)>

Get insight scores Return insights scores, based on the given parameters. This data is also used in engineering insights metrics views.

Parameters:

  • project_key (String)

    The project key

  • environment_key (String)

    The environment key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :application_key (String)

    Comma separated list of application keys

Returns:

  • (Array<(InsightScores, Integer, Hash)>)

    InsightScores data, response status code and response headers



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 310

def get_insights_scores_with_http_info(project_key, environment_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InsightsScoresBetaApi.get_insights_scores ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling InsightsScoresBetaApi.get_insights_scores"
  end
  # verify the required parameter 'environment_key' is set
  if @api_client.config.client_side_validation && environment_key.nil?
    fail ArgumentError, "Missing the required parameter 'environment_key' when calling InsightsScoresBetaApi.get_insights_scores"
  end
  # resource path
  local_var_path = '/api/v2/engineering-insights/insights/scores'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'projectKey'] = project_key
  query_params[:'environmentKey'] = environment_key
  query_params[:'applicationKey'] = opts[:'application_key'] if !opts[:'application_key'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'InsightScores'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"InsightsScoresBetaApi.get_insights_scores",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InsightsScoresBetaApi#get_insights_scores\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_insight_group(insight_group_key, patch_operation, opts = {}) ⇒ InsightGroup

Patch insight group Update an insight group. Updating an insight group uses a JSON patch representation of the desired changes. To learn more, read Updates.

Parameters:

  • insight_group_key (String)

    The insight group key

  • patch_operation (Array<PatchOperation>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



371
372
373
374
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 371

def patch_insight_group(insight_group_key, patch_operation, opts = {})
  data, _status_code, _headers = patch_insight_group_with_http_info(insight_group_key, patch_operation, opts)
  data
end

#patch_insight_group_with_http_info(insight_group_key, patch_operation, opts = {}) ⇒ Array<(InsightGroup, Integer, Hash)>

Patch insight group Update an insight group. Updating an insight group uses a JSON patch representation of the desired changes. To learn more, read Updates.

Parameters:

  • insight_group_key (String)

    The insight group key

  • patch_operation (Array<PatchOperation>)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(InsightGroup, Integer, Hash)>)

    InsightGroup data, response status code and response headers



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
# File 'lib/launchdarkly_api/api/insights_scores_beta_api.rb', line 382

def patch_insight_group_with_http_info(insight_group_key, patch_operation, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: InsightsScoresBetaApi.patch_insight_group ...'
  end
  # verify the required parameter 'insight_group_key' is set
  if @api_client.config.client_side_validation && insight_group_key.nil?
    fail ArgumentError, "Missing the required parameter 'insight_group_key' when calling InsightsScoresBetaApi.patch_insight_group"
  end
  # verify the required parameter 'patch_operation' is set
  if @api_client.config.client_side_validation && patch_operation.nil?
    fail ArgumentError, "Missing the required parameter 'patch_operation' when calling InsightsScoresBetaApi.patch_insight_group"
  end
  # resource path
  local_var_path = '/api/v2/engineering-insights/insights/groups/{insightGroupKey}'.sub('{' + 'insightGroupKey' + '}', CGI.escape(insight_group_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept']
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_operation)

  # return_type
  return_type = opts[:debug_return_type] || 'InsightGroup'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"InsightsScoresBetaApi.patch_insight_group",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: InsightsScoresBetaApi#patch_insight_group\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end