Class: LaunchDarklyApi::InstructionUserRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::InstructionUserRequest
- Defined in:
- lib/launchdarkly_api/models/instruction_user_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#flag_key ⇒ Object
The flag key.
-
#kind ⇒ Object
The type of change to make to the removal date for this user from individual targeting for this flag.
-
#value ⇒ Object
The time, in Unix milliseconds, when LaunchDarkly should remove the user from individual targeting for this flag.
-
#variation_id ⇒ Object
ID of a variation on the flag.
-
#version ⇒ Object
The version of the expiring user target to update.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InstructionUserRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InstructionUserRequest
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InstructionUserRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InstructionUserRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'flag_key') self.flag_key = attributes[:'flag_key'] else self.flag_key = nil end if attributes.key?(:'variation_id') self.variation_id = attributes[:'variation_id'] else self.variation_id = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'version') self.version = attributes[:'version'] end end |
Instance Attribute Details
#flag_key ⇒ Object
The flag key
22 23 24 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 22 def flag_key @flag_key end |
#kind ⇒ Object
The type of change to make to the removal date for this user from individual targeting for this flag.
19 20 21 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 19 def kind @kind end |
#value ⇒ Object
The time, in Unix milliseconds, when LaunchDarkly should remove the user from individual targeting for this flag. Required if kind is addExpireUserTargetDate or updateExpireUserTargetDate.
28 29 30 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 28 def value @value end |
#variation_id ⇒ Object
ID of a variation on the flag
25 26 27 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 25 def variation_id @variation_id end |
#version ⇒ Object
The version of the expiring user target to update. Optional and only used if kind is updateExpireUserTargetDate. If included, update will fail if version doesn't match current version of the expiring user target.
31 32 33 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 31 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
67 68 69 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 67 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
72 73 74 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 72 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 56 def self.attribute_map { :'kind' => :'kind', :'flag_key' => :'flagKey', :'variation_id' => :'variationId', :'value' => :'value', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 225 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
77 78 79 80 81 82 83 84 85 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 77 def self.openapi_types { :'kind' => :'String', :'flag_key' => :'String', :'variation_id' => :'String', :'value' => :'Integer', :'version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 200 def ==(o) return true if self.equal?(o) self.class == o.class && kind == o.kind && flag_key == o.flag_key && variation_id == o.variation_id && value == o.value && version == o.version end |
#eql?(o) ⇒ Boolean
212 213 214 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 212 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
218 219 220 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 218 def hash [kind, flag_key, variation_id, value, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 138 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @flag_key.nil? invalid_properties.push('invalid value for "flag_key", flag_key cannot be nil.') end if @variation_id.nil? invalid_properties.push('invalid value for "variation_id", variation_id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
247 248 249 250 251 252 253 254 255 256 257 258 259 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 247 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
158 159 160 161 162 163 164 165 166 |
# File 'lib/launchdarkly_api/models/instruction_user_request.rb', line 158 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["addExpireUserTargetDate", "updateExpireUserTargetDate", "removeExpireUserTargetDate"]) return false unless kind_validator.valid?(@kind) return false if @flag_key.nil? return false if @variation_id.nil? true end |