Class: LaunchDarklyApi::IntegrationConfigurationPost

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/integration_configuration_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationConfigurationPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 72

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::IntegrationConfigurationPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::IntegrationConfigurationPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'config_values')
    if (value = attributes[:'config_values']).is_a?(Hash)
      self.config_values = value
    end
  else
    self.config_values = nil
  end

  if attributes.key?(:'capability_config')
    self.capability_config = attributes[:'capability_config']
  end
end

Instance Attribute Details

#capability_configObject

Returns the value of attribute capability_config.



30
31
32
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 30

def capability_config
  @capability_config
end

#config_valuesObject

The unique set of fields required to configure the integration. Refer to the formVariables field in the corresponding manifest.json at github.com/launchdarkly/integration-framework/tree/main/integrations for a full list of fields for the integration you wish to configure.



28
29
30
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 28

def config_values
  @config_values
end

#enabledObject

Whether the integration configuration is enabled. If omitted, defaults to true



22
23
24
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 22

def enabled
  @enabled
end

#nameObject

The name of the integration configuration



19
20
21
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 19

def name
  @name
end

#tagsObject

Tags for the integration



25
26
27
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 25

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



44
45
46
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



33
34
35
36
37
38
39
40
41
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 33

def self.attribute_map
  {
    :'name' => :'name',
    :'enabled' => :'enabled',
    :'tags' => :'tags',
    :'config_values' => :'configValues',
    :'capability_config' => :'capabilityConfig'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 187

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



65
66
67
68
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 65

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 54

def self.openapi_types
  {
    :'name' => :'String',
    :'enabled' => :'Boolean',
    :'tags' => :'Array<String>',
    :'config_values' => :'Hash<String, Object>',
    :'capability_config' => :'CapabilityConfigPost'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



162
163
164
165
166
167
168
169
170
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 162

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      enabled == o.enabled &&
      tags == o.tags &&
      config_values == o.config_values &&
      capability_config == o.capability_config
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


174
175
176
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 174

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



180
181
182
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 180

def hash
  [name, enabled, tags, config_values, capability_config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



117
118
119
120
121
122
123
124
125
126
127
128
129
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 117

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @config_values.nil?
    invalid_properties.push('invalid value for "config_values", config_values cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 209

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



133
134
135
136
137
138
# File 'lib/launchdarkly_api/models/integration_configuration_post.rb', line 133

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @config_values.nil?
  true
end