Class: LaunchDarklyApi::IntegrationConfigurationsRep

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/integration_configurations_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationConfigurationsRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::IntegrationConfigurationsRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::IntegrationConfigurationsRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'_created_at')
    self._created_at = attributes[:'_created_at']
  end

  if attributes.key?(:'_integration_key')
    self._integration_key = attributes[:'_integration_key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'config_values')
    if (value = attributes[:'config_values']).is_a?(Hash)
      self.config_values = value
    end
  end

  if attributes.key?(:'capability_config')
    self.capability_config = attributes[:'capability_config']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



38
39
40
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 38

def _access
  @_access
end

#_created_atObject

Returns the value of attribute _created_at.



27
28
29
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 27

def _created_at
  @_created_at
end

#_idObject

The unique identifier for this integration configuration



22
23
24
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 22

def _id
  @_id
end

#_integration_keyObject

The type of integration



30
31
32
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 30

def _integration_key
  @_integration_key
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 19

def _links
  @_links
end

#capability_configObject

Returns the value of attribute capability_config.



43
44
45
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 43

def capability_config
  @capability_config
end

#config_valuesObject

Details on configuration for an integration of this type. Refer to the formVariables field in the corresponding manifest.json for a full list of fields for each integration.



41
42
43
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 41

def config_values
  @config_values
end

#enabledObject

Whether the integration is currently active



36
37
38
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 36

def enabled
  @enabled
end

#nameObject

A human-friendly name for the integration



25
26
27
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 25

def name
  @name
end

#tagsObject

An array of tags for this integration



33
34
35
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 33

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 46

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'name' => :'name',
    :'_created_at' => :'_createdAt',
    :'_integration_key' => :'_integrationKey',
    :'tags' => :'tags',
    :'enabled' => :'enabled',
    :'_access' => :'_access',
    :'config_values' => :'configValues',
    :'capability_config' => :'capabilityConfig'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 254

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 72

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'name' => :'String',
    :'_created_at' => :'Integer',
    :'_integration_key' => :'String',
    :'tags' => :'Array<String>',
    :'enabled' => :'Boolean',
    :'_access' => :'Access',
    :'config_values' => :'Hash<String, Object>',
    :'capability_config' => :'CapabilityConfigRep'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      name == o.name &&
      _created_at == o._created_at &&
      _integration_key == o._integration_key &&
      tags == o.tags &&
      enabled == o.enabled &&
      _access == o._access &&
      config_values == o.config_values &&
      capability_config == o.capability_config
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


241
242
243
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 241

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



247
248
249
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 247

def hash
  [_links, _id, name, _created_at, _integration_key, tags, enabled, _access, config_values, capability_config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 164

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



276
277
278
279
280
281
282
283
284
285
286
287
288
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 276

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



184
185
186
187
188
189
190
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 184

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @name.nil?
  true
end