Class: LaunchDarklyApi::IntegrationDeliveryConfigurationPost

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/integration_delivery_configuration_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ IntegrationDeliveryConfigurationPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 67

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::IntegrationDeliveryConfigurationPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::IntegrationDeliveryConfigurationPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'on')
    self.on = attributes[:'on']
  end

  if attributes.key?(:'config')
    if (value = attributes[:'config']).is_a?(Hash)
      self.config = value
    end
  else
    self.config = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end
end

Instance Attribute Details

#configObject

Returns the value of attribute config.



21
22
23
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 21

def config
  @config
end

#nameObject

Name to identify the integration



27
28
29
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 27

def name
  @name
end

#onObject

Whether the integration configuration is active. Default value is false.



19
20
21
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 19

def on
  @on
end

#tagsObject

Tags to associate with the integration



24
25
26
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 24

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



40
41
42
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 40

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



45
46
47
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 45

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



30
31
32
33
34
35
36
37
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 30

def self.attribute_map
  {
    :'on' => :'on',
    :'config' => :'config',
    :'tags' => :'tags',
    :'name' => :'name'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 160

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



60
61
62
63
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 60

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



50
51
52
53
54
55
56
57
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 50

def self.openapi_types
  {
    :'on' => :'Boolean',
    :'config' => :'Hash<String, Object>',
    :'tags' => :'Array<String>',
    :'name' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



136
137
138
139
140
141
142
143
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 136

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      on == o.on &&
      config == o.config &&
      tags == o.tags &&
      name == o.name
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


147
148
149
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 147

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



153
154
155
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 153

def hash
  [on, config, tags, name].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



106
107
108
109
110
111
112
113
114
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 106

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @config.nil?
    invalid_properties.push('invalid value for "config", config cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



182
183
184
185
186
187
188
189
190
191
192
193
194
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 182

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



118
119
120
121
122
# File 'lib/launchdarkly_api/models/integration_delivery_configuration_post.rb', line 118

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @config.nil?
  true
end