Class: LaunchDarklyApi::LayerPatchInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::LayerPatchInput
- Defined in:
- lib/launchdarkly_api/models/layer_patch_input.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Optional comment describing the update.
-
#environment_key ⇒ Object
The environment key used for making environment specific updates.
-
#instructions ⇒ Object
Returns the value of attribute instructions.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LayerPatchInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LayerPatchInput
Initializes the object
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 62 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::LayerPatchInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::LayerPatchInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] end if attributes.key?(:'instructions') if (value = attributes[:'instructions']).is_a?(Array) self.instructions = value end else self.instructions = nil end end |
Instance Attribute Details
#comment ⇒ Object
Optional comment describing the update
19 20 21 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 19 def comment @comment end |
#environment_key ⇒ Object
The environment key used for making environment specific updates. For example, updating the reservation of an experiment
22 23 24 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 22 def environment_key @environment_key end |
#instructions ⇒ Object
Returns the value of attribute instructions.
24 25 26 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 24 def instructions @instructions end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
36 37 38 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 36 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
41 42 43 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 41 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
27 28 29 30 31 32 33 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 27 def self.attribute_map { :'comment' => :'comment', :'environment_key' => :'environmentKey', :'instructions' => :'instructions' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 148 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
55 56 57 58 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 55 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
46 47 48 49 50 51 52 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 46 def self.openapi_types { :'comment' => :'String', :'environment_key' => :'String', :'instructions' => :'Array<Hash>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && comment == o.comment && environment_key == o.environment_key && instructions == o.instructions end |
#eql?(o) ⇒ Boolean
135 136 137 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 135 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
141 142 143 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 141 def hash [comment, environment_key, instructions].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
95 96 97 98 99 100 101 102 103 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 95 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @instructions.nil? invalid_properties.push('invalid value for "instructions", instructions cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
170 171 172 173 174 175 176 177 178 179 180 181 182 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 170 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
107 108 109 110 111 |
# File 'lib/launchdarkly_api/models/layer_patch_input.rb', line 107 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @instructions.nil? true end |