Class: LaunchDarklyApi::LayerRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::LayerRep
- Defined in:
- lib/launchdarkly_api/models/layer_rep.rb
Instance Attribute Summary collapse
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
The description of the layer.
-
#environments ⇒ Object
The layer configurations for each requested environment.
-
#key ⇒ Object
The key of the layer.
-
#name ⇒ Object
The name of the layer.
-
#randomization_unit ⇒ Object
The unit of randomization for the layer.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LayerRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LayerRep
Initializes the object
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 77 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::LayerRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::LayerRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'randomization_unit') self.randomization_unit = attributes[:'randomization_unit'] end if attributes.key?(:'environments') if (value = attributes[:'environments']).is_a?(Hash) self.environments = value end end end |
Instance Attribute Details
#created_at ⇒ Object
Returns the value of attribute created_at.
27 28 29 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 27 def created_at @created_at end |
#description ⇒ Object
The description of the layer
25 26 27 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 25 def description @description end |
#environments ⇒ Object
The layer configurations for each requested environment
33 34 35 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 33 def environments @environments end |
#key ⇒ Object
The key of the layer
19 20 21 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 19 def key @key end |
#name ⇒ Object
The name of the layer
22 23 24 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 22 def name @name end |
#randomization_unit ⇒ Object
The unit of randomization for the layer
30 31 32 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 30 def randomization_unit @randomization_unit end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
48 49 50 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 48 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
53 54 55 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 53 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
36 37 38 39 40 41 42 43 44 45 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 36 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'description' => :'description', :'created_at' => :'createdAt', :'randomization_unit' => :'randomizationUnit', :'environments' => :'environments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 229 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
70 71 72 73 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 70 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
58 59 60 61 62 63 64 65 66 67 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 58 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'description' => :'String', :'created_at' => :'Integer', :'randomization_unit' => :'String', :'environments' => :'Hash<String, LayerConfigurationRep>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && description == o.description && created_at == o.created_at && randomization_unit == o.randomization_unit && environments == o.environments end |
#eql?(o) ⇒ Boolean
216 217 218 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 216 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
222 223 224 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 222 def hash [key, name, description, created_at, randomization_unit, environments].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 128 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
251 252 253 254 255 256 257 258 259 260 261 262 263 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 251 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 159 |
# File 'lib/launchdarkly_api/models/layer_rep.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? return false if @description.nil? return false if @created_at.nil? true end |