Class: LaunchDarklyApi::LeadTimeStagesRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::LeadTimeStagesRep
- Defined in:
- lib/launchdarkly_api/models/lead_time_stages_rep.rb
Instance Attribute Summary collapse
-
#coding_duration_ms ⇒ Object
The coding duration in milliseconds.
-
#deploy_duration_ms ⇒ Object
The deploy duration in milliseconds.
-
#review_duration_ms ⇒ Object
The review duration in milliseconds.
-
#total_lead_time_ms ⇒ Object
The total lead time in milliseconds.
-
#wait_duration_ms ⇒ Object
The wait duration between merge time and deploy start time in milliseconds.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ LeadTimeStagesRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ LeadTimeStagesRep
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::LeadTimeStagesRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::LeadTimeStagesRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'coding_duration_ms') self.coding_duration_ms = attributes[:'coding_duration_ms'] else self.coding_duration_ms = nil end if attributes.key?(:'review_duration_ms') self.review_duration_ms = attributes[:'review_duration_ms'] end if attributes.key?(:'wait_duration_ms') self.wait_duration_ms = attributes[:'wait_duration_ms'] end if attributes.key?(:'deploy_duration_ms') self.deploy_duration_ms = attributes[:'deploy_duration_ms'] end if attributes.key?(:'total_lead_time_ms') self.total_lead_time_ms = attributes[:'total_lead_time_ms'] end end |
Instance Attribute Details
#coding_duration_ms ⇒ Object
The coding duration in milliseconds
19 20 21 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 19 def coding_duration_ms @coding_duration_ms end |
#deploy_duration_ms ⇒ Object
The deploy duration in milliseconds
28 29 30 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 28 def deploy_duration_ms @deploy_duration_ms end |
#review_duration_ms ⇒ Object
The review duration in milliseconds
22 23 24 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 22 def review_duration_ms @review_duration_ms end |
#total_lead_time_ms ⇒ Object
The total lead time in milliseconds
31 32 33 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 31 def total_lead_time_ms @total_lead_time_ms end |
#wait_duration_ms ⇒ Object
The wait duration between merge time and deploy start time in milliseconds
25 26 27 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 25 def wait_duration_ms @wait_duration_ms end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 34 def self.attribute_map { :'coding_duration_ms' => :'codingDurationMs', :'review_duration_ms' => :'reviewDurationMs', :'wait_duration_ms' => :'waitDurationMs', :'deploy_duration_ms' => :'deployDurationMs', :'total_lead_time_ms' => :'totalLeadTimeMs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 167 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 55 def self.openapi_types { :'coding_duration_ms' => :'Integer', :'review_duration_ms' => :'Integer', :'wait_duration_ms' => :'Integer', :'deploy_duration_ms' => :'Integer', :'total_lead_time_ms' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
142 143 144 145 146 147 148 149 150 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 142 def ==(o) return true if self.equal?(o) self.class == o.class && coding_duration_ms == o.coding_duration_ms && review_duration_ms == o.review_duration_ms && wait_duration_ms == o.wait_duration_ms && deploy_duration_ms == o.deploy_duration_ms && total_lead_time_ms == o.total_lead_time_ms end |
#eql?(o) ⇒ Boolean
154 155 156 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 154 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
160 161 162 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 160 def hash [coding_duration_ms, review_duration_ms, wait_duration_ms, deploy_duration_ms, total_lead_time_ms].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
112 113 114 115 116 117 118 119 120 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 112 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @coding_duration_ms.nil? invalid_properties.push('invalid value for "coding_duration_ms", coding_duration_ms cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 189 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
124 125 126 127 128 |
# File 'lib/launchdarkly_api/models/lead_time_stages_rep.rb', line 124 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @coding_duration_ms.nil? true end |