Class: LaunchDarklyApi::Member

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/member.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Member

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
# File 'lib/launchdarkly_api/models/member.rb', line 161

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Member` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Member`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  else
    self.role = nil
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'_pending_invite')
    self._pending_invite = attributes[:'_pending_invite']
  else
    self._pending_invite = nil
  end

  if attributes.key?(:'_verified')
    self._verified = attributes[:'_verified']
  else
    self._verified = nil
  end

  if attributes.key?(:'_pending_email')
    self._pending_email = attributes[:'_pending_email']
  end

  if attributes.key?(:'custom_roles')
    if (value = attributes[:'custom_roles']).is_a?(Array)
      self.custom_roles = value
    end
  else
    self.custom_roles = nil
  end

  if attributes.key?(:'mfa')
    self.mfa = attributes[:'mfa']
  else
    self.mfa = nil
  end

  if attributes.key?(:'excluded_dashboards')
    if (value = attributes[:'excluded_dashboards']).is_a?(Array)
      self.excluded_dashboards = value
    end
  end

  if attributes.key?(:'_last_seen')
    self._last_seen = attributes[:'_last_seen']
  else
    self._last_seen = nil
  end

  if attributes.key?(:'_last_seen_metadata')
    self. = attributes[:'_last_seen_metadata']
  end

  if attributes.key?(:'_integration_metadata')
    self. = attributes[:'_integration_metadata']
  end

  if attributes.key?(:'teams')
    if (value = attributes[:'teams']).is_a?(Array)
      self.teams = value
    end
  end

  if attributes.key?(:'permission_grants')
    if (value = attributes[:'permission_grants']).is_a?(Array)
      self.permission_grants = value
    end
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'oauth_providers')
    if (value = attributes[:'oauth_providers']).is_a?(Array)
      self.oauth_providers = value
    end
  end

  if attributes.key?(:'has_password')
    self.has_password = attributes[:'has_password']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'role_attributes')
    if (value = attributes[:'role_attributes']).is_a?(Hash)
      self.role_attributes = value
    end
  end

  if attributes.key?(:'mfa_enforced')
    self.mfa_enforced = attributes[:'mfa_enforced']
  end

  if attributes.key?(:'mfa_grace_period_expires_at')
    self.mfa_grace_period_expires_at = attributes[:'mfa_grace_period_expires_at']
  end
end

Instance Attribute Details

#_idObject

The member's ID



22
23
24
# File 'lib/launchdarkly_api/models/member.rb', line 22

def _id
  @_id
end

#_integration_metadataObject

Returns the value of attribute _integration_metadata.



58
59
60
# File 'lib/launchdarkly_api/models/member.rb', line 58

def 
  @_integration_metadata
end

#_last_seenObject

Returns the value of attribute _last_seen.



54
55
56
# File 'lib/launchdarkly_api/models/member.rb', line 54

def _last_seen
  @_last_seen
end

#_last_seen_metadataObject

Returns the value of attribute _last_seen_metadata.



56
57
58
# File 'lib/launchdarkly_api/models/member.rb', line 56

def 
  @_last_seen_metadata
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/member.rb', line 19

def _links
  @_links
end

#_pending_emailObject

The member's email address before it has been verified, for accounts where email verification is required



43
44
45
# File 'lib/launchdarkly_api/models/member.rb', line 43

def _pending_email
  @_pending_email
end

#_pending_inviteObject

Whether the member has a pending invitation



37
38
39
# File 'lib/launchdarkly_api/models/member.rb', line 37

def _pending_invite
  @_pending_invite
end

#_verifiedObject

Whether the member's email address has been verified



40
41
42
# File 'lib/launchdarkly_api/models/member.rb', line 40

def _verified
  @_verified
end

#creation_dateObject

Returns the value of attribute creation_date.



66
67
68
# File 'lib/launchdarkly_api/models/member.rb', line 66

def creation_date
  @creation_date
end

#custom_rolesObject

The set of additional roles, besides the base role, assigned to the member



46
47
48
# File 'lib/launchdarkly_api/models/member.rb', line 46

def custom_roles
  @custom_roles
end

#emailObject

The member's email address



34
35
36
# File 'lib/launchdarkly_api/models/member.rb', line 34

def email
  @email
end

#excluded_dashboardsObject

Default dashboards that the member has chosen to ignore



52
53
54
# File 'lib/launchdarkly_api/models/member.rb', line 52

def excluded_dashboards
  @excluded_dashboards
end

#first_nameObject

The member's first name



25
26
27
# File 'lib/launchdarkly_api/models/member.rb', line 25

def first_name
  @first_name
end

#has_passwordObject

Whether the member has a password set (basic auth). False for OAuth-only or SCIM-provisioned members without a password.



72
73
74
# File 'lib/launchdarkly_api/models/member.rb', line 72

def has_password
  @has_password
end

#last_nameObject

The member's last name



28
29
30
# File 'lib/launchdarkly_api/models/member.rb', line 28

def last_name
  @last_name
end

#mfaObject

Whether multi-factor authentication is enabled for this member



49
50
51
# File 'lib/launchdarkly_api/models/member.rb', line 49

def mfa
  @mfa
end

#mfa_enforcedObject

Returns the value of attribute mfa_enforced.



79
80
81
# File 'lib/launchdarkly_api/models/member.rb', line 79

def mfa_enforced
  @mfa_enforced
end

#mfa_grace_period_expires_atObject

Returns the value of attribute mfa_grace_period_expires_at.



81
82
83
# File 'lib/launchdarkly_api/models/member.rb', line 81

def mfa_grace_period_expires_at
  @mfa_grace_period_expires_at
end

#oauth_providersObject

A list of OAuth providers



69
70
71
# File 'lib/launchdarkly_api/models/member.rb', line 69

def oauth_providers
  @oauth_providers
end

#permission_grantsObject

A list of permission grants. Permission grants allow a member to have access to a specific action, without having to create or update a custom role.



64
65
66
# File 'lib/launchdarkly_api/models/member.rb', line 64

def permission_grants
  @permission_grants
end

#roleObject

The member's base role. If the member has no additional roles, this role will be in effect.



31
32
33
# File 'lib/launchdarkly_api/models/member.rb', line 31

def role
  @role
end

#role_attributesObject

Returns the value of attribute role_attributes.



77
78
79
# File 'lib/launchdarkly_api/models/member.rb', line 77

def role_attributes
  @role_attributes
end

#teamsObject

Details on the teams this member is assigned to



61
62
63
# File 'lib/launchdarkly_api/models/member.rb', line 61

def teams
  @teams
end

#versionObject

Version of the current configuration



75
76
77
# File 'lib/launchdarkly_api/models/member.rb', line 75

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



114
115
116
# File 'lib/launchdarkly_api/models/member.rb', line 114

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



119
120
121
# File 'lib/launchdarkly_api/models/member.rb', line 119

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/launchdarkly_api/models/member.rb', line 84

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'role' => :'role',
    :'email' => :'email',
    :'_pending_invite' => :'_pendingInvite',
    :'_verified' => :'_verified',
    :'_pending_email' => :'_pendingEmail',
    :'custom_roles' => :'customRoles',
    :'mfa' => :'mfa',
    :'excluded_dashboards' => :'excludedDashboards',
    :'_last_seen' => :'_lastSeen',
    :'_last_seen_metadata' => :'_lastSeenMetadata',
    :'_integration_metadata' => :'_integrationMetadata',
    :'teams' => :'teams',
    :'permission_grants' => :'permissionGrants',
    :'creation_date' => :'creationDate',
    :'oauth_providers' => :'oauthProviders',
    :'has_password' => :'hasPassword',
    :'version' => :'version',
    :'role_attributes' => :'roleAttributes',
    :'mfa_enforced' => :'mfaEnforced',
    :'mfa_grace_period_expires_at' => :'mfaGracePeriodExpiresAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
# File 'lib/launchdarkly_api/models/member.rb', line 517

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



154
155
156
157
# File 'lib/launchdarkly_api/models/member.rb', line 154

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
# File 'lib/launchdarkly_api/models/member.rb', line 124

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'role' => :'String',
    :'email' => :'String',
    :'_pending_invite' => :'Boolean',
    :'_verified' => :'Boolean',
    :'_pending_email' => :'String',
    :'custom_roles' => :'Array<String>',
    :'mfa' => :'String',
    :'excluded_dashboards' => :'Array<String>',
    :'_last_seen' => :'Integer',
    :'_last_seen_metadata' => :'LastSeenMetadata',
    :'_integration_metadata' => :'IntegrationMetadata',
    :'teams' => :'Array<MemberTeamSummaryRep>',
    :'permission_grants' => :'Array<MemberPermissionGrantSummaryRep>',
    :'creation_date' => :'Integer',
    :'oauth_providers' => :'Array<String>',
    :'has_password' => :'Boolean',
    :'version' => :'Integer',
    :'role_attributes' => :'Hash<String, Array>',
    :'mfa_enforced' => :'Boolean',
    :'mfa_grace_period_expires_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
# File 'lib/launchdarkly_api/models/member.rb', line 473

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      role == o.role &&
      email == o.email &&
      _pending_invite == o._pending_invite &&
      _verified == o._verified &&
      _pending_email == o._pending_email &&
      custom_roles == o.custom_roles &&
      mfa == o.mfa &&
      excluded_dashboards == o.excluded_dashboards &&
      _last_seen == o._last_seen &&
       == o. &&
       == o. &&
      teams == o.teams &&
      permission_grants == o.permission_grants &&
      creation_date == o.creation_date &&
      oauth_providers == o.oauth_providers &&
      has_password == o.has_password &&
      version == o.version &&
      role_attributes == o.role_attributes &&
      mfa_enforced == o.mfa_enforced &&
      mfa_grace_period_expires_at == o.mfa_grace_period_expires_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


504
505
506
# File 'lib/launchdarkly_api/models/member.rb', line 504

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



510
511
512
# File 'lib/launchdarkly_api/models/member.rb', line 510

def hash
  [_links, _id, first_name, last_name, role, email, _pending_invite, _verified, _pending_email, custom_roles, mfa, excluded_dashboards, _last_seen, , , teams, permission_grants, creation_date, oauth_providers, has_password, version, role_attributes, mfa_enforced, mfa_grace_period_expires_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/launchdarkly_api/models/member.rb', line 308

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @_pending_invite.nil?
    invalid_properties.push('invalid value for "_pending_invite", _pending_invite cannot be nil.')
  end

  if @_verified.nil?
    invalid_properties.push('invalid value for "_verified", _verified cannot be nil.')
  end

  if @custom_roles.nil?
    invalid_properties.push('invalid value for "custom_roles", custom_roles cannot be nil.')
  end

  if @mfa.nil?
    invalid_properties.push('invalid value for "mfa", mfa cannot be nil.')
  end

  if @_last_seen.nil?
    invalid_properties.push('invalid value for "_last_seen", _last_seen cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



539
540
541
542
543
544
545
546
547
548
549
550
551
# File 'lib/launchdarkly_api/models/member.rb', line 539

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



356
357
358
359
360
361
362
363
364
365
366
367
368
369
# File 'lib/launchdarkly_api/models/member.rb', line 356

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @role.nil?
  return false if @email.nil?
  return false if @_pending_invite.nil?
  return false if @_verified.nil?
  return false if @custom_roles.nil?
  return false if @mfa.nil?
  return false if @_last_seen.nil?
  return false if @creation_date.nil?
  true
end