Class: LaunchDarklyApi::MemberTeamSummaryRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::MemberTeamSummaryRep
- Defined in:
- lib/launchdarkly_api/models/member_team_summary_rep.rb
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#custom_role_keys ⇒ Object
A list of keys of the custom roles this team has access to.
-
#key ⇒ Object
The team key.
-
#name ⇒ Object
The team name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MemberTeamSummaryRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MemberTeamSummaryRep
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MemberTeamSummaryRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MemberTeamSummaryRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'custom_role_keys') if (value = attributes[:'custom_role_keys']).is_a?(Array) self.custom_role_keys = value end else self.custom_role_keys = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
24 25 26 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 24 def _links @_links end |
#custom_role_keys ⇒ Object
A list of keys of the custom roles this team has access to
19 20 21 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 19 def custom_role_keys @custom_role_keys end |
#key ⇒ Object
The team key
22 23 24 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 22 def key @key end |
#name ⇒ Object
The team name
27 28 29 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 27 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 30 def self.attribute_map { :'custom_role_keys' => :'customRoleKeys', :'key' => :'key', :'_links' => :'_links', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 194 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 50 def self.openapi_types { :'custom_role_keys' => :'Array<String>', :'key' => :'String', :'_links' => :'Hash<String, Link>', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
170 171 172 173 174 175 176 177 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 170 def ==(o) return true if self.equal?(o) self.class == o.class && custom_role_keys == o.custom_role_keys && key == o.key && _links == o._links && name == o.name end |
#eql?(o) ⇒ Boolean
181 182 183 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 181 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
187 188 189 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 187 def hash [custom_role_keys, key, _links, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @custom_role_keys.nil? invalid_properties.push('invalid value for "custom_role_keys", custom_role_keys cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
216 217 218 219 220 221 222 223 224 225 226 227 228 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 216 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
130 131 132 133 134 135 136 |
# File 'lib/launchdarkly_api/models/member_team_summary_rep.rb', line 130 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @custom_role_keys.nil? return false if @key.nil? return false if @name.nil? true end |