Class: LaunchDarklyApi::MetricGroupPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::MetricGroupPost
- Defined in:
- lib/launchdarkly_api/models/metric_group_post.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#description ⇒ Object
Description of the metric group.
-
#key ⇒ Object
A unique key to reference the metric group.
-
#kind ⇒ Object
The type of the metric group.
-
#maintainer_id ⇒ Object
The ID of the member who maintains this metric group.
-
#metrics ⇒ Object
An ordered list of the metrics in this metric group.
-
#name ⇒ Object
A human-friendly name for the metric group.
-
#tags ⇒ Object
Tags for the metric group.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricGroupPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MetricGroupPost
Initializes the object
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 105 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricGroupPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricGroupPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] else self.maintainer_id = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'metrics') if (value = attributes[:'metrics']).is_a?(Array) self.metrics = value end else self.metrics = nil end end |
Instance Attribute Details
#description ⇒ Object
Description of the metric group
28 29 30 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 28 def description @description end |
#key ⇒ Object
A unique key to reference the metric group
19 20 21 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 19 def key @key end |
#kind ⇒ Object
The type of the metric group
25 26 27 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 25 def kind @kind end |
#maintainer_id ⇒ Object
The ID of the member who maintains this metric group
31 32 33 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 31 def maintainer_id @maintainer_id end |
#metrics ⇒ Object
An ordered list of the metrics in this metric group
37 38 39 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 37 def metrics @metrics end |
#name ⇒ Object
A human-friendly name for the metric group
22 23 24 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 22 def name @name end |
#tags ⇒ Object
Tags for the metric group
34 35 36 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 34 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
75 76 77 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 75 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 80 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 62 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'kind' => :'kind', :'description' => :'description', :'maintainer_id' => :'maintainerId', :'tags' => :'tags', :'metrics' => :'metrics' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 283 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
98 99 100 101 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 98 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 85 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'kind' => :'String', :'description' => :'String', :'maintainer_id' => :'String', :'tags' => :'Array<String>', :'metrics' => :'Array<MetricInMetricGroupInput>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 256 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && kind == o.kind && description == o.description && maintainer_id == o.maintainer_id && == o. && metrics == o.metrics end |
#eql?(o) ⇒ Boolean
270 271 272 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 270 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
276 277 278 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 276 def hash [key, name, kind, description, maintainer_id, , metrics].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @maintainer_id.nil? invalid_properties.push('invalid value for "maintainer_id", maintainer_id cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @metrics.nil? invalid_properties.push('invalid value for "metrics", metrics cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 305 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/launchdarkly_api/models/metric_group_post.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["funnel", "standard"]) return false unless kind_validator.valid?(@kind) return false if @maintainer_id.nil? return false if @tags.nil? return false if @metrics.nil? true end |