Class: LaunchDarklyApi::MetricGroupRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/metric_group_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetricGroupRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 150

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricGroupRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricGroupRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  else
    self._creation_date = nil
  end

  if attributes.key?(:'_last_modified')
    self._last_modified = attributes[:'_last_modified']
  else
    self._last_modified = nil
  end

  if attributes.key?(:'maintainer')
    self.maintainer = attributes[:'maintainer']
  else
    self.maintainer = nil
  end

  if attributes.key?(:'metrics')
    if (value = attributes[:'metrics']).is_a?(Array)
      self.metrics = value
    end
  else
    self.metrics = nil
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  else
    self._version = nil
  end

  if attributes.key?(:'experiments')
    if (value = attributes[:'experiments']).is_a?(Array)
      self.experiments = value
    end
  end

  if attributes.key?(:'experiment_count')
    self.experiment_count = attributes[:'experiment_count']
  end

  if attributes.key?(:'active_experiment_count')
    self.active_experiment_count = attributes[:'active_experiment_count']
  end

  if attributes.key?(:'active_guarded_rollout_count')
    self.active_guarded_rollout_count = attributes[:'active_guarded_rollout_count']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



36
37
38
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 36

def _access
  @_access
end

#_creation_dateObject

Returns the value of attribute _creation_date.



41
42
43
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 41

def _creation_date
  @_creation_date
end

#_idObject

The ID of this metric group



19
20
21
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 19

def _id
  @_id
end

#_last_modifiedObject

Returns the value of attribute _last_modified.



43
44
45
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 43

def _last_modified
  @_last_modified
end

The location and content type of related resources



34
35
36
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 34

def _links
  @_links
end

#_versionObject

The version of this metric group



51
52
53
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 51

def _version
  @_version
end

#active_experiment_countObject

The number of active experiments using this metric group



59
60
61
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 59

def active_experiment_count
  @active_experiment_count
end

#active_guarded_rollout_countObject

The number of active guarded rollouts using this metric group



62
63
64
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 62

def active_guarded_rollout_count
  @active_guarded_rollout_count
end

#descriptionObject

Description of the metric group



31
32
33
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 31

def description
  @description
end

#experiment_countObject

The number of experiments using this metric group



56
57
58
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 56

def experiment_count
  @experiment_count
end

#experimentsObject

Returns the value of attribute experiments.



53
54
55
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 53

def experiments
  @experiments
end

#keyObject

A unique key to reference the metric group



22
23
24
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 22

def key
  @key
end

#kindObject

The type of the metric group



28
29
30
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 28

def kind
  @kind
end

#maintainerObject

Returns the value of attribute maintainer.



45
46
47
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 45

def maintainer
  @maintainer
end

#metricsObject

An ordered list of the metrics in this metric group



48
49
50
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 48

def metrics
  @metrics
end

#nameObject

A human-friendly name for the metric group



25
26
27
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 25

def name
  @name
end

#tagsObject

Tags for the metric group



39
40
41
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 39

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



110
111
112
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 110

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



115
116
117
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 115

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 87

def self.attribute_map
  {
    :'_id' => :'_id',
    :'key' => :'key',
    :'name' => :'name',
    :'kind' => :'kind',
    :'description' => :'description',
    :'_links' => :'_links',
    :'_access' => :'_access',
    :'tags' => :'tags',
    :'_creation_date' => :'_creationDate',
    :'_last_modified' => :'_lastModified',
    :'maintainer' => :'maintainer',
    :'metrics' => :'metrics',
    :'_version' => :'_version',
    :'experiments' => :'experiments',
    :'experiment_count' => :'experimentCount',
    :'active_experiment_count' => :'activeExperimentCount',
    :'active_guarded_rollout_count' => :'activeGuardedRolloutCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



484
485
486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 484

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



143
144
145
146
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 143

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 120

def self.openapi_types
  {
    :'_id' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'description' => :'String',
    :'_links' => :'Hash<String, Link>',
    :'_access' => :'Access',
    :'tags' => :'Array<String>',
    :'_creation_date' => :'Integer',
    :'_last_modified' => :'Integer',
    :'maintainer' => :'MaintainerRep',
    :'metrics' => :'Array<MetricInGroupRep>',
    :'_version' => :'Integer',
    :'experiments' => :'Array<DependentExperimentRep>',
    :'experiment_count' => :'Integer',
    :'active_experiment_count' => :'Integer',
    :'active_guarded_rollout_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 447

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      key == o.key &&
      name == o.name &&
      kind == o.kind &&
      description == o.description &&
      _links == o._links &&
      _access == o._access &&
      tags == o.tags &&
      _creation_date == o._creation_date &&
      _last_modified == o._last_modified &&
      maintainer == o.maintainer &&
      metrics == o.metrics &&
      _version == o._version &&
      experiments == o.experiments &&
      experiment_count == o.experiment_count &&
      active_experiment_count == o.active_experiment_count &&
      active_guarded_rollout_count == o.active_guarded_rollout_count
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


471
472
473
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 471

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



477
478
479
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 477

def hash
  [_id, key, name, kind, description, _links, _access, tags, _creation_date, _last_modified, maintainer, metrics, _version, experiments, experiment_count, active_experiment_count, active_guarded_rollout_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 265

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @_creation_date.nil?
    invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.')
  end

  if @_last_modified.nil?
    invalid_properties.push('invalid value for "_last_modified", _last_modified cannot be nil.')
  end

  if @maintainer.nil?
    invalid_properties.push('invalid value for "maintainer", maintainer cannot be nil.')
  end

  if @metrics.nil?
    invalid_properties.push('invalid value for "metrics", metrics cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



506
507
508
509
510
511
512
513
514
515
516
517
518
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 506

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 317

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @key.nil?
  return false if @name.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["funnel", "standard"])
  return false unless kind_validator.valid?(@kind)
  return false if @_links.nil?
  return false if @tags.nil?
  return false if @_creation_date.nil?
  return false if @_last_modified.nil?
  return false if @maintainer.nil?
  return false if @metrics.nil?
  return false if @_version.nil?
  true
end