Class: LaunchDarklyApi::MetricPost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/metric_post.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetricPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/launchdarkly_api/models/metric_post.rb', line 216

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'selector')
    self.selector = attributes[:'selector']
  end

  if attributes.key?(:'urls')
    if (value = attributes[:'urls']).is_a?(Array)
      self.urls = value
    end
  end

  if attributes.key?(:'is_numeric')
    self.is_numeric = attributes[:'is_numeric']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'event_key')
    self.event_key = attributes[:'event_key']
  end

  if attributes.key?(:'success_criteria')
    self.success_criteria = attributes[:'success_criteria']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'randomization_units')
    if (value = attributes[:'randomization_units']).is_a?(Array)
      self.randomization_units = value
    end
  end

  if attributes.key?(:'analysis_units')
    if (value = attributes[:'analysis_units']).is_a?(Array)
      self.analysis_units = value
    end
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'unit_aggregation_type')
    self.unit_aggregation_type = attributes[:'unit_aggregation_type']
  end

  if attributes.key?(:'analysis_type')
    self.analysis_type = attributes[:'analysis_type']
  end

  if attributes.key?(:'percentile_value')
    self.percentile_value = attributes[:'percentile_value']
  end

  if attributes.key?(:'event_default')
    self.event_default = attributes[:'event_default']
  end

  if attributes.key?(:'data_source')
    self.data_source = attributes[:'data_source']
  end

  if attributes.key?(:'filters')
    self.filters = attributes[:'filters']
  end

  if attributes.key?(:'window_start_offset')
    self.window_start_offset = attributes[:'window_start_offset']
  end

  if attributes.key?(:'window_end_offset')
    self.window_end_offset = attributes[:'window_end_offset']
  end

  if attributes.key?(:'winsor_lower_percentile')
    self.winsor_lower_percentile = attributes[:'winsor_lower_percentile']
  end

  if attributes.key?(:'winsor_upper_percentile')
    self.winsor_upper_percentile = attributes[:'winsor_upper_percentile']
  end

  if attributes.key?(:'winsor_exclude_imputed')
    self.winsor_exclude_imputed = attributes[:'winsor_exclude_imputed']
  end

  if attributes.key?(:'winsor_include_imputed')
    self.winsor_include_imputed = attributes[:'winsor_include_imputed']
  end

  if attributes.key?(:'trace_query')
    self.trace_query = attributes[:'trace_query']
  end

  if attributes.key?(:'trace_value_location')
    self.trace_value_location = attributes[:'trace_value_location']
  end

  if attributes.key?(:'unit_aggregation_field')
    self.unit_aggregation_field = attributes[:'unit_aggregation_field']
  end

  if attributes.key?(:'denominator')
    self.denominator = attributes[:'denominator']
  end
end

Instance Attribute Details

#analysis_typeObject

The method for analyzing metric events



64
65
66
# File 'lib/launchdarkly_api/models/metric_post.rb', line 64

def analysis_type
  @analysis_type
end

#analysis_unitsObject

An array of analysis units allowed for this metric.



55
56
57
# File 'lib/launchdarkly_api/models/metric_post.rb', line 55

def analysis_units
  @analysis_units
end

#data_sourceObject

Returns the value of attribute data_source.



71
72
73
# File 'lib/launchdarkly_api/models/metric_post.rb', line 71

def data_source
  @data_source
end

#denominatorObject

Returns the value of attribute denominator.



102
103
104
# File 'lib/launchdarkly_api/models/metric_post.rb', line 102

def denominator
  @denominator
end

#descriptionObject

Description of the metric



25
26
27
# File 'lib/launchdarkly_api/models/metric_post.rb', line 25

def description
  @description
end

#event_defaultObject

Returns the value of attribute event_default.



69
70
71
# File 'lib/launchdarkly_api/models/metric_post.rb', line 69

def event_default
  @event_default
end

#event_keyObject

The event key to use in your code. Required for custom conversion/binary and custom numeric metrics only.



43
44
45
# File 'lib/launchdarkly_api/models/metric_post.rb', line 43

def event_key
  @event_key
end

#filtersObject

Returns the value of attribute filters.



73
74
75
# File 'lib/launchdarkly_api/models/metric_post.rb', line 73

def filters
  @filters
end

#is_numericObject

Whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false). Required for custom and trace metrics only.



37
38
39
# File 'lib/launchdarkly_api/models/metric_post.rb', line 37

def is_numeric
  @is_numeric
end

#keyObject

A unique key to reference the metric



19
20
21
# File 'lib/launchdarkly_api/models/metric_post.rb', line 19

def key
  @key
end

#kindObject

The kind of event your metric will track



28
29
30
# File 'lib/launchdarkly_api/models/metric_post.rb', line 28

def kind
  @kind
end

#maintainer_idObject

The ID of the member who maintains this metric



58
59
60
# File 'lib/launchdarkly_api/models/metric_post.rb', line 58

def maintainer_id
  @maintainer_id
end

#nameObject

A human-friendly name for the metric



22
23
24
# File 'lib/launchdarkly_api/models/metric_post.rb', line 22

def name
  @name
end

#percentile_valueObject

The percentile for the analysis method. An integer denoting the target percentile between 0 and 100. Required when analysisType is percentile.



67
68
69
# File 'lib/launchdarkly_api/models/metric_post.rb', line 67

def percentile_value
  @percentile_value
end

#randomization_unitsObject

Deprecated, use analysisUnits instead.



52
53
54
# File 'lib/launchdarkly_api/models/metric_post.rb', line 52

def randomization_units
  @randomization_units
end

#selectorObject

One or more CSS selectors. Required for click metrics only.



31
32
33
# File 'lib/launchdarkly_api/models/metric_post.rb', line 31

def selector
  @selector
end

#success_criteriaObject

Success criteria. Required for custom and trace numeric metrics, optional for custom and trace conversion metrics.



46
47
48
# File 'lib/launchdarkly_api/models/metric_post.rb', line 46

def success_criteria
  @success_criteria
end

#tagsObject

Tags for the metric



49
50
51
# File 'lib/launchdarkly_api/models/metric_post.rb', line 49

def tags
  @tags
end

#trace_queryObject

The trace query to use for the metric. Required for trace metrics.



94
95
96
# File 'lib/launchdarkly_api/models/metric_post.rb', line 94

def trace_query
  @trace_query
end

#trace_value_locationObject

The location in the trace to use for numeric values. Required for numeric trace metrics.



97
98
99
# File 'lib/launchdarkly_api/models/metric_post.rb', line 97

def trace_value_location
  @trace_value_location
end

#unitObject

The unit of measure. Applicable for numeric custom and trace metrics only.



40
41
42
# File 'lib/launchdarkly_api/models/metric_post.rb', line 40

def unit
  @unit
end

#unit_aggregation_fieldObject

The warehouse column to use for counting distinct values. Required when the unitAggregationType is count_distinct.



100
101
102
# File 'lib/launchdarkly_api/models/metric_post.rb', line 100

def unit_aggregation_field
  @unit_aggregation_field
end

#unit_aggregation_typeObject

The method by which multiple unit event values are aggregated



61
62
63
# File 'lib/launchdarkly_api/models/metric_post.rb', line 61

def unit_aggregation_type
  @unit_aggregation_type
end

#urlsObject

One or more target URLs. Required for click and pageview metrics only.



34
35
36
# File 'lib/launchdarkly_api/models/metric_post.rb', line 34

def urls
  @urls
end

#window_end_offsetObject

Not yet implemented - The end of the measurement window, in milliseconds relative to the unit's first exposure to a flag variation



79
80
81
# File 'lib/launchdarkly_api/models/metric_post.rb', line 79

def window_end_offset
  @window_end_offset
end

#window_start_offsetObject

Not yet implemented - The start of the measurement window, in milliseconds relative to the unit's first exposure to a flag variation



76
77
78
# File 'lib/launchdarkly_api/models/metric_post.rb', line 76

def window_start_offset
  @window_start_offset
end

#winsor_exclude_imputedObject

Deprecated and ignored. Use winsorIncludeImputed instead.



88
89
90
# File 'lib/launchdarkly_api/models/metric_post.rb', line 88

def winsor_exclude_imputed
  @winsor_exclude_imputed
end

#winsor_include_imputedObject

When true, the percentile bound calculation includes imputed zeros. Only meaningful when at least one bound is set and the metric includes units that didn't send events.



91
92
93
# File 'lib/launchdarkly_api/models/metric_post.rb', line 91

def winsor_include_imputed
  @winsor_include_imputed
end

#winsor_lower_percentileObject

Lower winsorization percentile, expressed as a percent in the open interval (0, 100). When both bounds are set, defines a two-sided clamp range. Otherwise lower-only winsorization.



82
83
84
# File 'lib/launchdarkly_api/models/metric_post.rb', line 82

def winsor_lower_percentile
  @winsor_lower_percentile
end

#winsor_upper_percentileObject

Upper winsorization percentile, expressed as a percent in the open interval (0, 100). When both bounds are set, must be greater than winsorLowerPercentile.



85
86
87
# File 'lib/launchdarkly_api/models/metric_post.rb', line 85

def winsor_upper_percentile
  @winsor_upper_percentile
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



163
164
165
# File 'lib/launchdarkly_api/models/metric_post.rb', line 163

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



168
169
170
# File 'lib/launchdarkly_api/models/metric_post.rb', line 168

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
# File 'lib/launchdarkly_api/models/metric_post.rb', line 127

def self.attribute_map
  {
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'kind' => :'kind',
    :'selector' => :'selector',
    :'urls' => :'urls',
    :'is_numeric' => :'isNumeric',
    :'unit' => :'unit',
    :'event_key' => :'eventKey',
    :'success_criteria' => :'successCriteria',
    :'tags' => :'tags',
    :'randomization_units' => :'randomizationUnits',
    :'analysis_units' => :'analysisUnits',
    :'maintainer_id' => :'maintainerId',
    :'unit_aggregation_type' => :'unitAggregationType',
    :'analysis_type' => :'analysisType',
    :'percentile_value' => :'percentileValue',
    :'event_default' => :'eventDefault',
    :'data_source' => :'dataSource',
    :'filters' => :'filters',
    :'window_start_offset' => :'windowStartOffset',
    :'window_end_offset' => :'windowEndOffset',
    :'winsor_lower_percentile' => :'winsorLowerPercentile',
    :'winsor_upper_percentile' => :'winsorUpperPercentile',
    :'winsor_exclude_imputed' => :'winsorExcludeImputed',
    :'winsor_include_imputed' => :'winsorIncludeImputed',
    :'trace_query' => :'traceQuery',
    :'trace_value_location' => :'traceValueLocation',
    :'unit_aggregation_field' => :'unitAggregationField',
    :'denominator' => :'denominator'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



486
487
488
489
490
491
492
493
494
495
496
497
498
499
500
501
502
503
504
# File 'lib/launchdarkly_api/models/metric_post.rb', line 486

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



209
210
211
212
# File 'lib/launchdarkly_api/models/metric_post.rb', line 209

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/launchdarkly_api/models/metric_post.rb', line 173

def self.openapi_types
  {
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'kind' => :'String',
    :'selector' => :'String',
    :'urls' => :'Array<UrlPost>',
    :'is_numeric' => :'Boolean',
    :'unit' => :'String',
    :'event_key' => :'String',
    :'success_criteria' => :'String',
    :'tags' => :'Array<String>',
    :'randomization_units' => :'Array<String>',
    :'analysis_units' => :'Array<String>',
    :'maintainer_id' => :'String',
    :'unit_aggregation_type' => :'String',
    :'analysis_type' => :'String',
    :'percentile_value' => :'Integer',
    :'event_default' => :'MetricEventDefaultRep',
    :'data_source' => :'MetricDataSourceRefRep',
    :'filters' => :'EventFilter',
    :'window_start_offset' => :'Integer',
    :'window_end_offset' => :'Integer',
    :'winsor_lower_percentile' => :'Float',
    :'winsor_upper_percentile' => :'Float',
    :'winsor_exclude_imputed' => :'Boolean',
    :'winsor_include_imputed' => :'Boolean',
    :'trace_query' => :'String',
    :'trace_value_location' => :'String',
    :'unit_aggregation_field' => :'String',
    :'denominator' => :'DenominatorPost'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



436
437
438
439
440
441
442
443
444
445
446
447
448
449
450
451
452
453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
# File 'lib/launchdarkly_api/models/metric_post.rb', line 436

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      kind == o.kind &&
      selector == o.selector &&
      urls == o.urls &&
      is_numeric == o.is_numeric &&
      unit == o.unit &&
      event_key == o.event_key &&
      success_criteria == o.success_criteria &&
      tags == o.tags &&
      randomization_units == o.randomization_units &&
      analysis_units == o.analysis_units &&
      maintainer_id == o.maintainer_id &&
      unit_aggregation_type == o.unit_aggregation_type &&
      analysis_type == o.analysis_type &&
      percentile_value == o.percentile_value &&
      event_default == o.event_default &&
      data_source == o.data_source &&
      filters == o.filters &&
      window_start_offset == o.window_start_offset &&
      window_end_offset == o.window_end_offset &&
      winsor_lower_percentile == o.winsor_lower_percentile &&
      winsor_upper_percentile == o.winsor_upper_percentile &&
      winsor_exclude_imputed == o.winsor_exclude_imputed &&
      winsor_include_imputed == o.winsor_include_imputed &&
      trace_query == o.trace_query &&
      trace_value_location == o.trace_value_location &&
      unit_aggregation_field == o.unit_aggregation_field &&
      denominator == o.denominator
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


473
474
475
# File 'lib/launchdarkly_api/models/metric_post.rb', line 473

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



479
480
481
# File 'lib/launchdarkly_api/models/metric_post.rb', line 479

def hash
  [key, name, description, kind, selector, urls, is_numeric, unit, event_key, success_criteria, tags, randomization_units, analysis_units, maintainer_id, unit_aggregation_type, analysis_type, percentile_value, event_default, data_source, filters, window_start_offset, window_end_offset, winsor_lower_percentile, winsor_upper_percentile, winsor_exclude_imputed, winsor_include_imputed, trace_query, trace_value_location, unit_aggregation_field, denominator].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/launchdarkly_api/models/metric_post.rb', line 365

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



508
509
510
511
512
513
514
515
516
517
518
519
520
# File 'lib/launchdarkly_api/models/metric_post.rb', line 508

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/launchdarkly_api/models/metric_post.rb', line 381

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom", "trace"])
  return false unless kind_validator.valid?(@kind)
  success_criteria_validator = EnumAttributeValidator.new('String', ["HigherThanBaseline", "LowerThanBaseline"])
  return false unless success_criteria_validator.valid?(@success_criteria)
  unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["average", "sum", "count_distinct"])
  return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type)
  true
end