Class: LaunchDarklyApi::ModelConfig

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/model_config.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
# File 'lib/launchdarkly_api/models/model_config.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ModelConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ModelConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'global')
    self.global = attributes[:'global']
  else
    self.global = nil
  end

  if attributes.key?(:'params')
    self.params = attributes[:'params']
  end

  if attributes.key?(:'custom_params')
    self.custom_params = attributes[:'custom_params']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'cost_per_input_token')
    self.cost_per_input_token = attributes[:'cost_per_input_token']
  end

  if attributes.key?(:'cost_per_output_token')
    self.cost_per_output_token = attributes[:'cost_per_output_token']
  end

  if attributes.key?(:'is_restricted')
    self.is_restricted = attributes[:'is_restricted']
  else
    self.is_restricted = nil
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



18
19
20
# File 'lib/launchdarkly_api/models/model_config.rb', line 18

def _access
  @_access
end

#cost_per_input_tokenObject

Cost per input token in USD



47
48
49
# File 'lib/launchdarkly_api/models/model_config.rb', line 47

def cost_per_input_token
  @cost_per_input_token
end

#cost_per_output_tokenObject

Cost per output token in USD



50
51
52
# File 'lib/launchdarkly_api/models/model_config.rb', line 50

def cost_per_output_token
  @cost_per_output_token
end

#custom_paramsObject

Returns the value of attribute custom_params.



40
41
42
# File 'lib/launchdarkly_api/models/model_config.rb', line 40

def custom_params
  @custom_params
end

#globalObject

Whether the model is global



36
37
38
# File 'lib/launchdarkly_api/models/model_config.rb', line 36

def global
  @global
end

#iconObject

Icon for the model



30
31
32
# File 'lib/launchdarkly_api/models/model_config.rb', line 30

def icon
  @icon
end

#idObject

Identifier for the model, for use with third party providers



27
28
29
# File 'lib/launchdarkly_api/models/model_config.rb', line 27

def id
  @id
end

#is_restrictedObject

Whether the model is restricted



53
54
55
# File 'lib/launchdarkly_api/models/model_config.rb', line 53

def is_restricted
  @is_restricted
end

#keyObject

Unique key for the model



24
25
26
# File 'lib/launchdarkly_api/models/model_config.rb', line 24

def key
  @key
end

#nameObject

Human readable name of the model



21
22
23
# File 'lib/launchdarkly_api/models/model_config.rb', line 21

def name
  @name
end

#paramsObject

Returns the value of attribute params.



38
39
40
# File 'lib/launchdarkly_api/models/model_config.rb', line 38

def params
  @params
end

#providerObject

Provider for the model



33
34
35
# File 'lib/launchdarkly_api/models/model_config.rb', line 33

def provider
  @provider
end

#tagsObject

Returns the value of attribute tags.



42
43
44
# File 'lib/launchdarkly_api/models/model_config.rb', line 42

def tags
  @tags
end

#versionObject

Returns the value of attribute version.



44
45
46
# File 'lib/launchdarkly_api/models/model_config.rb', line 44

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



76
77
78
# File 'lib/launchdarkly_api/models/model_config.rb', line 76

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



81
82
83
# File 'lib/launchdarkly_api/models/model_config.rb', line 81

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
# File 'lib/launchdarkly_api/models/model_config.rb', line 56

def self.attribute_map
  {
    :'_access' => :'_access',
    :'name' => :'name',
    :'key' => :'key',
    :'id' => :'id',
    :'icon' => :'icon',
    :'provider' => :'provider',
    :'global' => :'global',
    :'params' => :'params',
    :'custom_params' => :'customParams',
    :'tags' => :'tags',
    :'version' => :'version',
    :'cost_per_input_token' => :'costPerInputToken',
    :'cost_per_output_token' => :'costPerOutputToken',
    :'is_restricted' => :'isRestricted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/launchdarkly_api/models/model_config.rb', line 356

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



106
107
108
109
# File 'lib/launchdarkly_api/models/model_config.rb', line 106

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/launchdarkly_api/models/model_config.rb', line 86

def self.openapi_types
  {
    :'_access' => :'AiConfigsAccess',
    :'name' => :'String',
    :'key' => :'String',
    :'id' => :'String',
    :'icon' => :'String',
    :'provider' => :'String',
    :'global' => :'Boolean',
    :'params' => :'Object',
    :'custom_params' => :'Object',
    :'tags' => :'Array<String>',
    :'version' => :'Integer',
    :'cost_per_input_token' => :'Float',
    :'cost_per_output_token' => :'Float',
    :'is_restricted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
# File 'lib/launchdarkly_api/models/model_config.rb', line 322

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _access == o._access &&
      name == o.name &&
      key == o.key &&
      id == o.id &&
      icon == o.icon &&
      provider == o.provider &&
      global == o.global &&
      params == o.params &&
      custom_params == o.custom_params &&
      tags == o.tags &&
      version == o.version &&
      cost_per_input_token == o.cost_per_input_token &&
      cost_per_output_token == o.cost_per_output_token &&
      is_restricted == o.is_restricted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


343
344
345
# File 'lib/launchdarkly_api/models/model_config.rb', line 343

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



349
350
351
# File 'lib/launchdarkly_api/models/model_config.rb', line 349

def hash
  [_access, name, key, id, icon, provider, global, params, custom_params, tags, version, cost_per_input_token, cost_per_output_token, is_restricted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/launchdarkly_api/models/model_config.rb', line 202

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @global.nil?
    invalid_properties.push('invalid value for "global", global cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @is_restricted.nil?
    invalid_properties.push('invalid value for "is_restricted", is_restricted cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/launchdarkly_api/models/model_config.rb', line 378

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



238
239
240
241
242
243
244
245
246
247
248
# File 'lib/launchdarkly_api/models/model_config.rb', line 238

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @key.nil?
  return false if @id.nil?
  return false if @global.nil?
  return false if @tags.nil?
  return false if @version.nil?
  return false if @is_restricted.nil?
  true
end