Class: LaunchDarklyApi::ModelConfigPatch

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/model_config_patch.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelConfigPatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 98

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ModelConfigPatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ModelConfigPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'cost_per_input_token')
    self.cost_per_input_token = attributes[:'cost_per_input_token']
  end

  if attributes.key?(:'cost_per_output_token')
    self.cost_per_output_token = attributes[:'cost_per_output_token']
  end

  if attributes.key?(:'cost_per_cached_input_token')
    self.cost_per_cached_input_token = attributes[:'cost_per_cached_input_token']
  end

  if attributes.key?(:'params')
    self.params = attributes[:'params']
  end

  if attributes.key?(:'custom_params')
    self.custom_params = attributes[:'custom_params']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end
end

Instance Attribute Details

#cost_per_cached_input_tokenObject

Cost per cached input token in USD



34
35
36
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 34

def cost_per_cached_input_token
  @cost_per_cached_input_token
end

#cost_per_input_tokenObject

Cost per input token in USD



28
29
30
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 28

def cost_per_input_token
  @cost_per_input_token
end

#cost_per_output_tokenObject

Cost per output token in USD



31
32
33
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 31

def cost_per_output_token
  @cost_per_output_token
end

#custom_paramsObject

Returns the value of attribute custom_params.



38
39
40
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 38

def custom_params
  @custom_params
end

#idObject

Immutable provider model identifier. To use a different model identifier, create a new model config.



19
20
21
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 19

def id
  @id
end

#maintainer_idObject

Returns the value of attribute maintainer_id.



42
43
44
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 42

def maintainer_id
  @maintainer_id
end

#maintainer_team_keyObject

Returns the value of attribute maintainer_team_key.



44
45
46
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 44

def maintainer_team_key
  @maintainer_team_key
end

#nameObject

Human-readable name of the model



25
26
27
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 25

def name
  @name
end

#paramsObject

Returns the value of attribute params.



36
37
38
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 36

def params
  @params
end

#providerObject

Immutable model provider. To use a different provider, create a new model config.



22
23
24
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 22

def provider
  @provider
end

#tagsObject

Returns the value of attribute tags.



40
41
42
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 40

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 47

def self.attribute_map
  {
    :'id' => :'id',
    :'provider' => :'provider',
    :'name' => :'name',
    :'cost_per_input_token' => :'costPerInputToken',
    :'cost_per_output_token' => :'costPerOutputToken',
    :'cost_per_cached_input_token' => :'costPerCachedInputToken',
    :'params' => :'params',
    :'custom_params' => :'customParams',
    :'tags' => :'tags',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 207

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



91
92
93
94
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 91

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 74

def self.openapi_types
  {
    :'id' => :'String',
    :'provider' => :'String',
    :'name' => :'String',
    :'cost_per_input_token' => :'Float',
    :'cost_per_output_token' => :'Float',
    :'cost_per_cached_input_token' => :'Float',
    :'params' => :'Object',
    :'custom_params' => :'Object',
    :'tags' => :'Array<String>',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      id == o.id &&
      provider == o.provider &&
      name == o.name &&
      cost_per_input_token == o.cost_per_input_token &&
      cost_per_output_token == o.cost_per_output_token &&
      cost_per_cached_input_token == o.cost_per_cached_input_token &&
      params == o.params &&
      custom_params == o.custom_params &&
      tags == o.tags &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


194
195
196
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 194

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



200
201
202
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 200

def hash
  [id, provider, name, cost_per_input_token, cost_per_output_token, cost_per_cached_input_token, params, custom_params, tags, maintainer_id, maintainer_team_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



229
230
231
232
233
234
235
236
237
238
239
240
241
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 229

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



169
170
171
172
# File 'lib/launchdarkly_api/models/model_config_patch.rb', line 169

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end