Class: LaunchDarklyApi::NewMemberForm

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/new_member_form.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ NewMemberForm

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 109

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::NewMemberForm` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::NewMemberForm`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  else
    self.email = nil
  end

  if attributes.key?(:'password')
    self.password = attributes[:'password']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'custom_roles')
    if (value = attributes[:'custom_roles']).is_a?(Array)
      self.custom_roles = value
    end
  end

  if attributes.key?(:'team_keys')
    if (value = attributes[:'team_keys']).is_a?(Array)
      self.team_keys = value
    end
  end

  if attributes.key?(:'role_attributes')
    if (value = attributes[:'role_attributes']).is_a?(Hash)
      self.role_attributes = value
    end
  end
end

Instance Attribute Details

#custom_rolesObject

An array of the member's initial roles, if you are using custom roles or preset roles provided by LaunchDarkly



34
35
36
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 34

def custom_roles
  @custom_roles
end

#emailObject

The member's email



19
20
21
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 19

def email
  @email
end

#first_nameObject

The member's first name



25
26
27
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 25

def first_name
  @first_name
end

#last_nameObject

The member's last name



28
29
30
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 28

def last_name
  @last_name
end

#passwordObject

The member's password



22
23
24
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 22

def password
  @password
end

#roleObject

The member's initial role, if you are using a base role for the initial role



31
32
33
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 31

def role
  @role
end

#role_attributesObject

Returns the value of attribute role_attributes.



39
40
41
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 39

def role_attributes
  @role_attributes
end

#team_keysObject

An array of the member's teams



37
38
39
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 37

def team_keys
  @team_keys
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



78
79
80
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 78

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



83
84
85
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 83

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 64

def self.attribute_map
  {
    :'email' => :'email',
    :'password' => :'password',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'role' => :'role',
    :'custom_roles' => :'customRoles',
    :'team_keys' => :'teamKeys',
    :'role_attributes' => :'roleAttributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 236

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



102
103
104
105
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 102

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 88

def self.openapi_types
  {
    :'email' => :'String',
    :'password' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'role' => :'String',
    :'custom_roles' => :'Array<String>',
    :'team_keys' => :'Array<String>',
    :'role_attributes' => :'Hash<String, Array>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



208
209
210
211
212
213
214
215
216
217
218
219
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 208

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      email == o.email &&
      password == o.password &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      role == o.role &&
      custom_roles == o.custom_roles &&
      team_keys == o.team_keys &&
      role_attributes == o.role_attributes
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


223
224
225
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 223

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



229
230
231
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 229

def hash
  [email, password, first_name, last_name, role, custom_roles, team_keys, role_attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 258

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
# File 'lib/launchdarkly_api/models/new_member_form.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @email.nil?
  role_validator = EnumAttributeValidator.new('String', ["reader", "writer", "admin", "no_access"])
  return false unless role_validator.valid?(@role)
  true
end