Class: LaunchDarklyApi::PatchSegmentInstruction

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/patch_segment_instruction.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PatchSegmentInstruction

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PatchSegmentInstruction` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PatchSegmentInstruction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'user_key')
    self.user_key = attributes[:'user_key']
  else
    self.user_key = nil
  end

  if attributes.key?(:'target_type')
    self.target_type = attributes[:'target_type']
  else
    self.target_type = nil
  end

  if attributes.key?(:'value')
    self.value = attributes[:'value']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#kindObject

The type of change to make to the user's removal date from this segment



19
20
21
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 19

def kind
  @kind
end

#target_typeObject

The segment's target type



25
26
27
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 25

def target_type
  @target_type
end

#user_keyObject

A unique key used to represent the user



22
23
24
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 22

def user_key
  @user_key
end

#valueObject

The time, in Unix milliseconds, when the user should be removed from this segment. Required if kind is addExpireUserTargetDate or updateExpireUserTargetDate.



28
29
30
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 28

def value
  @value
end

#versionObject

The version of the segment to update. Required if kind is updateExpireUserTargetDate.



31
32
33
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 31

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 56

def self.attribute_map
  {
    :'kind' => :'kind',
    :'user_key' => :'userKey',
    :'target_type' => :'targetType',
    :'value' => :'value',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 227

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 77

def self.openapi_types
  {
    :'kind' => :'String',
    :'user_key' => :'String',
    :'target_type' => :'String',
    :'value' => :'Integer',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



202
203
204
205
206
207
208
209
210
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 202

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      kind == o.kind &&
      user_key == o.user_key &&
      target_type == o.target_type &&
      value == o.value &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


214
215
216
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 214

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



220
221
222
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 220

def hash
  [kind, user_key, target_type, value, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 138

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @user_key.nil?
    invalid_properties.push('invalid value for "user_key", user_key cannot be nil.')
  end

  if @target_type.nil?
    invalid_properties.push('invalid value for "target_type", target_type cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 249

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



158
159
160
161
162
163
164
165
166
167
168
# File 'lib/launchdarkly_api/models/patch_segment_instruction.rb', line 158

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["addExpireUserTargetDate", "updateExpireUserTargetDate", "removeExpireUserTargetDate"])
  return false unless kind_validator.valid?(@kind)
  return false if @user_key.nil?
  return false if @target_type.nil?
  target_type_validator = EnumAttributeValidator.new('String', ["included", "excluded"])
  return false unless target_type_validator.valid?(@target_type)
  true
end