Class: LaunchDarklyApi::PostInsightGroupParams
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::PostInsightGroupParams
- Defined in:
- lib/launchdarkly_api/models/post_insight_group_params.rb
Instance Attribute Summary collapse
-
#application_keys ⇒ Object
The application keys to associate with the insight group.
-
#environment_key ⇒ Object
The environmentKey to be associated with the insight group.
-
#key ⇒ Object
The key of the insight group.
-
#name ⇒ Object
The name of the insight group.
-
#project_key ⇒ Object
The projectKey to be associated with the insight group.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostInsightGroupParams
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostInsightGroupParams
Initializes the object
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 73 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PostInsightGroupParams` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PostInsightGroupParams`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'project_key') self.project_key = attributes[:'project_key'] else self.project_key = nil end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] else self.environment_key = nil end if attributes.key?(:'application_keys') if (value = attributes[:'application_keys']).is_a?(Array) self.application_keys = value end end end |
Instance Attribute Details
#application_keys ⇒ Object
The application keys to associate with the insight group. If not provided, the insight group will include data from all applications.
31 32 33 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 31 def application_keys @application_keys end |
#environment_key ⇒ Object
The environmentKey to be associated with the insight group
28 29 30 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 28 def environment_key @environment_key end |
#key ⇒ Object
The key of the insight group
22 23 24 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 22 def key @key end |
#name ⇒ Object
The name of the insight group
19 20 21 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 19 def name @name end |
#project_key ⇒ Object
The projectKey to be associated with the insight group
25 26 27 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 25 def project_key @project_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
45 46 47 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 45 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
50 51 52 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 50 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
34 35 36 37 38 39 40 41 42 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 34 def self.attribute_map { :'name' => :'name', :'key' => :'key', :'project_key' => :'projectKey', :'environment_key' => :'environmentKey', :'application_keys' => :'applicationKeys' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 220 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
66 67 68 69 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 66 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
55 56 57 58 59 60 61 62 63 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 55 def self.openapi_types { :'name' => :'String', :'key' => :'String', :'project_key' => :'String', :'environment_key' => :'String', :'application_keys' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
195 196 197 198 199 200 201 202 203 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 195 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && key == o.key && project_key == o.project_key && environment_key == o.environment_key && application_keys == o.application_keys end |
#eql?(o) ⇒ Boolean
207 208 209 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 207 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
213 214 215 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 213 def hash [name, key, project_key, environment_key, application_keys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 120 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @project_key.nil? invalid_properties.push('invalid value for "project_key", project_key cannot be nil.') end if @environment_key.nil? invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 242 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
144 145 146 147 148 149 150 151 |
# File 'lib/launchdarkly_api/models/post_insight_group_params.rb', line 144 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @key.nil? return false if @project_key.nil? return false if @environment_key.nil? true end |