Class: LaunchDarklyApi::PostReleasePolicyRequest

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/post_release_policy_request.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PostReleasePolicyRequest

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PostReleasePolicyRequest` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PostReleasePolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'scope')
    self.scope = attributes[:'scope']
  end

  if attributes.key?(:'release_method')
    self.release_method = attributes[:'release_method']
  else
    self.release_method = nil
  end

  if attributes.key?(:'guarded_release_config')
    self.guarded_release_config = attributes[:'guarded_release_config']
  end

  if attributes.key?(:'progressive_release_config')
    self.progressive_release_config = attributes[:'progressive_release_config']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end
end

Instance Attribute Details

#guarded_release_configObject

Returns the value of attribute guarded_release_config.



22
23
24
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 22

def guarded_release_config
  @guarded_release_config
end

#keyObject

The human-readable key of the release policy



30
31
32
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 30

def key
  @key
end

#nameObject

The name of the release policy



27
28
29
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 27

def name
  @name
end

#progressive_release_configObject

Returns the value of attribute progressive_release_config.



24
25
26
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 24

def progressive_release_config
  @progressive_release_config
end

#release_methodObject

Returns the value of attribute release_method.



20
21
22
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 20

def release_method
  @release_method
end

#scopeObject

Returns the value of attribute scope.



18
19
20
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 18

def scope
  @scope
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



55
56
57
58
59
60
61
62
63
64
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 55

def self.attribute_map
  {
    :'scope' => :'scope',
    :'release_method' => :'releaseMethod',
    :'guarded_release_config' => :'guardedReleaseConfig',
    :'progressive_release_config' => :'progressiveReleaseConfig',
    :'name' => :'name',
    :'key' => :'key'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 238

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 77

def self.openapi_types
  {
    :'scope' => :'ReleasePolicyScope',
    :'release_method' => :'ReleaseMethod',
    :'guarded_release_config' => :'GuardedReleaseConfig',
    :'progressive_release_config' => :'ProgressiveReleaseConfig',
    :'name' => :'String',
    :'key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      scope == o.scope &&
      release_method == o.release_method &&
      guarded_release_config == o.guarded_release_config &&
      progressive_release_config == o.progressive_release_config &&
      name == o.name &&
      key == o.key
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


225
226
227
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 225

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



231
232
233
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 231

def hash
  [scope, release_method, guarded_release_config, progressive_release_config, name, key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 143

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @release_method.nil?
    invalid_properties.push('invalid value for "release_method", release_method cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @name.to_s.length > 256
    invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



260
261
262
263
264
265
266
267
268
269
270
271
272
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 260

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



167
168
169
170
171
172
173
174
# File 'lib/launchdarkly_api/models/post_release_policy_request.rb', line 167

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @release_method.nil?
  return false if @name.nil?
  return false if @name.to_s.length > 256
  return false if @key.nil?
  true
end