Class: LaunchDarklyApi::ProjectPost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/project_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
# File 'lib/launchdarkly_api/models/project_post.rb', line 81

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ProjectPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ProjectPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'include_in_snippet_by_default')
    self.include_in_snippet_by_default = attributes[:'include_in_snippet_by_default']
  end

  if attributes.key?(:'default_client_side_availability')
    self.default_client_side_availability = attributes[:'default_client_side_availability']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'environments')
    if (value = attributes[:'environments']).is_a?(Array)
      self.environments = value
    end
  end

  if attributes.key?(:'naming_convention')
    self.naming_convention = attributes[:'naming_convention']
  end
end

Instance Attribute Details

#default_client_side_availabilityObject

Returns the value of attribute default_client_side_availability.



27
28
29
# File 'lib/launchdarkly_api/models/project_post.rb', line 27

def default_client_side_availability
  @default_client_side_availability
end

#environmentsObject

Creates the provided environments for this project. If omitted default environments will be created instead.



33
34
35
# File 'lib/launchdarkly_api/models/project_post.rb', line 33

def environments
  @environments
end

#include_in_snippet_by_defaultObject

Whether or not flags created in this project are made available to the client-side JavaScript SDK by default.



25
26
27
# File 'lib/launchdarkly_api/models/project_post.rb', line 25

def include_in_snippet_by_default
  @include_in_snippet_by_default
end

#keyObject

A unique key used to reference the project in your code.



22
23
24
# File 'lib/launchdarkly_api/models/project_post.rb', line 22

def key
  @key
end

#nameObject

A human-friendly name for the project.



19
20
21
# File 'lib/launchdarkly_api/models/project_post.rb', line 19

def name
  @name
end

#naming_conventionObject

Returns the value of attribute naming_convention.



35
36
37
# File 'lib/launchdarkly_api/models/project_post.rb', line 35

def naming_convention
  @naming_convention
end

#tagsObject

Tags for the project



30
31
32
# File 'lib/launchdarkly_api/models/project_post.rb', line 30

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



51
52
53
# File 'lib/launchdarkly_api/models/project_post.rb', line 51

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



56
57
58
# File 'lib/launchdarkly_api/models/project_post.rb', line 56

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



38
39
40
41
42
43
44
45
46
47
48
# File 'lib/launchdarkly_api/models/project_post.rb', line 38

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'include_in_snippet_by_default' => :'includeInSnippetByDefault',
    :'default_client_side_availability' => :'defaultClientSideAvailability',
    :'tags' => :'tags',
    :'environments' => :'environments',
    :'naming_convention' => :'namingConvention'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
# File 'lib/launchdarkly_api/models/project_post.rb', line 206

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



74
75
76
77
# File 'lib/launchdarkly_api/models/project_post.rb', line 74

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



61
62
63
64
65
66
67
68
69
70
71
# File 'lib/launchdarkly_api/models/project_post.rb', line 61

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'include_in_snippet_by_default' => :'Boolean',
    :'default_client_side_availability' => :'DefaultClientSideAvailabilityPost',
    :'tags' => :'Array<String>',
    :'environments' => :'Array<EnvironmentPost>',
    :'naming_convention' => :'NamingConvention'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



179
180
181
182
183
184
185
186
187
188
189
# File 'lib/launchdarkly_api/models/project_post.rb', line 179

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      include_in_snippet_by_default == o.include_in_snippet_by_default &&
      default_client_side_availability == o.default_client_side_availability &&
      tags == o.tags &&
      environments == o.environments &&
      naming_convention == o.naming_convention
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


193
194
195
# File 'lib/launchdarkly_api/models/project_post.rb', line 193

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



199
200
201
# File 'lib/launchdarkly_api/models/project_post.rb', line 199

def hash
  [name, key, include_in_snippet_by_default, default_client_side_availability, tags, environments, naming_convention].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/project_post.rb', line 134

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



228
229
230
231
232
233
234
235
236
237
238
239
240
# File 'lib/launchdarkly_api/models/project_post.rb', line 228

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
# File 'lib/launchdarkly_api/models/project_post.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @key.nil?
  true
end