Class: LaunchDarklyApi::ProjectRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/project_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/launchdarkly_api/models/project_rep.rb', line 96

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ProjectRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ProjectRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'include_in_snippet_by_default')
    self.include_in_snippet_by_default = attributes[:'include_in_snippet_by_default']
  else
    self.include_in_snippet_by_default = nil
  end

  if attributes.key?(:'default_client_side_availability')
    self.default_client_side_availability = attributes[:'default_client_side_availability']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'default_release_pipeline_key')
    self.default_release_pipeline_key = attributes[:'default_release_pipeline_key']
  end

  if attributes.key?(:'environments')
    if (value = attributes[:'environments']).is_a?(Array)
      self.environments = value
    end
  else
    self.environments = nil
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



35
36
37
# File 'lib/launchdarkly_api/models/project_rep.rb', line 35

def _access
  @_access
end

#_idObject

The ID of this project



22
23
24
# File 'lib/launchdarkly_api/models/project_rep.rb', line 22

def _id
  @_id
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/project_rep.rb', line 19

def _links
  @_links
end

#default_client_side_availabilityObject

Returns the value of attribute default_client_side_availability.



30
31
32
# File 'lib/launchdarkly_api/models/project_rep.rb', line 30

def default_client_side_availability
  @default_client_side_availability
end

#default_release_pipeline_keyObject

The key of the default release pipeline for this project



41
42
43
# File 'lib/launchdarkly_api/models/project_rep.rb', line 41

def default_release_pipeline_key
  @default_release_pipeline_key
end

#environmentsObject

A list of environments for the project



44
45
46
# File 'lib/launchdarkly_api/models/project_rep.rb', line 44

def environments
  @environments
end

#include_in_snippet_by_defaultObject

Whether or not flags created in this project are made available to the client-side JavaScript SDK by default



28
29
30
# File 'lib/launchdarkly_api/models/project_rep.rb', line 28

def include_in_snippet_by_default
  @include_in_snippet_by_default
end

#keyObject

The key of this project



25
26
27
# File 'lib/launchdarkly_api/models/project_rep.rb', line 25

def key
  @key
end

#nameObject

A human-friendly name for the project



33
34
35
# File 'lib/launchdarkly_api/models/project_rep.rb', line 33

def name
  @name
end

#tagsObject

A list of tags for the project



38
39
40
# File 'lib/launchdarkly_api/models/project_rep.rb', line 38

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



63
64
65
# File 'lib/launchdarkly_api/models/project_rep.rb', line 63

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



68
69
70
# File 'lib/launchdarkly_api/models/project_rep.rb', line 68

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



47
48
49
50
51
52
53
54
55
56
57
58
59
60
# File 'lib/launchdarkly_api/models/project_rep.rb', line 47

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'key' => :'key',
    :'include_in_snippet_by_default' => :'includeInSnippetByDefault',
    :'default_client_side_availability' => :'defaultClientSideAvailability',
    :'name' => :'name',
    :'_access' => :'_access',
    :'tags' => :'tags',
    :'default_release_pipeline_key' => :'defaultReleasePipelineKey',
    :'environments' => :'environments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/launchdarkly_api/models/project_rep.rb', line 323

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



89
90
91
92
# File 'lib/launchdarkly_api/models/project_rep.rb', line 89

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/launchdarkly_api/models/project_rep.rb', line 73

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'key' => :'String',
    :'include_in_snippet_by_default' => :'Boolean',
    :'default_client_side_availability' => :'ClientSideAvailability',
    :'name' => :'String',
    :'_access' => :'Access',
    :'tags' => :'Array<String>',
    :'default_release_pipeline_key' => :'String',
    :'environments' => :'Array<Environment>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



293
294
295
296
297
298
299
300
301
302
303
304
305
306
# File 'lib/launchdarkly_api/models/project_rep.rb', line 293

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      key == o.key &&
      include_in_snippet_by_default == o.include_in_snippet_by_default &&
      default_client_side_availability == o.default_client_side_availability &&
      name == o.name &&
      _access == o._access &&
      tags == o.tags &&
      default_release_pipeline_key == o.default_release_pipeline_key &&
      environments == o.environments
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


310
311
312
# File 'lib/launchdarkly_api/models/project_rep.rb', line 310

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



316
317
318
# File 'lib/launchdarkly_api/models/project_rep.rb', line 316

def hash
  [_links, _id, key, include_in_snippet_by_default, default_client_side_availability, name, _access, tags, default_release_pipeline_key, environments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/launchdarkly_api/models/project_rep.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @include_in_snippet_by_default.nil?
    invalid_properties.push('invalid value for "include_in_snippet_by_default", include_in_snippet_by_default cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @environments.nil?
    invalid_properties.push('invalid value for "environments", environments cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



345
346
347
348
349
350
351
352
353
354
355
356
357
# File 'lib/launchdarkly_api/models/project_rep.rb', line 345

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
217
218
219
# File 'lib/launchdarkly_api/models/project_rep.rb', line 209

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @key.nil?
  return false if @include_in_snippet_by_default.nil?
  return false if @name.nil?
  return false if @tags.nil?
  return false if @environments.nil?
  true
end