Class: LaunchDarklyApi::ProjectSummaryCollection

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/project_summary_collection.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ProjectSummaryCollection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 60

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ProjectSummaryCollection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ProjectSummaryCollection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'total_count')
    self.total_count = attributes[:'total_count']
  else
    self.total_count = nil
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end
end

Instance Attribute Details

Returns the value of attribute _links.



22
23
24
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 22

def _links
  @_links
end

#itemsObject

Returns the value of attribute items.



20
21
22
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 20

def items
  @items
end

#total_countObject

Returns the value of attribute total_count.



18
19
20
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 18

def total_count
  @total_count
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



34
35
36
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 34

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



39
40
41
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 39

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



25
26
27
28
29
30
31
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 25

def self.attribute_map
  {
    :'total_count' => :'totalCount',
    :'items' => :'items',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 165

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



53
54
55
56
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 53

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



44
45
46
47
48
49
50
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 44

def self.openapi_types
  {
    :'total_count' => :'Integer',
    :'items' => :'Array<ProjectSummary>',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      total_count == o.total_count &&
      items == o.items &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


152
153
154
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 152

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



158
159
160
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 158

def hash
  [total_count, items, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



97
98
99
100
101
102
103
104
105
106
107
108
109
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 97

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @total_count.nil?
    invalid_properties.push('invalid value for "total_count", total_count cannot be nil.')
  end

  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



187
188
189
190
191
192
193
194
195
196
197
198
199
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 187

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



113
114
115
116
117
118
# File 'lib/launchdarkly_api/models/project_summary_collection.rb', line 113

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @total_count.nil?
  return false if @items.nil?
  true
end