Class: LaunchDarklyApi::PromptSnippet

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/prompt_snippet.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PromptSnippet

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 89

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PromptSnippet` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PromptSnippet`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  end

  if attributes.key?(:'_maintainer')
    self._maintainer = attributes[:'_maintainer']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



20
21
22
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 20

def _access
  @_access
end

Returns the value of attribute _links.



22
23
24
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 22

def _links
  @_links
end

#_maintainerObject

Returns the value of attribute _maintainer.



24
25
26
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 24

def _maintainer
  @_maintainer
end

#created_atObject

Returns the value of attribute created_at.



37
38
39
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 37

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



28
29
30
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 28

def description
  @description
end

#keyObject

Returns the value of attribute key.



18
19
20
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 18

def key
  @key
end

#nameObject

Returns the value of attribute name.



26
27
28
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 26

def name
  @name
end

#tagsObject

Returns the value of attribute tags.



33
34
35
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 33

def tags
  @tags
end

#textObject

The text content of the prompt snippet



31
32
33
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 31

def text
  @text
end

#versionObject

Returns the value of attribute version.



35
36
37
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 35

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 40

def self.attribute_map
  {
    :'key' => :'key',
    :'_access' => :'_access',
    :'_links' => :'_links',
    :'_maintainer' => :'_maintainer',
    :'name' => :'name',
    :'description' => :'description',
    :'text' => :'text',
    :'tags' => :'tags',
    :'version' => :'version',
    :'created_at' => :'createdAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 295

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



82
83
84
85
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 82

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 66

def self.openapi_types
  {
    :'key' => :'String',
    :'_access' => :'AiConfigsAccess',
    :'_links' => :'ParentAndSelfLinks',
    :'_maintainer' => :'AIConfigMaintainer',
    :'name' => :'String',
    :'description' => :'String',
    :'text' => :'String',
    :'tags' => :'Array<String>',
    :'version' => :'Integer',
    :'created_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 265

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      _access == o._access &&
      _links == o._links &&
      _maintainer == o._maintainer &&
      name == o.name &&
      description == o.description &&
      text == o.text &&
      tags == o.tags &&
      version == o.version &&
      created_at == o.created_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


282
283
284
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 282

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



288
289
290
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 288

def hash
  [key, _access, _links, _maintainer, name, description, text, tags, version, created_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 160

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



317
318
319
320
321
322
323
324
325
326
327
328
329
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 317

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
200
201
# File 'lib/launchdarkly_api/models/prompt_snippet.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @text.nil?
  return false if @tags.nil?
  return false if @version.nil?
  return false if @created_at.nil?
  true
end