Class: LaunchDarklyApi::PromptSnippetPatch

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/prompt_snippet_patch.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PromptSnippetPatch

Initializes the object



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PromptSnippetPatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PromptSnippetPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end
end

Instance Attribute Details

#description ⇒ Object

Returns the value of attribute description.



20
21
22
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 20

def description
  @description
end

#maintainer_id ⇒ Object

Returns the value of attribute maintainer_id.



25
26
27
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 25

def maintainer_id
  @maintainer_id
end

#maintainer_team_key ⇒ Object

Returns the value of attribute maintainer_team_key.



27
28
29
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 27

def maintainer_team_key
  @maintainer_team_key
end

#name ⇒ Object

Returns the value of attribute name.



18
19
20
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 18

def name
  @name
end

#tags ⇒ Object

Returns the value of attribute tags.



29
30
31
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 29

def tags
  @tags
end

#text ⇒ Object

The text content of the prompt snippet



23
24
25
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 23

def text
  @text
end

Class Method Details

.acceptable_attribute_map ⇒ Object

Returns attribute mapping this model knows about



44
45
46
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 44

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributes ⇒ Object

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 49

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_map ⇒ Object

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
41
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 32

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'text' => :'text',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey',
    :'tags' => :'tags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 157

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullable ⇒ Object

List of attributes with nullable: true



66
67
68
69
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_types ⇒ Object

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 54

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'text' => :'String',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String',
    :'tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.



131
132
133
134
135
136
137
138
139
140
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 131

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      text == o.text &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key &&
      tags == o.tags
end

#eql?(o) ⇒ Boolean

See Also:

  • `==` method


144
145
146
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 144

def eql?(o)
  self == o
end

#hash ⇒ Integer

Calculates hash code according to all attributes.



150
151
152
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 150

def hash
  [name, description, text, maintainer_id, maintainer_team_key, tags].hash
end

#list_invalid_properties ⇒ Object

Show invalid properties with the reasons. Usually used together with valid?



116
117
118
119
120
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 116

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hash ⇒ Hash

Returns the object in the form of hash



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 179

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid? ⇒ Boolean

Check to see if the all the properties in the model are valid



124
125
126
127
# File 'lib/launchdarkly_api/models/prompt_snippet_patch.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end