Class: LaunchDarklyApi::PromptSnippetPost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/prompt_snippet_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PromptSnippetPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 77

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PromptSnippetPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PromptSnippetPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'text')
    self.text = attributes[:'text']
  else
    self.text = nil
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end
end

Instance Attribute Details

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 22

def description
  @description
end

#keyObject

Returns the value of attribute key.



18
19
20
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 18

def key
  @key
end

#maintainer_idObject

Returns the value of attribute maintainer_id.



27
28
29
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 27

def maintainer_id
  @maintainer_id
end

#maintainer_team_keyObject

Returns the value of attribute maintainer_team_key.



29
30
31
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 29

def maintainer_team_key
  @maintainer_team_key
end

#nameObject

Returns the value of attribute name.



20
21
22
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 20

def name
  @name
end

#tagsObject

Returns the value of attribute tags.



31
32
33
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 31

def tags
  @tags
end

#textObject

The text content of the prompt snippet



25
26
27
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 25

def text
  @text
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



47
48
49
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 47

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



52
53
54
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 52

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
43
44
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 34

def self.attribute_map
  {
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'text' => :'text',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey',
    :'tags' => :'tags'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



70
71
72
73
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 70

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



57
58
59
60
61
62
63
64
65
66
67
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 57

def self.openapi_types
  {
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'text' => :'String',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String',
    :'tags' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



190
191
192
193
194
195
196
197
198
199
200
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 190

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      text == o.text &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key &&
      tags == o.tags
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 210

def hash
  [key, name, description, text, maintainer_id, maintainer_team_key, tags].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @text.nil?
    invalid_properties.push('invalid value for "text", text cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



150
151
152
153
154
155
156
# File 'lib/launchdarkly_api/models/prompt_snippet_post.rb', line 150

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @text.nil?
  true
end