Class: LaunchDarklyApi::PullRequestLeadTimeRep

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/pull_request_lead_time_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ PullRequestLeadTimeRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 88

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PullRequestLeadTimeRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PullRequestLeadTimeRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'coding_duration_ms')
    self.coding_duration_ms = attributes[:'coding_duration_ms']
  else
    self.coding_duration_ms = nil
  end

  if attributes.key?(:'review_duration_ms')
    self.review_duration_ms = attributes[:'review_duration_ms']
  end

  if attributes.key?(:'max_wait_duration_ms')
    self.max_wait_duration_ms = attributes[:'max_wait_duration_ms']
  end

  if attributes.key?(:'avg_wait_duration_ms')
    self.avg_wait_duration_ms = attributes[:'avg_wait_duration_ms']
  end

  if attributes.key?(:'max_deploy_duration_ms')
    self.max_deploy_duration_ms = attributes[:'max_deploy_duration_ms']
  end

  if attributes.key?(:'avg_deploy_duration_ms')
    self.avg_deploy_duration_ms = attributes[:'avg_deploy_duration_ms']
  end

  if attributes.key?(:'max_total_lead_time_ms')
    self.max_total_lead_time_ms = attributes[:'max_total_lead_time_ms']
  end

  if attributes.key?(:'avg_total_lead_time_ms')
    self.avg_total_lead_time_ms = attributes[:'avg_total_lead_time_ms']
  end
end

Instance Attribute Details

#avg_deploy_duration_msObject

The average deploy duration in milliseconds



34
35
36
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 34

def avg_deploy_duration_ms
  @avg_deploy_duration_ms
end

#avg_total_lead_time_msObject

The average total lead time in milliseconds



40
41
42
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 40

def avg_total_lead_time_ms
  @avg_total_lead_time_ms
end

#avg_wait_duration_msObject

The average wait duration between merge time and deploy start time in milliseconds



28
29
30
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 28

def avg_wait_duration_ms
  @avg_wait_duration_ms
end

#coding_duration_msObject

The coding duration in milliseconds



19
20
21
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 19

def coding_duration_ms
  @coding_duration_ms
end

#max_deploy_duration_msObject

The max deploy duration in milliseconds



31
32
33
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 31

def max_deploy_duration_ms
  @max_deploy_duration_ms
end

#max_total_lead_time_msObject

The max total lead time in milliseconds



37
38
39
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 37

def max_total_lead_time_ms
  @max_total_lead_time_ms
end

#max_wait_duration_msObject

The max wait duration between merge time and deploy start time in milliseconds



25
26
27
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 25

def max_wait_duration_ms
  @max_wait_duration_ms
end

#review_duration_msObject

The review duration in milliseconds



22
23
24
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 22

def review_duration_ms
  @review_duration_ms
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



57
58
59
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 57

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



62
63
64
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 62

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



43
44
45
46
47
48
49
50
51
52
53
54
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 43

def self.attribute_map
  {
    :'coding_duration_ms' => :'codingDurationMs',
    :'review_duration_ms' => :'reviewDurationMs',
    :'max_wait_duration_ms' => :'maxWaitDurationMs',
    :'avg_wait_duration_ms' => :'avgWaitDurationMs',
    :'max_deploy_duration_ms' => :'maxDeployDurationMs',
    :'avg_deploy_duration_ms' => :'avgDeployDurationMs',
    :'max_total_lead_time_ms' => :'maxTotalLeadTimeMs',
    :'avg_total_lead_time_ms' => :'avgTotalLeadTimeMs'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 197

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



81
82
83
84
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 81

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



67
68
69
70
71
72
73
74
75
76
77
78
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 67

def self.openapi_types
  {
    :'coding_duration_ms' => :'Integer',
    :'review_duration_ms' => :'Integer',
    :'max_wait_duration_ms' => :'Integer',
    :'avg_wait_duration_ms' => :'Integer',
    :'max_deploy_duration_ms' => :'Integer',
    :'avg_deploy_duration_ms' => :'Integer',
    :'max_total_lead_time_ms' => :'Integer',
    :'avg_total_lead_time_ms' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



169
170
171
172
173
174
175
176
177
178
179
180
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 169

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      coding_duration_ms == o.coding_duration_ms &&
      review_duration_ms == o.review_duration_ms &&
      max_wait_duration_ms == o.max_wait_duration_ms &&
      avg_wait_duration_ms == o.avg_wait_duration_ms &&
      max_deploy_duration_ms == o.max_deploy_duration_ms &&
      avg_deploy_duration_ms == o.avg_deploy_duration_ms &&
      max_total_lead_time_ms == o.max_total_lead_time_ms &&
      avg_total_lead_time_ms == o.avg_total_lead_time_ms
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


184
185
186
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 184

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



190
191
192
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 190

def hash
  [coding_duration_ms, review_duration_ms, max_wait_duration_ms, avg_wait_duration_ms, max_deploy_duration_ms, avg_deploy_duration_ms, max_total_lead_time_ms, avg_total_lead_time_ms].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



139
140
141
142
143
144
145
146
147
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 139

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @coding_duration_ms.nil?
    invalid_properties.push('invalid value for "coding_duration_ms", coding_duration_ms cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 219

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



151
152
153
154
155
# File 'lib/launchdarkly_api/models/pull_request_lead_time_rep.rb', line 151

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @coding_duration_ms.nil?
  true
end