Class: LaunchDarklyApi::PutBranch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::PutBranch
- Defined in:
- lib/launchdarkly_api/models/put_branch.rb
Instance Attribute Summary collapse
-
#commit_time ⇒ Object
Returns the value of attribute commit_time.
-
#head ⇒ Object
An ID representing the branch HEAD.
-
#name ⇒ Object
The branch name.
-
#references ⇒ Object
An array of flag references found on the branch.
-
#sync_time ⇒ Object
Returns the value of attribute sync_time.
-
#update_sequence_id ⇒ Object
An optional ID used to prevent older data from overwriting newer data.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PutBranch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PutBranch
Initializes the object
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 76 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PutBranch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PutBranch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'head') self.head = attributes[:'head'] else self.head = nil end if attributes.key?(:'update_sequence_id') self.update_sequence_id = attributes[:'update_sequence_id'] end if attributes.key?(:'sync_time') self.sync_time = attributes[:'sync_time'] else self.sync_time = nil end if attributes.key?(:'references') if (value = attributes[:'references']).is_a?(Array) self.references = value end end if attributes.key?(:'commit_time') self.commit_time = attributes[:'commit_time'] end end |
Instance Attribute Details
#commit_time ⇒ Object
Returns the value of attribute commit_time.
32 33 34 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 32 def commit_time @commit_time end |
#head ⇒ Object
An ID representing the branch HEAD. For example, a commit SHA.
22 23 24 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 22 def head @head end |
#name ⇒ Object
The branch name
19 20 21 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 19 def name @name end |
#references ⇒ Object
An array of flag references found on the branch
30 31 32 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 30 def references @references end |
#sync_time ⇒ Object
Returns the value of attribute sync_time.
27 28 29 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 27 def sync_time @sync_time end |
#update_sequence_id ⇒ Object
An optional ID used to prevent older data from overwriting newer data. If no sequence ID is included, the newly submitted data will always be saved.
25 26 27 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 25 def update_sequence_id @update_sequence_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
47 48 49 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 47 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
52 53 54 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 52 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
35 36 37 38 39 40 41 42 43 44 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 35 def self.attribute_map { :'name' => :'name', :'head' => :'head', :'update_sequence_id' => :'updateSequenceId', :'sync_time' => :'syncTime', :'references' => :'references', :'commit_time' => :'commitTime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
69 70 71 72 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 69 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
57 58 59 60 61 62 63 64 65 66 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 57 def self.openapi_types { :'name' => :'String', :'head' => :'String', :'update_sequence_id' => :'Integer', :'sync_time' => :'Integer', :'references' => :'Array<ReferenceRep>', :'commit_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 185 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && head == o.head && update_sequence_id == o.update_sequence_id && sync_time == o.sync_time && references == o.references && commit_time == o.commit_time end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 204 def hash [name, head, update_sequence_id, sync_time, references, commit_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 125 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @head.nil? invalid_properties.push('invalid value for "head", head cannot be nil.') end if @sync_time.nil? invalid_properties.push('invalid value for "sync_time", sync_time cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
145 146 147 148 149 150 151 |
# File 'lib/launchdarkly_api/models/put_branch.rb', line 145 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @head.nil? return false if @sync_time.nil? true end |