Class: LaunchDarklyApi::PutReleasePolicyRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::PutReleasePolicyRequest
- Defined in:
- lib/launchdarkly_api/models/put_release_policy_request.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#guarded_release_config ⇒ Object
Returns the value of attribute guarded_release_config.
-
#name ⇒ Object
The name of the release policy.
-
#progressive_release_config ⇒ Object
Returns the value of attribute progressive_release_config.
-
#release_method ⇒ Object
Returns the value of attribute release_method.
-
#scope ⇒ Object
Returns the value of attribute scope.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PutReleasePolicyRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PutReleasePolicyRequest
Initializes the object
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 91 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PutReleasePolicyRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PutReleasePolicyRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'scope') self.scope = attributes[:'scope'] end if attributes.key?(:'release_method') self.release_method = attributes[:'release_method'] else self.release_method = nil end if attributes.key?(:'guarded_release_config') self.guarded_release_config = attributes[:'guarded_release_config'] end if attributes.key?(:'progressive_release_config') self.progressive_release_config = attributes[:'progressive_release_config'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end end |
Instance Attribute Details
#guarded_release_config ⇒ Object
Returns the value of attribute guarded_release_config.
22 23 24 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 22 def guarded_release_config @guarded_release_config end |
#name ⇒ Object
The name of the release policy
27 28 29 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 27 def name @name end |
#progressive_release_config ⇒ Object
Returns the value of attribute progressive_release_config.
24 25 26 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 24 def progressive_release_config @progressive_release_config end |
#release_method ⇒ Object
Returns the value of attribute release_method.
20 21 22 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 20 def release_method @release_method end |
#scope ⇒ Object
Returns the value of attribute scope.
18 19 20 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 18 def scope @scope end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 52 def self.attribute_map { :'scope' => :'scope', :'release_method' => :'releaseMethod', :'guarded_release_config' => :'guardedReleaseConfig', :'progressive_release_config' => :'progressiveReleaseConfig', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
84 85 86 87 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 84 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 73 def self.openapi_types { :'scope' => :'ReleasePolicyScope', :'release_method' => :'ReleaseMethod', :'guarded_release_config' => :'GuardedReleaseConfig', :'progressive_release_config' => :'ProgressiveReleaseConfig', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && scope == o.scope && release_method == o.release_method && guarded_release_config == o.guarded_release_config && progressive_release_config == o.progressive_release_config && name == o.name end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 204 def hash [scope, release_method, guarded_release_config, progressive_release_config, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 132 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @release_method.nil? invalid_properties.push('invalid value for "release_method", release_method cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 256 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
152 153 154 155 156 157 158 |
# File 'lib/launchdarkly_api/models/put_release_policy_request.rb', line 152 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @release_method.nil? return false if @name.nil? return false if @name.to_s.length > 256 true end |