Class: LaunchDarklyApi::RandomizationSettingsRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::RandomizationSettingsRep
- Defined in:
- lib/launchdarkly_api/models/randomization_settings_rep.rb
Instance Attribute Summary collapse
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_project_id ⇒ Object
The project ID.
-
#_project_key ⇒ Object
The project key.
-
#randomization_units ⇒ Object
An array of the randomization units in this project.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RandomizationSettingsRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RandomizationSettingsRep
Initializes the object
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 72 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::RandomizationSettingsRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::RandomizationSettingsRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_project_id') self._project_id = attributes[:'_project_id'] end if attributes.key?(:'_project_key') self._project_key = attributes[:'_project_key'] end if attributes.key?(:'randomization_units') if (value = attributes[:'randomization_units']).is_a?(Array) self.randomization_units = value end end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end end |
Instance Attribute Details
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
27 28 29 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 27 def _creation_date @_creation_date end |
#_links ⇒ Object
The location and content type of related resources
30 31 32 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 30 def _links @_links end |
#_project_id ⇒ Object
The project ID
19 20 21 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 19 def _project_id @_project_id end |
#_project_key ⇒ Object
The project key
22 23 24 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 22 def _project_key @_project_key end |
#randomization_units ⇒ Object
An array of the randomization units in this project
25 26 27 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 25 def randomization_units @randomization_units end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
44 45 46 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 44 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
49 50 51 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 49 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
33 34 35 36 37 38 39 40 41 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 33 def self.attribute_map { :'_project_id' => :'_projectId', :'_project_key' => :'_projectKey', :'randomization_units' => :'randomizationUnits', :'_creation_date' => :'_creationDate', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 153 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
65 66 67 68 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 65 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
54 55 56 57 58 59 60 61 62 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 54 def self.openapi_types { :'_project_id' => :'String', :'_project_key' => :'String', :'randomization_units' => :'Array<RandomizationUnitRep>', :'_creation_date' => :'Integer', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
128 129 130 131 132 133 134 135 136 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 128 def ==(o) return true if self.equal?(o) self.class == o.class && _project_id == o._project_id && _project_key == o._project_key && randomization_units == o.randomization_units && _creation_date == o._creation_date && _links == o._links end |
#eql?(o) ⇒ Boolean
140 141 142 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 140 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
146 147 148 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 146 def hash [_project_id, _project_key, randomization_units, _creation_date, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
113 114 115 116 117 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 113 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 175 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
121 122 123 124 |
# File 'lib/launchdarkly_api/models/randomization_settings_rep.rb', line 121 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |