Class: LaunchDarklyApi::RecentTriggerBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::RecentTriggerBody
- Defined in:
- lib/launchdarkly_api/models/recent_trigger_body.rb
Instance Attribute Summary collapse
-
#json_body ⇒ Object
The marshalled JSON request body for the incoming trigger webhook.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RecentTriggerBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RecentTriggerBody
Initializes the object
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 57 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::RecentTriggerBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::RecentTriggerBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'json_body') if (value = attributes[:'json_body']).is_a?(Hash) self.json_body = value end end end |
Instance Attribute Details
#json_body ⇒ Object
The marshalled JSON request body for the incoming trigger webhook. If this is empty or contains invalid JSON, the timestamp is recorded but this field will be empty.
21 22 23 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 21 def json_body @json_body end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
18 19 20 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 18 def @timestamp end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
32 33 34 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 32 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
37 38 39 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 37 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
24 25 26 27 28 29 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 24 def self.attribute_map { :'timestamp' => :'timestamp', :'json_body' => :'jsonBody' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 121 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
50 51 52 53 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 50 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
42 43 44 45 46 47 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 42 def self.openapi_types { :'timestamp' => :'Integer', :'json_body' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
99 100 101 102 103 104 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 99 def ==(o) return true if self.equal?(o) self.class == o.class && == o. && json_body == o.json_body end |
#eql?(o) ⇒ Boolean
108 109 110 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 108 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
114 115 116 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 114 def hash [, json_body].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
84 85 86 87 88 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 84 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 143 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
92 93 94 95 |
# File 'lib/launchdarkly_api/models/recent_trigger_body.rb', line 92 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |