Class: LaunchDarklyApi::Release

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/release.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Release

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/release.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Release` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Release`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'release_pipeline_key')
    self.release_pipeline_key = attributes[:'release_pipeline_key']
  else
    self.release_pipeline_key = nil
  end

  if attributes.key?(:'release_pipeline_description')
    self.release_pipeline_description = attributes[:'release_pipeline_description']
  else
    self.release_pipeline_description = nil
  end

  if attributes.key?(:'phases')
    if (value = attributes[:'phases']).is_a?(Array)
      self.phases = value
    end
  else
    self.phases = nil
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  else
    self._version = nil
  end

  if attributes.key?(:'_release_variation_id')
    self._release_variation_id = attributes[:'_release_variation_id']
  end

  if attributes.key?(:'_canceled_at')
    self._canceled_at = attributes[:'_canceled_at']
  end
end

Instance Attribute Details

#_canceled_atObject

Returns the value of attribute _canceled_at.



39
40
41
# File 'lib/launchdarkly_api/models/release.rb', line 39

def _canceled_at
  @_canceled_at
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/release.rb', line 19

def _links
  @_links
end

#_release_variation_idObject

The chosen release variation ID to use across all phases of a release



37
38
39
# File 'lib/launchdarkly_api/models/release.rb', line 37

def _release_variation_id
  @_release_variation_id
end

#_versionObject

The release version



34
35
36
# File 'lib/launchdarkly_api/models/release.rb', line 34

def _version
  @_version
end

#nameObject

The release pipeline name



22
23
24
# File 'lib/launchdarkly_api/models/release.rb', line 22

def name
  @name
end

#phasesObject

An ordered list of the release pipeline phases



31
32
33
# File 'lib/launchdarkly_api/models/release.rb', line 31

def phases
  @phases
end

#release_pipeline_descriptionObject

The release pipeline description



28
29
30
# File 'lib/launchdarkly_api/models/release.rb', line 28

def release_pipeline_description
  @release_pipeline_description
end

#release_pipeline_keyObject

The release pipeline key



25
26
27
# File 'lib/launchdarkly_api/models/release.rb', line 25

def release_pipeline_key
  @release_pipeline_key
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/launchdarkly_api/models/release.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/launchdarkly_api/models/release.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/launchdarkly_api/models/release.rb', line 42

def self.attribute_map
  {
    :'_links' => :'_links',
    :'name' => :'name',
    :'release_pipeline_key' => :'releasePipelineKey',
    :'release_pipeline_description' => :'releasePipelineDescription',
    :'phases' => :'phases',
    :'_version' => :'_version',
    :'_release_variation_id' => :'_releaseVariationId',
    :'_canceled_at' => :'_canceledAt'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/launchdarkly_api/models/release.rb', line 268

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/launchdarkly_api/models/release.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/launchdarkly_api/models/release.rb', line 66

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'name' => :'String',
    :'release_pipeline_key' => :'String',
    :'release_pipeline_description' => :'String',
    :'phases' => :'Array<ReleasePhase>',
    :'_version' => :'Integer',
    :'_release_variation_id' => :'String',
    :'_canceled_at' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/launchdarkly_api/models/release.rb', line 240

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      name == o.name &&
      release_pipeline_key == o.release_pipeline_key &&
      release_pipeline_description == o.release_pipeline_description &&
      phases == o.phases &&
      _version == o._version &&
      _release_variation_id == o._release_variation_id &&
      _canceled_at == o._canceled_at
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


255
256
257
# File 'lib/launchdarkly_api/models/release.rb', line 255

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



261
262
263
# File 'lib/launchdarkly_api/models/release.rb', line 261

def hash
  [_links, name, release_pipeline_key, release_pipeline_description, phases, _version, _release_variation_id, _canceled_at].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
# File 'lib/launchdarkly_api/models/release.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @release_pipeline_key.nil?
    invalid_properties.push('invalid value for "release_pipeline_key", release_pipeline_key cannot be nil.')
  end

  if @release_pipeline_description.nil?
    invalid_properties.push('invalid value for "release_pipeline_description", release_pipeline_description cannot be nil.')
  end

  if @phases.nil?
    invalid_properties.push('invalid value for "phases", phases cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/launchdarkly_api/models/release.rb', line 290

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



178
179
180
181
182
183
184
185
186
# File 'lib/launchdarkly_api/models/release.rb', line 178

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @release_pipeline_key.nil?
  return false if @release_pipeline_description.nil?
  return false if @phases.nil?
  return false if @_version.nil?
  true
end