Class: LaunchDarklyApi::ReleaseAudience

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/release_audience.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReleaseAudience

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/launchdarkly_api/models/release_audience.rb', line 85

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleaseAudience` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleaseAudience`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'environment')
    self.environment = attributes[:'environment']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'configuration')
    self.configuration = attributes[:'configuration']
  end

  if attributes.key?(:'segment_keys')
    if (value = attributes[:'segment_keys']).is_a?(Array)
      self.segment_keys = value
    end
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  end

  if attributes.key?(:'_rule_ids')
    if (value = attributes[:'_rule_ids']).is_a?(Array)
      self._rule_ids = value
    end
  end
end

Instance Attribute Details

#_idObject

The audience ID



19
20
21
# File 'lib/launchdarkly_api/models/release_audience.rb', line 19

def _id
  @_id
end

The location and content type of related resources



22
23
24
# File 'lib/launchdarkly_api/models/release_audience.rb', line 22

def _links
  @_links
end

#_rule_idsObject

The rules IDs added or updated by this audience



37
38
39
# File 'lib/launchdarkly_api/models/release_audience.rb', line 37

def _rule_ids
  @_rule_ids
end

#configurationObject

Returns the value of attribute configuration.



29
30
31
# File 'lib/launchdarkly_api/models/release_audience.rb', line 29

def configuration
  @configuration
end

#environmentObject

Returns the value of attribute environment.



24
25
26
# File 'lib/launchdarkly_api/models/release_audience.rb', line 24

def environment
  @environment
end

#nameObject

The release phase name



27
28
29
# File 'lib/launchdarkly_api/models/release_audience.rb', line 27

def name
  @name
end

#segment_keysObject

A list of segment keys



32
33
34
# File 'lib/launchdarkly_api/models/release_audience.rb', line 32

def segment_keys
  @segment_keys
end

#statusObject

Returns the value of attribute status.



34
35
36
# File 'lib/launchdarkly_api/models/release_audience.rb', line 34

def status
  @status
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/release_audience.rb', line 54

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/launchdarkly_api/models/release_audience.rb', line 59

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
51
# File 'lib/launchdarkly_api/models/release_audience.rb', line 40

def self.attribute_map
  {
    :'_id' => :'_id',
    :'_links' => :'_links',
    :'environment' => :'environment',
    :'name' => :'name',
    :'configuration' => :'configuration',
    :'segment_keys' => :'segmentKeys',
    :'status' => :'status',
    :'_rule_ids' => :'_ruleIds'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/launchdarkly_api/models/release_audience.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



78
79
80
81
# File 'lib/launchdarkly_api/models/release_audience.rb', line 78

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
# File 'lib/launchdarkly_api/models/release_audience.rb', line 64

def self.openapi_types
  {
    :'_id' => :'String',
    :'_links' => :'Hash<String, Link>',
    :'environment' => :'EnvironmentSummary',
    :'name' => :'String',
    :'configuration' => :'AudienceConfiguration',
    :'segment_keys' => :'Array<String>',
    :'status' => :'String',
    :'_rule_ids' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



189
190
191
192
193
194
195
196
197
198
199
200
# File 'lib/launchdarkly_api/models/release_audience.rb', line 189

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      _links == o._links &&
      environment == o.environment &&
      name == o.name &&
      configuration == o.configuration &&
      segment_keys == o.segment_keys &&
      status == o.status &&
      _rule_ids == o._rule_ids
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/launchdarkly_api/models/release_audience.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/launchdarkly_api/models/release_audience.rb', line 210

def hash
  [_id, _links, environment, name, configuration, segment_keys, status, _rule_ids].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/launchdarkly_api/models/release_audience.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/launchdarkly_api/models/release_audience.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
# File 'lib/launchdarkly_api/models/release_audience.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @name.nil?
  true
end