Class: LaunchDarklyApi::ReleasePhase
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ReleasePhase
- Defined in:
- lib/launchdarkly_api/models/release_phase.rb
Instance Attribute Summary collapse
-
#_audiences ⇒ Object
A logical grouping of one or more environments that share attributes for rolling out changes.
-
#_completed_by ⇒ Object
Returns the value of attribute _completed_by.
-
#_completion_date ⇒ Object
Returns the value of attribute _completion_date.
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_id ⇒ Object
The phase ID.
-
#_name ⇒ Object
The release phase name.
-
#_started_date ⇒ Object
Returns the value of attribute _started_date.
-
#complete ⇒ Object
Whether this phase is complete.
-
#configuration ⇒ Object
Returns the value of attribute configuration.
-
#started ⇒ Object
Whether or not this phase has started.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReleasePhase
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReleasePhase
Initializes the object
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 97 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleasePhase` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleasePhase`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_name') self._name = attributes[:'_name'] else self._name = nil end if attributes.key?(:'complete') self.complete = attributes[:'complete'] else self.complete = nil end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] else self._creation_date = nil end if attributes.key?(:'_completion_date') self._completion_date = attributes[:'_completion_date'] end if attributes.key?(:'_completed_by') self._completed_by = attributes[:'_completed_by'] end if attributes.key?(:'_audiences') if (value = attributes[:'_audiences']).is_a?(Array) self._audiences = value end else self._audiences = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'started') self.started = attributes[:'started'] end if attributes.key?(:'_started_date') self._started_date = attributes[:'_started_date'] end if attributes.key?(:'configuration') self.configuration = attributes[:'configuration'] end end |
Instance Attribute Details
#_audiences ⇒ Object
A logical grouping of one or more environments that share attributes for rolling out changes
34 35 36 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 34 def _audiences @_audiences end |
#_completed_by ⇒ Object
Returns the value of attribute _completed_by.
31 32 33 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 31 def _completed_by @_completed_by end |
#_completion_date ⇒ Object
Returns the value of attribute _completion_date.
29 30 31 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 29 def _completion_date @_completion_date end |
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
27 28 29 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 27 def _creation_date @_creation_date end |
#_id ⇒ Object
The phase ID
19 20 21 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 19 def _id @_id end |
#_name ⇒ Object
The release phase name
22 23 24 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 22 def _name @_name end |
#_started_date ⇒ Object
Returns the value of attribute _started_date.
41 42 43 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 41 def _started_date @_started_date end |
#complete ⇒ Object
Whether this phase is complete
25 26 27 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 25 def complete @complete end |
#configuration ⇒ Object
Returns the value of attribute configuration.
43 44 45 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 43 def configuration @configuration end |
#started ⇒ Object
Whether or not this phase has started
39 40 41 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 39 def started @started end |
#status ⇒ Object
Returns the value of attribute status.
36 37 38 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 36 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
63 64 65 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 63 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
68 69 70 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 68 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 46 def self.attribute_map { :'_id' => :'_id', :'_name' => :'_name', :'complete' => :'complete', :'_creation_date' => :'_creationDate', :'_completion_date' => :'_completionDate', :'_completed_by' => :'_completedBy', :'_audiences' => :'_audiences', :'status' => :'status', :'started' => :'started', :'_started_date' => :'_startedDate', :'configuration' => :'configuration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 291 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
90 91 92 93 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 90 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 73 def self.openapi_types { :'_id' => :'String', :'_name' => :'String', :'complete' => :'Boolean', :'_creation_date' => :'Integer', :'_completion_date' => :'Integer', :'_completed_by' => :'CompletedBy', :'_audiences' => :'Array<ReleaseAudience>', :'status' => :'String', :'started' => :'Boolean', :'_started_date' => :'Integer', :'configuration' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 260 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _name == o._name && complete == o.complete && _creation_date == o._creation_date && _completion_date == o._completion_date && _completed_by == o._completed_by && _audiences == o._audiences && status == o.status && started == o.started && _started_date == o._started_date && configuration == o.configuration end |
#eql?(o) ⇒ Boolean
278 279 280 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 278 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
284 285 286 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 284 def hash [_id, _name, complete, _creation_date, _completion_date, _completed_by, _audiences, status, started, _started_date, configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 170 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_name.nil? invalid_properties.push('invalid value for "_name", _name cannot be nil.') end if @complete.nil? invalid_properties.push('invalid value for "complete", complete cannot be nil.') end if @_creation_date.nil? invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.') end if @_audiences.nil? invalid_properties.push('invalid value for "_audiences", _audiences cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 313 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
198 199 200 201 202 203 204 205 206 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 198 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @_name.nil? return false if @complete.nil? return false if @_creation_date.nil? return false if @_audiences.nil? true end |