Class: LaunchDarklyApi::ReleasePipeline

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/release_pipeline.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReleasePipeline

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 97

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleasePipeline` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleasePipeline`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'phases')
    if (value = attributes[:'phases']).is_a?(Array)
      self.phases = value
    end
  else
    self.phases = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'is_project_default')
    self.is_project_default = attributes[:'is_project_default']
  end

  if attributes.key?(:'_is_legacy')
    self._is_legacy = attributes[:'_is_legacy']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



39
40
41
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 39

def _access
  @_access
end

#_is_legacyObject

Whether this release pipeline is a legacy pipeline



45
46
47
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 45

def _is_legacy
  @_is_legacy
end

#_versionObject

The release pipeline version



37
38
39
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 37

def _version
  @_version
end

#created_atObject

Timestamp of when the release pipeline was created



19
20
21
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 19

def created_at
  @created_at
end

#descriptionObject

The release pipeline description



22
23
24
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 22

def description
  @description
end

#is_project_defaultObject

Whether this release pipeline is the default pipeline for the project



42
43
44
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 42

def is_project_default
  @is_project_default
end

#keyObject

The release pipeline key



25
26
27
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 25

def key
  @key
end

#nameObject

The release pipeline name



28
29
30
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 28

def name
  @name
end

#phasesObject

An ordered list of the release pipeline phases. Each phase is a logical grouping of one or more environments that share attributes for rolling out changes.



31
32
33
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 31

def phases
  @phases
end

#tagsObject

A list of the release pipeline's tags



34
35
36
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 34

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



64
65
66
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 64

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



69
70
71
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 69

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 48

def self.attribute_map
  {
    :'created_at' => :'createdAt',
    :'description' => :'description',
    :'key' => :'key',
    :'name' => :'name',
    :'phases' => :'phases',
    :'tags' => :'tags',
    :'_version' => :'_version',
    :'_access' => :'_access',
    :'is_project_default' => :'isProjectDefault',
    :'_is_legacy' => :'_isLegacy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 271

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



90
91
92
93
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 90

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 74

def self.openapi_types
  {
    :'created_at' => :'Time',
    :'description' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'phases' => :'Array<Phase>',
    :'tags' => :'Array<String>',
    :'_version' => :'Integer',
    :'_access' => :'Access',
    :'is_project_default' => :'Boolean',
    :'_is_legacy' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



241
242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 241

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      created_at == o.created_at &&
      description == o.description &&
      key == o.key &&
      name == o.name &&
      phases == o.phases &&
      tags == o.tags &&
      _version == o._version &&
      _access == o._access &&
      is_project_default == o.is_project_default &&
      _is_legacy == o._is_legacy
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


258
259
260
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 258

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



264
265
266
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 264

def hash
  [created_at, description, key, name, phases, tags, _version, _access, is_project_default, _is_legacy].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 166

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @phases.nil?
    invalid_properties.push('invalid value for "phases", phases cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



293
294
295
296
297
298
299
300
301
302
303
304
305
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 293

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



190
191
192
193
194
195
196
197
# File 'lib/launchdarkly_api/models/release_pipeline.rb', line 190

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @created_at.nil?
  return false if @key.nil?
  return false if @name.nil?
  return false if @phases.nil?
  true
end