Class: LaunchDarklyApi::ReleasePipelinesBetaApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/release_pipelines_beta_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ReleasePipelinesBetaApi

Returns a new instance of ReleasePipelinesBetaApi.



19
20
21
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#delete_release_pipeline(project_key, pipeline_key, opts = {}) ⇒ nil

Delete release pipeline Delete a release pipeline

Parameters:

  • project_key (String)

    The project key

  • pipeline_key (String)

    The release pipeline key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


28
29
30
31
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 28

def delete_release_pipeline(project_key, pipeline_key, opts = {})
  delete_release_pipeline_with_http_info(project_key, pipeline_key, opts)
  nil
end

#delete_release_pipeline_with_http_info(project_key, pipeline_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Delete release pipeline Delete a release pipeline

Parameters:

  • project_key (String)

    The project key

  • pipeline_key (String)

    The release pipeline key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



39
40
41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 39

def delete_release_pipeline_with_http_info(project_key, pipeline_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ReleasePipelinesBetaApi.delete_release_pipeline ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ReleasePipelinesBetaApi.delete_release_pipeline"
  end
  # verify the required parameter 'pipeline_key' is set
  if @api_client.config.client_side_validation && pipeline_key.nil?
    fail ArgumentError, "Missing the required parameter 'pipeline_key' when calling ReleasePipelinesBetaApi.delete_release_pipeline"
  end
  # resource path
  local_var_path = '/api/v2/projects/{projectKey}/release-pipelines/{pipelineKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'pipelineKey' + '}', CGI.escape(pipeline_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ReleasePipelinesBetaApi.delete_release_pipeline",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ReleasePipelinesBetaApi#delete_release_pipeline\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_all_release_pipelines(project_key, opts = {}) ⇒ ReleasePipelineCollection

Get all release pipelines Get all release pipelines for a project

Parameters:

  • project_key (String)

    The project key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



96
97
98
99
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 96

def get_all_release_pipelines(project_key, opts = {})
  data, _status_code, _headers = get_all_release_pipelines_with_http_info(project_key, opts)
  data
end

#get_all_release_pipelines_with_http_info(project_key, opts = {}) ⇒ Array<(ReleasePipelineCollection, Integer, Hash)>

Get all release pipelines Get all release pipelines for a project

Parameters:

  • project_key (String)

    The project key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ReleasePipelineCollection, Integer, Hash)>)

    ReleasePipelineCollection data, response status code and response headers



106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 106

def get_all_release_pipelines_with_http_info(project_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ReleasePipelinesBetaApi.get_all_release_pipelines ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ReleasePipelinesBetaApi.get_all_release_pipelines"
  end
  # resource path
  local_var_path = '/api/v2/projects/{projectKey}/release-pipelines'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ReleasePipelineCollection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ReleasePipelinesBetaApi.get_all_release_pipelines",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ReleasePipelinesBetaApi#get_all_release_pipelines\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_release_pipeline_by_key(project_key, pipeline_key, opts = {}) ⇒ ReleasePipeline

Get release pipeline by key Get a release pipeline by key

Parameters:

  • project_key (String)

    The project key

  • pipeline_key (String)

    The release pipeline key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



160
161
162
163
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 160

def get_release_pipeline_by_key(project_key, pipeline_key, opts = {})
  data, _status_code, _headers = get_release_pipeline_by_key_with_http_info(project_key, pipeline_key, opts)
  data
end

#get_release_pipeline_by_key_with_http_info(project_key, pipeline_key, opts = {}) ⇒ Array<(ReleasePipeline, Integer, Hash)>

Get release pipeline by key Get a release pipeline by key

Parameters:

  • project_key (String)

    The project key

  • pipeline_key (String)

    The release pipeline key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ReleasePipeline, Integer, Hash)>)

    ReleasePipeline data, response status code and response headers



171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 171

def get_release_pipeline_by_key_with_http_info(project_key, pipeline_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ReleasePipelinesBetaApi.get_release_pipeline_by_key ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ReleasePipelinesBetaApi.get_release_pipeline_by_key"
  end
  # verify the required parameter 'pipeline_key' is set
  if @api_client.config.client_side_validation && pipeline_key.nil?
    fail ArgumentError, "Missing the required parameter 'pipeline_key' when calling ReleasePipelinesBetaApi.get_release_pipeline_by_key"
  end
  # resource path
  local_var_path = '/api/v2/projects/{projectKey}/release-pipelines/{pipelineKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'pipelineKey' + '}', CGI.escape(pipeline_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ReleasePipeline'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ReleasePipelinesBetaApi.get_release_pipeline_by_key",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ReleasePipelinesBetaApi#get_release_pipeline_by_key\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#patch_release_pipeline(project_key, pipeline_key, opts = {}) ⇒ ReleasePipeline

Update a release pipeline Updates a release pipeline. Updating a release pipeline uses a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](/#section/Overview/Updates).

Parameters:

  • project_key (String)

    The project key

  • pipeline_key (String)

    The release pipeline key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



229
230
231
232
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 229

def patch_release_pipeline(project_key, pipeline_key, opts = {})
  data, _status_code, _headers = patch_release_pipeline_with_http_info(project_key, pipeline_key, opts)
  data
end

#patch_release_pipeline_with_http_info(project_key, pipeline_key, opts = {}) ⇒ Array<(ReleasePipeline, Integer, Hash)>

Update a release pipeline Updates a release pipeline. Updating a release pipeline uses a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](/#section/Overview/Updates).

Parameters:

  • project_key (String)

    The project key

  • pipeline_key (String)

    The release pipeline key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ReleasePipeline, Integer, Hash)>)

    ReleasePipeline data, response status code and response headers



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 240

def patch_release_pipeline_with_http_info(project_key, pipeline_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ReleasePipelinesBetaApi.patch_release_pipeline ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ReleasePipelinesBetaApi.patch_release_pipeline"
  end
  # verify the required parameter 'pipeline_key' is set
  if @api_client.config.client_side_validation && pipeline_key.nil?
    fail ArgumentError, "Missing the required parameter 'pipeline_key' when calling ReleasePipelinesBetaApi.patch_release_pipeline"
  end
  # resource path
  local_var_path = '/api/v2/projects/{projectKey}/release-pipelines/{pipelineKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'pipelineKey' + '}', CGI.escape(pipeline_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ReleasePipeline'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ReleasePipelinesBetaApi.patch_release_pipeline",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ReleasePipelinesBetaApi#patch_release_pipeline\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_release_pipeline(project_key, create_release_pipeline_input, opts = {}) ⇒ ReleasePipeline

Create a release pipeline Creates a new release pipeline

Parameters:

  • project_key (String)

    The project key

  • create_release_pipeline_input (CreateReleasePipelineInput)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



298
299
300
301
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 298

def post_release_pipeline(project_key, create_release_pipeline_input, opts = {})
  data, _status_code, _headers = post_release_pipeline_with_http_info(project_key, create_release_pipeline_input, opts)
  data
end

#post_release_pipeline_with_http_info(project_key, create_release_pipeline_input, opts = {}) ⇒ Array<(ReleasePipeline, Integer, Hash)>

Create a release pipeline Creates a new release pipeline

Parameters:

  • project_key (String)

    The project key

  • create_release_pipeline_input (CreateReleasePipelineInput)
  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(ReleasePipeline, Integer, Hash)>)

    ReleasePipeline data, response status code and response headers



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
# File 'lib/launchdarkly_api/api/release_pipelines_beta_api.rb', line 309

def post_release_pipeline_with_http_info(project_key, create_release_pipeline_input, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ReleasePipelinesBetaApi.post_release_pipeline ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ReleasePipelinesBetaApi.post_release_pipeline"
  end
  # verify the required parameter 'create_release_pipeline_input' is set
  if @api_client.config.client_side_validation && create_release_pipeline_input.nil?
    fail ArgumentError, "Missing the required parameter 'create_release_pipeline_input' when calling ReleasePipelinesBetaApi.post_release_pipeline"
  end
  # resource path
  local_var_path = '/api/v2/projects/{projectKey}/release-pipelines'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(create_release_pipeline_input)

  # return_type
  return_type = opts[:debug_return_type] || 'ReleasePipeline'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ReleasePipelinesBetaApi.post_release_pipeline",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ReleasePipelinesBetaApi#post_release_pipeline\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end