Class: LaunchDarklyApi::ReleaseProgressionCollection

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/release_progression_collection.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ReleaseProgressionCollection

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleaseProgressionCollection` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleaseProgressionCollection`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'active_count')
    self.active_count = attributes[:'active_count']
  else
    self.active_count = nil
  end

  if attributes.key?(:'completed_count')
    self.completed_count = attributes[:'completed_count']
  else
    self.completed_count = nil
  end

  if attributes.key?(:'items')
    if (value = attributes[:'items']).is_a?(Array)
      self.items = value
    end
  else
    self.items = nil
  end

  if attributes.key?(:'phases')
    if (value = attributes[:'phases']).is_a?(Array)
      self.phases = value
    end
  else
    self.phases = nil
  end

  if attributes.key?(:'total_count')
    self.total_count = attributes[:'total_count']
  else
    self.total_count = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end
end

Instance Attribute Details

The location and content type of related resources



34
35
36
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 34

def _links
  @_links
end

#active_countObject

The number of active releases



19
20
21
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 19

def active_count
  @active_count
end

#completed_countObject

The number of completed releases



22
23
24
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 22

def completed_count
  @completed_count
end

#itemsObject

A list of details for each release, across all flags, for this release pipeline



25
26
27
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 25

def items
  @items
end

#phasesObject

A list of details for each phase, across all releases, for this release pipeline



28
29
30
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 28

def phases
  @phases
end

#total_countObject

The total number of releases for this release pipeline



31
32
33
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 31

def total_count
  @total_count
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 226

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 49

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 37

def self.attribute_map
  {
    :'active_count' => :'activeCount',
    :'completed_count' => :'completedCount',
    :'items' => :'items',
    :'phases' => :'phases',
    :'total_count' => :'totalCount',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 202

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



54
55
56
57
58
59
60
61
62
63
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 54

def self.openapi_types
  {
    :'active_count' => :'Integer',
    :'completed_count' => :'Integer',
    :'items' => :'Array<ReleaseProgression>',
    :'phases' => :'Array<PhaseInfo>',
    :'total_count' => :'Integer',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



176
177
178
179
180
181
182
183
184
185
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 176

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      active_count == o.active_count &&
      completed_count == o.completed_count &&
      items == o.items &&
      phases == o.phases &&
      total_count == o.total_count &&
      _links == o._links
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 297

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


189
190
191
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 189

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



195
196
197
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 195

def hash
  [active_count, completed_count, items, phases, total_count, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 131

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @active_count.nil?
    invalid_properties.push('invalid value for "active_count", active_count cannot be nil.')
  end

  if @completed_count.nil?
    invalid_properties.push('invalid value for "completed_count", completed_count cannot be nil.')
  end

  if @items.nil?
    invalid_properties.push('invalid value for "items", items cannot be nil.')
  end

  if @phases.nil?
    invalid_properties.push('invalid value for "phases", phases cannot be nil.')
  end

  if @total_count.nil?
    invalid_properties.push('invalid value for "total_count", total_count cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



273
274
275
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 273

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 279

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



267
268
269
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 267

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



163
164
165
166
167
168
169
170
171
172
# File 'lib/launchdarkly_api/models/release_progression_collection.rb', line 163

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @active_count.nil?
  return false if @completed_count.nil?
  return false if @items.nil?
  return false if @phases.nil?
  return false if @total_count.nil?
  return false if @_links.nil?
  true
end