Class: LaunchDarklyApi::ReleaserAudienceConfigInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ReleaserAudienceConfigInput
- Defined in:
- lib/launchdarkly_api/models/releaser_audience_config_input.rb
Instance Attribute Summary collapse
-
#audience_id ⇒ Object
UUID of the audience.
-
#notify_member_ids ⇒ Object
An array of member IDs.
-
#notify_team_keys ⇒ Object
An array of team keys.
-
#release_guardian_configuration ⇒ Object
Returns the value of attribute release_guardian_configuration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReleaserAudienceConfigInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReleaserAudienceConfigInput
Initializes the object
67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 67 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleaserAudienceConfigInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleaserAudienceConfigInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'audience_id') self.audience_id = attributes[:'audience_id'] end if attributes.key?(:'release_guardian_configuration') self.release_guardian_configuration = attributes[:'release_guardian_configuration'] end if attributes.key?(:'notify_member_ids') if (value = attributes[:'notify_member_ids']).is_a?(Array) self.notify_member_ids = value end end if attributes.key?(:'notify_team_keys') if (value = attributes[:'notify_team_keys']).is_a?(Array) self.notify_team_keys = value end end end |
Instance Attribute Details
#audience_id ⇒ Object
UUID of the audience.
19 20 21 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 19 def audience_id @audience_id end |
#notify_member_ids ⇒ Object
An array of member IDs. These members are notified to review the approval request.
24 25 26 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 24 def notify_member_ids @notify_member_ids end |
#notify_team_keys ⇒ Object
An array of team keys. The members of these teams are notified to review the approval request.
27 28 29 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 27 def notify_team_keys @notify_team_keys end |
#release_guardian_configuration ⇒ Object
Returns the value of attribute release_guardian_configuration.
21 22 23 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 21 def release_guardian_configuration @release_guardian_configuration end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
40 41 42 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 40 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
45 46 47 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 45 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
30 31 32 33 34 35 36 37 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 30 def self.attribute_map { :'audience_id' => :'audienceId', :'release_guardian_configuration' => :'releaseGuardianConfiguration', :'notify_member_ids' => :'notifyMemberIds', :'notify_team_keys' => :'notifyTeamKeys' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 143 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
60 61 62 63 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 60 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
50 51 52 53 54 55 56 57 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 50 def self.openapi_types { :'audience_id' => :'String', :'release_guardian_configuration' => :'ReleaseGuardianConfigurationInput', :'notify_member_ids' => :'Array<String>', :'notify_team_keys' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
119 120 121 122 123 124 125 126 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 119 def ==(o) return true if self.equal?(o) self.class == o.class && audience_id == o.audience_id && release_guardian_configuration == o.release_guardian_configuration && notify_member_ids == o.notify_member_ids && notify_team_keys == o.notify_team_keys end |
#eql?(o) ⇒ Boolean
130 131 132 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 130 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
136 137 138 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 136 def hash [audience_id, release_guardian_configuration, notify_member_ids, notify_team_keys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
104 105 106 107 108 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 104 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
165 166 167 168 169 170 171 172 173 174 175 176 177 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 165 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
112 113 114 115 |
# File 'lib/launchdarkly_api/models/releaser_audience_config_input.rb', line 112 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |