Class: LaunchDarklyApi::RepositoryPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::RepositoryPost
- Defined in:
- lib/launchdarkly_api/models/repository_post.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#commit_url_template ⇒ Object
A template for constructing a valid URL to view the commit.
-
#default_branch ⇒ Object
The repository’s default branch.
-
#hunk_url_template ⇒ Object
A template for constructing a valid URL to view the hunk.
-
#name ⇒ Object
The repository name.
-
#source_link ⇒ Object
A URL to access the repository.
-
#type ⇒ Object
The type of repository.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RepositoryPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RepositoryPost
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::RepositoryPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::RepositoryPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'source_link') self.source_link = attributes[:'source_link'] end if attributes.key?(:'commit_url_template') self.commit_url_template = attributes[:'commit_url_template'] end if attributes.key?(:'hunk_url_template') self.hunk_url_template = attributes[:'hunk_url_template'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'default_branch') self.default_branch = attributes[:'default_branch'] end end |
Instance Attribute Details
#commit_url_template ⇒ Object
A template for constructing a valid URL to view the commit
25 26 27 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 25 def commit_url_template @commit_url_template end |
#default_branch ⇒ Object
The repository’s default branch. If not specified, the default value is main.
34 35 36 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 34 def default_branch @default_branch end |
#hunk_url_template ⇒ Object
A template for constructing a valid URL to view the hunk
28 29 30 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 28 def hunk_url_template @hunk_url_template end |
#name ⇒ Object
The repository name
19 20 21 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 19 def name @name end |
#source_link ⇒ Object
A URL to access the repository
22 23 24 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 22 def source_link @source_link end |
#type ⇒ Object
The type of repository. If not specified, the default value is custom.
31 32 33 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 31 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 59 def self.attribute_map { :'name' => :'name', :'source_link' => :'sourceLink', :'commit_url_template' => :'commitUrlTemplate', :'hunk_url_template' => :'hunkUrlTemplate', :'type' => :'type', :'default_branch' => :'defaultBranch' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 81 def self.openapi_types { :'name' => :'String', :'source_link' => :'String', :'commit_url_template' => :'String', :'hunk_url_template' => :'String', :'type' => :'String', :'default_branch' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
185 186 187 188 189 190 191 192 193 194 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 185 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && source_link == o.source_link && commit_url_template == o.commit_url_template && hunk_url_template == o.hunk_url_template && type == o.type && default_branch == o.default_branch end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 204 def hash [name, source_link, commit_url_template, hunk_url_template, type, default_branch].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 159 160 161 |
# File 'lib/launchdarkly_api/models/repository_post.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? type_validator = EnumAttributeValidator.new('String', ["bitbucket", "custom", "github", "gitlab"]) return false unless type_validator.valid?(@type) true end |