Class: LaunchDarklyApi::RepositoryRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/repository_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ RepositoryRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 123

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::RepositoryRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::RepositoryRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'source_link')
    self.source_link = attributes[:'source_link']
  end

  if attributes.key?(:'commit_url_template')
    self.commit_url_template = attributes[:'commit_url_template']
  end

  if attributes.key?(:'hunk_url_template')
    self.hunk_url_template = attributes[:'hunk_url_template']
  end

  if attributes.key?(:'type')
    self.type = attributes[:'type']
  else
    self.type = nil
  end

  if attributes.key?(:'default_branch')
    self.default_branch = attributes[:'default_branch']
  else
    self.default_branch = nil
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  else
    self.enabled = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'branches')
    if (value = attributes[:'branches']).is_a?(Array)
      self.branches = value
    end
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



47
48
49
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 47

def _access
  @_access
end

Returns the value of attribute _links.



45
46
47
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 45

def _links
  @_links
end

#branchesObject

An array of the repository’s branches that have been scanned for code references



43
44
45
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 43

def branches
  @branches
end

#commit_url_templateObject

A template for constructing a valid URL to view the commit



25
26
27
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 25

def commit_url_template
  @commit_url_template
end

#default_branchObject

The repository’s default branch



34
35
36
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 34

def default_branch
  @default_branch
end

#enabledObject

Whether or not a repository is enabled for code reference scanning



37
38
39
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 37

def enabled
  @enabled
end

#hunk_url_templateObject

A template for constructing a valid URL to view the hunk



28
29
30
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 28

def hunk_url_template
  @hunk_url_template
end

#nameObject

The repository name



19
20
21
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 19

def name
  @name
end

A URL to access the repository



22
23
24
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 22

def source_link
  @source_link
end

#typeObject

The type of repository



31
32
33
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 31

def type
  @type
end

#versionObject

The version of the repository’s saved information



40
41
42
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 40

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



89
90
91
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 89

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



94
95
96
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 94

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 72

def self.attribute_map
  {
    :'name' => :'name',
    :'source_link' => :'sourceLink',
    :'commit_url_template' => :'commitUrlTemplate',
    :'hunk_url_template' => :'hunkUrlTemplate',
    :'type' => :'type',
    :'default_branch' => :'defaultBranch',
    :'enabled' => :'enabled',
    :'version' => :'version',
    :'branches' => :'branches',
    :'_links' => :'_links',
    :'_access' => :'_access'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 338

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



116
117
118
119
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 116

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 99

def self.openapi_types
  {
    :'name' => :'String',
    :'source_link' => :'String',
    :'commit_url_template' => :'String',
    :'hunk_url_template' => :'String',
    :'type' => :'String',
    :'default_branch' => :'String',
    :'enabled' => :'Boolean',
    :'version' => :'Integer',
    :'branches' => :'Array<BranchRep>',
    :'_links' => :'Hash<String, Object>',
    :'_access' => :'Access'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 307

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      source_link == o.source_link &&
      commit_url_template == o.commit_url_template &&
      hunk_url_template == o.hunk_url_template &&
      type == o.type &&
      default_branch == o.default_branch &&
      enabled == o.enabled &&
      version == o.version &&
      branches == o.branches &&
      _links == o._links &&
      _access == o._access
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


325
326
327
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 325

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



331
332
333
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 331

def hash
  [name, source_link, commit_url_template, hunk_url_template, type, default_branch, enabled, version, branches, _links, _access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 200

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @type.nil?
    invalid_properties.push('invalid value for "type", type cannot be nil.')
  end

  if @default_branch.nil?
    invalid_properties.push('invalid value for "default_branch", default_branch cannot be nil.')
  end

  if @enabled.nil?
    invalid_properties.push('invalid value for "enabled", enabled cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/launchdarkly_api/models/repository_rep.rb', line 232

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @type.nil?
  type_validator = EnumAttributeValidator.new('String', ["bitbucket", "custom", "github", "gitlab"])
  return false unless type_validator.valid?(@type)
  return false if @default_branch.nil?
  return false if @enabled.nil?
  return false if @version.nil?
  return false if @_links.nil?
  true
end