Class: LaunchDarklyApi::ReviewResponse

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/review_response.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ReviewResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/launchdarkly_api/models/review_response.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReviewResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReviewResponse`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'member_id')
    self.member_id = attributes[:'member_id']
  end

  if attributes.key?(:'service_token_id')
    self.service_token_id = attributes[:'service_token_id']
  end
end

Instance Attribute Details

#_idObject

The approval request ID



19
20
21
# File 'lib/launchdarkly_api/models/review_response.rb', line 19

def _id
  @_id
end

#commentObject

A comment describing the approval response



27
28
29
# File 'lib/launchdarkly_api/models/review_response.rb', line 27

def comment
  @comment
end

#creation_dateObject

Returns the value of attribute creation_date.



24
25
26
# File 'lib/launchdarkly_api/models/review_response.rb', line 24

def creation_date
  @creation_date
end

#kindObject

The type of review action to take



22
23
24
# File 'lib/launchdarkly_api/models/review_response.rb', line 22

def kind
  @kind
end

#member_idObject

ID of account member that reviewed request



30
31
32
# File 'lib/launchdarkly_api/models/review_response.rb', line 30

def member_id
  @member_id
end

#service_token_idObject

ID of account service token that reviewed request



33
34
35
# File 'lib/launchdarkly_api/models/review_response.rb', line 33

def service_token_id
  @service_token_id
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



70
71
72
# File 'lib/launchdarkly_api/models/review_response.rb', line 70

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



75
76
77
# File 'lib/launchdarkly_api/models/review_response.rb', line 75

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



58
59
60
61
62
63
64
65
66
67
# File 'lib/launchdarkly_api/models/review_response.rb', line 58

def self.attribute_map
  {
    :'_id' => :'_id',
    :'kind' => :'kind',
    :'creation_date' => :'creationDate',
    :'comment' => :'comment',
    :'member_id' => :'memberId',
    :'service_token_id' => :'serviceTokenId'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/launchdarkly_api/models/review_response.rb', line 217

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/launchdarkly_api/models/review_response.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



80
81
82
83
84
85
86
87
88
89
# File 'lib/launchdarkly_api/models/review_response.rb', line 80

def self.openapi_types
  {
    :'_id' => :'String',
    :'kind' => :'String',
    :'creation_date' => :'Integer',
    :'comment' => :'String',
    :'member_id' => :'String',
    :'service_token_id' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



191
192
193
194
195
196
197
198
199
200
# File 'lib/launchdarkly_api/models/review_response.rb', line 191

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      kind == o.kind &&
      creation_date == o.creation_date &&
      comment == o.comment &&
      member_id == o.member_id &&
      service_token_id == o.service_token_id
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


204
205
206
# File 'lib/launchdarkly_api/models/review_response.rb', line 204

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



210
211
212
# File 'lib/launchdarkly_api/models/review_response.rb', line 210

def hash
  [_id, kind, creation_date, comment, member_id, service_token_id].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



144
145
146
147
148
149
150
151
152
153
154
155
156
# File 'lib/launchdarkly_api/models/review_response.rb', line 144

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/launchdarkly_api/models/review_response.rb', line 239

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



160
161
162
163
164
165
166
167
# File 'lib/launchdarkly_api/models/review_response.rb', line 160

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["approve", "decline", "comment"])
  return false unless kind_validator.valid?(@kind)
  true
end