Class: LaunchDarklyApi::SdkKeyListItem
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::SdkKeyListItem
- Defined in:
- lib/launchdarkly_api/models/sdk_key_list_item.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_created_at ⇒ Object
Returns the value of attribute _created_at.
-
#_created_by_member_id ⇒ Object
The ID of the member who created the SDK key.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_updated_at ⇒ Object
Returns the value of attribute _updated_at.
-
#_version ⇒ Object
The auto-incremented version number of the SDK key.
-
#description ⇒ Object
The optional description of the SDK key.
-
#environment_summary ⇒ Object
Returns the value of attribute environment_summary.
-
#expiry ⇒ Object
Returns the value of attribute expiry.
-
#is_default ⇒ Object
Indicates if this SDK key is the system-defined default for the environment.
-
#key ⇒ Object
The user-defined identifying key of the SDK key.
-
#kind ⇒ Object
Returns the value of attribute kind.
-
#name ⇒ Object
The human-readable name of the SDK key.
-
#value ⇒ Object
The string value of the SDK key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3).
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SdkKeyListItem
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SdkKeyListItem
Initializes the object
136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 136 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::SdkKeyListItem` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::SdkKeyListItem`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') self._links = attributes[:'_links'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'expiry') self.expiry = attributes[:'expiry'] end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] else self.is_default = nil end if attributes.key?(:'_created_by_member_id') self._created_by_member_id = attributes[:'_created_by_member_id'] end if attributes.key?(:'_created_at') self._created_at = attributes[:'_created_at'] else self._created_at = nil end if attributes.key?(:'_updated_at') self._updated_at = attributes[:'_updated_at'] else self._updated_at = nil end if attributes.key?(:'_version') self._version = attributes[:'_version'] else self._version = nil end if attributes.key?(:'environment_summary') self.environment_summary = attributes[:'environment_summary'] end end |
Instance Attribute Details
#_created_at ⇒ Object
Returns the value of attribute _created_at.
42 43 44 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 42 def _created_at @_created_at end |
#_created_by_member_id ⇒ Object
The ID of the member who created the SDK key. This field is immutable.
40 41 42 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 40 def _created_by_member_id @_created_by_member_id end |
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 18 def _links @_links end |
#_updated_at ⇒ Object
Returns the value of attribute _updated_at.
44 45 46 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 44 def _updated_at @_updated_at end |
#_version ⇒ Object
The auto-incremented version number of the SDK key.
47 48 49 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 47 def _version @_version end |
#description ⇒ Object
The optional description of the SDK key.
29 30 31 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 29 def description @description end |
#environment_summary ⇒ Object
Returns the value of attribute environment_summary.
49 50 51 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 49 def environment_summary @environment_summary end |
#expiry ⇒ Object
Returns the value of attribute expiry.
31 32 33 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 31 def expiry @expiry end |
#is_default ⇒ Object
Indicates if this SDK key is the system-defined default for the environment. There may also be an expiring default SDK key for the environment (not possible with mobile keys).
37 38 39 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 37 def is_default @is_default end |
#key ⇒ Object
The user-defined identifying key of the SDK key. This is used solely to identify an SDK key and is distinct from the value field, which is the actual SDK key value.
23 24 25 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 23 def key @key end |
#kind ⇒ Object
Returns the value of attribute kind.
20 21 22 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 20 def kind @kind end |
#name ⇒ Object
The human-readable name of the SDK key.
26 27 28 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 26 def name @name end |
#value ⇒ Object
The string value of the SDK key. Use this when configuring your SDK.
34 35 36 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 34 def value @value end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
93 94 95 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 93 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
98 99 100 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 98 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 74 def self.attribute_map { :'_links' => :'_links', :'kind' => :'kind', :'key' => :'key', :'name' => :'name', :'description' => :'description', :'expiry' => :'expiry', :'value' => :'value', :'is_default' => :'isDefault', :'_created_by_member_id' => :'_createdByMemberId', :'_created_at' => :'_createdAt', :'_updated_at' => :'_updatedAt', :'_version' => :'_version', :'environment_summary' => :'environmentSummary' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 389 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_all_of ⇒ Object
List of class defined in allOf (OpenAPI v3)
128 129 130 131 132 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 128 def self.openapi_all_of [ :'SdkKey' ] end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
122 123 124 125 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 122 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 103 def self.openapi_types { :'_links' => :'ParentAndSelfLinks', :'kind' => :'SdkKeyKind', :'key' => :'String', :'name' => :'String', :'description' => :'String', :'expiry' => :'Integer', :'value' => :'String', :'is_default' => :'Boolean', :'_created_by_member_id' => :'String', :'_created_at' => :'Integer', :'_updated_at' => :'Integer', :'_version' => :'Integer', :'environment_summary' => :'SdkKeysEnvironmentSummary' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 356 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && kind == o.kind && key == o.key && name == o.name && description == o.description && expiry == o.expiry && value == o.value && is_default == o.is_default && _created_by_member_id == o._created_by_member_id && _created_at == o._created_at && _updated_at == o._updated_at && _version == o._version && environment_summary == o.environment_summary end |
#eql?(o) ⇒ Boolean
376 377 378 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 376 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
382 383 384 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 382 def hash [_links, kind, key, name, description, expiry, value, is_default, _created_by_member_id, _created_at, _updated_at, _version, environment_summary].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 221 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @is_default.nil? invalid_properties.push('invalid value for "is_default", is_default cannot be nil.') end if @_created_at.nil? invalid_properties.push('invalid value for "_created_at", _created_at cannot be nil.') end if @_updated_at.nil? invalid_properties.push('invalid value for "_updated_at", _updated_at cannot be nil.') end if @_version.nil? invalid_properties.push('invalid value for "_version", _version cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 411 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/launchdarkly_api/models/sdk_key_list_item.rb', line 261 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kind.nil? return false if @key.nil? return false if @name.nil? return false if @value.nil? return false if @is_default.nil? return false if @_created_at.nil? return false if @_updated_at.nil? return false if @_version.nil? true end |