Class: LaunchDarklyApi::SegmentBody

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/segment_body.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ SegmentBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/launchdarkly_api/models/segment_body.rb', line 78

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::SegmentBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::SegmentBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'unbounded')
    self.unbounded = attributes[:'unbounded']
  end

  if attributes.key?(:'unbounded_context_kind')
    self.unbounded_context_kind = attributes[:'unbounded_context_kind']
  end
end

Instance Attribute Details

#descriptionObject

A description of the segment's purpose



25
26
27
# File 'lib/launchdarkly_api/models/segment_body.rb', line 25

def description
  @description
end

#keyObject

A unique key used to reference the segment



22
23
24
# File 'lib/launchdarkly_api/models/segment_body.rb', line 22

def key
  @key
end

#nameObject

A human-friendly name for the segment



19
20
21
# File 'lib/launchdarkly_api/models/segment_body.rb', line 19

def name
  @name
end

#tagsObject

Tags for the segment



28
29
30
# File 'lib/launchdarkly_api/models/segment_body.rb', line 28

def tags
  @tags
end

#unboundedObject

Whether to create a standard segment (false) or a big segment (true). Standard segments include rule-based and smaller list-based segments. Big segments include larger list-based segments and synced segments. Only use a big segment if you need to add more than 15,000 individual targets.



31
32
33
# File 'lib/launchdarkly_api/models/segment_body.rb', line 31

def unbounded
  @unbounded
end

#unbounded_context_kindObject

For big segments, the targeted context kind.



34
35
36
# File 'lib/launchdarkly_api/models/segment_body.rb', line 34

def unbounded_context_kind
  @unbounded_context_kind
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/segment_body.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/segment_body.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/segment_body.rb', line 37

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'description' => :'description',
    :'tags' => :'tags',
    :'unbounded' => :'unbounded',
    :'unbounded_context_kind' => :'unboundedContextKind'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/launchdarkly_api/models/segment_body.rb', line 196

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



71
72
73
74
# File 'lib/launchdarkly_api/models/segment_body.rb', line 71

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
# File 'lib/launchdarkly_api/models/segment_body.rb', line 59

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'description' => :'String',
    :'tags' => :'Array<String>',
    :'unbounded' => :'Boolean',
    :'unbounded_context_kind' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



170
171
172
173
174
175
176
177
178
179
# File 'lib/launchdarkly_api/models/segment_body.rb', line 170

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      description == o.description &&
      tags == o.tags &&
      unbounded == o.unbounded &&
      unbounded_context_kind == o.unbounded_context_kind
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


183
184
185
# File 'lib/launchdarkly_api/models/segment_body.rb', line 183

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



189
190
191
# File 'lib/launchdarkly_api/models/segment_body.rb', line 189

def hash
  [name, key, description, tags, unbounded, unbounded_context_kind].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



125
126
127
128
129
130
131
132
133
134
135
136
137
# File 'lib/launchdarkly_api/models/segment_body.rb', line 125

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/launchdarkly_api/models/segment_body.rb', line 218

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/segment_body.rb', line 141

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @key.nil?
  true
end