Class: LaunchDarklyApi::Statement

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/statement.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Statement

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/launchdarkly_api/models/statement.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Statement` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Statement`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'resources')
    if (value = attributes[:'resources']).is_a?(Array)
      self.resources = value
    end
  end

  if attributes.key?(:'not_resources')
    if (value = attributes[:'not_resources']).is_a?(Array)
      self.not_resources = value
    end
  end

  if attributes.key?(:'actions')
    if (value = attributes[:'actions']).is_a?(Array)
      self.actions = value
    end
  end

  if attributes.key?(:'not_actions')
    if (value = attributes[:'not_actions']).is_a?(Array)
      self.not_actions = value
    end
  end

  if attributes.key?(:'effect')
    self.effect = attributes[:'effect']
  else
    self.effect = nil
  end
end

Instance Attribute Details

#actionsObject

Actions to perform on a resource



25
26
27
# File 'lib/launchdarkly_api/models/statement.rb', line 25

def actions
  @actions
end

#effectObject

Whether this statement should allow or deny actions on the resources.



31
32
33
# File 'lib/launchdarkly_api/models/statement.rb', line 31

def effect
  @effect
end

#not_actionsObject

Targeted actions are the actions NOT in this list. The actions and notResources fields must be empty to use this field.



28
29
30
# File 'lib/launchdarkly_api/models/statement.rb', line 28

def not_actions
  @not_actions
end

#not_resourcesObject

Targeted resources are the resources NOT in this list. The resources and notActions fields must be empty to use this field.



22
23
24
# File 'lib/launchdarkly_api/models/statement.rb', line 22

def not_resources
  @not_resources
end

#resourcesObject

Resource specifier strings



19
20
21
# File 'lib/launchdarkly_api/models/statement.rb', line 19

def resources
  @resources
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/launchdarkly_api/models/statement.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/statement.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



56
57
58
59
60
61
62
63
64
# File 'lib/launchdarkly_api/models/statement.rb', line 56

def self.attribute_map
  {
    :'resources' => :'resources',
    :'not_resources' => :'notResources',
    :'actions' => :'actions',
    :'not_actions' => :'notActions',
    :'effect' => :'effect'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/launchdarkly_api/models/statement.rb', line 199

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/launchdarkly_api/models/statement.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
# File 'lib/launchdarkly_api/models/statement.rb', line 77

def self.openapi_types
  {
    :'resources' => :'Array<String>',
    :'not_resources' => :'Array<String>',
    :'actions' => :'Array<String>',
    :'not_actions' => :'Array<String>',
    :'effect' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



174
175
176
177
178
179
180
181
182
# File 'lib/launchdarkly_api/models/statement.rb', line 174

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      resources == o.resources &&
      not_resources == o.not_resources &&
      actions == o.actions &&
      not_actions == o.not_actions &&
      effect == o.effect
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


186
187
188
# File 'lib/launchdarkly_api/models/statement.rb', line 186

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



192
193
194
# File 'lib/launchdarkly_api/models/statement.rb', line 192

def hash
  [resources, not_resources, actions, not_actions, effect].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
# File 'lib/launchdarkly_api/models/statement.rb', line 142

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @effect.nil?
    invalid_properties.push('invalid value for "effect", effect cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



221
222
223
224
225
226
227
228
229
230
231
232
233
# File 'lib/launchdarkly_api/models/statement.rb', line 221

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



154
155
156
157
158
159
160
# File 'lib/launchdarkly_api/models/statement.rb', line 154

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @effect.nil?
  effect_validator = EnumAttributeValidator.new('String', ["allow", "deny"])
  return false unless effect_validator.valid?(@effect)
  true
end