Class: LaunchDarklyApi::StatisticRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::StatisticRep
- Defined in:
- lib/launchdarkly_api/models/statistic_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#default_branch ⇒ Object
The repository's default branch.
-
#enabled ⇒ Object
Whether or not a repository is enabled for code reference scanning.
-
#file_count ⇒ Object
The number of files in which the flag appears in this repository.
-
#hunk_count ⇒ Object
The number of code reference hunks in which the flag appears in this repository.
-
#latest_commit_time ⇒ Object
Returns the value of attribute latest_commit_time.
-
#name ⇒ Object
The repository name.
-
#source_link ⇒ Object
A URL to access the repository.
-
#type ⇒ Object
The type of repository.
-
#version ⇒ Object
The version of the repository's saved information.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ StatisticRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ StatisticRep
Initializes the object
119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 119 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::StatisticRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::StatisticRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'type') self.type = attributes[:'type'] else self.type = nil end if attributes.key?(:'source_link') self.source_link = attributes[:'source_link'] else self.source_link = nil end if attributes.key?(:'default_branch') self.default_branch = attributes[:'default_branch'] else self.default_branch = nil end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] else self.enabled = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'hunk_count') self.hunk_count = attributes[:'hunk_count'] else self.hunk_count = nil end if attributes.key?(:'file_count') self.file_count = attributes[:'file_count'] else self.file_count = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'latest_commit_time') self.latest_commit_time = attributes[:'latest_commit_time'] end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
43 44 45 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 43 def _links @_links end |
#default_branch ⇒ Object
The repository's default branch
28 29 30 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 28 def default_branch @default_branch end |
#enabled ⇒ Object
Whether or not a repository is enabled for code reference scanning
31 32 33 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 31 def enabled @enabled end |
#file_count ⇒ Object
The number of files in which the flag appears in this repository
40 41 42 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 40 def file_count @file_count end |
#hunk_count ⇒ Object
The number of code reference hunks in which the flag appears in this repository
37 38 39 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 37 def hunk_count @hunk_count end |
#latest_commit_time ⇒ Object
Returns the value of attribute latest_commit_time.
45 46 47 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 45 def latest_commit_time @latest_commit_time end |
#name ⇒ Object
The repository name
19 20 21 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 19 def name @name end |
#source_link ⇒ Object
A URL to access the repository
25 26 27 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 25 def source_link @source_link end |
#type ⇒ Object
The type of repository
22 23 24 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 22 def type @type end |
#version ⇒ Object
The version of the repository's saved information
34 35 36 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 34 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
86 87 88 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 86 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
91 92 93 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 91 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 70 def self.attribute_map { :'name' => :'name', :'type' => :'type', :'source_link' => :'sourceLink', :'default_branch' => :'defaultBranch', :'enabled' => :'enabled', :'version' => :'version', :'hunk_count' => :'hunkCount', :'file_count' => :'fileCount', :'_links' => :'_links', :'latest_commit_time' => :'latestCommitTime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 378 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
112 113 114 115 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 112 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
96 97 98 99 100 101 102 103 104 105 106 107 108 109 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 96 def self.openapi_types { :'name' => :'String', :'type' => :'String', :'source_link' => :'String', :'default_branch' => :'String', :'enabled' => :'Boolean', :'version' => :'Integer', :'hunk_count' => :'Integer', :'file_count' => :'Integer', :'_links' => :'Hash<String, Link>', :'latest_commit_time' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 348 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && type == o.type && source_link == o.source_link && default_branch == o.default_branch && enabled == o.enabled && version == o.version && hunk_count == o.hunk_count && file_count == o.file_count && _links == o._links && latest_commit_time == o.latest_commit_time end |
#eql?(o) ⇒ Boolean
365 366 367 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 365 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
371 372 373 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 371 def hash [name, type, source_link, default_branch, enabled, version, hunk_count, file_count, _links, latest_commit_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 196 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @type.nil? invalid_properties.push('invalid value for "type", type cannot be nil.') end if @source_link.nil? invalid_properties.push('invalid value for "source_link", source_link cannot be nil.') end if @default_branch.nil? invalid_properties.push('invalid value for "default_branch", default_branch cannot be nil.') end if @enabled.nil? invalid_properties.push('invalid value for "enabled", enabled cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @hunk_count.nil? invalid_properties.push('invalid value for "hunk_count", hunk_count cannot be nil.') end if @file_count.nil? invalid_properties.push('invalid value for "file_count", file_count cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 400 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/launchdarkly_api/models/statistic_rep.rb', line 240 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @type.nil? type_validator = EnumAttributeValidator.new('String', ["bitbucket", "custom", "github", "gitlab"]) return false unless type_validator.valid?(@type) return false if @source_link.nil? return false if @default_branch.nil? return false if @enabled.nil? return false if @version.nil? return false if @hunk_count.nil? return false if @file_count.nil? return false if @_links.nil? true end |