Class: LaunchDarklyApi::SubscriptionPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::SubscriptionPost
- Defined in:
- lib/launchdarkly_api/models/subscription_post.rb
Instance Attribute Summary collapse
-
#api_key ⇒ Object
Datadog API key.
-
#config ⇒ Object
The unique set of fields required to configure an audit log subscription integration of this type.
-
#name ⇒ Object
A human-friendly name for your audit log subscription.
-
#on ⇒ Object
Whether or not you want your subscription to actively send events.
-
#statements ⇒ Object
Returns the value of attribute statements.
-
#tags ⇒ Object
An array of tags for this subscription.
-
#url ⇒ Object
Slack webhook receiver URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SubscriptionPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SubscriptionPost
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::SubscriptionPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::SubscriptionPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'statements') if (value = attributes[:'statements']).is_a?(Array) self.statements = value end end if attributes.key?(:'on') self.on = attributes[:'on'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Hash) self.config = value end else self.config = nil end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end end |
Instance Attribute Details
#api_key ⇒ Object
Datadog API key. Only necessary for legacy Datadog webhook integrations.
36 37 38 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 36 def api_key @api_key end |
#config ⇒ Object
The unique set of fields required to configure an audit log subscription integration of this type. Refer to the formVariables field in the corresponding manifest.json at https://github.com/launchdarkly/integration-framework/tree/main/integrations for a full list of fields for the integration you wish to configure.
30 31 32 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 30 def config @config end |
#name ⇒ Object
A human-friendly name for your audit log subscription.
19 20 21 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 19 def name @name end |
#on ⇒ Object
Whether or not you want your subscription to actively send events.
24 25 26 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 24 def on @on end |
#statements ⇒ Object
Returns the value of attribute statements.
21 22 23 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 21 def statements @statements end |
#tags ⇒ Object
An array of tags for this subscription.
27 28 29 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 27 def @tags end |
#url ⇒ Object
Slack webhook receiver URL. Only necessary for legacy Slack webhook integrations.
33 34 35 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 33 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 39 def self.attribute_map { :'name' => :'name', :'statements' => :'statements', :'on' => :'on', :'tags' => :'tags', :'config' => :'config', :'url' => :'url', :'api_key' => :'apiKey' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 209 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 62 def self.openapi_types { :'name' => :'String', :'statements' => :'Array<StatementPost>', :'on' => :'Boolean', :'tags' => :'Array<String>', :'config' => :'Hash<String, Object>', :'url' => :'String', :'api_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
182 183 184 185 186 187 188 189 190 191 192 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 182 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && statements == o.statements && on == o.on && == o. && config == o.config && url == o.url && api_key == o.api_key end |
#eql?(o) ⇒ Boolean
196 197 198 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 196 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
202 203 204 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 202 def hash [name, statements, on, , config, url, api_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
231 232 233 234 235 236 237 238 239 240 241 242 243 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 231 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
153 154 155 156 157 158 |
# File 'lib/launchdarkly_api/models/subscription_post.rb', line 153 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @config.nil? true end |