Class: LaunchDarklyApi::Team
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::Team
- Defined in:
- lib/launchdarkly_api/models/team.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_idp_synced ⇒ Object
Whether the team has been synced with an external identity provider (IdP).
-
#_last_modified ⇒ Object
Returns the value of attribute _last_modified.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_version ⇒ Object
The team version.
-
#description ⇒ Object
A description of the team.
-
#key ⇒ Object
The team key.
-
#maintainers ⇒ Object
Returns the value of attribute maintainers.
-
#members ⇒ Object
Returns the value of attribute members.
-
#name ⇒ Object
A human-friendly name for the team.
-
#projects ⇒ Object
Returns the value of attribute projects.
-
#role_attributes ⇒ Object
Returns the value of attribute role_attributes.
-
#roles ⇒ Object
Returns the value of attribute roles.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Team
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Team
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/launchdarkly_api/models/team.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Team` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Team`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_last_modified') self._last_modified = attributes[:'_last_modified'] end if attributes.key?(:'_version') self._version = attributes[:'_version'] end if attributes.key?(:'_idp_synced') self._idp_synced = attributes[:'_idp_synced'] end if attributes.key?(:'role_attributes') if (value = attributes[:'role_attributes']).is_a?(Hash) self.role_attributes = value end end if attributes.key?(:'roles') self.roles = attributes[:'roles'] end if attributes.key?(:'members') self.members = attributes[:'members'] end if attributes.key?(:'projects') self.projects = attributes[:'projects'] end if attributes.key?(:'maintainers') self.maintainers = attributes[:'maintainers'] end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
27 28 29 |
# File 'lib/launchdarkly_api/models/team.rb', line 27 def _access @_access end |
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
29 30 31 |
# File 'lib/launchdarkly_api/models/team.rb', line 29 def _creation_date @_creation_date end |
#_idp_synced ⇒ Object
Whether the team has been synced with an external identity provider (IdP). Team sync is available to customers on an Enterprise plan.
40 41 42 |
# File 'lib/launchdarkly_api/models/team.rb', line 40 def _idp_synced @_idp_synced end |
#_last_modified ⇒ Object
Returns the value of attribute _last_modified.
34 35 36 |
# File 'lib/launchdarkly_api/models/team.rb', line 34 def _last_modified @_last_modified end |
#_links ⇒ Object
The location and content type of related resources
32 33 34 |
# File 'lib/launchdarkly_api/models/team.rb', line 32 def _links @_links end |
#_version ⇒ Object
The team version
37 38 39 |
# File 'lib/launchdarkly_api/models/team.rb', line 37 def _version @_version end |
#description ⇒ Object
A description of the team
19 20 21 |
# File 'lib/launchdarkly_api/models/team.rb', line 19 def description @description end |
#key ⇒ Object
The team key
22 23 24 |
# File 'lib/launchdarkly_api/models/team.rb', line 22 def key @key end |
#maintainers ⇒ Object
Returns the value of attribute maintainers.
50 51 52 |
# File 'lib/launchdarkly_api/models/team.rb', line 50 def maintainers @maintainers end |
#members ⇒ Object
Returns the value of attribute members.
46 47 48 |
# File 'lib/launchdarkly_api/models/team.rb', line 46 def members @members end |
#name ⇒ Object
A human-friendly name for the team
25 26 27 |
# File 'lib/launchdarkly_api/models/team.rb', line 25 def name @name end |
#projects ⇒ Object
Returns the value of attribute projects.
48 49 50 |
# File 'lib/launchdarkly_api/models/team.rb', line 48 def projects @projects end |
#role_attributes ⇒ Object
Returns the value of attribute role_attributes.
42 43 44 |
# File 'lib/launchdarkly_api/models/team.rb', line 42 def role_attributes @role_attributes end |
#roles ⇒ Object
Returns the value of attribute roles.
44 45 46 |
# File 'lib/launchdarkly_api/models/team.rb', line 44 def roles @roles end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/launchdarkly_api/models/team.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/launchdarkly_api/models/team.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/launchdarkly_api/models/team.rb', line 53 def self.attribute_map { :'description' => :'description', :'key' => :'key', :'name' => :'name', :'_access' => :'_access', :'_creation_date' => :'_creationDate', :'_links' => :'_links', :'_last_modified' => :'_lastModified', :'_version' => :'_version', :'_idp_synced' => :'_idpSynced', :'role_attributes' => :'roleAttributes', :'roles' => :'roles', :'members' => :'members', :'projects' => :'projects', :'maintainers' => :'maintainers' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 |
# File 'lib/launchdarkly_api/models/team.rb', line 236 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/launchdarkly_api/models/team.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/launchdarkly_api/models/team.rb', line 83 def self.openapi_types { :'description' => :'String', :'key' => :'String', :'name' => :'String', :'_access' => :'Access', :'_creation_date' => :'Integer', :'_links' => :'Hash<String, Link>', :'_last_modified' => :'Integer', :'_version' => :'Integer', :'_idp_synced' => :'Boolean', :'role_attributes' => :'Hash<String, Array>', :'roles' => :'TeamCustomRoles', :'members' => :'TeamMembers', :'projects' => :'TeamProjects', :'maintainers' => :'TeamMaintainers' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/launchdarkly_api/models/team.rb', line 202 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && key == o.key && name == o.name && _access == o._access && _creation_date == o._creation_date && _links == o._links && _last_modified == o._last_modified && _version == o._version && _idp_synced == o._idp_synced && role_attributes == o.role_attributes && roles == o.roles && members == o.members && projects == o.projects && maintainers == o.maintainers end |
#eql?(o) ⇒ Boolean
223 224 225 |
# File 'lib/launchdarkly_api/models/team.rb', line 223 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
229 230 231 |
# File 'lib/launchdarkly_api/models/team.rb', line 229 def hash [description, key, name, _access, _creation_date, _links, _last_modified, _version, _idp_synced, role_attributes, roles, members, projects, maintainers].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
187 188 189 190 191 |
# File 'lib/launchdarkly_api/models/team.rb', line 187 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/launchdarkly_api/models/team.rb', line 258 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 |
# File 'lib/launchdarkly_api/models/team.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |