Class: LaunchDarklyApi::Token

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/token.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Token

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
# File 'lib/launchdarkly_api/models/token.rb', line 121

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Token` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Token`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'owner_id')
    self.owner_id = attributes[:'owner_id']
  else
    self.owner_id = nil
  end

  if attributes.key?(:'member_id')
    self.member_id = attributes[:'member_id']
  else
    self.member_id = nil
  end

  if attributes.key?(:'_member')
    self._member = attributes[:'_member']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  else
    self.last_modified = nil
  end

  if attributes.key?(:'custom_role_ids')
    if (value = attributes[:'custom_role_ids']).is_a?(Array)
      self.custom_role_ids = value
    end
  end

  if attributes.key?(:'inline_role')
    if (value = attributes[:'inline_role']).is_a?(Array)
      self.inline_role = value
    end
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'token')
    self.token = attributes[:'token']
  end

  if attributes.key?(:'service_token')
    self.service_token = attributes[:'service_token']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'default_api_version')
    self.default_api_version = attributes[:'default_api_version']
  end

  if attributes.key?(:'last_used')
    self.last_used = attributes[:'last_used']
  end
end

Instance Attribute Details

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/launchdarkly_api/models/token.rb', line 18

def _id
  @_id
end

The location and content type of related resources



52
53
54
# File 'lib/launchdarkly_api/models/token.rb', line 52

def _links
  @_links
end

#_memberObject

Returns the value of attribute _member.



24
25
26
# File 'lib/launchdarkly_api/models/token.rb', line 24

def _member
  @_member
end

#creation_dateObject

Returns the value of attribute creation_date.



32
33
34
# File 'lib/launchdarkly_api/models/token.rb', line 32

def creation_date
  @creation_date
end

#custom_role_idsObject

A list of custom role IDs to use as access limits for the access token



37
38
39
# File 'lib/launchdarkly_api/models/token.rb', line 37

def custom_role_ids
  @custom_role_ids
end

#default_api_versionObject

The default API version for this token



55
56
57
# File 'lib/launchdarkly_api/models/token.rb', line 55

def default_api_version
  @default_api_version
end

#descriptionObject

A description for the access token



30
31
32
# File 'lib/launchdarkly_api/models/token.rb', line 30

def description
  @description
end

#inline_roleObject

An array of policy statements, with three attributes: effect, resources, actions. May be used in place of a role.



40
41
42
# File 'lib/launchdarkly_api/models/token.rb', line 40

def inline_role
  @inline_role
end

#last_modifiedObject

Returns the value of attribute last_modified.



34
35
36
# File 'lib/launchdarkly_api/models/token.rb', line 34

def last_modified
  @last_modified
end

#last_usedObject

Returns the value of attribute last_used.



57
58
59
# File 'lib/launchdarkly_api/models/token.rb', line 57

def last_used
  @last_used
end

#member_idObject

Returns the value of attribute member_id.



22
23
24
# File 'lib/launchdarkly_api/models/token.rb', line 22

def member_id
  @member_id
end

#nameObject

A human-friendly name for the access token



27
28
29
# File 'lib/launchdarkly_api/models/token.rb', line 27

def name
  @name
end

#owner_idObject

Returns the value of attribute owner_id.



20
21
22
# File 'lib/launchdarkly_api/models/token.rb', line 20

def owner_id
  @owner_id
end

#roleObject

Base role for the token



43
44
45
# File 'lib/launchdarkly_api/models/token.rb', line 43

def role
  @role
end

#service_tokenObject

Whether this is a service token or a personal token



49
50
51
# File 'lib/launchdarkly_api/models/token.rb', line 49

def service_token
  @service_token
end

#tokenObject

The token value. When creating or resetting, contains the entire token value. Otherwise, contains the last four characters.



46
47
48
# File 'lib/launchdarkly_api/models/token.rb', line 46

def token
  @token
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



82
83
84
# File 'lib/launchdarkly_api/models/token.rb', line 82

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



87
88
89
# File 'lib/launchdarkly_api/models/token.rb', line 87

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
# File 'lib/launchdarkly_api/models/token.rb', line 60

def self.attribute_map
  {
    :'_id' => :'_id',
    :'owner_id' => :'ownerId',
    :'member_id' => :'memberId',
    :'_member' => :'_member',
    :'name' => :'name',
    :'description' => :'description',
    :'creation_date' => :'creationDate',
    :'last_modified' => :'lastModified',
    :'custom_role_ids' => :'customRoleIds',
    :'inline_role' => :'inlineRole',
    :'role' => :'role',
    :'token' => :'token',
    :'service_token' => :'serviceToken',
    :'_links' => :'_links',
    :'default_api_version' => :'defaultApiVersion',
    :'last_used' => :'lastUsed'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
# File 'lib/launchdarkly_api/models/token.rb', line 361

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



114
115
116
117
# File 'lib/launchdarkly_api/models/token.rb', line 114

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/launchdarkly_api/models/token.rb', line 92

def self.openapi_types
  {
    :'_id' => :'String',
    :'owner_id' => :'String',
    :'member_id' => :'String',
    :'_member' => :'MemberSummary',
    :'name' => :'String',
    :'description' => :'String',
    :'creation_date' => :'Integer',
    :'last_modified' => :'Integer',
    :'custom_role_ids' => :'Array<String>',
    :'inline_role' => :'Array<Statement>',
    :'role' => :'String',
    :'token' => :'String',
    :'service_token' => :'Boolean',
    :'_links' => :'Hash<String, Link>',
    :'default_api_version' => :'Integer',
    :'last_used' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/launchdarkly_api/models/token.rb', line 325

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      owner_id == o.owner_id &&
      member_id == o.member_id &&
      _member == o._member &&
      name == o.name &&
      description == o.description &&
      creation_date == o.creation_date &&
      last_modified == o.last_modified &&
      custom_role_ids == o.custom_role_ids &&
      inline_role == o.inline_role &&
      role == o.role &&
      token == o.token &&
      service_token == o.service_token &&
      _links == o._links &&
      default_api_version == o.default_api_version &&
      last_used == o.last_used
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


348
349
350
# File 'lib/launchdarkly_api/models/token.rb', line 348

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



354
355
356
# File 'lib/launchdarkly_api/models/token.rb', line 354

def hash
  [_id, owner_id, member_id, _member, name, description, creation_date, last_modified, custom_role_ids, inline_role, role, token, service_token, _links, default_api_version, last_used].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
# File 'lib/launchdarkly_api/models/token.rb', line 220

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @owner_id.nil?
    invalid_properties.push('invalid value for "owner_id", owner_id cannot be nil.')
  end

  if @member_id.nil?
    invalid_properties.push('invalid value for "member_id", member_id cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @last_modified.nil?
    invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



383
384
385
386
387
388
389
390
391
392
393
394
395
# File 'lib/launchdarkly_api/models/token.rb', line 383

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



252
253
254
255
256
257
258
259
260
261
# File 'lib/launchdarkly_api/models/token.rb', line 252

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @owner_id.nil?
  return false if @member_id.nil?
  return false if @creation_date.nil?
  return false if @last_modified.nil?
  return false if @_links.nil?
  true
end