Class: LaunchDarklyApi::TokenSummary
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::TokenSummary
- Defined in:
- lib/launchdarkly_api/models/token_summary.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#ending ⇒ Object
The last few characters of the token.
-
#name ⇒ Object
The name of the token.
-
#service_token ⇒ Object
Whether this is a service token.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TokenSummary
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TokenSummary
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::TokenSummary` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::TokenSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'ending') self.ending = attributes[:'ending'] end if attributes.key?(:'service_token') self.service_token = attributes[:'service_token'] end end |
Instance Attribute Details
#_id ⇒ Object
Returns the value of attribute _id.
20 21 22 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 20 def _id @_id end |
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 18 def _links @_links end |
#ending ⇒ Object
The last few characters of the token
26 27 28 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 26 def ending @ending end |
#name ⇒ Object
The name of the token
23 24 25 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 23 def name @name end |
#service_token ⇒ Object
Whether this is a service token
29 30 31 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 29 def service_token @service_token end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 32 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'name' => :'name', :'ending' => :'ending', :'service_token' => :'serviceToken' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 150 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 53 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_id' => :'String', :'name' => :'String', :'ending' => :'String', :'service_token' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
125 126 127 128 129 130 131 132 133 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 125 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && name == o.name && ending == o.ending && service_token == o.service_token end |
#eql?(o) ⇒ Boolean
137 138 139 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 137 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
143 144 145 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 143 def hash [_links, _id, name, ending, service_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
110 111 112 113 114 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 110 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 172 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
118 119 120 121 |
# File 'lib/launchdarkly_api/models/token_summary.rb', line 118 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |