Class: LaunchDarklyApi::TriggerWorkflowRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/trigger_workflow_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ TriggerWorkflowRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::TriggerWorkflowRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::TriggerWorkflowRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  end

  if attributes.key?(:'_maintainer_id')
    self._maintainer_id = attributes[:'_maintainer_id']
  end

  if attributes.key?(:'_maintainer')
    self._maintainer = attributes[:'_maintainer']
  end

  if attributes.key?(:'enabled')
    self.enabled = attributes[:'enabled']
  end

  if attributes.key?(:'_integration_key')
    self._integration_key = attributes[:'_integration_key']
  end

  if attributes.key?(:'instructions')
    if (value = attributes[:'instructions']).is_a?(Array)
      self.instructions = value
    end
  end

  if attributes.key?(:'_last_triggered_at')
    self._last_triggered_at = attributes[:'_last_triggered_at']
  end

  if attributes.key?(:'_recent_trigger_bodies')
    if (value = attributes[:'_recent_trigger_bodies']).is_a?(Array)
      self._recent_trigger_bodies = value
    end
  end

  if attributes.key?(:'_trigger_count')
    self._trigger_count = attributes[:'_trigger_count']
  end

  if attributes.key?(:'trigger_url')
    self.trigger_url = attributes[:'trigger_url']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end
end

Instance Attribute Details

#_creation_dateObject

Returns the value of attribute _creation_date.



23
24
25
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 23

def _creation_date
  @_creation_date
end

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 18

def _id
  @_id
end

#_integration_keyObject

The unique identifier of the integration for your trigger



34
35
36
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 34

def _integration_key
  @_integration_key
end

#_last_triggered_atObject

Returns the value of attribute _last_triggered_at.



38
39
40
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 38

def _last_triggered_at
  @_last_triggered_at
end

The location and content type of related resources



50
51
52
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 50

def _links
  @_links
end

#_maintainerObject

Returns the value of attribute _maintainer.



28
29
30
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 28

def _maintainer
  @_maintainer
end

#_maintainer_idObject

The ID of the flag trigger maintainer



26
27
28
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 26

def _maintainer_id
  @_maintainer_id
end

#_recent_trigger_bodiesObject

Details on recent flag trigger requests.



41
42
43
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 41

def _recent_trigger_bodies
  @_recent_trigger_bodies
end

#_trigger_countObject

Number of times the trigger has been executed



44
45
46
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 44

def _trigger_count
  @_trigger_count
end

#_versionObject

The flag trigger version



21
22
23
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 21

def _version
  @_version
end

#enabledObject

Whether the flag trigger is currently enabled



31
32
33
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 31

def enabled
  @enabled
end

#instructionsObject

Returns the value of attribute instructions.



36
37
38
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 36

def instructions
  @instructions
end

#trigger_urlObject

The unguessable URL for this flag trigger



47
48
49
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 47

def trigger_url
  @trigger_url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 53

def self.attribute_map
  {
    :'_id' => :'_id',
    :'_version' => :'_version',
    :'_creation_date' => :'_creationDate',
    :'_maintainer_id' => :'_maintainerId',
    :'_maintainer' => :'_maintainer',
    :'enabled' => :'enabled',
    :'_integration_key' => :'_integrationKey',
    :'instructions' => :'instructions',
    :'_last_triggered_at' => :'_lastTriggeredAt',
    :'_recent_trigger_bodies' => :'_recentTriggerBodies',
    :'_trigger_count' => :'_triggerCount',
    :'trigger_url' => :'triggerURL',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 231

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 82

def self.openapi_types
  {
    :'_id' => :'String',
    :'_version' => :'Integer',
    :'_creation_date' => :'Integer',
    :'_maintainer_id' => :'String',
    :'_maintainer' => :'MemberSummary',
    :'enabled' => :'Boolean',
    :'_integration_key' => :'String',
    :'instructions' => :'Array<Hash>',
    :'_last_triggered_at' => :'Integer',
    :'_recent_trigger_bodies' => :'Array<RecentTriggerBody>',
    :'_trigger_count' => :'Integer',
    :'trigger_url' => :'String',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 198

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      _version == o._version &&
      _creation_date == o._creation_date &&
      _maintainer_id == o._maintainer_id &&
      _maintainer == o._maintainer &&
      enabled == o.enabled &&
      _integration_key == o._integration_key &&
      instructions == o.instructions &&
      _last_triggered_at == o._last_triggered_at &&
      _recent_trigger_bodies == o._recent_trigger_bodies &&
      _trigger_count == o._trigger_count &&
      trigger_url == o.trigger_url &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


218
219
220
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 218

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



224
225
226
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 224

def hash
  [_id, _version, _creation_date, _maintainer_id, _maintainer, enabled, _integration_key, instructions, _last_triggered_at, _recent_trigger_bodies, _trigger_count, trigger_url, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



183
184
185
186
187
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 183

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



253
254
255
256
257
258
259
260
261
262
263
264
265
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 253

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



191
192
193
194
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 191

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end