Class: LaunchDarklyApi::UpsertContextKindPayload

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/upsert_context_kind_payload.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpsertContextKindPayload

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 73

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::UpsertContextKindPayload` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::UpsertContextKindPayload`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'hide_in_targeting')
    self.hide_in_targeting = attributes[:'hide_in_targeting']
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end
end

Instance Attribute Details

#archivedObject

Whether the context kind is archived. Archived context kinds are unavailable for targeting.



28
29
30
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 28

def archived
  @archived
end

#descriptionObject

The context kind description



22
23
24
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 22

def description
  @description
end

#hide_in_targetingObject

Alias for archived.



25
26
27
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 25

def hide_in_targeting
  @hide_in_targeting
end

#nameObject

The context kind name



19
20
21
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 19

def name
  @name
end

#versionObject

The context kind version. If not specified when the context kind is created, defaults to 1.



31
32
33
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 31

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



45
46
47
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 45

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



50
51
52
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 50

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



34
35
36
37
38
39
40
41
42
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 34

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'hide_in_targeting' => :'hideInTargeting',
    :'archived' => :'archived',
    :'version' => :'version'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 167

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



66
67
68
69
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 66

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



55
56
57
58
59
60
61
62
63
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 55

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'hide_in_targeting' => :'Boolean',
    :'archived' => :'Boolean',
    :'version' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      hide_in_targeting == o.hide_in_targeting &&
      archived == o.archived &&
      version == o.version
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


154
155
156
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 154

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



160
161
162
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 160

def hash
  [name, description, hide_in_targeting, archived, version].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



112
113
114
115
116
117
118
119
120
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 112

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 189

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



124
125
126
127
128
# File 'lib/launchdarkly_api/models/upsert_context_kind_payload.rb', line 124

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  true
end