Class: LaunchDarklyApi::UpsertPayloadRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/upsert_payload_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UpsertPayloadRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 71

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::UpsertPayloadRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::UpsertPayloadRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'temporary')
    self.temporary = attributes[:'temporary']
  else
    self.temporary = nil
  end

  if attributes.key?(:'boolean_defaults')
    self.boolean_defaults = attributes[:'boolean_defaults']
  else
    self.boolean_defaults = nil
  end

  if attributes.key?(:'default_client_side_availability')
    self.default_client_side_availability = attributes[:'default_client_side_availability']
  else
    self.default_client_side_availability = nil
  end
end

Instance Attribute Details

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 19

def _links
  @_links
end

#boolean_defaultsObject

Returns the value of attribute boolean_defaults.



27
28
29
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 27

def boolean_defaults
  @boolean_defaults
end

#default_client_side_availabilityObject

Returns the value of attribute default_client_side_availability.



29
30
31
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 29

def default_client_side_availability
  @default_client_side_availability
end

#tagsObject

A list of default tags for each flag



22
23
24
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 22

def tags
  @tags
end

#temporaryObject

Whether the flag should be temporary by default



25
26
27
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 25

def temporary
  @temporary
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



43
44
45
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 43

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



48
49
50
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 48

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



32
33
34
35
36
37
38
39
40
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 32

def self.attribute_map
  {
    :'_links' => :'_links',
    :'tags' => :'tags',
    :'temporary' => :'temporary',
    :'boolean_defaults' => :'booleanDefaults',
    :'default_client_side_availability' => :'defaultClientSideAvailability'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 220

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



64
65
66
67
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 64

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



53
54
55
56
57
58
59
60
61
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 53

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'tags' => :'Array<String>',
    :'temporary' => :'Boolean',
    :'boolean_defaults' => :'BooleanFlagDefaults',
    :'default_client_side_availability' => :'DefaultClientSideAvailability'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      tags == o.tags &&
      temporary == o.temporary &&
      boolean_defaults == o.boolean_defaults &&
      default_client_side_availability == o.default_client_side_availability
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


207
208
209
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 207

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



213
214
215
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 213

def hash
  [_links, tags, temporary, boolean_defaults, default_client_side_availability].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 120

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @temporary.nil?
    invalid_properties.push('invalid value for "temporary", temporary cannot be nil.')
  end

  if @boolean_defaults.nil?
    invalid_properties.push('invalid value for "boolean_defaults", boolean_defaults cannot be nil.')
  end

  if @default_client_side_availability.nil?
    invalid_properties.push('invalid value for "default_client_side_availability", default_client_side_availability cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



242
243
244
245
246
247
248
249
250
251
252
253
254
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 242

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



144
145
146
147
148
149
150
151
# File 'lib/launchdarkly_api/models/upsert_payload_rep.rb', line 144

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @tags.nil?
  return false if @temporary.nil?
  return false if @boolean_defaults.nil?
  return false if @default_client_side_availability.nil?
  true
end