Class: LaunchDarklyApi::UserRecord

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/user_record.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserRecord

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/launchdarkly_api/models/user_record.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::UserRecord` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::UserRecord`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'last_ping')
    self.last_ping = attributes[:'last_ping']
  end

  if attributes.key?(:'environment_id')
    self.environment_id = attributes[:'environment_id']
  end

  if attributes.key?(:'owner_id')
    self.owner_id = attributes[:'owner_id']
  end

  if attributes.key?(:'user')
    self.user = attributes[:'user']
  end

  if attributes.key?(:'sort_value')
    self.sort_value = attributes[:'sort_value']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



33
34
35
# File 'lib/launchdarkly_api/models/user_record.rb', line 33

def _access
  @_access
end

The location and content type of related resources



31
32
33
# File 'lib/launchdarkly_api/models/user_record.rb', line 31

def _links
  @_links
end

#environment_idObject

Returns the value of attribute environment_id.



21
22
23
# File 'lib/launchdarkly_api/models/user_record.rb', line 21

def environment_id
  @environment_id
end

#last_pingObject

Timestamp of the last time this user was seen



19
20
21
# File 'lib/launchdarkly_api/models/user_record.rb', line 19

def last_ping
  @last_ping
end

#owner_idObject

Returns the value of attribute owner_id.



23
24
25
# File 'lib/launchdarkly_api/models/user_record.rb', line 23

def owner_id
  @owner_id
end

#sort_valueObject

If this record is returned as part of a list, the value used to sort the list. This is only included when the sort query parameter is specified. It is a time, in Unix milliseconds, if the sort is by lastSeen. It is a user key if the sort is by userKey.



28
29
30
# File 'lib/launchdarkly_api/models/user_record.rb', line 28

def sort_value
  @sort_value
end

#userObject

Returns the value of attribute user.



25
26
27
# File 'lib/launchdarkly_api/models/user_record.rb', line 25

def user
  @user
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/user_record.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/user_record.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



36
37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/user_record.rb', line 36

def self.attribute_map
  {
    :'last_ping' => :'lastPing',
    :'environment_id' => :'environmentId',
    :'owner_id' => :'ownerId',
    :'user' => :'user',
    :'sort_value' => :'sortValue',
    :'_links' => :'_links',
    :'_access' => :'_access'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
# File 'lib/launchdarkly_api/models/user_record.rb', line 169

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



72
73
74
75
76
# File 'lib/launchdarkly_api/models/user_record.rb', line 72

def self.openapi_nullable
  Set.new([
    :'sort_value',
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
# File 'lib/launchdarkly_api/models/user_record.rb', line 59

def self.openapi_types
  {
    :'last_ping' => :'Time',
    :'environment_id' => :'String',
    :'owner_id' => :'String',
    :'user' => :'User',
    :'sort_value' => :'Object',
    :'_links' => :'Hash<String, Link>',
    :'_access' => :'Access'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



142
143
144
145
146
147
148
149
150
151
152
# File 'lib/launchdarkly_api/models/user_record.rb', line 142

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      last_ping == o.last_ping &&
      environment_id == o.environment_id &&
      owner_id == o.owner_id &&
      user == o.user &&
      sort_value == o.sort_value &&
      _links == o._links &&
      _access == o._access
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


156
157
158
# File 'lib/launchdarkly_api/models/user_record.rb', line 156

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



162
163
164
# File 'lib/launchdarkly_api/models/user_record.rb', line 162

def hash
  [last_ping, environment_id, owner_id, user, sort_value, _links, _access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



127
128
129
130
131
# File 'lib/launchdarkly_api/models/user_record.rb', line 127

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



191
192
193
194
195
196
197
198
199
200
201
202
203
# File 'lib/launchdarkly_api/models/user_record.rb', line 191

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



135
136
137
138
# File 'lib/launchdarkly_api/models/user_record.rb', line 135

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end