Class: LaunchDarklyApi::UserSegment

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/user_segment.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ UserSegment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/launchdarkly_api/models/user_segment.rb', line 157

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::UserSegment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::UserSegment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'last_modified_date')
    self.last_modified_date = attributes[:'last_modified_date']
  else
    self.last_modified_date = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'included')
    if (value = attributes[:'included']).is_a?(Array)
      self.included = value
    end
  end

  if attributes.key?(:'excluded')
    if (value = attributes[:'excluded']).is_a?(Array)
      self.excluded = value
    end
  end

  if attributes.key?(:'included_contexts')
    if (value = attributes[:'included_contexts']).is_a?(Array)
      self.included_contexts = value
    end
  end

  if attributes.key?(:'excluded_contexts')
    if (value = attributes[:'excluded_contexts']).is_a?(Array)
      self.excluded_contexts = value
    end
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'rules')
    if (value = attributes[:'rules']).is_a?(Array)
      self.rules = value
    end
  else
    self.rules = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'deleted')
    self.deleted = attributes[:'deleted']
  else
    self.deleted = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_flags')
    if (value = attributes[:'_flags']).is_a?(Array)
      self._flags = value
    end
  end

  if attributes.key?(:'unbounded')
    self.unbounded = attributes[:'unbounded']
  end

  if attributes.key?(:'unbounded_context_kind')
    self.unbounded_context_kind = attributes[:'unbounded_context_kind']
  end

  if attributes.key?(:'generation')
    self.generation = attributes[:'generation']
  else
    self.generation = nil
  end

  if attributes.key?(:'_unbounded_metadata')
    self. = attributes[:'_unbounded_metadata']
  end

  if attributes.key?(:'_external')
    self._external = attributes[:'_external']
  end

  if attributes.key?(:'_external_link')
    self._external_link = attributes[:'_external_link']
  end

  if attributes.key?(:'_import_in_progress')
    self._import_in_progress = attributes[:'_import_in_progress']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



56
57
58
# File 'lib/launchdarkly_api/models/user_segment.rb', line 56

def _access
  @_access
end

#_externalObject

The external data store backing this segment. Only applies to synced segments.



73
74
75
# File 'lib/launchdarkly_api/models/user_segment.rb', line 73

def _external
  @_external
end

The URL for the external data store backing this segment. Only applies to synced segments.



76
77
78
# File 'lib/launchdarkly_api/models/user_segment.rb', line 76

def _external_link
  @_external_link
end

#_flagsObject

A list of flags targeting this segment. Only included when getting a single segment, using the getSegment endpoint.



59
60
61
# File 'lib/launchdarkly_api/models/user_segment.rb', line 59

def _flags
  @_flags
end

#_import_in_progressObject

Whether an import is currently in progress for the specified segment. Only applies to big segments.



79
80
81
# File 'lib/launchdarkly_api/models/user_segment.rb', line 79

def _import_in_progress
  @_import_in_progress
end

The location and content type of related resources



45
46
47
# File 'lib/launchdarkly_api/models/user_segment.rb', line 45

def _links
  @_links
end

#_unbounded_metadataObject

Returns the value of attribute _unbounded_metadata.



70
71
72
# File 'lib/launchdarkly_api/models/user_segment.rb', line 70

def 
  @_unbounded_metadata
end

#creation_dateObject

Returns the value of attribute creation_date.



27
28
29
# File 'lib/launchdarkly_api/models/user_segment.rb', line 27

def creation_date
  @creation_date
end

#deletedObject

Whether the segment has been deleted



54
55
56
# File 'lib/launchdarkly_api/models/user_segment.rb', line 54

def deleted
  @deleted
end

#descriptionObject

A description of the segment's purpose. Defaults to null and is omitted in the response if not provided.



22
23
24
# File 'lib/launchdarkly_api/models/user_segment.rb', line 22

def description
  @description
end

#excludedObject

An array of keys for excluded targets. Segment rules bypass individual excluded targets, so they will never be included based on rules. Excluded targets may still be included explicitly. This value is omitted for list-based segments over 15,000 entries, also called big segments.



38
39
40
# File 'lib/launchdarkly_api/models/user_segment.rb', line 38

def excluded
  @excluded
end

#excluded_contextsObject

Returns the value of attribute excluded_contexts.



42
43
44
# File 'lib/launchdarkly_api/models/user_segment.rb', line 42

def excluded_contexts
  @excluded_contexts
end

#generationObject

For big segments, how many times this segment has been created.



68
69
70
# File 'lib/launchdarkly_api/models/user_segment.rb', line 68

def generation
  @generation
end

#includedObject

An array of keys for included targets. Included individual targets are always segment members, regardless of segment rules. For list-based segments over 15,000 entries, also called big segments, this array is either empty or omitted.



35
36
37
# File 'lib/launchdarkly_api/models/user_segment.rb', line 35

def included
  @included
end

#included_contextsObject

Returns the value of attribute included_contexts.



40
41
42
# File 'lib/launchdarkly_api/models/user_segment.rb', line 40

def included_contexts
  @included_contexts
end

#keyObject

A unique key used to reference the segment



32
33
34
# File 'lib/launchdarkly_api/models/user_segment.rb', line 32

def key
  @key
end

#last_modified_dateObject

Returns the value of attribute last_modified_date.



29
30
31
# File 'lib/launchdarkly_api/models/user_segment.rb', line 29

def last_modified_date
  @last_modified_date
end

#nameObject

A human-friendly name for the segment.



19
20
21
# File 'lib/launchdarkly_api/models/user_segment.rb', line 19

def name
  @name
end

#rulesObject

An array of the targeting rules for this segment.



48
49
50
# File 'lib/launchdarkly_api/models/user_segment.rb', line 48

def rules
  @rules
end

#tagsObject

Tags for the segment. Defaults to an empty array.



25
26
27
# File 'lib/launchdarkly_api/models/user_segment.rb', line 25

def tags
  @tags
end

#unboundedObject

Whether this is a standard segment (false) or a big segment (true). Standard segments include rule-based segments and smaller list-based segments. Big segments include larger list-based segments and synced segments. If omitted, the segment is a standard segment.



62
63
64
# File 'lib/launchdarkly_api/models/user_segment.rb', line 62

def unbounded
  @unbounded
end

#unbounded_context_kindObject

For big segments, the targeted context kind.



65
66
67
# File 'lib/launchdarkly_api/models/user_segment.rb', line 65

def unbounded_context_kind
  @unbounded_context_kind
end

#versionObject

Version of the segment



51
52
53
# File 'lib/launchdarkly_api/models/user_segment.rb', line 51

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



111
112
113
# File 'lib/launchdarkly_api/models/user_segment.rb', line 111

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



116
117
118
# File 'lib/launchdarkly_api/models/user_segment.rb', line 116

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
# File 'lib/launchdarkly_api/models/user_segment.rb', line 82

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'tags' => :'tags',
    :'creation_date' => :'creationDate',
    :'last_modified_date' => :'lastModifiedDate',
    :'key' => :'key',
    :'included' => :'included',
    :'excluded' => :'excluded',
    :'included_contexts' => :'includedContexts',
    :'excluded_contexts' => :'excludedContexts',
    :'_links' => :'_links',
    :'rules' => :'rules',
    :'version' => :'version',
    :'deleted' => :'deleted',
    :'_access' => :'_access',
    :'_flags' => :'_flags',
    :'unbounded' => :'unbounded',
    :'unbounded_context_kind' => :'unboundedContextKind',
    :'generation' => :'generation',
    :'_unbounded_metadata' => :'_unboundedMetadata',
    :'_external' => :'_external',
    :'_external_link' => :'_externalLink',
    :'_import_in_progress' => :'_importInProgress'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



510
511
512
513
514
515
516
517
518
519
520
521
522
523
524
525
526
527
528
# File 'lib/launchdarkly_api/models/user_segment.rb', line 510

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



150
151
152
153
# File 'lib/launchdarkly_api/models/user_segment.rb', line 150

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/launchdarkly_api/models/user_segment.rb', line 121

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'tags' => :'Array<String>',
    :'creation_date' => :'Integer',
    :'last_modified_date' => :'Integer',
    :'key' => :'String',
    :'included' => :'Array<String>',
    :'excluded' => :'Array<String>',
    :'included_contexts' => :'Array<SegmentTarget>',
    :'excluded_contexts' => :'Array<SegmentTarget>',
    :'_links' => :'Hash<String, Link>',
    :'rules' => :'Array<UserSegmentRule>',
    :'version' => :'Integer',
    :'deleted' => :'Boolean',
    :'_access' => :'Access',
    :'_flags' => :'Array<FlagListingRep>',
    :'unbounded' => :'Boolean',
    :'unbounded_context_kind' => :'String',
    :'generation' => :'Integer',
    :'_unbounded_metadata' => :'SegmentMetadata',
    :'_external' => :'String',
    :'_external_link' => :'String',
    :'_import_in_progress' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/launchdarkly_api/models/user_segment.rb', line 467

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      tags == o.tags &&
      creation_date == o.creation_date &&
      last_modified_date == o.last_modified_date &&
      key == o.key &&
      included == o.included &&
      excluded == o.excluded &&
      included_contexts == o.included_contexts &&
      excluded_contexts == o.excluded_contexts &&
      _links == o._links &&
      rules == o.rules &&
      version == o.version &&
      deleted == o.deleted &&
      _access == o._access &&
      _flags == o._flags &&
      unbounded == o.unbounded &&
      unbounded_context_kind == o.unbounded_context_kind &&
      generation == o.generation &&
       == o. &&
      _external == o._external &&
      _external_link == o._external_link &&
      _import_in_progress == o._import_in_progress
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


497
498
499
# File 'lib/launchdarkly_api/models/user_segment.rb', line 497

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



503
504
505
# File 'lib/launchdarkly_api/models/user_segment.rb', line 503

def hash
  [name, description, tags, creation_date, last_modified_date, key, included, excluded, included_contexts, excluded_contexts, _links, rules, version, deleted, _access, _flags, unbounded, unbounded_context_kind, generation, , _external, _external_link, _import_in_progress].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/launchdarkly_api/models/user_segment.rb', line 302

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @last_modified_date.nil?
    invalid_properties.push('invalid value for "last_modified_date", last_modified_date cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @rules.nil?
    invalid_properties.push('invalid value for "rules", rules cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @deleted.nil?
    invalid_properties.push('invalid value for "deleted", deleted cannot be nil.')
  end

  if @generation.nil?
    invalid_properties.push('invalid value for "generation", generation cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



532
533
534
535
536
537
538
539
540
541
542
543
544
# File 'lib/launchdarkly_api/models/user_segment.rb', line 532

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



350
351
352
353
354
355
356
357
358
359
360
361
362
363
# File 'lib/launchdarkly_api/models/user_segment.rb', line 350

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @tags.nil?
  return false if @creation_date.nil?
  return false if @last_modified_date.nil?
  return false if @key.nil?
  return false if @_links.nil?
  return false if @rules.nil?
  return false if @version.nil?
  return false if @deleted.nil?
  return false if @generation.nil?
  true
end