Class: LaunchDarklyApi::VariationSummary

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/variation_summary.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ VariationSummary

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 80

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::VariationSummary` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::VariationSummary`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'rules')
    self.rules = attributes[:'rules']
  else
    self.rules = nil
  end

  if attributes.key?(:'null_rules')
    self.null_rules = attributes[:'null_rules']
  else
    self.null_rules = nil
  end

  if attributes.key?(:'targets')
    self.targets = attributes[:'targets']
  else
    self.targets = nil
  end

  if attributes.key?(:'context_targets')
    self.context_targets = attributes[:'context_targets']
  else
    self.context_targets = nil
  end

  if attributes.key?(:'is_fallthrough')
    self.is_fallthrough = attributes[:'is_fallthrough']
  end

  if attributes.key?(:'is_off')
    self.is_off = attributes[:'is_off']
  end

  if attributes.key?(:'rollout')
    self.rollout = attributes[:'rollout']
  end

  if attributes.key?(:'bucket_by')
    self.bucket_by = attributes[:'bucket_by']
  end
end

Instance Attribute Details

#bucket_byObject

Returns the value of attribute bucket_by.



32
33
34
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 32

def bucket_by
  @bucket_by
end

#context_targetsObject

Returns the value of attribute context_targets.



24
25
26
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 24

def context_targets
  @context_targets
end

#is_fallthroughObject

Returns the value of attribute is_fallthrough.



26
27
28
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 26

def is_fallthrough
  @is_fallthrough
end

#is_offObject

Returns the value of attribute is_off.



28
29
30
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 28

def is_off
  @is_off
end

#null_rulesObject

Returns the value of attribute null_rules.



20
21
22
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 20

def null_rules
  @null_rules
end

#rolloutObject

Returns the value of attribute rollout.



30
31
32
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 30

def rollout
  @rollout
end

#rulesObject

Returns the value of attribute rules.



18
19
20
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 18

def rules
  @rules
end

#targetsObject

Returns the value of attribute targets.



22
23
24
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 22

def targets
  @targets
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



49
50
51
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 49

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



54
55
56
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 54

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



35
36
37
38
39
40
41
42
43
44
45
46
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 35

def self.attribute_map
  {
    :'rules' => :'rules',
    :'null_rules' => :'nullRules',
    :'targets' => :'targets',
    :'context_targets' => :'contextTargets',
    :'is_fallthrough' => :'isFallthrough',
    :'is_off' => :'isOff',
    :'rollout' => :'rollout',
    :'bucket_by' => :'bucketBy'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 240

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



73
74
75
76
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 73

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



59
60
61
62
63
64
65
66
67
68
69
70
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 59

def self.openapi_types
  {
    :'rules' => :'Integer',
    :'null_rules' => :'Integer',
    :'targets' => :'Integer',
    :'context_targets' => :'Integer',
    :'is_fallthrough' => :'Boolean',
    :'is_off' => :'Boolean',
    :'rollout' => :'Integer',
    :'bucket_by' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 212

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      rules == o.rules &&
      null_rules == o.null_rules &&
      targets == o.targets &&
      context_targets == o.context_targets &&
      is_fallthrough == o.is_fallthrough &&
      is_off == o.is_off &&
      rollout == o.rollout &&
      bucket_by == o.bucket_by
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


227
228
229
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 227

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



233
234
235
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 233

def hash
  [rules, null_rules, targets, context_targets, is_fallthrough, is_off, rollout, bucket_by].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 137

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @rules.nil?
    invalid_properties.push('invalid value for "rules", rules cannot be nil.')
  end

  if @null_rules.nil?
    invalid_properties.push('invalid value for "null_rules", null_rules cannot be nil.')
  end

  if @targets.nil?
    invalid_properties.push('invalid value for "targets", targets cannot be nil.')
  end

  if @context_targets.nil?
    invalid_properties.push('invalid value for "context_targets", context_targets cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 262

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



161
162
163
164
165
166
167
168
# File 'lib/launchdarkly_api/models/variation_summary.rb', line 161

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @rules.nil?
  return false if @null_rules.nil?
  return false if @targets.nil?
  return false if @context_targets.nil?
  true
end