Class: LaunchDarklyApi::ViewLinkRequestSegmentIdentifiers

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ViewLinkRequestSegmentIdentifiers

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 68

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ViewLinkRequestSegmentIdentifiers` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ViewLinkRequestSegmentIdentifiers`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'segment_identifiers')
    if (value = attributes[:'segment_identifiers']).is_a?(Array)
      self.segment_identifiers = value
    end
  else
    self.segment_identifiers = nil
  end

  if attributes.key?(:'filter')
    self.filter = attributes[:'filter']
  end

  if attributes.key?(:'environment_id')
    self.environment_id = attributes[:'environment_id']
  end

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  else
    self.comment = ''
  end
end

Instance Attribute Details

#commentObject

Optional comment for the link/unlink operation



28
29
30
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 28

def comment
  @comment
end

#environment_idObject

Required when using filter for segment resources. Specifies which environment to query for segments matching the filter. Ignored when only using explicit segmentIdentifiers (since each identifier contains its own environmentId).



25
26
27
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 25

def environment_id
  @environment_id
end

#filterObject

Optional filter string to determine which resources should be linked. Resources only need to match either the filter or explicitly-listed keys to be linked (union). Uses the same queryfilter syntax as the segments list endpoint. Supported filters for segments: query, tags, keys, excludedKeys, unbounded, external, view, type



22
23
24
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 22

def filter
  @filter
end

#segment_identifiersObject

Identifiers of the segments to link/unlink (environmentId and segmentKey)



19
20
21
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 19

def segment_identifiers
  @segment_identifiers
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



41
42
43
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 41

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



46
47
48
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 46

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



31
32
33
34
35
36
37
38
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 31

def self.attribute_map
  {
    :'segment_identifiers' => :'segmentIdentifiers',
    :'filter' => :'filter',
    :'environment_id' => :'environmentId',
    :'comment' => :'comment'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 161

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



61
62
63
64
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 61

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



51
52
53
54
55
56
57
58
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 51

def self.openapi_types
  {
    :'segment_identifiers' => :'Array<ViewLinkRequestSegmentIdentifier>',
    :'filter' => :'String',
    :'environment_id' => :'String',
    :'comment' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



137
138
139
140
141
142
143
144
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 137

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      segment_identifiers == o.segment_identifiers &&
      filter == o.filter &&
      environment_id == o.environment_id &&
      comment == o.comment
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


148
149
150
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 148

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



154
155
156
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 154

def hash
  [segment_identifiers, filter, environment_id, comment].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



107
108
109
110
111
112
113
114
115
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 107

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @segment_identifiers.nil?
    invalid_properties.push('invalid value for "segment_identifiers", segment_identifiers cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



183
184
185
186
187
188
189
190
191
192
193
194
195
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 183

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



119
120
121
122
123
# File 'lib/launchdarkly_api/models/view_link_request_segment_identifiers.rb', line 119

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @segment_identifiers.nil?
  true
end