Class: LaunchDarklyApi::ViewLinkedResource
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ViewLinkedResource
- Defined in:
- lib/launchdarkly_api/models/view_linked_resource.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#environment_id ⇒ Object
Environment ID of the resource (only present for segments).
-
#environment_key ⇒ Object
Environment Key of the resource (only present for segments).
-
#linked_at ⇒ Object
Returns the value of attribute linked_at.
-
#resource_details ⇒ Object
Returns the value of attribute resource_details.
-
#resource_key ⇒ Object
Key of the resource (flag or segment).
-
#resource_type ⇒ Object
Returns the value of attribute resource_type.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ViewLinkedResource
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ViewLinkedResource
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ViewLinkedResource` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ViewLinkedResource`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') self._links = attributes[:'_links'] else self._links = nil end if attributes.key?(:'resource_key') self.resource_key = attributes[:'resource_key'] else self.resource_key = nil end if attributes.key?(:'environment_id') self.environment_id = attributes[:'environment_id'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] end if attributes.key?(:'resource_type') self.resource_type = attributes[:'resource_type'] else self.resource_type = nil end if attributes.key?(:'linked_at') self.linked_at = attributes[:'linked_at'] else self.linked_at = nil end if attributes.key?(:'resource_details') self.resource_details = attributes[:'resource_details'] end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 18 def _links @_links end |
#environment_id ⇒ Object
Environment ID of the resource (only present for segments)
24 25 26 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 24 def environment_id @environment_id end |
#environment_key ⇒ Object
Environment Key of the resource (only present for segments)
27 28 29 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 27 def environment_key @environment_key end |
#linked_at ⇒ Object
Returns the value of attribute linked_at.
31 32 33 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 31 def linked_at @linked_at end |
#resource_details ⇒ Object
Returns the value of attribute resource_details.
33 34 35 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 33 def resource_details @resource_details end |
#resource_key ⇒ Object
Key of the resource (flag or segment)
21 22 23 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 21 def resource_key @resource_key end |
#resource_type ⇒ Object
Returns the value of attribute resource_type.
29 30 31 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 29 def resource_type @resource_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 58 def self.attribute_map { :'_links' => :'_links', :'resource_key' => :'resourceKey', :'environment_id' => :'environmentId', :'environment_key' => :'environmentKey', :'resource_type' => :'resourceType', :'linked_at' => :'linkedAt', :'resource_details' => :'resourceDetails' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 258 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 81 def self.openapi_types { :'_links' => :'ParentAndSelfLinks', :'resource_key' => :'String', :'environment_id' => :'String', :'environment_key' => :'String', :'resource_type' => :'String', :'linked_at' => :'Integer', :'resource_details' => :'ViewLinkedResourceDetails' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && resource_key == o.resource_key && environment_id == o.environment_id && environment_key == o.environment_key && resource_type == o.resource_type && linked_at == o.linked_at && resource_details == o.resource_details end |
#eql?(o) ⇒ Boolean
245 246 247 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 245 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
251 252 253 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 251 def hash [_links, resource_key, environment_id, environment_key, resource_type, linked_at, resource_details].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 154 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @resource_key.nil? invalid_properties.push('invalid value for "resource_key", resource_key cannot be nil.') end if @resource_type.nil? invalid_properties.push('invalid value for "resource_type", resource_type cannot be nil.') end if @linked_at.nil? invalid_properties.push('invalid value for "linked_at", linked_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
280 281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 280 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
178 179 180 181 182 183 184 185 186 187 |
# File 'lib/launchdarkly_api/models/view_linked_resource.rb', line 178 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_links.nil? return false if @resource_key.nil? return false if @resource_type.nil? resource_type_validator = EnumAttributeValidator.new('String', ["flag", "segment", "aiConfig"]) return false unless resource_type_validator.valid?(@resource_type) return false if @linked_at.nil? true end |