Class: LaunchDarklyApi::ViewPatch

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/view_patch.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ViewPatch

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
# File 'lib/launchdarkly_api/models/view_patch.rb', line 83

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ViewPatch` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ViewPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'generate_sdk_keys')
    self.generate_sdk_keys = attributes[:'generate_sdk_keys']
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end
end

Instance Attribute Details

#archivedObject

Whether or not the view is archived



37
38
39
# File 'lib/launchdarkly_api/models/view_patch.rb', line 37

def archived
  @archived
end

#descriptionObject

Optional detailed description of the view



22
23
24
# File 'lib/launchdarkly_api/models/view_patch.rb', line 22

def description
  @description
end

#generate_sdk_keysObject

Whether to generate SDK keys for this view



25
26
27
# File 'lib/launchdarkly_api/models/view_patch.rb', line 25

def generate_sdk_keys
  @generate_sdk_keys
end

#maintainer_idObject

Member ID of the maintainer for this view. Only one of ‘maintainerId` or `maintainerTeamKey` can be specified.



28
29
30
# File 'lib/launchdarkly_api/models/view_patch.rb', line 28

def maintainer_id
  @maintainer_id
end

#maintainer_team_keyObject

Key of the maintainer team for this view. Only one of ‘maintainerId` or `maintainerTeamKey` can be specified.



31
32
33
# File 'lib/launchdarkly_api/models/view_patch.rb', line 31

def maintainer_team_key
  @maintainer_team_key
end

#nameObject

Human-readable name for the view



19
20
21
# File 'lib/launchdarkly_api/models/view_patch.rb', line 19

def name
  @name
end

#tagsObject

Tags associated with this view



34
35
36
# File 'lib/launchdarkly_api/models/view_patch.rb', line 34

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



53
54
55
# File 'lib/launchdarkly_api/models/view_patch.rb', line 53

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



58
59
60
# File 'lib/launchdarkly_api/models/view_patch.rb', line 58

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



40
41
42
43
44
45
46
47
48
49
50
# File 'lib/launchdarkly_api/models/view_patch.rb', line 40

def self.attribute_map
  {
    :'name' => :'name',
    :'description' => :'description',
    :'generate_sdk_keys' => :'generateSdkKeys',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey',
    :'tags' => :'tags',
    :'archived' => :'archived'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/launchdarkly_api/models/view_patch.rb', line 172

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



76
77
78
79
# File 'lib/launchdarkly_api/models/view_patch.rb', line 76

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



63
64
65
66
67
68
69
70
71
72
73
# File 'lib/launchdarkly_api/models/view_patch.rb', line 63

def self.openapi_types
  {
    :'name' => :'String',
    :'description' => :'String',
    :'generate_sdk_keys' => :'Boolean',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String',
    :'tags' => :'Array<String>',
    :'archived' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



145
146
147
148
149
150
151
152
153
154
155
# File 'lib/launchdarkly_api/models/view_patch.rb', line 145

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      description == o.description &&
      generate_sdk_keys == o.generate_sdk_keys &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key &&
      tags == o.tags &&
      archived == o.archived
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


159
160
161
# File 'lib/launchdarkly_api/models/view_patch.rb', line 159

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



165
166
167
# File 'lib/launchdarkly_api/models/view_patch.rb', line 165

def hash
  [name, description, generate_sdk_keys, maintainer_id, maintainer_team_key, tags, archived].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



130
131
132
133
134
# File 'lib/launchdarkly_api/models/view_patch.rb', line 130

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



194
195
196
197
198
199
200
201
202
203
204
205
206
# File 'lib/launchdarkly_api/models/view_patch.rb', line 194

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



138
139
140
141
# File 'lib/launchdarkly_api/models/view_patch.rb', line 138

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  true
end