Class: LaunchDarklyApi::WarehouseDestinationSetupScriptRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::WarehouseDestinationSetupScriptRep
- Defined in:
- lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb
Instance Attribute Summary collapse
-
#public_key ⇒ Object
The RSA public key (Snowflake only) to store as the destination public_key.
-
#public_key_pkcs8 ⇒ Object
The PKCS8 RSA public key (Snowflake only).
-
#redshift_iam_permissions_policy ⇒ Object
For Redshift, present only when clusterIdentifier, clusterRegion, and clusterAwsAccountId are supplied in the request body.
-
#redshift_iam_trust_policy ⇒ Object
For Redshift, present only when clusterIdentifier, clusterRegion, and clusterAwsAccountId are supplied in the request body.
-
#s3_bucket_name ⇒ Object
The auto-generated S3 staging bucket name (ClickHouse and Redshift).
-
#script ⇒ Object
The SQL setup script to run in your data warehouse.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WarehouseDestinationSetupScriptRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WarehouseDestinationSetupScriptRep
Initializes the object
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 78 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::WarehouseDestinationSetupScriptRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::WarehouseDestinationSetupScriptRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'script') self.script = attributes[:'script'] end if attributes.key?(:'public_key') self.public_key = attributes[:'public_key'] end if attributes.key?(:'public_key_pkcs8') self.public_key_pkcs8 = attributes[:'public_key_pkcs8'] end if attributes.key?(:'redshift_iam_permissions_policy') self. = attributes[:'redshift_iam_permissions_policy'] end if attributes.key?(:'redshift_iam_trust_policy') self.redshift_iam_trust_policy = attributes[:'redshift_iam_trust_policy'] end if attributes.key?(:'s3_bucket_name') self.s3_bucket_name = attributes[:'s3_bucket_name'] end end |
Instance Attribute Details
#public_key ⇒ Object
The RSA public key (Snowflake only) to store as the destination public_key
22 23 24 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 22 def public_key @public_key end |
#public_key_pkcs8 ⇒ Object
The PKCS8 RSA public key (Snowflake only)
25 26 27 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 25 def public_key_pkcs8 @public_key_pkcs8 end |
#redshift_iam_permissions_policy ⇒ Object
For Redshift, present only when clusterIdentifier, clusterRegion, and clusterAwsAccountId are supplied in the request body.
28 29 30 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 28 def @redshift_iam_permissions_policy end |
#redshift_iam_trust_policy ⇒ Object
For Redshift, present only when clusterIdentifier, clusterRegion, and clusterAwsAccountId are supplied in the request body.
31 32 33 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 31 def redshift_iam_trust_policy @redshift_iam_trust_policy end |
#s3_bucket_name ⇒ Object
The auto-generated S3 staging bucket name (ClickHouse and Redshift)
34 35 36 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 34 def s3_bucket_name @s3_bucket_name end |
#script ⇒ Object
The SQL setup script to run in your data warehouse
19 20 21 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 19 def script @script end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
49 50 51 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 49 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
54 55 56 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 54 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
37 38 39 40 41 42 43 44 45 46 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 37 def self.attribute_map { :'script' => :'script', :'public_key' => :'publicKey', :'public_key_pkcs8' => :'publicKeyPkcs8', :'redshift_iam_permissions_policy' => :'redshiftIAMPermissionsPolicy', :'redshift_iam_trust_policy' => :'redshiftIAMTrustPolicy', :'s3_bucket_name' => :'s3BucketName' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 160 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
71 72 73 74 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 71 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 59 def self.openapi_types { :'script' => :'String', :'public_key' => :'String', :'public_key_pkcs8' => :'String', :'redshift_iam_permissions_policy' => :'String', :'redshift_iam_trust_policy' => :'String', :'s3_bucket_name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
134 135 136 137 138 139 140 141 142 143 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 134 def ==(o) return true if self.equal?(o) self.class == o.class && script == o.script && public_key == o.public_key && public_key_pkcs8 == o.public_key_pkcs8 && == o. && redshift_iam_trust_policy == o.redshift_iam_trust_policy && s3_bucket_name == o.s3_bucket_name end |
#eql?(o) ⇒ Boolean
147 148 149 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 147 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
153 154 155 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 153 def hash [script, public_key, public_key_pkcs8, , redshift_iam_trust_policy, s3_bucket_name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
119 120 121 122 123 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 119 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
182 183 184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 182 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
127 128 129 130 |
# File 'lib/launchdarkly_api/models/warehouse_destination_setup_script_rep.rb', line 127 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |