Class: LaunchDarklyApi::Webhook

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/webhook.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Webhook

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
# File 'lib/launchdarkly_api/models/webhook.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Webhook` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Webhook`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'url')
    self.url = attributes[:'url']
  else
    self.url = nil
  end

  if attributes.key?(:'secret')
    self.secret = attributes[:'secret']
  end

  if attributes.key?(:'statements')
    if (value = attributes[:'statements']).is_a?(Array)
      self.statements = value
    end
  end

  if attributes.key?(:'on')
    self.on = attributes[:'on']
  else
    self.on = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



42
43
44
# File 'lib/launchdarkly_api/models/webhook.rb', line 42

def _access
  @_access
end

#_idObject

The ID of this webhook



22
23
24
# File 'lib/launchdarkly_api/models/webhook.rb', line 22

def _id
  @_id
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/webhook.rb', line 19

def _links
  @_links
end

#nameObject

A human-readable name for this webhook



25
26
27
# File 'lib/launchdarkly_api/models/webhook.rb', line 25

def name
  @name
end

#onObject

Whether or not this webhook is enabled



37
38
39
# File 'lib/launchdarkly_api/models/webhook.rb', line 37

def on
  @on
end

#secretObject

The secret for this webhook



31
32
33
# File 'lib/launchdarkly_api/models/webhook.rb', line 31

def secret
  @secret
end

#statementsObject

Represents a Custom role policy, defining a resource kinds filter the webhook responds to.



34
35
36
# File 'lib/launchdarkly_api/models/webhook.rb', line 34

def statements
  @statements
end

#tagsObject

List of tags for this webhook



40
41
42
# File 'lib/launchdarkly_api/models/webhook.rb', line 40

def tags
  @tags
end

#urlObject

The URL to which LaunchDarkly sends an HTTP POST payload for this webhook



28
29
30
# File 'lib/launchdarkly_api/models/webhook.rb', line 28

def url
  @url
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



60
61
62
# File 'lib/launchdarkly_api/models/webhook.rb', line 60

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



65
66
67
# File 'lib/launchdarkly_api/models/webhook.rb', line 65

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
# File 'lib/launchdarkly_api/models/webhook.rb', line 45

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'name' => :'name',
    :'url' => :'url',
    :'secret' => :'secret',
    :'statements' => :'statements',
    :'on' => :'on',
    :'tags' => :'tags',
    :'_access' => :'_access'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
# File 'lib/launchdarkly_api/models/webhook.rb', line 280

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/launchdarkly_api/models/webhook.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/launchdarkly_api/models/webhook.rb', line 70

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'name' => :'String',
    :'url' => :'String',
    :'secret' => :'String',
    :'statements' => :'Array<Statement>',
    :'on' => :'Boolean',
    :'tags' => :'Array<String>',
    :'_access' => :'Access'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



251
252
253
254
255
256
257
258
259
260
261
262
263
# File 'lib/launchdarkly_api/models/webhook.rb', line 251

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      name == o.name &&
      url == o.url &&
      secret == o.secret &&
      statements == o.statements &&
      on == o.on &&
      tags == o.tags &&
      _access == o._access
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


267
268
269
# File 'lib/launchdarkly_api/models/webhook.rb', line 267

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



273
274
275
# File 'lib/launchdarkly_api/models/webhook.rb', line 273

def hash
  [_links, _id, name, url, secret, statements, on, tags, _access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/launchdarkly_api/models/webhook.rb', line 161

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @url.nil?
    invalid_properties.push('invalid value for "url", url cannot be nil.')
  end

  if @on.nil?
    invalid_properties.push('invalid value for "on", on cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/launchdarkly_api/models/webhook.rb', line 302

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
195
196
197
# File 'lib/launchdarkly_api/models/webhook.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @url.nil?
  return false if @on.nil?
  return false if @tags.nil?
  true
end