Class: LaunchDarklyApi::WebhookPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::WebhookPost
- Defined in:
- lib/launchdarkly_api/models/webhook_post.rb
Instance Attribute Summary collapse
-
#name ⇒ Object
A human-readable name for your webhook.
-
#on ⇒ Object
Whether or not this webhook is enabled.
-
#secret ⇒ Object
If sign is true, and the secret attribute is omitted, LaunchDarkly automatically generates a secret for you.
-
#sign ⇒ Object
If sign is false, the webhook does not include a signature header, and the secret can be omitted.
-
#statements ⇒ Object
Returns the value of attribute statements.
-
#tags ⇒ Object
List of tags for this webhook.
-
#url ⇒ Object
The URL of the remote webhook.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ WebhookPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ WebhookPost
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::WebhookPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::WebhookPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'secret') self.secret = attributes[:'secret'] end if attributes.key?(:'statements') if (value = attributes[:'statements']).is_a?(Array) self.statements = value end end if attributes.key?(:'sign') self.sign = attributes[:'sign'] else self.sign = nil end if attributes.key?(:'on') self.on = attributes[:'on'] else self.on = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end end |
Instance Attribute Details
#name ⇒ Object
A human-readable name for your webhook
19 20 21 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 19 def name @name end |
#on ⇒ Object
Whether or not this webhook is enabled.
33 34 35 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 33 def on @on end |
#secret ⇒ Object
If sign is true, and the secret attribute is omitted, LaunchDarkly automatically generates a secret for you.
25 26 27 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 25 def secret @secret end |
#sign ⇒ Object
If sign is false, the webhook does not include a signature header, and the secret can be omitted.
30 31 32 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 30 def sign @sign end |
#statements ⇒ Object
Returns the value of attribute statements.
27 28 29 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 27 def statements @statements end |
#tags ⇒ Object
List of tags for this webhook
36 37 38 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 36 def @tags end |
#url ⇒ Object
The URL of the remote webhook
22 23 24 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 22 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 39 def self.attribute_map { :'name' => :'name', :'url' => :'url', :'secret' => :'secret', :'statements' => :'statements', :'sign' => :'sign', :'on' => :'on', :'tags' => :'tags' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 224 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 62 def self.openapi_types { :'name' => :'String', :'url' => :'String', :'secret' => :'String', :'statements' => :'Array<StatementPost>', :'sign' => :'Boolean', :'on' => :'Boolean', :'tags' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 197 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && url == o.url && secret == o.secret && statements == o.statements && sign == o.sign && on == o.on && == o. end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 217 def hash [name, url, secret, statements, sign, on, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 137 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end if @sign.nil? invalid_properties.push('invalid value for "sign", sign cannot be nil.') end if @on.nil? invalid_properties.push('invalid value for "on", on cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 163 |
# File 'lib/launchdarkly_api/models/webhook_post.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @url.nil? return false if @sign.nil? return false if @on.nil? true end |