Class: LaunchDarklyApi::WorkflowTemplatesApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::WorkflowTemplatesApi
- Defined in:
- lib/launchdarkly_api/api/workflow_templates_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_workflow_template(create_workflow_template_input, opts = {}) ⇒ WorkflowTemplateOutput
Create workflow template > ### Workflows are in maintenance mode > > The workflows feature is in maintenance mode, and is planned for future deprecation at a date not yet specified.
-
#create_workflow_template_with_http_info(create_workflow_template_input, opts = {}) ⇒ Array<(WorkflowTemplateOutput, Integer, Hash)>
Create workflow template > ### Workflows are in maintenance mode > > The workflows feature is in maintenance mode, and is planned for future deprecation at a date not yet specified.
-
#delete_workflow_template(template_key, opts = {}) ⇒ nil
Delete workflow template Delete a workflow template.
-
#delete_workflow_template_with_http_info(template_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete workflow template Delete a workflow template.
-
#get_workflow_templates(opts = {}) ⇒ WorkflowTemplatesListingOutputRep
Get workflow templates Get workflow templates belonging to an account, or can optionally return templates_endpoints.workflowTemplateSummariesListingOutputRep when summary query param is true.
-
#get_workflow_templates_with_http_info(opts = {}) ⇒ Array<(WorkflowTemplatesListingOutputRep, Integer, Hash)>
Get workflow templates Get workflow templates belonging to an account, or can optionally return templates_endpoints.workflowTemplateSummariesListingOutputRep when summary query param is true.
-
#initialize(api_client = ApiClient.default) ⇒ WorkflowTemplatesApi
constructor
A new instance of WorkflowTemplatesApi.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ WorkflowTemplatesApi
Returns a new instance of WorkflowTemplatesApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_workflow_template(create_workflow_template_input, opts = {}) ⇒ WorkflowTemplateOutput
Create workflow template
Workflows are in maintenance mode > > The workflows feature is in maintenance mode, and is planned for future deprecation at a date not yet specified. We will work with existing customers using workflows to migrate to a replacement solution when deprecation occurs. Create a template for a feature flag workflow.
27 28 29 30 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 27 def create_workflow_template(create_workflow_template_input, opts = {}) data, _status_code, _headers = create_workflow_template_with_http_info(create_workflow_template_input, opts) data end |
#create_workflow_template_with_http_info(create_workflow_template_input, opts = {}) ⇒ Array<(WorkflowTemplateOutput, Integer, Hash)>
Create workflow template > ### Workflows are in maintenance mode > > The workflows feature is in maintenance mode, and is planned for future deprecation at a date not yet specified. We will work with existing customers using workflows to migrate to a replacement solution when deprecation occurs. Create a template for a feature flag workflow.
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 37 def create_workflow_template_with_http_info(create_workflow_template_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowTemplatesApi.create_workflow_template ...' end # verify the required parameter 'create_workflow_template_input' is set if @api_client.config.client_side_validation && create_workflow_template_input.nil? fail ArgumentError, "Missing the required parameter 'create_workflow_template_input' when calling WorkflowTemplatesApi.create_workflow_template" end # resource path local_var_path = '/api/v2/templates' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(create_workflow_template_input) # return_type return_type = opts[:debug_return_type] || 'WorkflowTemplateOutput' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"WorkflowTemplatesApi.create_workflow_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowTemplatesApi#create_workflow_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_workflow_template(template_key, opts = {}) ⇒ nil
Delete workflow template Delete a workflow template
95 96 97 98 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 95 def delete_workflow_template(template_key, opts = {}) delete_workflow_template_with_http_info(template_key, opts) nil end |
#delete_workflow_template_with_http_info(template_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete workflow template Delete a workflow template
105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 105 def delete_workflow_template_with_http_info(template_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowTemplatesApi.delete_workflow_template ...' end # verify the required parameter 'template_key' is set if @api_client.config.client_side_validation && template_key.nil? fail ArgumentError, "Missing the required parameter 'template_key' when calling WorkflowTemplatesApi.delete_workflow_template" end # resource path local_var_path = '/api/v2/templates/{templateKey}'.sub('{' + 'templateKey' + '}', CGI.escape(template_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"WorkflowTemplatesApi.delete_workflow_template", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowTemplatesApi#delete_workflow_template\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_workflow_templates(opts = {}) ⇒ WorkflowTemplatesListingOutputRep
Get workflow templates Get workflow templates belonging to an account, or can optionally return templates_endpoints.workflowTemplateSummariesListingOutputRep when summary query param is true
159 160 161 162 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 159 def get_workflow_templates(opts = {}) data, _status_code, _headers = get_workflow_templates_with_http_info(opts) data end |
#get_workflow_templates_with_http_info(opts = {}) ⇒ Array<(WorkflowTemplatesListingOutputRep, Integer, Hash)>
Get workflow templates Get workflow templates belonging to an account, or can optionally return templates_endpoints.workflowTemplateSummariesListingOutputRep when summary query param is true
170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/launchdarkly_api/api/workflow_templates_api.rb', line 170 def get_workflow_templates_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: WorkflowTemplatesApi.get_workflow_templates ...' end # resource path local_var_path = '/api/v2/templates' # query parameters query_params = opts[:query_params] || {} query_params[:'summary'] = opts[:'summary'] if !opts[:'summary'].nil? query_params[:'search'] = opts[:'search'] if !opts[:'search'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'WorkflowTemplatesListingOutputRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"WorkflowTemplatesApi.get_workflow_templates", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: WorkflowTemplatesApi#get_workflow_templates\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |