Class: LaunchDarklyApi::AIConfig

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/ai_config.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AIConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/launchdarkly_api/models/ai_config.rb', line 133

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'_maintainer')
    self._maintainer = attributes[:'_maintainer']
  end

  if attributes.key?(:'mode')
    self.mode = attributes[:'mode']
  else
    self.mode = 'completion'
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'variations')
    if (value = attributes[:'variations']).is_a?(Array)
      self.variations = value
    end
  else
    self.variations = nil
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  else
    self.created_at = nil
  end

  if attributes.key?(:'updated_at')
    self.updated_at = attributes[:'updated_at']
  else
    self.updated_at = nil
  end

  if attributes.key?(:'evaluation_metric_key')
    self.evaluation_metric_key = attributes[:'evaluation_metric_key']
  end

  if attributes.key?(:'evaluation_metric_keys')
    if (value = attributes[:'evaluation_metric_keys']).is_a?(Array)
      self.evaluation_metric_keys = value
    end
  end

  if attributes.key?(:'is_inverted')
    self.is_inverted = attributes[:'is_inverted']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



18
19
20
# File 'lib/launchdarkly_api/models/ai_config.rb', line 18

def _access
  @_access
end

Returns the value of attribute _links.



20
21
22
# File 'lib/launchdarkly_api/models/ai_config.rb', line 20

def _links
  @_links
end

#_maintainerObject

Returns the value of attribute _maintainer.



26
27
28
# File 'lib/launchdarkly_api/models/ai_config.rb', line 26

def _maintainer
  @_maintainer
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/launchdarkly_api/models/ai_config.rb', line 38

def created_at
  @created_at
end

#descriptionObject

Returns the value of attribute description.



22
23
24
# File 'lib/launchdarkly_api/models/ai_config.rb', line 22

def description
  @description
end

#evaluation_metric_keyObject

Evaluation metric key for this AI Config



43
44
45
# File 'lib/launchdarkly_api/models/ai_config.rb', line 43

def evaluation_metric_key
  @evaluation_metric_key
end

#evaluation_metric_keysObject

List of evaluation metric keys for this AI Config



46
47
48
# File 'lib/launchdarkly_api/models/ai_config.rb', line 46

def evaluation_metric_keys
  @evaluation_metric_keys
end

#is_invertedObject

Whether the evaluation metric is inverted, meaning a lower value is better if set as true



49
50
51
# File 'lib/launchdarkly_api/models/ai_config.rb', line 49

def is_inverted
  @is_inverted
end

#keyObject

Returns the value of attribute key.



24
25
26
# File 'lib/launchdarkly_api/models/ai_config.rb', line 24

def key
  @key
end

#modeObject

Returns the value of attribute mode.



28
29
30
# File 'lib/launchdarkly_api/models/ai_config.rb', line 28

def mode
  @mode
end

#nameObject

Returns the value of attribute name.



30
31
32
# File 'lib/launchdarkly_api/models/ai_config.rb', line 30

def name
  @name
end

#tagsObject

Returns the value of attribute tags.



32
33
34
# File 'lib/launchdarkly_api/models/ai_config.rb', line 32

def tags
  @tags
end

#updated_atObject

Returns the value of attribute updated_at.



40
41
42
# File 'lib/launchdarkly_api/models/ai_config.rb', line 40

def updated_at
  @updated_at
end

#variationsObject

Returns the value of attribute variations.



36
37
38
# File 'lib/launchdarkly_api/models/ai_config.rb', line 36

def variations
  @variations
end

#versionObject

Returns the value of attribute version.



34
35
36
# File 'lib/launchdarkly_api/models/ai_config.rb', line 34

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/launchdarkly_api/models/ai_config.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/launchdarkly_api/models/ai_config.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/launchdarkly_api/models/ai_config.rb', line 74

def self.attribute_map
  {
    :'_access' => :'_access',
    :'_links' => :'_links',
    :'description' => :'description',
    :'key' => :'key',
    :'_maintainer' => :'_maintainer',
    :'mode' => :'mode',
    :'name' => :'name',
    :'tags' => :'tags',
    :'version' => :'version',
    :'variations' => :'variations',
    :'created_at' => :'createdAt',
    :'updated_at' => :'updatedAt',
    :'evaluation_metric_key' => :'evaluationMetricKey',
    :'evaluation_metric_keys' => :'evaluationMetricKeys',
    :'is_inverted' => :'isInverted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
# File 'lib/launchdarkly_api/models/ai_config.rb', line 416

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



126
127
128
129
# File 'lib/launchdarkly_api/models/ai_config.rb', line 126

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
# File 'lib/launchdarkly_api/models/ai_config.rb', line 105

def self.openapi_types
  {
    :'_access' => :'AiConfigsAccess',
    :'_links' => :'ParentAndSelfLinks',
    :'description' => :'String',
    :'key' => :'String',
    :'_maintainer' => :'AIConfigMaintainer',
    :'mode' => :'String',
    :'name' => :'String',
    :'tags' => :'Array<String>',
    :'version' => :'Integer',
    :'variations' => :'Array<AIConfigVariation>',
    :'created_at' => :'Integer',
    :'updated_at' => :'Integer',
    :'evaluation_metric_key' => :'String',
    :'evaluation_metric_keys' => :'Array<String>',
    :'is_inverted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
# File 'lib/launchdarkly_api/models/ai_config.rb', line 381

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _access == o._access &&
      _links == o._links &&
      description == o.description &&
      key == o.key &&
      _maintainer == o._maintainer &&
      mode == o.mode &&
      name == o.name &&
      tags == o.tags &&
      version == o.version &&
      variations == o.variations &&
      created_at == o.created_at &&
      updated_at == o.updated_at &&
      evaluation_metric_key == o.evaluation_metric_key &&
      evaluation_metric_keys == o.evaluation_metric_keys &&
      is_inverted == o.is_inverted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


403
404
405
# File 'lib/launchdarkly_api/models/ai_config.rb', line 403

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



409
410
411
# File 'lib/launchdarkly_api/models/ai_config.rb', line 409

def hash
  [_access, _links, description, key, _maintainer, mode, name, tags, version, variations, created_at, updated_at, evaluation_metric_key, evaluation_metric_keys, is_inverted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
# File 'lib/launchdarkly_api/models/ai_config.rb', line 234

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @variations.nil?
    invalid_properties.push('invalid value for "variations", variations cannot be nil.')
  end

  if @created_at.nil?
    invalid_properties.push('invalid value for "created_at", created_at cannot be nil.')
  end

  if @updated_at.nil?
    invalid_properties.push('invalid value for "updated_at", updated_at cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



438
439
440
441
442
443
444
445
446
447
448
449
450
# File 'lib/launchdarkly_api/models/ai_config.rb', line 438

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



274
275
276
277
278
279
280
281
282
283
284
285
286
287
# File 'lib/launchdarkly_api/models/ai_config.rb', line 274

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @description.nil?
  return false if @key.nil?
  mode_validator = EnumAttributeValidator.new('String', ["agent", "completion", "judge"])
  return false unless mode_validator.valid?(@mode)
  return false if @name.nil?
  return false if @tags.nil?
  return false if @version.nil?
  return false if @variations.nil?
  return false if @created_at.nil?
  return false if @updated_at.nil?
  true
end