Class: LaunchDarklyApi::AIConfigPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIConfigPost
- Defined in:
- lib/launchdarkly_api/models/ai_config_post.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#default_variation ⇒ Object
Returns the value of attribute default_variation.
-
#description ⇒ Object
Returns the value of attribute description.
-
#evaluation_metric_key ⇒ Object
Evaluation metric key for this AI Config.
-
#is_inverted ⇒ Object
Whether the evaluation metric is inverted, meaning a lower value is better if set as true.
-
#key ⇒ Object
Returns the value of attribute key.
-
#maintainer_id ⇒ Object
Returns the value of attribute maintainer_id.
-
#maintainer_team_key ⇒ Object
Returns the value of attribute maintainer_team_key.
-
#mode ⇒ Object
Returns the value of attribute mode.
-
#name ⇒ Object
Returns the value of attribute name.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIConfigPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIConfigPost
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = '' end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'maintainer_team_key') self.maintainer_team_key = attributes[:'maintainer_team_key'] end if attributes.key?(:'mode') self.mode = attributes[:'mode'] else self.mode = 'completion' end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'default_variation') self.default_variation = attributes[:'default_variation'] end if attributes.key?(:'evaluation_metric_key') self.evaluation_metric_key = attributes[:'evaluation_metric_key'] end if attributes.key?(:'is_inverted') self.is_inverted = attributes[:'is_inverted'] end end |
Instance Attribute Details
#default_variation ⇒ Object
Returns the value of attribute default_variation.
32 33 34 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 32 def default_variation @default_variation end |
#description ⇒ Object
Returns the value of attribute description.
18 19 20 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 18 def description @description end |
#evaluation_metric_key ⇒ Object
Evaluation metric key for this AI Config
35 36 37 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 35 def evaluation_metric_key @evaluation_metric_key end |
#is_inverted ⇒ Object
Whether the evaluation metric is inverted, meaning a lower value is better if set as true
38 39 40 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 38 def is_inverted @is_inverted end |
#key ⇒ Object
Returns the value of attribute key.
20 21 22 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 20 def key @key end |
#maintainer_id ⇒ Object
Returns the value of attribute maintainer_id.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 22 def maintainer_id @maintainer_id end |
#maintainer_team_key ⇒ Object
Returns the value of attribute maintainer_team_key.
24 25 26 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 24 def maintainer_team_key @maintainer_team_key end |
#mode ⇒ Object
Returns the value of attribute mode.
26 27 28 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 26 def mode @mode end |
#name ⇒ Object
Returns the value of attribute name.
28 29 30 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 28 def name @name end |
#tags ⇒ Object
Returns the value of attribute tags.
30 31 32 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 30 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 63 def self.attribute_map { :'description' => :'description', :'key' => :'key', :'maintainer_id' => :'maintainerId', :'maintainer_team_key' => :'maintainerTeamKey', :'mode' => :'mode', :'name' => :'name', :'tags' => :'tags', :'default_variation' => :'defaultVariation', :'evaluation_metric_key' => :'evaluationMetricKey', :'is_inverted' => :'isInverted' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 89 def self.openapi_types { :'description' => :'String', :'key' => :'String', :'maintainer_id' => :'String', :'maintainer_team_key' => :'String', :'mode' => :'String', :'name' => :'String', :'tags' => :'Array<String>', :'default_variation' => :'AIConfigVariationPost', :'evaluation_metric_key' => :'String', :'is_inverted' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 236 def ==(o) return true if self.equal?(o) self.class == o.class && description == o.description && key == o.key && maintainer_id == o.maintainer_id && maintainer_team_key == o.maintainer_team_key && mode == o.mode && name == o.name && == o. && default_variation == o.default_variation && evaluation_metric_key == o.evaluation_metric_key && is_inverted == o.is_inverted end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 259 def hash [description, key, maintainer_id, maintainer_team_key, mode, name, , default_variation, evaluation_metric_key, is_inverted].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
195 196 197 198 199 200 201 202 |
# File 'lib/launchdarkly_api/models/ai_config_post.rb', line 195 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? mode_validator = EnumAttributeValidator.new('String', ["agent", "completion", "judge"]) return false unless mode_validator.valid?(@mode) return false if @name.nil? true end |