Class: LaunchDarklyApi::AIConfigVariation
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIConfigVariation
- Defined in:
- lib/launchdarkly_api/models/ai_config_variation.rb
Instance Attribute Summary collapse
-
#_archived_at ⇒ Object
Returns the value of attribute _archived_at.
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_published_at ⇒ Object
Returns the value of attribute _published_at.
-
#color ⇒ Object
Returns the value of attribute color.
-
#comment ⇒ Object
Returns the value of attribute comment.
-
#created_at ⇒ Object
Returns the value of attribute created_at.
-
#description ⇒ Object
Returns the description for the agent.
-
#instructions ⇒ Object
Returns the instructions for the agent.
-
#judge_configuration ⇒ Object
Returns the value of attribute judge_configuration.
-
#judging_config_keys ⇒ Object
Returns the value of attribute judging_config_keys.
-
#key ⇒ Object
Returns the value of attribute key.
-
#messages ⇒ Object
Returns the value of attribute messages.
-
#model ⇒ Object
Returns the value of attribute model.
-
#model_config_key ⇒ Object
Returns the value of attribute model_config_key.
-
#name ⇒ Object
Returns the value of attribute name.
-
#output_format ⇒ Object
JSON Schema defining the structured output format for the variation.
-
#state ⇒ Object
Returns the value of attribute state.
-
#tools ⇒ Object
Returns the value of attribute tools.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIConfigVariation
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIConfigVariation
Initializes the object
131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 131 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigVariation` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigVariation`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') self._links = attributes[:'_links'] end if attributes.key?(:'color') self.color = attributes[:'color'] end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'instructions') self.instructions = attributes[:'instructions'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'messages') if (value = attributes[:'messages']).is_a?(Array) self. = value end end if attributes.key?(:'model') self.model = attributes[:'model'] else self.model = nil end if attributes.key?(:'model_config_key') self.model_config_key = attributes[:'model_config_key'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'output_format') if (value = attributes[:'output_format']).is_a?(Hash) self.output_format = value end end if attributes.key?(:'created_at') self.created_at = attributes[:'created_at'] else self.created_at = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'_archived_at') self._archived_at = attributes[:'_archived_at'] end if attributes.key?(:'_published_at') self._published_at = attributes[:'_published_at'] end if attributes.key?(:'tools') if (value = attributes[:'tools']).is_a?(Array) self.tools = value end end if attributes.key?(:'judge_configuration') self.judge_configuration = attributes[:'judge_configuration'] end if attributes.key?(:'judging_config_keys') if (value = attributes[:'judging_config_keys']).is_a?(Array) self.judging_config_keys = value end end end |
Instance Attribute Details
#_archived_at ⇒ Object
Returns the value of attribute _archived_at.
51 52 53 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 51 def _archived_at @_archived_at end |
#_id ⇒ Object
Returns the value of attribute _id.
32 33 34 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 32 def _id @_id end |
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 18 def _links @_links end |
#_published_at ⇒ Object
Returns the value of attribute _published_at.
53 54 55 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 53 def _published_at @_published_at end |
#color ⇒ Object
Returns the value of attribute color.
20 21 22 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 20 def color @color end |
#comment ⇒ Object
Returns the value of attribute comment.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 22 def comment @comment end |
#created_at ⇒ Object
Returns the value of attribute created_at.
45 46 47 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 45 def created_at @created_at end |
#description ⇒ Object
Returns the description for the agent. This is only returned for agent variations.
25 26 27 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 25 def description @description end |
#instructions ⇒ Object
Returns the instructions for the agent. This is only returned for agent variations.
28 29 30 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 28 def instructions @instructions end |
#judge_configuration ⇒ Object
Returns the value of attribute judge_configuration.
57 58 59 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 57 def judge_configuration @judge_configuration end |
#judging_config_keys ⇒ Object
Returns the value of attribute judging_config_keys.
59 60 61 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 59 def judging_config_keys @judging_config_keys end |
#key ⇒ Object
Returns the value of attribute key.
30 31 32 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 30 def key @key end |
#messages ⇒ Object
Returns the value of attribute messages.
34 35 36 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 34 def @messages end |
#model ⇒ Object
Returns the value of attribute model.
36 37 38 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 36 def model @model end |
#model_config_key ⇒ Object
Returns the value of attribute model_config_key.
38 39 40 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 38 def model_config_key @model_config_key end |
#name ⇒ Object
Returns the value of attribute name.
40 41 42 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 40 def name @name end |
#output_format ⇒ Object
JSON Schema defining the structured output format for the variation.
43 44 45 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 43 def output_format @output_format end |
#state ⇒ Object
Returns the value of attribute state.
49 50 51 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 49 def state @state end |
#tools ⇒ Object
Returns the value of attribute tools.
55 56 57 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 55 def tools @tools end |
#version ⇒ Object
Returns the value of attribute version.
47 48 49 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 47 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 62 def self.attribute_map { :'_links' => :'_links', :'color' => :'color', :'comment' => :'comment', :'description' => :'description', :'instructions' => :'instructions', :'key' => :'key', :'_id' => :'_id', :'messages' => :'messages', :'model' => :'model', :'model_config_key' => :'modelConfigKey', :'name' => :'name', :'output_format' => :'outputFormat', :'created_at' => :'createdAt', :'version' => :'version', :'state' => :'state', :'_archived_at' => :'_archivedAt', :'_published_at' => :'_publishedAt', :'tools' => :'tools', :'judge_configuration' => :'judgeConfiguration', :'judging_config_keys' => :'judgingConfigKeys' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 393 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
124 125 126 127 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 124 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 98 def self.openapi_types { :'_links' => :'ParentLink', :'color' => :'String', :'comment' => :'String', :'description' => :'String', :'instructions' => :'String', :'key' => :'String', :'_id' => :'String', :'messages' => :'Array<Message>', :'model' => :'Object', :'model_config_key' => :'String', :'name' => :'String', :'output_format' => :'Hash<String, Object>', :'created_at' => :'Integer', :'version' => :'Integer', :'state' => :'String', :'_archived_at' => :'Integer', :'_published_at' => :'Integer', :'tools' => :'Array<VariationTool>', :'judge_configuration' => :'JudgeConfiguration', :'judging_config_keys' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 353 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && color == o.color && comment == o.comment && description == o.description && instructions == o.instructions && key == o.key && _id == o._id && == o. && model == o.model && model_config_key == o.model_config_key && name == o.name && output_format == o.output_format && created_at == o.created_at && version == o.version && state == o.state && _archived_at == o._archived_at && _published_at == o._published_at && tools == o.tools && judge_configuration == o.judge_configuration && judging_config_keys == o.judging_config_keys end |
#eql?(o) ⇒ Boolean
380 381 382 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 380 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
386 387 388 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 386 def hash [_links, color, comment, description, instructions, key, _id, , model, model_config_key, name, output_format, created_at, version, state, _archived_at, _published_at, tools, judge_configuration, judging_config_keys].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 248 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @model.nil? invalid_properties.push('invalid value for "model", model cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @created_at.nil? invalid_properties.push('invalid value for "created_at", created_at cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
415 416 417 418 419 420 421 422 423 424 425 426 427 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 415 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
280 281 282 283 284 285 286 287 288 289 |
# File 'lib/launchdarkly_api/models/ai_config_variation.rb', line 280 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @_id.nil? return false if @model.nil? return false if @name.nil? return false if @created_at.nil? return false if @version.nil? true end |