Class: LaunchDarklyApi::AIConfigVariationPatch
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AIConfigVariationPatch
- Defined in:
- lib/launchdarkly_api/models/ai_config_variation_patch.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Human-readable description of what this patch changes.
-
#description ⇒ Object
Description for agent when the config is in agent mode.
-
#instructions ⇒ Object
Instructions for agent when the config is in agent mode.
-
#judge_configuration ⇒ Object
Returns the value of attribute judge_configuration.
-
#messages ⇒ Object
Returns the value of attribute messages.
-
#model ⇒ Object
Returns the value of attribute model.
-
#model_config_key ⇒ Object
Returns the value of attribute model_config_key.
-
#name ⇒ Object
Returns the value of attribute name.
-
#output_format ⇒ Object
JSON Schema defining the structured output format for the variation.
-
#published ⇒ Object
Returns the value of attribute published.
-
#state ⇒ Object
One of 'archived', 'published'.
-
#tool_keys ⇒ Object
List of tool keys to use for this variation.
-
#tools ⇒ Object
List of tools to use for this variation.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AIConfigVariationPatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AIConfigVariationPatch
Initializes the object
107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 107 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigVariationPatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigVariationPatch`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'instructions') self.instructions = attributes[:'instructions'] end if attributes.key?(:'messages') if (value = attributes[:'messages']).is_a?(Array) self. = value end end if attributes.key?(:'model') self.model = attributes[:'model'] end if attributes.key?(:'model_config_key') self.model_config_key = attributes[:'model_config_key'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'output_format') if (value = attributes[:'output_format']).is_a?(Hash) self.output_format = value end end if attributes.key?(:'published') self.published = attributes[:'published'] end if attributes.key?(:'state') self.state = attributes[:'state'] end if attributes.key?(:'tools') if (value = attributes[:'tools']).is_a?(Array) self.tools = value end end if attributes.key?(:'tool_keys') if (value = attributes[:'tool_keys']).is_a?(Array) self.tool_keys = value end end if attributes.key?(:'judge_configuration') self.judge_configuration = attributes[:'judge_configuration'] end end |
Instance Attribute Details
#comment ⇒ Object
Human-readable description of what this patch changes
19 20 21 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 19 def comment @comment end |
#description ⇒ Object
Description for agent when the config is in agent mode.
22 23 24 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 22 def description @description end |
#instructions ⇒ Object
Instructions for agent when the config is in agent mode.
25 26 27 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 25 def instructions @instructions end |
#judge_configuration ⇒ Object
Returns the value of attribute judge_configuration.
49 50 51 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 49 def judge_configuration @judge_configuration end |
#messages ⇒ Object
Returns the value of attribute messages.
27 28 29 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 27 def @messages end |
#model ⇒ Object
Returns the value of attribute model.
29 30 31 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 29 def model @model end |
#model_config_key ⇒ Object
Returns the value of attribute model_config_key.
31 32 33 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 31 def model_config_key @model_config_key end |
#name ⇒ Object
Returns the value of attribute name.
33 34 35 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 33 def name @name end |
#output_format ⇒ Object
JSON Schema defining the structured output format for the variation.
36 37 38 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 36 def output_format @output_format end |
#published ⇒ Object
Returns the value of attribute published.
38 39 40 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 38 def published @published end |
#state ⇒ Object
One of 'archived', 'published'
41 42 43 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 41 def state @state end |
#tool_keys ⇒ Object
List of tool keys to use for this variation. The latest version of the tool will be used.
47 48 49 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 47 def tool_keys @tool_keys end |
#tools ⇒ Object
List of tools to use for this variation. The latest version of the tool will be used.
44 45 46 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 44 def tools @tools end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 52 def self.attribute_map { :'comment' => :'comment', :'description' => :'description', :'instructions' => :'instructions', :'messages' => :'messages', :'model' => :'model', :'model_config_key' => :'modelConfigKey', :'name' => :'name', :'output_format' => :'outputFormat', :'published' => :'published', :'state' => :'state', :'tools' => :'tools', :'tool_keys' => :'toolKeys', :'judge_configuration' => :'judgeConfiguration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 232 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
100 101 102 103 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 100 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 81 def self.openapi_types { :'comment' => :'String', :'description' => :'String', :'instructions' => :'String', :'messages' => :'Array<Message>', :'model' => :'Object', :'model_config_key' => :'String', :'name' => :'String', :'output_format' => :'Hash<String, Object>', :'published' => :'Boolean', :'state' => :'String', :'tools' => :'Array<VariationToolPost>', :'tool_keys' => :'Array<String>', :'judge_configuration' => :'JudgeConfiguration' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && comment == o.comment && description == o.description && instructions == o.instructions && == o. && model == o.model && model_config_key == o.model_config_key && name == o.name && output_format == o.output_format && published == o.published && state == o.state && tools == o.tools && tool_keys == o.tool_keys && judge_configuration == o.judge_configuration end |
#eql?(o) ⇒ Boolean
219 220 221 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 219 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 225 def hash [comment, description, instructions, , model, model_config_key, name, output_format, published, state, tools, tool_keys, judge_configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
254 255 256 257 258 259 260 261 262 263 264 265 266 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 254 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 |
# File 'lib/launchdarkly_api/models/ai_config_variation_patch.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |