Class: LaunchDarklyApi::AIConfigVariationPost

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/ai_config_variation_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AIConfigVariationPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 102

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AIConfigVariationPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AIConfigVariationPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'comment')
    self.comment = attributes[:'comment']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'instructions')
    self.instructions = attributes[:'instructions']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'messages')
    if (value = attributes[:'messages']).is_a?(Array)
      self.messages = value
    end
  end

  if attributes.key?(:'model')
    self.model = attributes[:'model']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'model_config_key')
    self.model_config_key = attributes[:'model_config_key']
  end

  if attributes.key?(:'output_format')
    if (value = attributes[:'output_format']).is_a?(Hash)
      self.output_format = value
    end
  end

  if attributes.key?(:'tools')
    if (value = attributes[:'tools']).is_a?(Array)
      self.tools = value
    end
  end

  if attributes.key?(:'tool_keys')
    if (value = attributes[:'tool_keys']).is_a?(Array)
      self.tool_keys = value
    end
  end

  if attributes.key?(:'judge_configuration')
    self.judge_configuration = attributes[:'judge_configuration']
  end
end

Instance Attribute Details

#commentObject

Human-readable description of this variation



19
20
21
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 19

def comment
  @comment
end

#descriptionObject

Returns the description for the agent. This is only returned for agent variations.



22
23
24
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 22

def description
  @description
end

#instructionsObject

Returns the instructions for the agent. This is only returned for agent variations.



25
26
27
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 25

def instructions
  @instructions
end

#judge_configurationObject

Returns the value of attribute judge_configuration.



46
47
48
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 46

def judge_configuration
  @judge_configuration
end

#keyObject

Returns the value of attribute key.



27
28
29
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 27

def key
  @key
end

#messagesObject

Returns the value of attribute messages.



29
30
31
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 29

def messages
  @messages
end

#modelObject

Returns the value of attribute model.



31
32
33
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 31

def model
  @model
end

#model_config_keyObject

Returns the value of attribute model_config_key.



35
36
37
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 35

def model_config_key
  @model_config_key
end

#nameObject

Returns the value of attribute name.



33
34
35
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 33

def name
  @name
end

#output_formatObject

JSON Schema defining the structured output format for the variation.



38
39
40
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 38

def output_format
  @output_format
end

#tool_keysObject

List of tool keys to use for this variation. The latest version of the tool will be used.



44
45
46
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 44

def tool_keys
  @tool_keys
end

#toolsObject

List of tools to use for this variation. The latest version of the tool will be used.



41
42
43
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 41

def tools
  @tools
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



67
68
69
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 67

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 72

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 49

def self.attribute_map
  {
    :'comment' => :'comment',
    :'description' => :'description',
    :'instructions' => :'instructions',
    :'key' => :'key',
    :'messages' => :'messages',
    :'model' => :'model',
    :'name' => :'name',
    :'model_config_key' => :'modelConfigKey',
    :'output_format' => :'outputFormat',
    :'tools' => :'tools',
    :'tool_keys' => :'toolKeys',
    :'judge_configuration' => :'judgeConfiguration'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 256

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



95
96
97
98
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 95

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 77

def self.openapi_types
  {
    :'comment' => :'String',
    :'description' => :'String',
    :'instructions' => :'String',
    :'key' => :'String',
    :'messages' => :'Array<Message>',
    :'model' => :'Object',
    :'name' => :'String',
    :'model_config_key' => :'String',
    :'output_format' => :'Hash<String, Object>',
    :'tools' => :'Array<VariationToolPost>',
    :'tool_keys' => :'Array<String>',
    :'judge_configuration' => :'JudgeConfiguration'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 224

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      comment == o.comment &&
      description == o.description &&
      instructions == o.instructions &&
      key == o.key &&
      messages == o.messages &&
      model == o.model &&
      name == o.name &&
      model_config_key == o.model_config_key &&
      output_format == o.output_format &&
      tools == o.tools &&
      tool_keys == o.tool_keys &&
      judge_configuration == o.judge_configuration
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


243
244
245
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 243

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



249
250
251
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 249

def hash
  [comment, description, instructions, key, messages, model, name, model_config_key, output_format, tools, tool_keys, judge_configuration].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



179
180
181
182
183
184
185
186
187
188
189
190
191
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 179

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



278
279
280
281
282
283
284
285
286
287
288
289
290
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 278

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



195
196
197
198
199
200
# File 'lib/launchdarkly_api/models/ai_config_variation_post.rb', line 195

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  true
end