Class: LaunchDarklyApi::AgentGraphPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::AgentGraphPost
- Defined in:
- lib/launchdarkly_api/models/agent_graph_post.rb
Overview
Request body for creating an agent graph
Instance Attribute Summary collapse
-
#description ⇒ Object
A description of the agent graph.
-
#edges ⇒ Object
The edges in the graph.
-
#key ⇒ Object
A unique key for the agent graph.
-
#maintainer_id ⇒ Object
The ID of the member who maintains this agent graph.
-
#maintainer_team_key ⇒ Object
The key of the team that maintains this agent graph.
-
#name ⇒ Object
A human-readable name for the agent graph.
-
#root_config_key ⇒ Object
The AI Config key of the root node.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AgentGraphPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ AgentGraphPost
Initializes the object
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 84 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AgentGraphPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AgentGraphPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'maintainer_team_key') self.maintainer_team_key = attributes[:'maintainer_team_key'] end if attributes.key?(:'root_config_key') self.root_config_key = attributes[:'root_config_key'] end if attributes.key?(:'edges') if (value = attributes[:'edges']).is_a?(Array) self.edges = value end end end |
Instance Attribute Details
#description ⇒ Object
A description of the agent graph
26 27 28 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 26 def description @description end |
#edges ⇒ Object
The edges in the graph. If edges or rootConfigKey is present, both must be present.
38 39 40 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 38 def edges @edges end |
#key ⇒ Object
A unique key for the agent graph
20 21 22 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 20 def key @key end |
#maintainer_id ⇒ Object
The ID of the member who maintains this agent graph
29 30 31 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 29 def maintainer_id @maintainer_id end |
#maintainer_team_key ⇒ Object
The key of the team that maintains this agent graph
32 33 34 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 32 def maintainer_team_key @maintainer_team_key end |
#name ⇒ Object
A human-readable name for the agent graph
23 24 25 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 23 def name @name end |
#root_config_key ⇒ Object
The AI Config key of the root node. A missing root implies a newly created graph with metadata only.
35 36 37 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 35 def root_config_key @root_config_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 41 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'description' => :'description', :'maintainer_id' => :'maintainerId', :'maintainer_team_key' => :'maintainerTeamKey', :'root_config_key' => :'rootConfigKey', :'edges' => :'edges' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 207 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
77 78 79 80 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 77 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 64 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'description' => :'String', :'maintainer_id' => :'String', :'maintainer_team_key' => :'String', :'root_config_key' => :'String', :'edges' => :'Array<AgentGraphEdgePost>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 180 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && description == o.description && maintainer_id == o.maintainer_id && maintainer_team_key == o.maintainer_team_key && root_config_key == o.root_config_key && edges == o.edges end |
#eql?(o) ⇒ Boolean
194 195 196 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 194 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
200 201 202 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 200 def hash [key, name, description, maintainer_id, maintainer_team_key, root_config_key, edges].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
135 136 137 138 139 140 141 142 143 144 145 146 147 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 135 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
229 230 231 232 233 234 235 236 237 238 239 240 241 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 229 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
151 152 153 154 155 156 |
# File 'lib/launchdarkly_api/models/agent_graph_post.rb', line 151 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? true end |