Class: LaunchDarklyApi::AiConfigsMetricListingRep

Inherits:
ApiModelBase
  • Object
show all
Defined in:
lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ AiConfigsMetricListingRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
431
432
433
434
435
436
437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 254

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AiConfigsMetricListingRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AiConfigsMetricListingRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'experiment_count')
    self.experiment_count = attributes[:'experiment_count']
  end

  if attributes.key?(:'metric_group_count')
    self.metric_group_count = attributes[:'metric_group_count']
  end

  if attributes.key?(:'guarded_rollout_count')
    self.guarded_rollout_count = attributes[:'guarded_rollout_count']
  end

  if attributes.key?(:'release_policy_count')
    self.release_policy_count = attributes[:'release_policy_count']
  end

  if attributes.key?(:'active_experiment_count')
    self.active_experiment_count = attributes[:'active_experiment_count']
  end

  if attributes.key?(:'active_guarded_rollout_count')
    self.active_guarded_rollout_count = attributes[:'active_guarded_rollout_count']
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'_version_id')
    self._version_id = attributes[:'_version_id']
  else
    self._version_id = nil
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'_attached_flag_count')
    self._attached_flag_count = attributes[:'_attached_flag_count']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_site')
    self._site = attributes[:'_site']
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  else
    self._creation_date = nil
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'_maintainer')
    self._maintainer = attributes[:'_maintainer']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'category')
    self.category = attributes[:'category']
  end

  if attributes.key?(:'is_numeric')
    self.is_numeric = attributes[:'is_numeric']
  end

  if attributes.key?(:'success_criteria')
    self.success_criteria = attributes[:'success_criteria']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'event_key')
    self.event_key = attributes[:'event_key']
  end

  if attributes.key?(:'randomization_units')
    if (value = attributes[:'randomization_units']).is_a?(Array)
      self.randomization_units = value
    end
  end

  if attributes.key?(:'filters')
    self.filters = attributes[:'filters']
  end

  if attributes.key?(:'unit_aggregation_type')
    self.unit_aggregation_type = attributes[:'unit_aggregation_type']
  end

  if attributes.key?(:'analysis_type')
    self.analysis_type = attributes[:'analysis_type']
  end

  if attributes.key?(:'percentile_value')
    self.percentile_value = attributes[:'percentile_value']
  end

  if attributes.key?(:'event_default')
    self.event_default = attributes[:'event_default']
  end

  if attributes.key?(:'data_source')
    self.data_source = attributes[:'data_source']
  else
    self.data_source = nil
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end

  if attributes.key?(:'archived_at')
    self.archived_at = attributes[:'archived_at']
  end

  if attributes.key?(:'selector')
    self.selector = attributes[:'selector']
  end

  if attributes.key?(:'urls')
    if (value = attributes[:'urls']).is_a?(Array)
      self.urls = value
    end
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



62
63
64
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 62

def _access
  @_access
end

#_attached_flag_countObject

The number of feature flags currently attached to this metric



55
56
57
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 55

def _attached_flag_count
  @_attached_flag_count
end

#_creation_dateObject

Returns the value of attribute _creation_date.



67
68
69
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 67

def _creation_date
  @_creation_date
end

#_idObject

The ID of this metric



37
38
39
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 37

def _id
  @_id
end

The location and content type of related resources



58
59
60
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 58

def _links
  @_links
end

#_maintainerObject

Returns the value of attribute _maintainer.



74
75
76
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 74

def _maintainer
  @_maintainer
end

#_siteObject

Returns the value of attribute _site.



60
61
62
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 60

def _site
  @_site
end

#_versionObject

Version of the metric



43
44
45
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 43

def _version
  @_version
end

#_version_idObject

The version ID of the metric



40
41
42
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 40

def _version_id
  @_version_id
end

#active_experiment_countObject

The number of active experiments using this metric



31
32
33
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 31

def active_experiment_count
  @active_experiment_count
end

#active_guarded_rollout_countObject

The number of active guarded rollouts using this metric



34
35
36
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 34

def active_guarded_rollout_count
  @active_guarded_rollout_count
end

#analysis_typeObject

The method for analyzing metric events



103
104
105
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 103

def analysis_type
  @analysis_type
end

#archivedObject

Whether the metric version is archived



115
116
117
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 115

def archived
  @archived
end

#archived_atObject

Returns the value of attribute archived_at.



117
118
119
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 117

def archived_at
  @archived_at
end

#categoryObject

The category of the metric



80
81
82
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 80

def category
  @category
end

#data_sourceObject

Returns the value of attribute data_source.



110
111
112
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 110

def data_source
  @data_source
end

#descriptionObject

Description of the metric



77
78
79
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 77

def description
  @description
end

#event_defaultObject

Returns the value of attribute event_default.



108
109
110
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 108

def event_default
  @event_default
end

#event_keyObject

For custom metrics, the event key to use in your code



92
93
94
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 92

def event_key
  @event_key
end

#experiment_countObject

The number of experiments using this metric



19
20
21
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 19

def experiment_count
  @experiment_count
end

#filtersObject

Returns the value of attribute filters.



97
98
99
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 97

def filters
  @filters
end

#guarded_rollout_countObject

The number of guarded rollouts using this metric



25
26
27
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 25

def guarded_rollout_count
  @guarded_rollout_count
end

#is_numericObject

For custom metrics, whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false).



83
84
85
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 83

def is_numeric
  @is_numeric
end

#keyObject

A unique key to reference the metric



46
47
48
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 46

def key
  @key
end

#kindObject

The kind of event the metric tracks



52
53
54
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 52

def kind
  @kind
end

#last_modifiedObject

Returns the value of attribute last_modified.



69
70
71
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 69

def last_modified
  @last_modified
end

#last_seenObject

Returns the value of attribute last_seen.



112
113
114
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 112

def last_seen
  @last_seen
end

#maintainer_idObject

The ID of the member who maintains this metric



72
73
74
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 72

def maintainer_id
  @maintainer_id
end

#metric_group_countObject

The number of metric groups using this metric



22
23
24
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 22

def metric_group_count
  @metric_group_count
end

#nameObject

A human-friendly name for the metric



49
50
51
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 49

def name
  @name
end

#percentile_valueObject

The percentile for the analysis method. An integer denoting the target percentile between 0 and 100. Required when analysisType is percentile.



106
107
108
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 106

def percentile_value
  @percentile_value
end

#randomization_unitsObject

An array of randomization units allowed for this metric



95
96
97
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 95

def randomization_units
  @randomization_units
end

#release_policy_countObject

The number of release policies using this metric



28
29
30
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 28

def release_policy_count
  @release_policy_count
end

#selectorObject

For click metrics, the CSS selectors



120
121
122
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 120

def selector
  @selector
end

#success_criteriaObject

For custom metrics, the success criteria



86
87
88
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 86

def success_criteria
  @success_criteria
end

#tagsObject

Tags for the metric



65
66
67
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 65

def tags
  @tags
end

#unitObject

For numeric custom metrics, the unit of measure



89
90
91
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 89

def unit
  @unit
end

#unit_aggregation_typeObject

The method by which multiple unit event values are aggregated



100
101
102
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 100

def unit_aggregation_type
  @unit_aggregation_type
end

#urlsObject

Returns the value of attribute urls.



122
123
124
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 122

def urls
  @urls
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



192
193
194
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 192

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



197
198
199
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 197

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 147

def self.attribute_map
  {
    :'experiment_count' => :'experimentCount',
    :'metric_group_count' => :'metricGroupCount',
    :'guarded_rollout_count' => :'guardedRolloutCount',
    :'release_policy_count' => :'releasePolicyCount',
    :'active_experiment_count' => :'activeExperimentCount',
    :'active_guarded_rollout_count' => :'activeGuardedRolloutCount',
    :'_id' => :'_id',
    :'_version_id' => :'_versionId',
    :'_version' => :'_version',
    :'key' => :'key',
    :'name' => :'name',
    :'kind' => :'kind',
    :'_attached_flag_count' => :'_attachedFlagCount',
    :'_links' => :'_links',
    :'_site' => :'_site',
    :'_access' => :'_access',
    :'tags' => :'tags',
    :'_creation_date' => :'_creationDate',
    :'last_modified' => :'lastModified',
    :'maintainer_id' => :'maintainerId',
    :'_maintainer' => :'_maintainer',
    :'description' => :'description',
    :'category' => :'category',
    :'is_numeric' => :'isNumeric',
    :'success_criteria' => :'successCriteria',
    :'unit' => :'unit',
    :'event_key' => :'eventKey',
    :'randomization_units' => :'randomizationUnits',
    :'filters' => :'filters',
    :'unit_aggregation_type' => :'unitAggregationType',
    :'analysis_type' => :'analysisType',
    :'percentile_value' => :'percentileValue',
    :'event_default' => :'eventDefault',
    :'data_source' => :'dataSource',
    :'last_seen' => :'lastSeen',
    :'archived' => :'archived',
    :'archived_at' => :'archivedAt',
    :'selector' => :'selector',
    :'urls' => :'urls'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



700
701
702
703
704
705
706
707
708
709
710
711
712
713
714
715
716
717
718
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 700

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



247
248
249
250
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 247

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 202

def self.openapi_types
  {
    :'experiment_count' => :'Integer',
    :'metric_group_count' => :'Integer',
    :'guarded_rollout_count' => :'Integer',
    :'release_policy_count' => :'Integer',
    :'active_experiment_count' => :'Integer',
    :'active_guarded_rollout_count' => :'Integer',
    :'_id' => :'String',
    :'_version_id' => :'String',
    :'_version' => :'Integer',
    :'key' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'_attached_flag_count' => :'Integer',
    :'_links' => :'Hash<String, AiConfigsLink>',
    :'_site' => :'AiConfigsLink',
    :'_access' => :'AiConfigsAccess',
    :'tags' => :'Array<String>',
    :'_creation_date' => :'Integer',
    :'last_modified' => :'AiConfigsModification',
    :'maintainer_id' => :'String',
    :'_maintainer' => :'AiConfigsMemberSummary',
    :'description' => :'String',
    :'category' => :'String',
    :'is_numeric' => :'Boolean',
    :'success_criteria' => :'String',
    :'unit' => :'String',
    :'event_key' => :'String',
    :'randomization_units' => :'Array<String>',
    :'filters' => :'AiConfigsFilter',
    :'unit_aggregation_type' => :'String',
    :'analysis_type' => :'String',
    :'percentile_value' => :'Integer',
    :'event_default' => :'AiConfigsMetricEventDefaultRep',
    :'data_source' => :'AiConfigsMetricDataSourceRefRep',
    :'last_seen' => :'Integer',
    :'archived' => :'Boolean',
    :'archived_at' => :'Integer',
    :'selector' => :'String',
    :'urls' => :'Array<Hash>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



641
642
643
644
645
646
647
648
649
650
651
652
653
654
655
656
657
658
659
660
661
662
663
664
665
666
667
668
669
670
671
672
673
674
675
676
677
678
679
680
681
682
683
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 641

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      experiment_count == o.experiment_count &&
      metric_group_count == o.metric_group_count &&
      guarded_rollout_count == o.guarded_rollout_count &&
      release_policy_count == o.release_policy_count &&
      active_experiment_count == o.active_experiment_count &&
      active_guarded_rollout_count == o.active_guarded_rollout_count &&
      _id == o._id &&
      _version_id == o._version_id &&
      _version == o._version &&
      key == o.key &&
      name == o.name &&
      kind == o.kind &&
      _attached_flag_count == o._attached_flag_count &&
      _links == o._links &&
      _site == o._site &&
      _access == o._access &&
      tags == o.tags &&
      _creation_date == o._creation_date &&
      last_modified == o.last_modified &&
      maintainer_id == o.maintainer_id &&
      _maintainer == o._maintainer &&
      description == o.description &&
      category == o.category &&
      is_numeric == o.is_numeric &&
      success_criteria == o.success_criteria &&
      unit == o.unit &&
      event_key == o.event_key &&
      randomization_units == o.randomization_units &&
      filters == o.filters &&
      unit_aggregation_type == o.unit_aggregation_type &&
      analysis_type == o.analysis_type &&
      percentile_value == o.percentile_value &&
      event_default == o.event_default &&
      data_source == o.data_source &&
      last_seen == o.last_seen &&
      archived == o.archived &&
      archived_at == o.archived_at &&
      selector == o.selector &&
      urls == o.urls
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


687
688
689
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 687

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



693
694
695
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 693

def hash
  [experiment_count, metric_group_count, guarded_rollout_count, release_policy_count, active_experiment_count, active_guarded_rollout_count, _id, _version_id, _version, key, name, kind, _attached_flag_count, _links, _site, _access, tags, _creation_date, last_modified, maintainer_id, _maintainer, description, category, is_numeric, success_criteria, unit, event_key, randomization_units, filters, unit_aggregation_type, analysis_type, percentile_value, event_default, data_source, last_seen, archived, archived_at, selector, urls].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



453
454
455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
487
488
489
490
491
492
493
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 453

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_version_id.nil?
    invalid_properties.push('invalid value for "_version_id", _version_id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @_creation_date.nil?
    invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.')
  end

  if @data_source.nil?
    invalid_properties.push('invalid value for "data_source", data_source cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



722
723
724
725
726
727
728
729
730
731
732
733
734
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 722

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
# File 'lib/launchdarkly_api/models/ai_configs_metric_listing_rep.rb', line 497

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @_version_id.nil?
  return false if @key.nil?
  return false if @name.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom"])
  return false unless kind_validator.valid?(@kind)
  return false if @_links.nil?
  return false if @tags.nil?
  return false if @_creation_date.nil?
  success_criteria_validator = EnumAttributeValidator.new('String', ["HigherThanBaseline", "LowerThanBaseline"])
  return false unless success_criteria_validator.valid?(@success_criteria)
  unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["average", "sum"])
  return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type)
  analysis_type_validator = EnumAttributeValidator.new('String', ["mean", "percentile"])
  return false unless analysis_type_validator.valid?(@analysis_type)
  return false if @data_source.nil?
  true
end