Class: LaunchDarklyApi::AnnouncementResponse

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/announcement_response.rb

Overview

Announcement response

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ AnnouncementResponse

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 114

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AnnouncementResponse` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AnnouncementResponse`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'is_dismissible')
    self.is_dismissible = attributes[:'is_dismissible']
  end

  if attributes.key?(:'title')
    self.title = attributes[:'title']
  end

  if attributes.key?(:'message')
    self.message = attributes[:'message']
  end

  if attributes.key?(:'start_time')
    self.start_time = attributes[:'start_time']
  end

  if attributes.key?(:'end_time')
    self.end_time = attributes[:'end_time']
  end

  if attributes.key?(:'severity')
    self.severity = attributes[:'severity']
  end

  if attributes.key?(:'_status')
    self._status = attributes[:'_status']
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_links')
    self._links = attributes[:'_links']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



43
44
45
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 43

def _access
  @_access
end

#_idObject

The ID of the announcement



20
21
22
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 20

def _id
  @_id
end

Returns the value of attribute _links.



45
46
47
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 45

def _links
  @_links
end

#_statusObject

The status of the announcement



41
42
43
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 41

def _status
  @_status
end

#end_timeObject

The end time of the announcement. This is a Unix timestamp in milliseconds.



35
36
37
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 35

def end_time
  @end_time
end

#is_dismissibleObject

true if the announcement is dismissible



23
24
25
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 23

def is_dismissible
  @is_dismissible
end

#messageObject

The message of the announcement



29
30
31
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 29

def message
  @message
end

#severityObject

The severity of the announcement



38
39
40
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 38

def severity
  @severity
end

#start_timeObject

The start time of the announcement. This is a Unix timestamp in milliseconds.



32
33
34
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 32

def start_time
  @start_time
end

#titleObject

The title of the announcement



26
27
28
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 26

def title
  @title
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



86
87
88
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 86

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



70
71
72
73
74
75
76
77
78
79
80
81
82
83
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 70

def self.attribute_map
  {
    :'_id' => :'_id',
    :'is_dismissible' => :'isDismissible',
    :'title' => :'title',
    :'message' => :'message',
    :'start_time' => :'startTime',
    :'end_time' => :'endTime',
    :'severity' => :'severity',
    :'_status' => :'_status',
    :'_access' => :'_access',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



277
278
279
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 277

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



107
108
109
110
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 107

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 91

def self.openapi_types
  {
    :'_id' => :'String',
    :'is_dismissible' => :'Boolean',
    :'title' => :'String',
    :'message' => :'String',
    :'start_time' => :'Integer',
    :'end_time' => :'Integer',
    :'severity' => :'String',
    :'_status' => :'String',
    :'_access' => :'AnnouncementAccessRep',
    :'_links' => :'AnnouncementResponseLinks'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



247
248
249
250
251
252
253
254
255
256
257
258
259
260
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 247

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      is_dismissible == o.is_dismissible &&
      title == o.title &&
      message == o.message &&
      start_time == o.start_time &&
      end_time == o.end_time &&
      severity == o.severity &&
      _status == o._status &&
      _access == o._access &&
      _links == o._links
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 308

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



379
380
381
382
383
384
385
386
387
388
389
390
391
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 379

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 284

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


264
265
266
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 264

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



270
271
272
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 270

def hash
  [_id, is_dismissible, title, message, start_time, end_time, severity, _status, _access, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 170

def list_invalid_properties
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @is_dismissible.nil?
    invalid_properties.push('invalid value for "is_dismissible", is_dismissible cannot be nil.')
  end

  if @title.nil?
    invalid_properties.push('invalid value for "title", title cannot be nil.')
  end

  if @message.nil?
    invalid_properties.push('invalid value for "message", message cannot be nil.')
  end

  if @start_time.nil?
    invalid_properties.push('invalid value for "start_time", start_time cannot be nil.')
  end

  if @severity.nil?
    invalid_properties.push('invalid value for "severity", severity cannot be nil.')
  end

  if @_status.nil?
    invalid_properties.push('invalid value for "_status", _status cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



355
356
357
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 355

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



361
362
363
364
365
366
367
368
369
370
371
372
373
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 361

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



349
350
351
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 349

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
# File 'lib/launchdarkly_api/models/announcement_response.rb', line 209

def valid?
  return false if @_id.nil?
  return false if @is_dismissible.nil?
  return false if @title.nil?
  return false if @message.nil?
  return false if @start_time.nil?
  return false if @severity.nil?
  severity_validator = EnumAttributeValidator.new('String', ["info", "warning", "critical"])
  return false unless severity_validator.valid?(@severity)
  return false if @_status.nil?
  _status_validator = EnumAttributeValidator.new('String', ["active", "inactive", "scheduled"])
  return false unless _status_validator.valid?(@_status)
  return false if @_links.nil?
  true
end