Class: LaunchDarklyApi::ApplicationRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ApplicationRep
- Defined in:
- lib/launchdarkly_api/models/application_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
-
#_version ⇒ Object
Version of the application.
-
#auto_added ⇒ Object
Whether the application was automatically created because it was included in a context when a LaunchDarkly SDK evaluated a feature flag, or was created through the LaunchDarkly UI or REST API.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#description ⇒ Object
The application description.
-
#flags ⇒ Object
Returns the value of attribute flags.
-
#key ⇒ Object
The unique identifier of this application.
-
#kind ⇒ Object
To distinguish the kind of application.
-
#name ⇒ Object
The name of the application.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationRep
Initializes the object
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 121 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApplicationRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApplicationRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'flags') self.flags = attributes[:'flags'] end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_version') self._version = attributes[:'_version'] end if attributes.key?(:'auto_added') self.auto_added = attributes[:'auto_added'] else self.auto_added = nil end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'_maintainer') self._maintainer = attributes[:'_maintainer'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
20 21 22 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 20 def _access @_access end |
#_links ⇒ Object
The location and content type of related resources
23 24 25 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 23 def _links @_links end |
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
42 43 44 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 42 def _maintainer @_maintainer end |
#_version ⇒ Object
Version of the application
26 27 28 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 26 def _version @_version end |
#auto_added ⇒ Object
Whether the application was automatically created because it was included in a context when a LaunchDarkly SDK evaluated a feature flag, or was created through the LaunchDarkly UI or REST API.
29 30 31 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 29 def auto_added @auto_added end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
31 32 33 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 31 def creation_date @creation_date end |
#description ⇒ Object
The application description
34 35 36 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 34 def description @description end |
#flags ⇒ Object
Returns the value of attribute flags.
18 19 20 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 18 def flags @flags end |
#key ⇒ Object
The unique identifier of this application
37 38 39 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 37 def key @key end |
#kind ⇒ Object
To distinguish the kind of application
40 41 42 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 40 def kind @kind end |
#name ⇒ Object
The name of the application
45 46 47 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 45 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
87 88 89 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 87 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
92 93 94 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 92 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 70 def self.attribute_map { :'flags' => :'flags', :'_access' => :'_access', :'_links' => :'_links', :'_version' => :'_version', :'auto_added' => :'autoAdded', :'creation_date' => :'creationDate', :'description' => :'description', :'key' => :'key', :'kind' => :'kind', :'_maintainer' => :'_maintainer', :'name' => :'name' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 300 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
114 115 116 117 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 114 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 97 def self.openapi_types { :'flags' => :'ApplicationFlagCollectionRep', :'_access' => :'Access', :'_links' => :'Hash<String, Link>', :'_version' => :'Integer', :'auto_added' => :'Boolean', :'creation_date' => :'Integer', :'description' => :'String', :'key' => :'String', :'kind' => :'String', :'_maintainer' => :'ApplicationMaintainerRep', :'name' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 269 def ==(o) return true if self.equal?(o) self.class == o.class && flags == o.flags && _access == o._access && _links == o._links && _version == o._version && auto_added == o.auto_added && creation_date == o.creation_date && description == o.description && key == o.key && kind == o.kind && _maintainer == o._maintainer && name == o.name end |
#eql?(o) ⇒ Boolean
287 288 289 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 287 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
293 294 295 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 293 def hash [flags, _access, _links, _version, auto_added, creation_date, description, key, kind, _maintainer, name].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 192 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @auto_added.nil? invalid_properties.push('invalid value for "auto_added", auto_added cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
322 323 324 325 326 327 328 329 330 331 332 333 334 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 322 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
216 217 218 219 220 221 222 223 224 225 |
# File 'lib/launchdarkly_api/models/application_rep.rb', line 216 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @auto_added.nil? return false if @key.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["browser", "mobile", "server"]) return false unless kind_validator.valid?(@kind) return false if @name.nil? true end |