Class: LaunchDarklyApi::ApplicationVersionRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ApplicationVersionRep
- Defined in:
- lib/launchdarkly_api/models/application_version_rep.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_version ⇒ Object
Version of the application version.
-
#auto_added ⇒ Object
Whether the application version was automatically created, because it was included in a context when a LaunchDarkly SDK evaluated a feature flag, or if the application version was created through the LaunchDarkly UI or REST API.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#key ⇒ Object
The unique identifier of this application version.
-
#name ⇒ Object
The name of this version.
-
#supported ⇒ Object
Whether this version is supported.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApplicationVersionRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ApplicationVersionRep
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApplicationVersionRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApplicationVersionRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_version') self._version = attributes[:'_version'] end if attributes.key?(:'auto_added') self.auto_added = attributes[:'auto_added'] else self.auto_added = nil end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'supported') self.supported = attributes[:'supported'] end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
18 19 20 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 18 def _access @_access end |
#_links ⇒ Object
The location and content type of related resources
21 22 23 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 21 def _links @_links end |
#_version ⇒ Object
Version of the application version
24 25 26 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 24 def _version @_version end |
#auto_added ⇒ Object
Whether the application version was automatically created, because it was included in a context when a LaunchDarkly SDK evaluated a feature flag, or if the application version was created through the LaunchDarkly UI or REST API.
27 28 29 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 27 def auto_added @auto_added end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
29 30 31 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 29 def creation_date @creation_date end |
#key ⇒ Object
The unique identifier of this application version
32 33 34 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 32 def key @key end |
#name ⇒ Object
The name of this version
35 36 37 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 35 def name @name end |
#supported ⇒ Object
Whether this version is supported. Only applicable if the application kind is mobile.
38 39 40 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 38 def supported @supported end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 41 def self.attribute_map { :'_access' => :'_access', :'_links' => :'_links', :'_version' => :'_version', :'auto_added' => :'autoAdded', :'creation_date' => :'creationDate', :'key' => :'key', :'name' => :'name', :'supported' => :'supported' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 231 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 65 def self.openapi_types { :'_access' => :'Access', :'_links' => :'Hash<String, Link>', :'_version' => :'Integer', :'auto_added' => :'Boolean', :'creation_date' => :'Integer', :'key' => :'String', :'name' => :'String', :'supported' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 203 def ==(o) return true if self.equal?(o) self.class == o.class && _access == o._access && _links == o._links && _version == o._version && auto_added == o.auto_added && creation_date == o.creation_date && key == o.key && name == o.name && supported == o.supported end |
#eql?(o) ⇒ Boolean
218 219 220 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 218 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
224 225 226 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 224 def hash [_access, _links, _version, auto_added, creation_date, key, name, supported].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 143 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @auto_added.nil? invalid_properties.push('invalid value for "auto_added", auto_added cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 253 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
163 164 165 166 167 168 169 |
# File 'lib/launchdarkly_api/models/application_version_rep.rb', line 163 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @auto_added.nil? return false if @key.nil? return false if @name.nil? true end |