Class: LaunchDarklyApi::ApprovalRequestSetting
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ApprovalRequestSetting
- Defined in:
- lib/launchdarkly_api/models/approval_request_setting.rb
Overview
Configuration that controls how changes to a resource are gated by approvals.
Instance Attribute Summary collapse
-
#auto_apply_approved_changes ⇒ Object
Automatically apply changes that have been approved by all reviewers.
-
#bypass_approvals_for_pending_changes ⇒ Object
Whether to skip approvals for pending changes.
-
#can_apply_declined_changes ⇒ Object
Allow applying the change as long as at least one person has approved.
-
#can_review_own_request ⇒ Object
Allow someone who makes an approval request to apply their own change.
-
#min_num_approvals ⇒ Object
Sets the amount of approvals required before a member can apply a change.
-
#required ⇒ Object
If approvals are required for this environment.
-
#required_approval_tags ⇒ Object
Require approval only on flags with the provided tags.
-
#service_config ⇒ Object
Arbitrary service-specific configuration.
-
#service_kind ⇒ Object
Which service to use for managing approvals.
-
#service_kind_configuration_id ⇒ Object
Optional integration configuration ID of a custom approval integration.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApprovalRequestSetting
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApprovalRequestSetting
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApprovalRequestSetting` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApprovalRequestSetting`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'required') self.required = attributes[:'required'] else self.required = nil end if attributes.key?(:'bypass_approvals_for_pending_changes') self.bypass_approvals_for_pending_changes = attributes[:'bypass_approvals_for_pending_changes'] else self.bypass_approvals_for_pending_changes = nil end if attributes.key?(:'min_num_approvals') self.min_num_approvals = attributes[:'min_num_approvals'] else self.min_num_approvals = nil end if attributes.key?(:'can_review_own_request') self.can_review_own_request = attributes[:'can_review_own_request'] else self.can_review_own_request = nil end if attributes.key?(:'can_apply_declined_changes') self.can_apply_declined_changes = attributes[:'can_apply_declined_changes'] else self.can_apply_declined_changes = nil end if attributes.key?(:'auto_apply_approved_changes') self.auto_apply_approved_changes = attributes[:'auto_apply_approved_changes'] end if attributes.key?(:'service_kind') self.service_kind = attributes[:'service_kind'] else self.service_kind = nil end if attributes.key?(:'service_config') if (value = attributes[:'service_config']).is_a?(Hash) self.service_config = value end else self.service_config = nil end if attributes.key?(:'required_approval_tags') if (value = attributes[:'required_approval_tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'service_kind_configuration_id') self.service_kind_configuration_id = attributes[:'service_kind_configuration_id'] end end |
Instance Attribute Details
#auto_apply_approved_changes ⇒ Object
Automatically apply changes that have been approved by all reviewers. This field is only applicable for approval services other than LaunchDarkly.
35 36 37 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 35 def auto_apply_approved_changes @auto_apply_approved_changes end |
#bypass_approvals_for_pending_changes ⇒ Object
Whether to skip approvals for pending changes
23 24 25 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 23 def bypass_approvals_for_pending_changes @bypass_approvals_for_pending_changes end |
#can_apply_declined_changes ⇒ Object
Allow applying the change as long as at least one person has approved
32 33 34 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 32 def can_apply_declined_changes @can_apply_declined_changes end |
#can_review_own_request ⇒ Object
Allow someone who makes an approval request to apply their own change
29 30 31 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 29 def can_review_own_request @can_review_own_request end |
#min_num_approvals ⇒ Object
Sets the amount of approvals required before a member can apply a change. The minimum is one and the maximum is five.
26 27 28 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 26 def min_num_approvals @min_num_approvals end |
#required ⇒ Object
If approvals are required for this environment
20 21 22 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 20 def required @required end |
#required_approval_tags ⇒ Object
Require approval only on flags with the provided tags. Otherwise all flags will require approval.
44 45 46 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 44 def @required_approval_tags end |
#service_config ⇒ Object
Arbitrary service-specific configuration
41 42 43 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 41 def service_config @service_config end |
#service_kind ⇒ Object
Which service to use for managing approvals
38 39 40 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 38 def service_kind @service_kind end |
#service_kind_configuration_id ⇒ Object
Optional integration configuration ID of a custom approval integration. This is an Enterprise-only feature.
47 48 49 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 47 def service_kind_configuration_id @service_kind_configuration_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 367 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 50 def self.attribute_map { :'required' => :'required', :'bypass_approvals_for_pending_changes' => :'bypassApprovalsForPendingChanges', :'min_num_approvals' => :'minNumApprovals', :'can_review_own_request' => :'canReviewOwnRequest', :'can_apply_declined_changes' => :'canApplyDeclinedChanges', :'auto_apply_approved_changes' => :'autoApplyApprovedChanges', :'service_kind' => :'serviceKind', :'service_config' => :'serviceConfig', :'required_approval_tags' => :'requiredApprovalTags', :'service_kind_configuration_id' => :'serviceKindConfigurationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 343 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
92 93 94 95 96 97 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 92 def self.openapi_nullable Set.new([ :'auto_apply_approved_changes', :'service_kind_configuration_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 76 def self.openapi_types { :'required' => :'Boolean', :'bypass_approvals_for_pending_changes' => :'Boolean', :'min_num_approvals' => :'Integer', :'can_review_own_request' => :'Boolean', :'can_apply_declined_changes' => :'Boolean', :'auto_apply_approved_changes' => :'Boolean', :'service_kind' => :'String', :'service_config' => :'Hash<String, Object>', :'required_approval_tags' => :'Array<String>', :'service_kind_configuration_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
313 314 315 316 317 318 319 320 321 322 323 324 325 326 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 313 def ==(o) return true if self.equal?(o) self.class == o.class && required == o.required && bypass_approvals_for_pending_changes == o.bypass_approvals_for_pending_changes && min_num_approvals == o.min_num_approvals && can_review_own_request == o.can_review_own_request && can_apply_declined_changes == o.can_apply_declined_changes && auto_apply_approved_changes == o.auto_apply_approved_changes && service_kind == o.service_kind && service_config == o.service_config && == o. && service_kind_configuration_id == o.service_kind_configuration_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 438 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
330 331 332 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 330 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
336 337 338 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 336 def hash [required, bypass_approvals_for_pending_changes, min_num_approvals, can_review_own_request, can_apply_declined_changes, auto_apply_approved_changes, service_kind, service_config, , service_kind_configuration_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 178 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @required.nil? invalid_properties.push('invalid value for "required", required cannot be nil.') end if @bypass_approvals_for_pending_changes.nil? invalid_properties.push('invalid value for "bypass_approvals_for_pending_changes", bypass_approvals_for_pending_changes cannot be nil.') end if @min_num_approvals.nil? invalid_properties.push('invalid value for "min_num_approvals", min_num_approvals cannot be nil.') end if @can_review_own_request.nil? invalid_properties.push('invalid value for "can_review_own_request", can_review_own_request cannot be nil.') end if @can_apply_declined_changes.nil? invalid_properties.push('invalid value for "can_apply_declined_changes", can_apply_declined_changes cannot be nil.') end if @service_kind.nil? invalid_properties.push('invalid value for "service_kind", service_kind cannot be nil.') end if @service_config.nil? invalid_properties.push('invalid value for "service_config", service_config cannot be nil.') end if @required_approval_tags.nil? invalid_properties.push('invalid value for "required_approval_tags", required_approval_tags cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
414 415 416 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 414 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
420 421 422 423 424 425 426 427 428 429 430 431 432 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 420 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
408 409 410 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 408 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/launchdarkly_api/models/approval_request_setting.rb', line 218 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @required.nil? return false if @bypass_approvals_for_pending_changes.nil? return false if @min_num_approvals.nil? return false if @can_review_own_request.nil? return false if @can_apply_declined_changes.nil? return false if @service_kind.nil? return false if @service_config.nil? return false if @required_approval_tags.nil? true end |