Class: LaunchDarklyApi::ApprovalRequestSettingsPatch
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ApprovalRequestSettingsPatch
- Defined in:
- lib/launchdarkly_api/models/approval_request_settings_patch.rb
Instance Attribute Summary collapse
-
#auto_apply_approved_changes ⇒ Object
Automatically apply changes that have been approved by all reviewers.
-
#bypass_approvals_for_pending_changes ⇒ Object
Whether to skip approvals for pending changes.
-
#can_apply_declined_changes ⇒ Object
Allow applying the change as long as at least one person has approved.
-
#can_review_own_request ⇒ Object
Allow someone who makes an approval request to apply their own change.
-
#environment_key ⇒ Object
Returns the value of attribute environment_key.
-
#min_num_approvals ⇒ Object
Sets the amount of approvals required before a member can apply a change.
-
#required ⇒ Object
If approvals are required for this environment.
-
#required_approval_tags ⇒ Object
Require approval only on flags with the provided tags.
-
#resource_kind ⇒ Object
Returns the value of attribute resource_kind.
-
#service_config ⇒ Object
Arbitrary service-specific configuration.
-
#service_kind ⇒ Object
Which service to use for managing approvals.
-
#service_kind_configuration_id ⇒ Object
Optional integration configuration ID of a custom approval integration.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ApprovalRequestSettingsPatch
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ApprovalRequestSettingsPatch
Initializes the object
103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 103 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ApprovalRequestSettingsPatch` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ApprovalRequestSettingsPatch`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'auto_apply_approved_changes') self.auto_apply_approved_changes = attributes[:'auto_apply_approved_changes'] end if attributes.key?(:'bypass_approvals_for_pending_changes') self.bypass_approvals_for_pending_changes = attributes[:'bypass_approvals_for_pending_changes'] end if attributes.key?(:'can_apply_declined_changes') self.can_apply_declined_changes = attributes[:'can_apply_declined_changes'] end if attributes.key?(:'can_review_own_request') self.can_review_own_request = attributes[:'can_review_own_request'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] else self.environment_key = nil end if attributes.key?(:'min_num_approvals') self.min_num_approvals = attributes[:'min_num_approvals'] end if attributes.key?(:'required') self.required = attributes[:'required'] end if attributes.key?(:'required_approval_tags') if (value = attributes[:'required_approval_tags']).is_a?(Array) self. = value end end if attributes.key?(:'resource_kind') self.resource_kind = attributes[:'resource_kind'] else self.resource_kind = nil end if attributes.key?(:'service_config') if (value = attributes[:'service_config']).is_a?(Hash) self.service_config = value end end if attributes.key?(:'service_kind') self.service_kind = attributes[:'service_kind'] end if attributes.key?(:'service_kind_configuration_id') self.service_kind_configuration_id = attributes[:'service_kind_configuration_id'] end end |
Instance Attribute Details
#auto_apply_approved_changes ⇒ Object
Automatically apply changes that have been approved by all reviewers. This field is only applicable for approval services other than LaunchDarkly.
19 20 21 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 19 def auto_apply_approved_changes @auto_apply_approved_changes end |
#bypass_approvals_for_pending_changes ⇒ Object
Whether to skip approvals for pending changes
22 23 24 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 22 def bypass_approvals_for_pending_changes @bypass_approvals_for_pending_changes end |
#can_apply_declined_changes ⇒ Object
Allow applying the change as long as at least one person has approved
25 26 27 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 25 def can_apply_declined_changes @can_apply_declined_changes end |
#can_review_own_request ⇒ Object
Allow someone who makes an approval request to apply their own change
28 29 30 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 28 def can_review_own_request @can_review_own_request end |
#environment_key ⇒ Object
Returns the value of attribute environment_key.
30 31 32 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 30 def environment_key @environment_key end |
#min_num_approvals ⇒ Object
Sets the amount of approvals required before a member can apply a change. The minimum is one and the maximum is five.
33 34 35 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 33 def min_num_approvals @min_num_approvals end |
#required ⇒ Object
If approvals are required for this environment
36 37 38 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 36 def required @required end |
#required_approval_tags ⇒ Object
Require approval only on flags with the provided tags. Otherwise all flags will require approval.
39 40 41 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 39 def @required_approval_tags end |
#resource_kind ⇒ Object
Returns the value of attribute resource_kind.
41 42 43 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 41 def resource_kind @resource_kind end |
#service_config ⇒ Object
Arbitrary service-specific configuration
44 45 46 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 44 def service_config @service_config end |
#service_kind ⇒ Object
Which service to use for managing approvals
47 48 49 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 47 def service_kind @service_kind end |
#service_kind_configuration_id ⇒ Object
Optional integration configuration ID of a custom approval integration. This is an Enterprise-only feature.
50 51 52 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 50 def service_kind_configuration_id @service_kind_configuration_id end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 256 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 71 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 53 def self.attribute_map { :'auto_apply_approved_changes' => :'autoApplyApprovedChanges', :'bypass_approvals_for_pending_changes' => :'bypassApprovalsForPendingChanges', :'can_apply_declined_changes' => :'canApplyDeclinedChanges', :'can_review_own_request' => :'canReviewOwnRequest', :'environment_key' => :'environmentKey', :'min_num_approvals' => :'minNumApprovals', :'required' => :'required', :'required_approval_tags' => :'requiredApprovalTags', :'resource_kind' => :'resourceKind', :'service_config' => :'serviceConfig', :'service_kind' => :'serviceKind', :'service_kind_configuration_id' => :'serviceKindConfigurationId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 232 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 98 99 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 94 def self.openapi_nullable Set.new([ :'auto_apply_approved_changes', :'service_kind_configuration_id' ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 76 def self.openapi_types { :'auto_apply_approved_changes' => :'Boolean', :'bypass_approvals_for_pending_changes' => :'Boolean', :'can_apply_declined_changes' => :'Boolean', :'can_review_own_request' => :'Boolean', :'environment_key' => :'String', :'min_num_approvals' => :'Integer', :'required' => :'Boolean', :'required_approval_tags' => :'Array<String>', :'resource_kind' => :'String', :'service_config' => :'Hash<String, Object>', :'service_kind' => :'String', :'service_kind_configuration_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 200 def ==(o) return true if self.equal?(o) self.class == o.class && auto_apply_approved_changes == o.auto_apply_approved_changes && bypass_approvals_for_pending_changes == o.bypass_approvals_for_pending_changes && can_apply_declined_changes == o.can_apply_declined_changes && can_review_own_request == o.can_review_own_request && environment_key == o.environment_key && min_num_approvals == o.min_num_approvals && required == o.required && == o. && resource_kind == o.resource_kind && service_config == o.service_config && service_kind == o.service_kind && service_kind_configuration_id == o.service_kind_configuration_id end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
327 328 329 330 331 332 333 334 335 336 337 338 339 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 327 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
219 220 221 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 219 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
225 226 227 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 225 def hash [auto_apply_approved_changes, bypass_approvals_for_pending_changes, can_apply_declined_changes, can_review_own_request, environment_key, min_num_approvals, required, , resource_kind, service_config, service_kind, service_kind_configuration_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @environment_key.nil? invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.') end if @resource_kind.nil? invalid_properties.push('invalid value for "resource_kind", resource_kind cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
303 304 305 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 303 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 309 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
297 298 299 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 297 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 |
# File 'lib/launchdarkly_api/models/approval_request_settings_patch.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @environment_key.nil? return false if @resource_kind.nil? true end |