Class: LaunchDarklyApi::ApprovalsBetaApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ApprovalsBetaApi
- Defined in:
- lib/launchdarkly_api/api/approvals_beta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_approval_request_settings(ld_api_version, project_key, opts = {}) ⇒ Hash<String, ApprovalRequestSettingWithEnvs>
Get approval request settings Get the approval request settings for the given project, optionally filtered by environment and resource kind.
-
#get_approval_request_settings_with_http_info(ld_api_version, project_key, opts = {}) ⇒ Array<(Hash<String, ApprovalRequestSettingWithEnvs>, Integer, Hash)>
Get approval request settings Get the approval request settings for the given project, optionally filtered by environment and resource kind.
-
#initialize(api_client = ApiClient.default) ⇒ ApprovalsBetaApi
constructor
A new instance of ApprovalsBetaApi.
-
#patch_approval_request(id, opts = {}) ⇒ FlagConfigApprovalRequestResponse
Update approval request Perform a partial update to an approval request.
-
#patch_approval_request_settings(ld_api_version, project_key, opts = {}) ⇒ Hash<String, ApprovalRequestSettingWithEnvs>
Update approval request settings Perform a partial update to approval request settings.
-
#patch_approval_request_settings_with_http_info(ld_api_version, project_key, opts = {}) ⇒ Array<(Hash<String, ApprovalRequestSettingWithEnvs>, Integer, Hash)>
Update approval request settings Perform a partial update to approval request settings.
-
#patch_approval_request_with_http_info(id, opts = {}) ⇒ Array<(FlagConfigApprovalRequestResponse, Integer, Hash)>
Update approval request Perform a partial update to an approval request.
-
#patch_flag_config_approval_request(project_key, feature_flag_key, environment_key, id, opts = {}) ⇒ FlagConfigApprovalRequestResponse
Update flag approval request Perform a partial update to an approval request.
-
#patch_flag_config_approval_request_with_http_info(project_key, feature_flag_key, environment_key, id, opts = {}) ⇒ Array<(FlagConfigApprovalRequestResponse, Integer, Hash)>
Update flag approval request Perform a partial update to an approval request.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ ApprovalsBetaApi
Returns a new instance of ApprovalsBetaApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_approval_request_settings(ld_api_version, project_key, opts = {}) ⇒ Hash<String, ApprovalRequestSettingWithEnvs>
Get approval request settings Get the approval request settings for the given project, optionally filtered by environment and resource kind.
31 32 33 34 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 31 def get_approval_request_settings(ld_api_version, project_key, opts = {}) data, _status_code, _headers = get_approval_request_settings_with_http_info(ld_api_version, project_key, opts) data end |
#get_approval_request_settings_with_http_info(ld_api_version, project_key, opts = {}) ⇒ Array<(Hash<String, ApprovalRequestSettingWithEnvs>, Integer, Hash)>
Get approval request settings Get the approval request settings for the given project, optionally filtered by environment and resource kind.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 45 def get_approval_request_settings_with_http_info(ld_api_version, project_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApprovalsBetaApi.get_approval_request_settings ...' end # verify the required parameter 'ld_api_version' is set if @api_client.config.client_side_validation && ld_api_version.nil? fail ArgumentError, "Missing the required parameter 'ld_api_version' when calling ApprovalsBetaApi.get_approval_request_settings" end # verify enum value allowable_values = ["beta"] if @api_client.config.client_side_validation && !allowable_values.include?(ld_api_version) fail ArgumentError, "invalid value for \"ld_api_version\", must be one of #{allowable_values}" end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ApprovalsBetaApi.get_approval_request_settings" end # resource path local_var_path = '/api/v2/approval-requests/projects/{projectKey}/settings'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)) # query parameters query_params = opts[:query_params] || {} query_params[:'environmentKey'] = opts[:'environment_key'] if !opts[:'environment_key'].nil? query_params[:'resourceKind'] = opts[:'resource_kind'] if !opts[:'resource_kind'].nil? query_params[:'expand'] = opts[:'expand'] if !opts[:'expand'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] header_params[:'LD-API-Version'] = ld_api_version # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Hash<String, ApprovalRequestSettingWithEnvs>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ApprovalsBetaApi.get_approval_request_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApprovalsBetaApi#get_approval_request_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_approval_request(id, opts = {}) ⇒ FlagConfigApprovalRequestResponse
Update approval request Perform a partial update to an approval request. Updating an approval request uses the semantic patch format. This endpoint works with any approval requests. To make a semantic patch request, you must append ‘domain-model=launchdarkly.semanticpatch` to your `Content-Type` header. To learn more, read [Updates using semantic patch](launchdarkly.com/docs/api#updates-using-semantic-patch). ### Instructions Semantic patch requests support the following `kind` instruction for updating an approval request. #### addReviewers Adds the specified members and teams to the existing list of reviewers. You must include at least one of `notifyMemberIds` and `notifyTeamKeys`. ##### Parameters - `notifyMemberIds`: (Optional) List of member IDs. - `notifyTeamKeys`: (Optional) List of team keys. Here’s an example: “‘json { "instructions": [{ "kind": "addReviewers", "notifyMemberIds": [ "user-key-123abc", "user-key-456def" ], "notifyTeamKeys": [ "team-key-789abc"] }] } “`
111 112 113 114 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 111 def patch_approval_request(id, opts = {}) data, _status_code, _headers = patch_approval_request_with_http_info(id, opts) data end |
#patch_approval_request_settings(ld_api_version, project_key, opts = {}) ⇒ Hash<String, ApprovalRequestSettingWithEnvs>
Update approval request settings Perform a partial update to approval request settings
176 177 178 179 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 176 def patch_approval_request_settings(ld_api_version, project_key, opts = {}) data, _status_code, _headers = patch_approval_request_settings_with_http_info(ld_api_version, project_key, opts) data end |
#patch_approval_request_settings_with_http_info(ld_api_version, project_key, opts = {}) ⇒ Array<(Hash<String, ApprovalRequestSettingWithEnvs>, Integer, Hash)>
Update approval request settings Perform a partial update to approval request settings
188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 188 def patch_approval_request_settings_with_http_info(ld_api_version, project_key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApprovalsBetaApi.patch_approval_request_settings ...' end # verify the required parameter 'ld_api_version' is set if @api_client.config.client_side_validation && ld_api_version.nil? fail ArgumentError, "Missing the required parameter 'ld_api_version' when calling ApprovalsBetaApi.patch_approval_request_settings" end # verify enum value allowable_values = ["beta"] if @api_client.config.client_side_validation && !allowable_values.include?(ld_api_version) fail ArgumentError, "invalid value for \"ld_api_version\", must be one of #{allowable_values}" end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ApprovalsBetaApi.patch_approval_request_settings" end # resource path local_var_path = '/api/v2/approval-requests/projects/{projectKey}/settings'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end header_params[:'LD-API-Version'] = ld_api_version # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'approval_request_settings_patch']) # return_type return_type = opts[:debug_return_type] || 'Hash<String, ApprovalRequestSettingWithEnvs>' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ApprovalsBetaApi.patch_approval_request_settings", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApprovalsBetaApi#patch_approval_request_settings\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_approval_request_with_http_info(id, opts = {}) ⇒ Array<(FlagConfigApprovalRequestResponse, Integer, Hash)>
Update approval request Perform a partial update to an approval request. Updating an approval request uses the semantic patch format. This endpoint works with any approval requests. To make a semantic patch request, you must append `domain-model=launchdarkly.semanticpatch` to your `Content-Type` header. To learn more, read [Updates using semantic patch](launchdarkly.com/docs/api#updates-using-semantic-patch). ### Instructions Semantic patch requests support the following `kind` instruction for updating an approval request. #### addReviewers Adds the specified members and teams to the existing list of reviewers. You must include at least one of `notifyMemberIds` and `notifyTeamKeys`. ##### Parameters - `notifyMemberIds`: (Optional) List of member IDs. - `notifyTeamKeys`: (Optional) List of team keys. Here's an example: ```json { "instructions": [{ "kind": "addReviewers", "notifyMemberIds": [ "user-key-123abc", "user-key-456def" ], "notifyTeamKeys": [ "team-key-789abc"] }] } ```
121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 121 def patch_approval_request_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApprovalsBetaApi.patch_approval_request ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ApprovalsBetaApi.patch_approval_request" end # resource path local_var_path = '/api/v2/approval-requests/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FlagConfigApprovalRequestResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ApprovalsBetaApi.patch_approval_request", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApprovalsBetaApi#patch_approval_request\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_flag_config_approval_request(project_key, feature_flag_key, environment_key, id, opts = {}) ⇒ FlagConfigApprovalRequestResponse
Update flag approval request Perform a partial update to an approval request. Updating an approval request uses the semantic patch format. This endpoint requires a feature flag key, and can only be used for updating approval requests for flags. To make a semantic patch request, you must append ‘domain-model=launchdarkly.semanticpatch` to your `Content-Type` header. To learn more, read [Updates using semantic patch](launchdarkly.com/docs/api#updates-using-semantic-patch). ### Instructions Semantic patch requests support the following `kind` instruction for updating an approval request. #### addReviewers Adds the specified members and teams to the existing list of reviewers. You must include at least one of `notifyMemberIds` and `notifyTeamKeys`. ##### Parameters - `notifyMemberIds`: (Optional) List of member IDs. - `notifyTeamKeys`: (Optional) List of team keys.
259 260 261 262 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 259 def patch_flag_config_approval_request(project_key, feature_flag_key, environment_key, id, opts = {}) data, _status_code, _headers = patch_flag_config_approval_request_with_http_info(project_key, feature_flag_key, environment_key, id, opts) data end |
#patch_flag_config_approval_request_with_http_info(project_key, feature_flag_key, environment_key, id, opts = {}) ⇒ Array<(FlagConfigApprovalRequestResponse, Integer, Hash)>
Update flag approval request Perform a partial update to an approval request. Updating an approval request uses the semantic patch format. This endpoint requires a feature flag key, and can only be used for updating approval requests for flags. To make a semantic patch request, you must append `domain-model=launchdarkly.semanticpatch` to your `Content-Type` header. To learn more, read [Updates using semantic patch](launchdarkly.com/docs/api#updates-using-semantic-patch). ### Instructions Semantic patch requests support the following `kind` instruction for updating an approval request. #### addReviewers Adds the specified members and teams to the existing list of reviewers. You must include at least one of `notifyMemberIds` and `notifyTeamKeys`. ##### Parameters - `notifyMemberIds`: (Optional) List of member IDs. - `notifyTeamKeys`: (Optional) List of team keys.
272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/launchdarkly_api/api/approvals_beta_api.rb', line 272 def patch_flag_config_approval_request_with_http_info(project_key, feature_flag_key, environment_key, id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: ApprovalsBetaApi.patch_flag_config_approval_request ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling ApprovalsBetaApi.patch_flag_config_approval_request" end # verify the required parameter 'feature_flag_key' is set if @api_client.config.client_side_validation && feature_flag_key.nil? fail ArgumentError, "Missing the required parameter 'feature_flag_key' when calling ApprovalsBetaApi.patch_flag_config_approval_request" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling ApprovalsBetaApi.patch_flag_config_approval_request" end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling ApprovalsBetaApi.patch_flag_config_approval_request" end # resource path local_var_path = '/api/v2/projects/{projectKey}/flags/{featureFlagKey}/environments/{environmentKey}/approval-requests/{id}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'featureFlagKey' + '}', CGI.escape(feature_flag_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FlagConfigApprovalRequestResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"ApprovalsBetaApi.patch_flag_config_approval_request", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: ApprovalsBetaApi#patch_flag_config_approval_request\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |