Class: LaunchDarklyApi::AuditLogApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::AuditLogApi
- Defined in:
- lib/launchdarkly_api/api/audit_log_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_audit_log_entries(opts = {}) ⇒ AuditLogEntryListingRepCollection
List audit log entries Get a list of all audit log entries.
-
#get_audit_log_entries_with_http_info(opts = {}) ⇒ Array<(AuditLogEntryListingRepCollection, Integer, Hash)>
List audit log entries Get a list of all audit log entries.
-
#get_audit_log_entry(id, opts = {}) ⇒ AuditLogEntryRep
Get audit log entry Fetch a detailed audit log entry representation.
-
#get_audit_log_entry_with_http_info(id, opts = {}) ⇒ Array<(AuditLogEntryRep, Integer, Hash)>
Get audit log entry Fetch a detailed audit log entry representation.
-
#initialize(api_client = ApiClient.default) ⇒ AuditLogApi
constructor
A new instance of AuditLogApi.
-
#post_audit_log_entries(opts = {}) ⇒ AuditLogEntryListingRepCollection
Search audit log entries Search your audit log entries.
-
#post_audit_log_entries_with_http_info(opts = {}) ⇒ Array<(AuditLogEntryListingRepCollection, Integer, Hash)>
Search audit log entries Search your audit log entries.
-
#post_audit_log_entry_counts(after, statement_post, opts = {}) ⇒ CountBucketsResult
Get audit log entry counts Returns aggregate counts of audit log entries per time bucket.
-
#post_audit_log_entry_counts_with_http_info(after, statement_post, opts = {}) ⇒ Array<(CountBucketsResult, Integer, Hash)>
Get audit log entry counts Returns aggregate counts of audit log entries per time bucket.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ AuditLogApi
Returns a new instance of AuditLogApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_audit_log_entries(opts = {}) ⇒ AuditLogEntryListingRepCollection
List audit log entries Get a list of all audit log entries. The query parameters let you restrict the results that return by date ranges, resource specifiers, or a full-text search query. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read About the resource specifier syntax.
31 32 33 34 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 31 def get_audit_log_entries(opts = {}) data, _status_code, _headers = get_audit_log_entries_with_http_info(opts) data end |
#get_audit_log_entries_with_http_info(opts = {}) ⇒ Array<(AuditLogEntryListingRepCollection, Integer, Hash)>
List audit log entries Get a list of all audit log entries. The query parameters let you restrict the results that return by date ranges, resource specifiers, or a full-text search query. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read About the resource specifier syntax.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 45 def get_audit_log_entries_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuditLogApi.get_audit_log_entries ...' end # resource path local_var_path = '/api/v2/auditlog' # query parameters query_params = opts[:query_params] || {} query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'spec'] = opts[:'spec'] if !opts[:'spec'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AuditLogEntryListingRepCollection' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"AuditLogApi.get_audit_log_entries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditLogApi#get_audit_log_entries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_audit_log_entry(id, opts = {}) ⇒ AuditLogEntryRep
Get audit log entry
Fetch a detailed audit log entry representation. The detailed representation includes several fields that are not present in the summary representation, including: - previousVersion: a JSON representation of the previous version of the entity. - currentVersion: a JSON representation of the current version of the entity. - delta: the JSON patch body that was used in the request to update the entity. This is only included if the update was made through a JSON patch. It is null when the update was made using semantic patch. Because most flag updates are made using semantic patch, this field is rarely returned.
99 100 101 102 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 99 def get_audit_log_entry(id, opts = {}) data, _status_code, _headers = get_audit_log_entry_with_http_info(id, opts) data end |
#get_audit_log_entry_with_http_info(id, opts = {}) ⇒ Array<(AuditLogEntryRep, Integer, Hash)>
Get audit log entry Fetch a detailed audit log entry representation. The detailed representation includes several fields that are not present in the summary representation, including: - `previousVersion`: a JSON representation of the previous version of the entity. - `currentVersion`: a JSON representation of the current version of the entity. - `delta`: the JSON patch body that was used in the request to update the entity. This is only included if the update was made through a JSON patch. It is null when the update was made using semantic patch. Because most flag updates are made using semantic patch, this field is rarely returned.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 109 def get_audit_log_entry_with_http_info(id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuditLogApi.get_audit_log_entry ...' end # verify the required parameter 'id' is set if @api_client.config.client_side_validation && id.nil? fail ArgumentError, "Missing the required parameter 'id' when calling AuditLogApi.get_audit_log_entry" end # resource path local_var_path = '/api/v2/auditlog/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'AuditLogEntryRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"AuditLogApi.get_audit_log_entry", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditLogApi#get_audit_log_entry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_audit_log_entries(opts = {}) ⇒ AuditLogEntryListingRepCollection
Search audit log entries Search your audit log entries. The query parameters let you restrict the results that return by date ranges, or a full-text search query. The request body lets you restrict the results that return by resource specifiers. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read About the resource specifier syntax.
166 167 168 169 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 166 def post_audit_log_entries(opts = {}) data, _status_code, _headers = post_audit_log_entries_with_http_info(opts) data end |
#post_audit_log_entries_with_http_info(opts = {}) ⇒ Array<(AuditLogEntryListingRepCollection, Integer, Hash)>
Search audit log entries Search your audit log entries. The query parameters let you restrict the results that return by date ranges, or a full-text search query. The request body lets you restrict the results that return by resource specifiers. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read About the resource specifier syntax.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 180 def post_audit_log_entries_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuditLogApi.post_audit_log_entries ...' end # resource path local_var_path = '/api/v2/auditlog' # query parameters query_params = opts[:query_params] || {} query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil? query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil? query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'statement_post']) # return_type return_type = opts[:debug_return_type] || 'AuditLogEntryListingRepCollection' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"AuditLogApi.post_audit_log_entries", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditLogApi#post_audit_log_entries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_audit_log_entry_counts(after, statement_post, opts = {}) ⇒ CountBucketsResult
Get audit log entry counts Returns aggregate counts of audit log entries per time bucket. Used for dashboard overlays that show flag targeting changes.
241 242 243 244 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 241 def post_audit_log_entry_counts(after, statement_post, opts = {}) data, _status_code, _headers = post_audit_log_entry_counts_with_http_info(after, statement_post, opts) data end |
#post_audit_log_entry_counts_with_http_info(after, statement_post, opts = {}) ⇒ Array<(CountBucketsResult, Integer, Hash)>
Get audit log entry counts Returns aggregate counts of audit log entries per time bucket. Used for dashboard overlays that show flag targeting changes.
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 254 def post_audit_log_entry_counts_with_http_info(after, statement_post, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: AuditLogApi.post_audit_log_entry_counts ...' end # verify the required parameter 'after' is set if @api_client.config.client_side_validation && after.nil? fail ArgumentError, "Missing the required parameter 'after' when calling AuditLogApi.post_audit_log_entry_counts" end # verify the required parameter 'statement_post' is set if @api_client.config.client_side_validation && statement_post.nil? fail ArgumentError, "Missing the required parameter 'statement_post' when calling AuditLogApi.post_audit_log_entry_counts" end # resource path local_var_path = '/api/v2/auditlog/counts' # query parameters query_params = opts[:query_params] || {} query_params[:'after'] = after query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil? query_params[:'buckets'] = opts[:'buckets'] if !opts[:'buckets'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(statement_post) # return_type return_type = opts[:debug_return_type] || 'CountBucketsResult' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"AuditLogApi.post_audit_log_entry_counts", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: AuditLogApi#post_audit_log_entry_counts\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |