Class: LaunchDarklyApi::AuditLogApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/audit_log_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ AuditLogApi

Returns a new instance of AuditLogApi.



19
20
21
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_audit_log_entries(opts = {}) ⇒ AuditLogEntryListingRepCollection

List audit log entries Get a list of all audit log entries. The query parameters let you restrict the results that return by date ranges, resource specifiers, or a full-text search query. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read [About the resource specifier syntax](docs.launchdarkly.com/home/account/role-resources#about-the-resource-specifier-syntax).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :before (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries this returns occurred before the timestamp.

  • :after (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries this returns occurred after the timestamp.

  • :q (String)

    Text to search for. You can search for the full or partial name of the resource.

  • :limit (Integer)

    A limit on the number of audit log entries that return. Set between 1 and 20. The default is 10.

  • :spec (String)

    A resource specifier that lets you filter audit log listings by resource

Returns:



31
32
33
34
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 31

def get_audit_log_entries(opts = {})
  data, _status_code, _headers = get_audit_log_entries_with_http_info(opts)
  data
end

#get_audit_log_entries_with_http_info(opts = {}) ⇒ Array<(AuditLogEntryListingRepCollection, Integer, Hash)>

List audit log entries Get a list of all audit log entries. The query parameters let you restrict the results that return by date ranges, resource specifiers, or a full-text search query. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read [About the resource specifier syntax](docs.launchdarkly.com/home/account/role-resources#about-the-resource-specifier-syntax).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :before (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries this returns occurred before the timestamp.

  • :after (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries this returns occurred after the timestamp.

  • :q (String)

    Text to search for. You can search for the full or partial name of the resource.

  • :limit (Integer)

    A limit on the number of audit log entries that return. Set between 1 and 20. The default is 10.

  • :spec (String)

    A resource specifier that lets you filter audit log listings by resource

Returns:



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 45

def get_audit_log_entries_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuditLogApi.get_audit_log_entries ...'
  end
  # resource path
  local_var_path = '/api/v2/auditlog'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?
  query_params[:'spec'] = opts[:'spec'] if !opts[:'spec'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AuditLogEntryListingRepCollection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"AuditLogApi.get_audit_log_entries",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuditLogApi#get_audit_log_entries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#get_audit_log_entry(id, opts = {}) ⇒ AuditLogEntryRep

Get audit log entry Fetch a detailed audit log entry representation. The detailed representation includes several fields that are not present in the summary representation, including: - ‘delta`: the JSON patch body that was used in the request to update the entity - `previousVersion`: a JSON representation of the previous version of the entity - `currentVersion`: a JSON representation of the current version of the entity

Parameters:

  • id (String)

    The ID of the audit log entry

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:



99
100
101
102
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 99

def get_audit_log_entry(id, opts = {})
  data, _status_code, _headers = get_audit_log_entry_with_http_info(id, opts)
  data
end

#get_audit_log_entry_with_http_info(id, opts = {}) ⇒ Array<(AuditLogEntryRep, Integer, Hash)>

Get audit log entry Fetch a detailed audit log entry representation. The detailed representation includes several fields that are not present in the summary representation, including: - &#x60;delta&#x60;: the JSON patch body that was used in the request to update the entity - &#x60;previousVersion&#x60;: a JSON representation of the previous version of the entity - &#x60;currentVersion&#x60;: a JSON representation of the current version of the entity

Parameters:

  • id (String)

    The ID of the audit log entry

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(AuditLogEntryRep, Integer, Hash)>)

    AuditLogEntryRep data, response status code and response headers



109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 109

def get_audit_log_entry_with_http_info(id, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuditLogApi.get_audit_log_entry ...'
  end
  # verify the required parameter 'id' is set
  if @api_client.config.client_side_validation && id.nil?
    fail ArgumentError, "Missing the required parameter 'id' when calling AuditLogApi.get_audit_log_entry"
  end
  # resource path
  local_var_path = '/api/v2/auditlog/{id}'.sub('{' + 'id' + '}', CGI.escape(id.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'AuditLogEntryRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"AuditLogApi.get_audit_log_entry",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuditLogApi#get_audit_log_entry\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#post_audit_log_entries(opts = {}) ⇒ AuditLogEntryListingRepCollection

Search audit log entries Search your audit log entries. The query parameters let you restrict the results that return by date ranges, or a full-text search query. The request body lets you restrict the results that return by resource specifiers. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read [About the resource specifier syntax](docs.launchdarkly.com/home/account/role-resources#about-the-resource-specifier-syntax).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :before (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries returned occurred before the timestamp.

  • :after (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries returned occurred after the timestamp.

  • :q (String)

    Text to search for. You can search for the full or partial name of the resource.

  • :limit (Integer)

    A limit on the number of audit log entries that return. Set between 1 and 20. The default is 10.

  • :statement_post (Array<StatementPost>)

Returns:



166
167
168
169
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 166

def post_audit_log_entries(opts = {})
  data, _status_code, _headers = post_audit_log_entries_with_http_info(opts)
  data
end

#post_audit_log_entries_with_http_info(opts = {}) ⇒ Array<(AuditLogEntryListingRepCollection, Integer, Hash)>

Search audit log entries Search your audit log entries. The query parameters let you restrict the results that return by date ranges, or a full-text search query. The request body lets you restrict the results that return by resource specifiers. LaunchDarkly uses a resource specifier syntax to name resources or collections of resources. To learn more, read [About the resource specifier syntax](docs.launchdarkly.com/home/account/role-resources#about-the-resource-specifier-syntax).

Parameters:

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :before (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries returned occurred before the timestamp.

  • :after (Integer)

    A timestamp filter, expressed as a Unix epoch time in milliseconds. All entries returned occurred after the timestamp.

  • :q (String)

    Text to search for. You can search for the full or partial name of the resource.

  • :limit (Integer)

    A limit on the number of audit log entries that return. Set between 1 and 20. The default is 10.

  • :statement_post (Array<StatementPost>)

Returns:



180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
# File 'lib/launchdarkly_api/api/audit_log_api.rb', line 180

def post_audit_log_entries_with_http_info(opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: AuditLogApi.post_audit_log_entries ...'
  end
  # resource path
  local_var_path = '/api/v2/auditlog'

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'before'] = opts[:'before'] if !opts[:'before'].nil?
  query_params[:'after'] = opts[:'after'] if !opts[:'after'].nil?
  query_params[:'q'] = opts[:'q'] if !opts[:'q'].nil?
  query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])
  # HTTP header 'Content-Type'
  content_type = @api_client.select_header_content_type(['application/json'])
  if !content_type.nil?
      header_params['Content-Type'] = content_type
  end

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body] || @api_client.object_to_http_body(opts[:'statement_post'])

  # return_type
  return_type = opts[:debug_return_type] || 'AuditLogEntryListingRepCollection'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"AuditLogApi.post_audit_log_entries",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:POST, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: AuditLogApi#post_audit_log_entries\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end