Class: LaunchDarklyApi::AuditLogEntryListingRep
- Inherits:
-
Object
- Object
- LaunchDarklyApi::AuditLogEntryListingRep
- Defined in:
- lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb
Instance Attribute Summary collapse
-
#_account_id ⇒ Object
The ID of the account to which this audit log entry belongs.
-
#_id ⇒ Object
The ID of the audit log entry.
-
#_links ⇒ Object
The location and content type of related resources.
-
#accesses ⇒ Object
Details on the actions performed and resources acted on in this audit log entry.
-
#app ⇒ Object
Returns the value of attribute app.
-
#comment ⇒ Object
Optional comment for the audit log entry.
-
#date ⇒ Object
Returns the value of attribute date.
-
#description ⇒ Object
Description of the change recorded in the audit log entry.
-
#kind ⇒ Object
Returns the value of attribute kind.
-
#member ⇒ Object
Returns the value of attribute member.
-
#name ⇒ Object
The name of the resource this audit log entry refers to.
-
#parent ⇒ Object
Returns the value of attribute parent.
-
#short_description ⇒ Object
Shorter version of the change recorded in the audit log entry.
-
#subject ⇒ Object
Returns the value of attribute subject.
-
#target ⇒ Object
Returns the value of attribute target.
-
#title ⇒ Object
A description of what occurred, in the format
membertitleVerbtarget. -
#title_verb ⇒ Object
The action and resource recorded in this audit log entry.
-
#token ⇒ Object
Returns the value of attribute token.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ AuditLogEntryListingRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ AuditLogEntryListingRep
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::AuditLogEntryListingRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::AuditLogEntryListingRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_account_id') self._account_id = attributes[:'_account_id'] else self._account_id = nil end if attributes.key?(:'date') self.date = attributes[:'date'] else self.date = nil end if attributes.key?(:'accesses') if (value = attributes[:'accesses']).is_a?(Array) self.accesses = value end else self.accesses = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'short_description') self.short_description = attributes[:'short_description'] else self.short_description = nil end if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'subject') self.subject = attributes[:'subject'] end if attributes.key?(:'member') self.member = attributes[:'member'] end if attributes.key?(:'token') self.token = attributes[:'token'] end if attributes.key?(:'app') self.app = attributes[:'app'] end if attributes.key?(:'title_verb') self.title_verb = attributes[:'title_verb'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'target') self.target = attributes[:'target'] end if attributes.key?(:'parent') self.parent = attributes[:'parent'] end end |
Instance Attribute Details
#_account_id ⇒ Object
The ID of the account to which this audit log entry belongs
25 26 27 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 25 def _account_id @_account_id end |
#_id ⇒ Object
The ID of the audit log entry
22 23 24 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 22 def _id @_id end |
#_links ⇒ Object
The location and content type of related resources
19 20 21 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 19 def _links @_links end |
#accesses ⇒ Object
Details on the actions performed and resources acted on in this audit log entry
30 31 32 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 30 def accesses @accesses end |
#app ⇒ Object
Returns the value of attribute app.
52 53 54 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 52 def app @app end |
#comment ⇒ Object
Optional comment for the audit log entry
44 45 46 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 44 def comment @comment end |
#date ⇒ Object
Returns the value of attribute date.
27 28 29 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 27 def date @date end |
#description ⇒ Object
Description of the change recorded in the audit log entry
38 39 40 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 38 def description @description end |
#kind ⇒ Object
Returns the value of attribute kind.
32 33 34 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 32 def kind @kind end |
#member ⇒ Object
Returns the value of attribute member.
48 49 50 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 48 def member @member end |
#name ⇒ Object
The name of the resource this audit log entry refers to
35 36 37 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 35 def name @name end |
#parent ⇒ Object
Returns the value of attribute parent.
62 63 64 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 62 def parent @parent end |
#short_description ⇒ Object
Shorter version of the change recorded in the audit log entry
41 42 43 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 41 def short_description @short_description end |
#subject ⇒ Object
Returns the value of attribute subject.
46 47 48 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 46 def subject @subject end |
#target ⇒ Object
Returns the value of attribute target.
60 61 62 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 60 def target @target end |
#title ⇒ Object
A description of what occurred, in the format member titleVerb target
58 59 60 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 58 def title @title end |
#title_verb ⇒ Object
The action and resource recorded in this audit log entry
55 56 57 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 55 def title_verb @title_verb end |
#token ⇒ Object
Returns the value of attribute token.
50 51 52 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 50 def token @token end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 453 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 65 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'_account_id' => :'_accountId', :'date' => :'date', :'accesses' => :'accesses', :'kind' => :'kind', :'name' => :'name', :'description' => :'description', :'short_description' => :'shortDescription', :'comment' => :'comment', :'subject' => :'subject', :'member' => :'member', :'token' => :'token', :'app' => :'app', :'title_verb' => :'titleVerb', :'title' => :'title', :'target' => :'target', :'parent' => :'parent' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 429 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 99 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_id' => :'String', :'_account_id' => :'String', :'date' => :'Integer', :'accesses' => :'Array<ResourceAccess>', :'kind' => :'String', :'name' => :'String', :'description' => :'String', :'short_description' => :'String', :'comment' => :'String', :'subject' => :'SubjectDataRep', :'member' => :'MemberDataRep', :'token' => :'TokenSummary', :'app' => :'AuthorizedAppDataRep', :'title_verb' => :'String', :'title' => :'String', :'target' => :'TargetResourceRep', :'parent' => :'ParentResourceRep' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 391 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && _account_id == o._account_id && date == o.date && accesses == o.accesses && kind == o.kind && name == o.name && description == o.description && short_description == o.short_description && comment == o.comment && subject == o.subject && member == o.member && token == o.token && app == o.app && title_verb == o.title_verb && title == o.title && target == o.target && parent == o.parent end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
524 525 526 527 528 529 530 531 532 533 534 535 536 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 524 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
416 417 418 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 416 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
422 423 424 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 422 def hash [_links, _id, _account_id, date, accesses, kind, name, description, short_description, comment, subject, member, token, app, title_verb, title, target, parent].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 241 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_account_id.nil? invalid_properties.push('invalid value for "_account_id", _account_id cannot be nil.') end if @date.nil? invalid_properties.push('invalid value for "date", date cannot be nil.') end if @accesses.nil? invalid_properties.push('invalid value for "accesses", accesses cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @short_description.nil? invalid_properties.push('invalid value for "short_description", short_description cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
500 501 502 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 500 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
506 507 508 509 510 511 512 513 514 515 516 517 518 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 506 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
494 495 496 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 494 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
285 286 287 288 289 290 291 292 293 294 295 296 297 |
# File 'lib/launchdarkly_api/models/audit_log_entry_listing_rep.rb', line 285 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_links.nil? return false if @_id.nil? return false if @_account_id.nil? return false if @date.nil? return false if @accesses.nil? return false if @kind.nil? return false if @name.nil? return false if @description.nil? return false if @short_description.nil? true end |