Class: LaunchDarklyApi::BigSegmentStoreIntegration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::BigSegmentStoreIntegration
- Defined in:
- lib/launchdarkly_api/models/big_segment_store_integration.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_id ⇒ Object
The integration ID.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_status ⇒ Object
Returns the value of attribute _status.
-
#config ⇒ Object
Returns the value of attribute config.
-
#environment_key ⇒ Object
The environment key.
-
#integration_key ⇒ Object
The integration key.
-
#name ⇒ Object
Name of the configuration.
-
#on ⇒ Object
Whether the configuration is turned on.
-
#project_key ⇒ Object
The project key.
-
#tags ⇒ Object
List of tags for this configuration.
-
#version ⇒ Object
Version of the current configuration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ BigSegmentStoreIntegration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ BigSegmentStoreIntegration
Initializes the object
126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 126 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::BigSegmentStoreIntegration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::BigSegmentStoreIntegration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') self._links = attributes[:'_links'] else self._links = nil end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'integration_key') self.integration_key = attributes[:'integration_key'] else self.integration_key = nil end if attributes.key?(:'project_key') self.project_key = attributes[:'project_key'] else self.project_key = nil end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] else self.environment_key = nil end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Hash) self.config = value end else self.config = nil end if attributes.key?(:'on') self.on = attributes[:'on'] else self.on = nil end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end else self. = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_status') self._status = attributes[:'_status'] else self._status = nil end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
46 47 48 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 46 def _access @_access end |
#_id ⇒ Object
The integration ID
21 22 23 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 21 def _id @_id end |
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 18 def _links @_links end |
#_status ⇒ Object
Returns the value of attribute _status.
48 49 50 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 48 def _status @_status end |
#config ⇒ Object
Returns the value of attribute config.
32 33 34 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 32 def config @config end |
#environment_key ⇒ Object
The environment key
30 31 32 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 30 def environment_key @environment_key end |
#integration_key ⇒ Object
The integration key
24 25 26 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 24 def integration_key @integration_key end |
#name ⇒ Object
Name of the configuration
41 42 43 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 41 def name @name end |
#on ⇒ Object
Whether the configuration is turned on
35 36 37 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 35 def on @on end |
#project_key ⇒ Object
The project key
27 28 29 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 27 def project_key @project_key end |
#tags ⇒ Object
List of tags for this configuration
38 39 40 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 38 def @tags end |
#version ⇒ Object
Version of the current configuration
44 45 46 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 44 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
91 92 93 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 91 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
96 97 98 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 96 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 73 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'integration_key' => :'integrationKey', :'project_key' => :'projectKey', :'environment_key' => :'environmentKey', :'config' => :'config', :'on' => :'on', :'tags' => :'tags', :'name' => :'name', :'version' => :'version', :'_access' => :'_access', :'_status' => :'_status' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
431 432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 431 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
119 120 121 122 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 119 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 101 def self.openapi_types { :'_links' => :'BigSegmentStoreIntegrationLinks', :'_id' => :'String', :'integration_key' => :'String', :'project_key' => :'String', :'environment_key' => :'String', :'config' => :'Hash<String, Object>', :'on' => :'Boolean', :'tags' => :'Array<String>', :'name' => :'String', :'version' => :'Integer', :'_access' => :'Access', :'_status' => :'BigSegmentStoreStatus' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 399 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && integration_key == o.integration_key && project_key == o.project_key && environment_key == o.environment_key && config == o.config && on == o.on && == o. && name == o.name && version == o.version && _access == o._access && _status == o._status end |
#eql?(o) ⇒ Boolean
418 419 420 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 418 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
424 425 426 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 424 def hash [_links, _id, integration_key, project_key, environment_key, config, on, , name, version, _access, _status].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 217 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @integration_key.nil? invalid_properties.push('invalid value for "integration_key", integration_key cannot be nil.') end if @project_key.nil? invalid_properties.push('invalid value for "project_key", project_key cannot be nil.') end if @environment_key.nil? invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.') end if @config.nil? invalid_properties.push('invalid value for "config", config cannot be nil.') end if @on.nil? invalid_properties.push('invalid value for "on", on cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @_status.nil? invalid_properties.push('invalid value for "_status", _status cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
453 454 455 456 457 458 459 460 461 462 463 464 465 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 453 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 |
# File 'lib/launchdarkly_api/models/big_segment_store_integration.rb', line 269 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_links.nil? return false if @_id.nil? return false if @integration_key.nil? integration_key_validator = EnumAttributeValidator.new('String', ["redis", "dynamodb"]) return false unless integration_key_validator.valid?(@integration_key) return false if @project_key.nil? return false if @environment_key.nil? return false if @config.nil? return false if @on.nil? return false if @tags.nil? return false if @name.nil? return false if @version.nil? return false if @_status.nil? true end |