Class: LaunchDarklyApi::CallerIdentityRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::CallerIdentityRep
- Defined in:
- lib/launchdarkly_api/models/caller_identity_rep.rb
Instance Attribute Summary collapse
-
#account_id ⇒ Object
Returns the value of attribute account_id.
-
#auth_kind ⇒ Object
Returns the value of attribute auth_kind.
-
#client_id ⇒ Object
Returns the value of attribute client_id.
-
#environment_id ⇒ Object
Returns the value of attribute environment_id.
-
#environment_name ⇒ Object
Returns the value of attribute environment_name.
-
#member_id ⇒ Object
Returns the value of attribute member_id.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#project_name ⇒ Object
Returns the value of attribute project_name.
-
#scopes ⇒ Object
Returns the value of attribute scopes.
-
#service_token ⇒ Object
Returns the value of attribute service_token.
-
#token_id ⇒ Object
Returns the value of attribute token_id.
-
#token_kind ⇒ Object
Returns the value of attribute token_kind.
-
#token_name ⇒ Object
Returns the value of attribute token_name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CallerIdentityRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CallerIdentityRep
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CallerIdentityRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CallerIdentityRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'account_id') self.account_id = attributes[:'account_id'] end if attributes.key?(:'environment_id') self.environment_id = attributes[:'environment_id'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'environment_name') self.environment_name = attributes[:'environment_name'] end if attributes.key?(:'project_name') self.project_name = attributes[:'project_name'] end if attributes.key?(:'auth_kind') self.auth_kind = attributes[:'auth_kind'] end if attributes.key?(:'token_kind') self.token_kind = attributes[:'token_kind'] end if attributes.key?(:'client_id') self.client_id = attributes[:'client_id'] end if attributes.key?(:'token_name') self.token_name = attributes[:'token_name'] end if attributes.key?(:'token_id') self.token_id = attributes[:'token_id'] end if attributes.key?(:'member_id') self.member_id = attributes[:'member_id'] end if attributes.key?(:'service_token') self.service_token = attributes[:'service_token'] end if attributes.key?(:'scopes') if (value = attributes[:'scopes']).is_a?(Array) self.scopes = value end end end |
Instance Attribute Details
#account_id ⇒ Object
Returns the value of attribute account_id.
18 19 20 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 18 def account_id @account_id end |
#auth_kind ⇒ Object
Returns the value of attribute auth_kind.
28 29 30 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 28 def auth_kind @auth_kind end |
#client_id ⇒ Object
Returns the value of attribute client_id.
32 33 34 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 32 def client_id @client_id end |
#environment_id ⇒ Object
Returns the value of attribute environment_id.
20 21 22 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 20 def environment_id @environment_id end |
#environment_name ⇒ Object
Returns the value of attribute environment_name.
24 25 26 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 24 def environment_name @environment_name end |
#member_id ⇒ Object
Returns the value of attribute member_id.
38 39 40 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 38 def member_id @member_id end |
#project_id ⇒ Object
Returns the value of attribute project_id.
22 23 24 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 22 def project_id @project_id end |
#project_name ⇒ Object
Returns the value of attribute project_name.
26 27 28 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 26 def project_name @project_name end |
#scopes ⇒ Object
Returns the value of attribute scopes.
42 43 44 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 42 def scopes @scopes end |
#service_token ⇒ Object
Returns the value of attribute service_token.
40 41 42 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 40 def service_token @service_token end |
#token_id ⇒ Object
Returns the value of attribute token_id.
36 37 38 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 36 def token_id @token_id end |
#token_kind ⇒ Object
Returns the value of attribute token_kind.
30 31 32 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 30 def token_kind @token_kind end |
#token_name ⇒ Object
Returns the value of attribute token_name.
34 35 36 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 34 def token_name @token_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
64 65 66 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 64 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
69 70 71 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 69 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 45 def self.attribute_map { :'account_id' => :'accountId', :'environment_id' => :'environmentId', :'project_id' => :'projectId', :'environment_name' => :'environmentName', :'project_name' => :'projectName', :'auth_kind' => :'authKind', :'token_kind' => :'tokenKind', :'client_id' => :'clientId', :'token_name' => :'tokenName', :'token_id' => :'tokenId', :'member_id' => :'memberId', :'service_token' => :'serviceToken', :'scopes' => :'scopes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 74 def self.openapi_types { :'account_id' => :'String', :'environment_id' => :'String', :'project_id' => :'String', :'environment_name' => :'String', :'project_name' => :'String', :'auth_kind' => :'String', :'token_kind' => :'String', :'client_id' => :'String', :'token_name' => :'String', :'token_id' => :'String', :'member_id' => :'String', :'service_token' => :'Boolean', :'scopes' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && account_id == o.account_id && environment_id == o.environment_id && project_id == o.project_id && environment_name == o.environment_name && project_name == o.project_name && auth_kind == o.auth_kind && token_kind == o.token_kind && client_id == o.client_id && token_name == o.token_name && token_id == o.token_id && member_id == o.member_id && service_token == o.service_token && scopes == o.scopes end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 212 def hash [account_id, environment_id, project_id, environment_name, project_name, auth_kind, token_kind, client_id, token_name, token_id, member_id, service_token, scopes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
179 180 181 182 |
# File 'lib/launchdarkly_api/models/caller_identity_rep.rb', line 179 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |