Class: LaunchDarklyApi::Client

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/client.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Client

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
# File 'lib/launchdarkly_api/models/client.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Client` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Client`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'_account_id')
    self. = attributes[:'_account_id']
  else
    self. = nil
  end

  if attributes.key?(:'_client_id')
    self._client_id = attributes[:'_client_id']
  else
    self._client_id = nil
  end

  if attributes.key?(:'_client_secret')
    self._client_secret = attributes[:'_client_secret']
  end

  if attributes.key?(:'redirect_uri')
    self.redirect_uri = attributes[:'redirect_uri']
  else
    self.redirect_uri = nil
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  else
    self._creation_date = nil
  end
end

Instance Attribute Details

#_account_idObject

The account ID the client is registered under



28
29
30
# File 'lib/launchdarkly_api/models/client.rb', line 28

def 
  @_account_id
end

#_client_idObject

The client’s unique ID



31
32
33
# File 'lib/launchdarkly_api/models/client.rb', line 31

def _client_id
  @_client_id
end

#_client_secretObject

The client secret. This will only be shown upon creation.



34
35
36
# File 'lib/launchdarkly_api/models/client.rb', line 34

def _client_secret
  @_client_secret
end

#_creation_dateObject

Returns the value of attribute _creation_date.



39
40
41
# File 'lib/launchdarkly_api/models/client.rb', line 39

def _creation_date
  @_creation_date
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/client.rb', line 19

def _links
  @_links
end

#descriptionObject

Client description



25
26
27
# File 'lib/launchdarkly_api/models/client.rb', line 25

def description
  @description
end

#nameObject

Client name



22
23
24
# File 'lib/launchdarkly_api/models/client.rb', line 22

def name
  @name
end

#redirect_uriObject

The client’s redirect URI



37
38
39
# File 'lib/launchdarkly_api/models/client.rb', line 37

def redirect_uri
  @redirect_uri
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
# File 'lib/launchdarkly_api/models/client.rb', line 307

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/launchdarkly_api/models/client.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/launchdarkly_api/models/client.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/launchdarkly_api/models/client.rb', line 42

def self.attribute_map
  {
    :'_links' => :'_links',
    :'name' => :'name',
    :'description' => :'description',
    :'_account_id' => :'_accountId',
    :'_client_id' => :'_clientId',
    :'_client_secret' => :'_clientSecret',
    :'redirect_uri' => :'redirectUri',
    :'_creation_date' => :'_creationDate'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
# File 'lib/launchdarkly_api/models/client.rb', line 283

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/launchdarkly_api/models/client.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/launchdarkly_api/models/client.rb', line 66

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'name' => :'String',
    :'description' => :'String',
    :'_account_id' => :'String',
    :'_client_id' => :'String',
    :'_client_secret' => :'String',
    :'redirect_uri' => :'String',
    :'_creation_date' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



255
256
257
258
259
260
261
262
263
264
265
266
# File 'lib/launchdarkly_api/models/client.rb', line 255

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      name == o.name &&
      description == o.description &&
       == o. &&
      _client_id == o._client_id &&
      _client_secret == o._client_secret &&
      redirect_uri == o.redirect_uri &&
      _creation_date == o._creation_date
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



378
379
380
381
382
383
384
385
386
387
388
389
390
# File 'lib/launchdarkly_api/models/client.rb', line 378

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


270
271
272
# File 'lib/launchdarkly_api/models/client.rb', line 270

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



276
277
278
# File 'lib/launchdarkly_api/models/client.rb', line 276

def hash
  [_links, name, description, , _client_id, _client_secret, redirect_uri, _creation_date].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
# File 'lib/launchdarkly_api/models/client.rb', line 150

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @_account_id.nil?
    invalid_properties.push('invalid value for "_account_id", _account_id cannot be nil.')
  end

  if @_client_id.nil?
    invalid_properties.push('invalid value for "_client_id", _client_id cannot be nil.')
  end

  if @redirect_uri.nil?
    invalid_properties.push('invalid value for "redirect_uri", redirect_uri cannot be nil.')
  end

  if @_creation_date.nil?
    invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



354
355
356
# File 'lib/launchdarkly_api/models/client.rb', line 354

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



360
361
362
363
364
365
366
367
368
369
370
371
372
# File 'lib/launchdarkly_api/models/client.rb', line 360

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



348
349
350
# File 'lib/launchdarkly_api/models/client.rb', line 348

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



182
183
184
185
186
187
188
189
190
191
# File 'lib/launchdarkly_api/models/client.rb', line 182

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @name.nil?
  return false if @_account_id.nil?
  return false if @_client_id.nil?
  return false if @redirect_uri.nil?
  return false if @_creation_date.nil?
  true
end