Class: LaunchDarklyApi::ConditionOutput

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/condition_output.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ConditionOutput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
# File 'lib/launchdarkly_api/models/condition_output.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ConditionOutput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ConditionOutput`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'_execution')
    self._execution = attributes[:'_execution']
  else
    self._execution = nil
  end

  if attributes.key?(:'schedule_kind')
    self.schedule_kind = attributes[:'schedule_kind']
  end

  if attributes.key?(:'execution_date')
    self.execution_date = attributes[:'execution_date']
  end

  if attributes.key?(:'wait_duration')
    self.wait_duration = attributes[:'wait_duration']
  end

  if attributes.key?(:'wait_duration_unit')
    self.wait_duration_unit = attributes[:'wait_duration_unit']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'notify_member_ids')
    if (value = attributes[:'notify_member_ids']).is_a?(Array)
      self.notify_member_ids = value
    end
  else
    self.notify_member_ids = nil
  end

  if attributes.key?(:'all_reviews')
    if (value = attributes[:'all_reviews']).is_a?(Array)
      self.all_reviews = value
    end
  else
    self.all_reviews = nil
  end

  if attributes.key?(:'review_status')
    self.review_status = attributes[:'review_status']
  else
    self.review_status = nil
  end

  if attributes.key?(:'applied_date')
    self.applied_date = attributes[:'applied_date']
  end

  if attributes.key?(:'creation_config')
    if (value = attributes[:'creation_config']).is_a?(Hash)
      self.creation_config = value
    end
  end
end

Instance Attribute Details

#_executionObject

Returns the value of attribute _execution.



22
23
24
# File 'lib/launchdarkly_api/models/condition_output.rb', line 22

def _execution
  @_execution
end

#_idObject

Returns the value of attribute _id.



18
19
20
# File 'lib/launchdarkly_api/models/condition_output.rb', line 18

def _id
  @_id
end

#all_reviewsObject

Returns the value of attribute all_reviews.



36
37
38
# File 'lib/launchdarkly_api/models/condition_output.rb', line 36

def all_reviews
  @all_reviews
end

#applied_dateObject

Returns the value of attribute applied_date.



40
41
42
# File 'lib/launchdarkly_api/models/condition_output.rb', line 40

def applied_date
  @applied_date
end

#creation_configObject

Returns the value of attribute creation_config.



42
43
44
# File 'lib/launchdarkly_api/models/condition_output.rb', line 42

def creation_config
  @creation_config
end

#descriptionObject

Returns the value of attribute description.



32
33
34
# File 'lib/launchdarkly_api/models/condition_output.rb', line 32

def description
  @description
end

#execution_dateObject

Returns the value of attribute execution_date.



26
27
28
# File 'lib/launchdarkly_api/models/condition_output.rb', line 26

def execution_date
  @execution_date
end

#kindObject

Returns the value of attribute kind.



20
21
22
# File 'lib/launchdarkly_api/models/condition_output.rb', line 20

def kind
  @kind
end

#notify_member_idsObject

Returns the value of attribute notify_member_ids.



34
35
36
# File 'lib/launchdarkly_api/models/condition_output.rb', line 34

def notify_member_ids
  @notify_member_ids
end

#review_statusObject

Returns the value of attribute review_status.



38
39
40
# File 'lib/launchdarkly_api/models/condition_output.rb', line 38

def review_status
  @review_status
end

#schedule_kindObject

Returns the value of attribute schedule_kind.



24
25
26
# File 'lib/launchdarkly_api/models/condition_output.rb', line 24

def schedule_kind
  @schedule_kind
end

#wait_durationObject

Returns the value of attribute wait_duration.



28
29
30
# File 'lib/launchdarkly_api/models/condition_output.rb', line 28

def wait_duration
  @wait_duration
end

#wait_duration_unitObject

Returns the value of attribute wait_duration_unit.



30
31
32
# File 'lib/launchdarkly_api/models/condition_output.rb', line 30

def wait_duration_unit
  @wait_duration_unit
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
# File 'lib/launchdarkly_api/models/condition_output.rb', line 283

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



64
65
66
# File 'lib/launchdarkly_api/models/condition_output.rb', line 64

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



45
46
47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
# File 'lib/launchdarkly_api/models/condition_output.rb', line 45

def self.attribute_map
  {
    :'_id' => :'_id',
    :'kind' => :'kind',
    :'_execution' => :'_execution',
    :'schedule_kind' => :'scheduleKind',
    :'execution_date' => :'executionDate',
    :'wait_duration' => :'waitDuration',
    :'wait_duration_unit' => :'waitDurationUnit',
    :'description' => :'description',
    :'notify_member_ids' => :'notifyMemberIds',
    :'all_reviews' => :'allReviews',
    :'review_status' => :'reviewStatus',
    :'applied_date' => :'appliedDate',
    :'creation_config' => :'creationConfig'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
# File 'lib/launchdarkly_api/models/condition_output.rb', line 259

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/launchdarkly_api/models/condition_output.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/launchdarkly_api/models/condition_output.rb', line 69

def self.openapi_types
  {
    :'_id' => :'String',
    :'kind' => :'String',
    :'_execution' => :'ExecutionOutput',
    :'schedule_kind' => :'String',
    :'execution_date' => :'Integer',
    :'wait_duration' => :'Integer',
    :'wait_duration_unit' => :'String',
    :'description' => :'String',
    :'notify_member_ids' => :'Array<String>',
    :'all_reviews' => :'Array<ReviewOutput>',
    :'review_status' => :'String',
    :'applied_date' => :'Integer',
    :'creation_config' => :'Hash<String, Object>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/launchdarkly_api/models/condition_output.rb', line 226

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      kind == o.kind &&
      _execution == o._execution &&
      schedule_kind == o.schedule_kind &&
      execution_date == o.execution_date &&
      wait_duration == o.wait_duration &&
      wait_duration_unit == o.wait_duration_unit &&
      description == o.description &&
      notify_member_ids == o.notify_member_ids &&
      all_reviews == o.all_reviews &&
      review_status == o.review_status &&
      applied_date == o.applied_date &&
      creation_config == o.creation_config
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



354
355
356
357
358
359
360
361
362
363
364
365
366
# File 'lib/launchdarkly_api/models/condition_output.rb', line 354

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


246
247
248
# File 'lib/launchdarkly_api/models/condition_output.rb', line 246

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



252
253
254
# File 'lib/launchdarkly_api/models/condition_output.rb', line 252

def hash
  [_id, kind, _execution, schedule_kind, execution_date, wait_duration, wait_duration_unit, description, notify_member_ids, all_reviews, review_status, applied_date, creation_config].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
# File 'lib/launchdarkly_api/models/condition_output.rb', line 181

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @_execution.nil?
    invalid_properties.push('invalid value for "_execution", _execution cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @notify_member_ids.nil?
    invalid_properties.push('invalid value for "notify_member_ids", notify_member_ids cannot be nil.')
  end

  if @all_reviews.nil?
    invalid_properties.push('invalid value for "all_reviews", all_reviews cannot be nil.')
  end

  if @review_status.nil?
    invalid_properties.push('invalid value for "review_status", review_status cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



330
331
332
# File 'lib/launchdarkly_api/models/condition_output.rb', line 330

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



336
337
338
339
340
341
342
343
344
345
346
347
348
# File 'lib/launchdarkly_api/models/condition_output.rb', line 336

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



324
325
326
# File 'lib/launchdarkly_api/models/condition_output.rb', line 324

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



213
214
215
216
217
218
219
220
221
222
# File 'lib/launchdarkly_api/models/condition_output.rb', line 213

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @_execution.nil?
  return false if @description.nil?
  return false if @notify_member_ids.nil?
  return false if @all_reviews.nil?
  return false if @review_status.nil?
  true
end