Class: LaunchDarklyApi::ContextInstanceSegmentMembership
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ContextInstanceSegmentMembership
- Defined in:
- lib/launchdarkly_api/models/context_instance_segment_membership.rb
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#description ⇒ Object
A description of the segment’s purpose.
-
#external ⇒ Object
If the segment is a synced segment, the name of the external source.
-
#is_individually_targeted ⇒ Object
Whether the context is explicitly included in this segment.
-
#is_member ⇒ Object
Whether the context is a member of this segment, either by explicit inclusion or by rule matching.
-
#is_rule_targeted ⇒ Object
Whether the context is captured by this segment’s rules.
-
#key ⇒ Object
A unique key used to reference the segment.
-
#name ⇒ Object
A human-friendly name for the segment.
-
#unbounded ⇒ Object
Whether this is an unbounded segment.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ContextInstanceSegmentMembership
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ContextInstanceSegmentMembership
Initializes the object
93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 93 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ContextInstanceSegmentMembership` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ContextInstanceSegmentMembership`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'unbounded') self.unbounded = attributes[:'unbounded'] else self.unbounded = nil end if attributes.key?(:'external') self.external = attributes[:'external'] else self.external = nil end if attributes.key?(:'is_member') self.is_member = attributes[:'is_member'] else self.is_member = nil end if attributes.key?(:'is_individually_targeted') self.is_individually_targeted = attributes[:'is_individually_targeted'] else self.is_individually_targeted = nil end if attributes.key?(:'is_rule_targeted') self.is_rule_targeted = attributes[:'is_rule_targeted'] else self.is_rule_targeted = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
43 44 45 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 43 def _links @_links end |
#description ⇒ Object
A description of the segment’s purpose
25 26 27 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 25 def description @description end |
#external ⇒ Object
If the segment is a synced segment, the name of the external source
31 32 33 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 31 def external @external end |
#is_individually_targeted ⇒ Object
Whether the context is explicitly included in this segment
37 38 39 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 37 def is_individually_targeted @is_individually_targeted end |
#is_member ⇒ Object
Whether the context is a member of this segment, either by explicit inclusion or by rule matching
34 35 36 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 34 def is_member @is_member end |
#is_rule_targeted ⇒ Object
Whether the context is captured by this segment’s rules. The value of this field is undefined if the context is also explicitly included (isIndividuallyTargeted is true).
40 41 42 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 40 def is_rule_targeted @is_rule_targeted end |
#key ⇒ Object
A unique key used to reference the segment
22 23 24 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 22 def key @key end |
#name ⇒ Object
A human-friendly name for the segment
19 20 21 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 19 def name @name end |
#unbounded ⇒ Object
Whether this is an unbounded segment. Unbounded segments, also called big segments, may be list-based segments with more than 15,000 entries, or synced segments.
28 29 30 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 28 def unbounded @unbounded end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 369 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
61 62 63 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 61 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
66 67 68 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 66 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 46 def self.attribute_map { :'name' => :'name', :'key' => :'key', :'description' => :'description', :'unbounded' => :'unbounded', :'external' => :'external', :'is_member' => :'isMember', :'is_individually_targeted' => :'isIndividuallyTargeted', :'is_rule_targeted' => :'isRuleTargeted', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 345 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
86 87 88 89 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 86 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 71 def self.openapi_types { :'name' => :'String', :'key' => :'String', :'description' => :'String', :'unbounded' => :'Boolean', :'external' => :'String', :'is_member' => :'Boolean', :'is_individually_targeted' => :'Boolean', :'is_rule_targeted' => :'Boolean', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 316 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && key == o.key && description == o.description && unbounded == o.unbounded && external == o.external && is_member == o.is_member && is_individually_targeted == o.is_individually_targeted && is_rule_targeted == o.is_rule_targeted && _links == o._links end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 440 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
332 333 334 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 332 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
338 339 340 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 338 def hash [name, key, description, unbounded, external, is_member, is_individually_targeted, is_rule_targeted, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 166 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @unbounded.nil? invalid_properties.push('invalid value for "unbounded", unbounded cannot be nil.') end if @external.nil? invalid_properties.push('invalid value for "external", external cannot be nil.') end if @is_member.nil? invalid_properties.push('invalid value for "is_member", is_member cannot be nil.') end if @is_individually_targeted.nil? invalid_properties.push('invalid value for "is_individually_targeted", is_individually_targeted cannot be nil.') end if @is_rule_targeted.nil? invalid_properties.push('invalid value for "is_rule_targeted", is_rule_targeted cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
416 417 418 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 416 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
422 423 424 425 426 427 428 429 430 431 432 433 434 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 422 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
410 411 412 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 410 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
210 211 212 213 214 215 216 217 218 219 220 221 222 |
# File 'lib/launchdarkly_api/models/context_instance_segment_membership.rb', line 210 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @key.nil? return false if @description.nil? return false if @unbounded.nil? return false if @external.nil? return false if @is_member.nil? return false if @is_individually_targeted.nil? return false if @is_rule_targeted.nil? return false if @_links.nil? true end |