Class: LaunchDarklyApi::ContextKindRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/context_kind_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ContextKindRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 99

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ContextKindRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ContextKindRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  else
    self.description = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'last_modified')
    self.last_modified = attributes[:'last_modified']
  else
    self.last_modified = nil
  end

  if attributes.key?(:'last_seen')
    self.last_seen = attributes[:'last_seen']
  end

  if attributes.key?(:'created_from')
    self.created_from = attributes[:'created_from']
  else
    self.created_from = nil
  end

  if attributes.key?(:'hide_in_targeting')
    self.hide_in_targeting = attributes[:'hide_in_targeting']
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end
end

Instance Attribute Details

The location and content type of related resources



45
46
47
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 45

def _links
  @_links
end

#archivedObject

Whether the context kind is archived. Archived context kinds are unavailable for targeting.



42
43
44
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 42

def archived
  @archived
end

#created_fromObject

Returns the value of attribute created_from.



36
37
38
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 36

def created_from
  @created_from
end

#creation_dateObject

Returns the value of attribute creation_date.



30
31
32
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 30

def creation_date
  @creation_date
end

#descriptionObject

The context kind description



25
26
27
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 25

def description
  @description
end

#hide_in_targetingObject

Alias for archived.



39
40
41
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 39

def hide_in_targeting
  @hide_in_targeting
end

#keyObject

The context kind key



19
20
21
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 19

def key
  @key
end

#last_modifiedObject

Returns the value of attribute last_modified.



32
33
34
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 32

def last_modified
  @last_modified
end

#last_seenObject

Returns the value of attribute last_seen.



34
35
36
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 34

def last_seen
  @last_seen
end

#nameObject

The context kind name



22
23
24
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 22

def name
  @name
end

#versionObject

The context kind version



28
29
30
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 28

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



65
66
67
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 65

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



70
71
72
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 70

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 48

def self.attribute_map
  {
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'version' => :'version',
    :'creation_date' => :'creationDate',
    :'last_modified' => :'lastModified',
    :'last_seen' => :'lastSeen',
    :'created_from' => :'createdFrom',
    :'hide_in_targeting' => :'hideInTargeting',
    :'archived' => :'archived',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 327

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



92
93
94
95
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 92

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 75

def self.openapi_types
  {
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'version' => :'Integer',
    :'creation_date' => :'Integer',
    :'last_modified' => :'Integer',
    :'last_seen' => :'Integer',
    :'created_from' => :'String',
    :'hide_in_targeting' => :'Boolean',
    :'archived' => :'Boolean',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 296

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      version == o.version &&
      creation_date == o.creation_date &&
      last_modified == o.last_modified &&
      last_seen == o.last_seen &&
      created_from == o.created_from &&
      hide_in_targeting == o.hide_in_targeting &&
      archived == o.archived &&
      _links == o._links
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


314
315
316
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 314

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



320
321
322
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 320

def hash
  [key, name, description, version, creation_date, last_modified, last_seen, created_from, hide_in_targeting, archived, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 176

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @description.nil?
    invalid_properties.push('invalid value for "description", description cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @last_modified.nil?
    invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.')
  end

  if @created_from.nil?
    invalid_properties.push('invalid value for "created_from", created_from cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



349
350
351
352
353
354
355
356
357
358
359
360
361
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 349

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



212
213
214
215
216
217
218
219
220
221
222
# File 'lib/launchdarkly_api/models/context_kind_rep.rb', line 212

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @description.nil?
  return false if @version.nil?
  return false if @creation_date.nil?
  return false if @last_modified.nil?
  return false if @created_from.nil?
  true
end