Class: LaunchDarklyApi::CreateAnnouncementBody
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::CreateAnnouncementBody
- Defined in:
- lib/launchdarkly_api/models/create_announcement_body.rb
Overview
Create announcement request body
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#end_time ⇒ Object
The end time of the announcement.
-
#is_dismissible ⇒ Object
true if the announcement is dismissible.
-
#message ⇒ Object
The message of the announcement.
-
#severity ⇒ Object
The severity of the announcement.
-
#start_time ⇒ Object
The start time of the announcement.
-
#title ⇒ Object
The title of the announcement.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateAnnouncementBody
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateAnnouncementBody
Initializes the object
101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 101 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CreateAnnouncementBody` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CreateAnnouncementBody`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'is_dismissible') self.is_dismissible = attributes[:'is_dismissible'] else self.is_dismissible = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'message') self. = attributes[:'message'] else self. = nil end if attributes.key?(:'start_time') self.start_time = attributes[:'start_time'] else self.start_time = nil end if attributes.key?(:'end_time') self.end_time = attributes[:'end_time'] end if attributes.key?(:'severity') self.severity = attributes[:'severity'] else self.severity = nil end end |
Instance Attribute Details
#end_time ⇒ Object
The end time of the announcement. This is a Unix timestamp in milliseconds.
32 33 34 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 32 def end_time @end_time end |
#is_dismissible ⇒ Object
true if the announcement is dismissible
20 21 22 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 20 def is_dismissible @is_dismissible end |
#message ⇒ Object
The message of the announcement
26 27 28 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 26 def @message end |
#severity ⇒ Object
The severity of the announcement
35 36 37 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 35 def severity @severity end |
#start_time ⇒ Object
The start time of the announcement. This is a Unix timestamp in milliseconds.
29 30 31 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 29 def start_time @start_time end |
#title ⇒ Object
The title of the announcement
23 24 25 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 23 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
72 73 74 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 72 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
77 78 79 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 77 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 60 def self.attribute_map { :'is_dismissible' => :'isDismissible', :'title' => :'title', :'message' => :'message', :'start_time' => :'startTime', :'end_time' => :'endTime', :'severity' => :'severity' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 270 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
94 95 96 97 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 94 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
82 83 84 85 86 87 88 89 90 91 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 82 def self.openapi_types { :'is_dismissible' => :'Boolean', :'title' => :'String', :'message' => :'String', :'start_time' => :'Integer', :'end_time' => :'Integer', :'severity' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
244 245 246 247 248 249 250 251 252 253 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 244 def ==(o) return true if self.equal?(o) self.class == o.class && is_dismissible == o.is_dismissible && title == o.title && == o. && start_time == o.start_time && end_time == o.end_time && severity == o.severity end |
#eql?(o) ⇒ Boolean
257 258 259 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 257 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
263 264 265 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 263 def hash [is_dismissible, title, , start_time, end_time, severity].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 152 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @is_dismissible.nil? invalid_properties.push('invalid value for "is_dismissible", is_dismissible cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @message.nil? invalid_properties.push('invalid value for "message", message cannot be nil.') end if @start_time.nil? invalid_properties.push('invalid value for "start_time", start_time cannot be nil.') end if @severity.nil? invalid_properties.push('invalid value for "severity", severity cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 292 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 187 188 189 190 |
# File 'lib/launchdarkly_api/models/create_announcement_body.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @is_dismissible.nil? return false if @title.nil? return false if @message.nil? return false if @start_time.nil? return false if @severity.nil? severity_validator = EnumAttributeValidator.new('String', ["info", "warning", "critical"]) return false unless severity_validator.valid?(@severity) true end |