Class: LaunchDarklyApi::CreateFlagConfigApprovalRequestRequest
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::CreateFlagConfigApprovalRequestRequest
- Defined in:
- lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb
Instance Attribute Summary collapse
-
#comment ⇒ Object
Optional comment describing the approval request.
-
#description ⇒ Object
A brief description of the changes you're requesting.
-
#execution_date ⇒ Object
Returns the value of attribute execution_date.
-
#instructions ⇒ Object
Returns the value of attribute instructions.
-
#integration_config ⇒ Object
Returns the value of attribute integration_config.
-
#notify_member_ids ⇒ Object
An array of member IDs.
-
#notify_team_keys ⇒ Object
An array of team keys.
-
#operating_on_id ⇒ Object
The ID of a scheduled change.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CreateFlagConfigApprovalRequestRequest
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CreateFlagConfigApprovalRequestRequest
Initializes the object
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 85 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CreateFlagConfigApprovalRequestRequest` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CreateFlagConfigApprovalRequestRequest`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'comment') self.comment = attributes[:'comment'] end if attributes.key?(:'description') self.description = attributes[:'description'] else self.description = nil end if attributes.key?(:'instructions') if (value = attributes[:'instructions']).is_a?(Array) self.instructions = value end else self.instructions = nil end if attributes.key?(:'notify_member_ids') if (value = attributes[:'notify_member_ids']).is_a?(Array) self.notify_member_ids = value end end if attributes.key?(:'notify_team_keys') if (value = attributes[:'notify_team_keys']).is_a?(Array) self.notify_team_keys = value end end if attributes.key?(:'execution_date') self.execution_date = attributes[:'execution_date'] end if attributes.key?(:'operating_on_id') self. = attributes[:'operating_on_id'] end if attributes.key?(:'integration_config') if (value = attributes[:'integration_config']).is_a?(Hash) self.integration_config = value end end end |
Instance Attribute Details
#comment ⇒ Object
Optional comment describing the approval request
19 20 21 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 19 def comment @comment end |
#description ⇒ Object
A brief description of the changes you're requesting
22 23 24 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 22 def description @description end |
#execution_date ⇒ Object
Returns the value of attribute execution_date.
32 33 34 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 32 def execution_date @execution_date end |
#instructions ⇒ Object
Returns the value of attribute instructions.
24 25 26 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 24 def instructions @instructions end |
#integration_config ⇒ Object
Returns the value of attribute integration_config.
37 38 39 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 37 def integration_config @integration_config end |
#notify_member_ids ⇒ Object
An array of member IDs. These members are notified to review the approval request.
27 28 29 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 27 def notify_member_ids @notify_member_ids end |
#notify_team_keys ⇒ Object
An array of team keys. The members of these teams are notified to review the approval request.
30 31 32 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 30 def notify_team_keys @notify_team_keys end |
#operating_on_id ⇒ Object
The ID of a scheduled change. Include this if your instructions include editing or deleting a scheduled change.
35 36 37 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 35 def @operating_on_id end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
54 55 56 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 54 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
59 60 61 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 59 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
40 41 42 43 44 45 46 47 48 49 50 51 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 40 def self.attribute_map { :'comment' => :'comment', :'description' => :'description', :'instructions' => :'instructions', :'notify_member_ids' => :'notifyMemberIds', :'notify_team_keys' => :'notifyTeamKeys', :'execution_date' => :'executionDate', :'operating_on_id' => :'operatingOnId', :'integration_config' => :'integrationConfig' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 219 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
78 79 80 81 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 78 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 64 def self.openapi_types { :'comment' => :'String', :'description' => :'String', :'instructions' => :'Array<Hash>', :'notify_member_ids' => :'Array<String>', :'notify_team_keys' => :'Array<String>', :'execution_date' => :'Integer', :'operating_on_id' => :'String', :'integration_config' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
191 192 193 194 195 196 197 198 199 200 201 202 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 191 def ==(o) return true if self.equal?(o) self.class == o.class && comment == o.comment && description == o.description && instructions == o.instructions && notify_member_ids == o.notify_member_ids && notify_team_keys == o.notify_team_keys && execution_date == o.execution_date && == o. && integration_config == o.integration_config end |
#eql?(o) ⇒ Boolean
206 207 208 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 206 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
212 213 214 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 212 def hash [comment, description, instructions, notify_member_ids, notify_team_keys, execution_date, , integration_config].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
146 147 148 149 150 151 152 153 154 155 156 157 158 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 146 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @instructions.nil? invalid_properties.push('invalid value for "instructions", instructions cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 241 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
162 163 164 165 166 167 |
# File 'lib/launchdarkly_api/models/create_flag_config_approval_request_request.rb', line 162 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @description.nil? return false if @instructions.nil? true end |