Class: LaunchDarklyApi::CustomWorkflowOutput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::CustomWorkflowOutput
- Defined in:
- lib/launchdarkly_api/models/custom_workflow_output.rb
Instance Attribute Summary collapse
-
#_conflicts ⇒ Object
Any conflicts that are present in the workflow stages.
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_execution ⇒ Object
Returns the value of attribute _execution.
-
#_id ⇒ Object
The ID of the workflow.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_maintainer_id ⇒ Object
The member ID of the maintainer of the workflow.
-
#_version ⇒ Object
The version of the workflow.
-
#description ⇒ Object
A brief description of the workflow.
-
#kind ⇒ Object
The kind of workflow.
-
#meta ⇒ Object
Returns the value of attribute meta.
-
#name ⇒ Object
The name of the workflow.
-
#stages ⇒ Object
The stages that make up the workflow.
-
#template_key ⇒ Object
For workflows being created from a workflow template, this value is the template’s key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ CustomWorkflowOutput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ CustomWorkflowOutput
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::CustomWorkflowOutput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::CustomWorkflowOutput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_version') self._version = attributes[:'_version'] else self._version = nil end if attributes.key?(:'_conflicts') if (value = attributes[:'_conflicts']).is_a?(Array) self._conflicts = value end else self._conflicts = nil end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] else self._creation_date = nil end if attributes.key?(:'_maintainer_id') self._maintainer_id = attributes[:'_maintainer_id'] else self._maintainer_id = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'stages') if (value = attributes[:'stages']).is_a?(Array) self.stages = value end end if attributes.key?(:'_execution') self._execution = attributes[:'_execution'] else self._execution = nil end if attributes.key?(:'meta') self. = attributes[:'meta'] end if attributes.key?(:'template_key') self.template_key = attributes[:'template_key'] end end |
Instance Attribute Details
#_conflicts ⇒ Object
Any conflicts that are present in the workflow stages
25 26 27 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 25 def _conflicts @_conflicts end |
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
27 28 29 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 27 def _creation_date @_creation_date end |
#_execution ⇒ Object
Returns the value of attribute _execution.
47 48 49 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 47 def _execution @_execution end |
#_id ⇒ Object
The ID of the workflow
19 20 21 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 19 def _id @_id end |
#_links ⇒ Object
The location and content type of related resources
33 34 35 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 33 def _links @_links end |
#_maintainer_id ⇒ Object
The member ID of the maintainer of the workflow. Defaults to the workflow creator.
30 31 32 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 30 def _maintainer_id @_maintainer_id end |
#_version ⇒ Object
The version of the workflow
22 23 24 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 22 def _version @_version end |
#description ⇒ Object
A brief description of the workflow
39 40 41 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 39 def description @description end |
#kind ⇒ Object
The kind of workflow
42 43 44 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 42 def kind @kind end |
#meta ⇒ Object
Returns the value of attribute meta.
49 50 51 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 49 def @meta end |
#name ⇒ Object
The name of the workflow
36 37 38 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 36 def name @name end |
#stages ⇒ Object
The stages that make up the workflow. Each stage contains conditions and actions.
45 46 47 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 45 def stages @stages end |
#template_key ⇒ Object
For workflows being created from a workflow template, this value is the template’s key
52 53 54 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 52 def template_key @template_key end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
74 75 76 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 74 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
79 80 81 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 79 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 55 def self.attribute_map { :'_id' => :'_id', :'_version' => :'_version', :'_conflicts' => :'_conflicts', :'_creation_date' => :'_creationDate', :'_maintainer_id' => :'_maintainerId', :'_links' => :'_links', :'name' => :'name', :'description' => :'description', :'kind' => :'kind', :'stages' => :'stages', :'_execution' => :'_execution', :'meta' => :'meta', :'template_key' => :'templateKey' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 369 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 84 def self.openapi_types { :'_id' => :'String', :'_version' => :'Integer', :'_conflicts' => :'Array<ConflictOutput>', :'_creation_date' => :'Integer', :'_maintainer_id' => :'String', :'_links' => :'Hash<String, Link>', :'name' => :'String', :'description' => :'String', :'kind' => :'String', :'stages' => :'Array<StageOutput>', :'_execution' => :'ExecutionOutput', :'meta' => :'WorkflowTemplateMetadata', :'template_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 336 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _version == o._version && _conflicts == o._conflicts && _creation_date == o._creation_date && _maintainer_id == o._maintainer_id && _links == o._links && name == o.name && description == o.description && kind == o.kind && stages == o.stages && _execution == o._execution && == o. && template_key == o.template_key end |
#eql?(o) ⇒ Boolean
356 357 358 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 356 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
362 363 364 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 362 def hash [_id, _version, _conflicts, _creation_date, _maintainer_id, _links, name, description, kind, stages, _execution, , template_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 201 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_version.nil? invalid_properties.push('invalid value for "_version", _version cannot be nil.') end if @_conflicts.nil? invalid_properties.push('invalid value for "_conflicts", _conflicts cannot be nil.') end if @_creation_date.nil? invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.') end if @_maintainer_id.nil? invalid_properties.push('invalid value for "_maintainer_id", _maintainer_id cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @_execution.nil? invalid_properties.push('invalid value for "_execution", _execution cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 391 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/launchdarkly_api/models/custom_workflow_output.rb', line 241 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @_version.nil? return false if @_conflicts.nil? return false if @_creation_date.nil? return false if @_maintainer_id.nil? return false if @_links.nil? return false if @name.nil? return false if @_execution.nil? true end |