Class: LaunchDarklyApi::DependentMeasuredRolloutRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::DependentMeasuredRolloutRep
- Defined in:
- lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
The guarded rollout measured rollout Id.
-
#_links ⇒ Object
The location and content type of related resources.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#environment_key ⇒ Object
The guarded rollout environment key.
-
#environment_name ⇒ Object
The guarded rollout environment name.
-
#flag_key ⇒ Object
The guarded rollout flag key.
-
#flag_name ⇒ Object
The guarded rollout flag name.
-
#flag_purpose ⇒ Object
The guarded rollout flag purpose.
-
#status ⇒ Object
The guarded rollout status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DependentMeasuredRolloutRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DependentMeasuredRolloutRep
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::DependentMeasuredRolloutRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::DependentMeasuredRolloutRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'flag_key') self.flag_key = attributes[:'flag_key'] else self.flag_key = nil end if attributes.key?(:'flag_name') self.flag_name = attributes[:'flag_name'] else self.flag_name = nil end if attributes.key?(:'flag_purpose') self.flag_purpose = attributes[:'flag_purpose'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] else self.environment_key = nil end if attributes.key?(:'environment_name') self.environment_name = attributes[:'environment_name'] else self.environment_name = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end end |
Instance Attribute Details
#_id ⇒ Object
The guarded rollout measured rollout Id
19 20 21 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 19 def _id @_id end |
#_links ⇒ Object
The location and content type of related resources
42 43 44 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 42 def _links @_links end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
39 40 41 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 39 def creation_date @creation_date end |
#environment_key ⇒ Object
The guarded rollout environment key
31 32 33 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 31 def environment_key @environment_key end |
#environment_name ⇒ Object
The guarded rollout environment name
34 35 36 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 34 def environment_name @environment_name end |
#flag_key ⇒ Object
The guarded rollout flag key
22 23 24 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 22 def flag_key @flag_key end |
#flag_name ⇒ Object
The guarded rollout flag name
25 26 27 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 25 def flag_name @flag_name end |
#flag_purpose ⇒ Object
The guarded rollout flag purpose
28 29 30 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 28 def flag_purpose @flag_purpose end |
#status ⇒ Object
The guarded rollout status
37 38 39 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 37 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
60 61 62 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 60 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
65 66 67 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 65 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
45 46 47 48 49 50 51 52 53 54 55 56 57 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 45 def self.attribute_map { :'_id' => :'_id', :'flag_key' => :'flagKey', :'flag_name' => :'flagName', :'flag_purpose' => :'flagPurpose', :'environment_key' => :'environmentKey', :'environment_name' => :'environmentName', :'status' => :'status', :'creation_date' => :'creationDate', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 327 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 70 def self.openapi_types { :'_id' => :'String', :'flag_key' => :'String', :'flag_name' => :'String', :'flag_purpose' => :'String', :'environment_key' => :'String', :'environment_name' => :'String', :'status' => :'String', :'creation_date' => :'Integer', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
298 299 300 301 302 303 304 305 306 307 308 309 310 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 298 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && flag_key == o.flag_key && flag_name == o.flag_name && flag_purpose == o.flag_purpose && environment_key == o.environment_key && environment_name == o.environment_name && status == o.status && creation_date == o.creation_date && _links == o._links end |
#eql?(o) ⇒ Boolean
314 315 316 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 314 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
320 321 322 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 320 def hash [_id, flag_key, flag_name, flag_purpose, environment_key, environment_name, status, creation_date, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 163 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @flag_key.nil? invalid_properties.push('invalid value for "flag_key", flag_key cannot be nil.') end if @flag_name.nil? invalid_properties.push('invalid value for "flag_name", flag_name cannot be nil.') end if @environment_key.nil? invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.') end if @environment_name.nil? invalid_properties.push('invalid value for "environment_name", environment_name cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
349 350 351 352 353 354 355 356 357 358 359 360 361 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 349 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 212 213 214 |
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @flag_key.nil? return false if @flag_name.nil? return false if @environment_key.nil? return false if @environment_name.nil? return false if @status.nil? return false if @creation_date.nil? return false if @_links.nil? true end |