Class: LaunchDarklyApi::DependentMeasuredRolloutRep

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ DependentMeasuredRolloutRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 87

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::DependentMeasuredRolloutRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::DependentMeasuredRolloutRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'flag_key')
    self.flag_key = attributes[:'flag_key']
  else
    self.flag_key = nil
  end

  if attributes.key?(:'flag_name')
    self.flag_name = attributes[:'flag_name']
  else
    self.flag_name = nil
  end

  if attributes.key?(:'environment_key')
    self.environment_key = attributes[:'environment_key']
  else
    self.environment_key = nil
  end

  if attributes.key?(:'environment_name')
    self.environment_name = attributes[:'environment_name']
  else
    self.environment_name = nil
  end

  if attributes.key?(:'status')
    self.status = attributes[:'status']
  else
    self.status = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end
end

Instance Attribute Details

#_idObject

The guarded rollout measured rollout Id



19
20
21
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 19

def _id
  @_id
end

The location and content type of related resources



39
40
41
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 39

def _links
  @_links
end

#creation_dateObject

Returns the value of attribute creation_date.



36
37
38
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 36

def creation_date
  @creation_date
end

#environment_keyObject

The guarded rollout environment key



28
29
30
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 28

def environment_key
  @environment_key
end

#environment_nameObject

The guarded rollout environment name



31
32
33
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 31

def environment_name
  @environment_name
end

#flag_keyObject

The guarded rollout flag key



22
23
24
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 22

def flag_key
  @flag_key
end

#flag_nameObject

The guarded rollout flag name



25
26
27
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 25

def flag_name
  @flag_name
end

#statusObject

The guarded rollout status



34
35
36
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 34

def status
  @status
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 341

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



56
57
58
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 56

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



61
62
63
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 61

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



42
43
44
45
46
47
48
49
50
51
52
53
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 42

def self.attribute_map
  {
    :'_id' => :'_id',
    :'flag_key' => :'flagKey',
    :'flag_name' => :'flagName',
    :'environment_key' => :'environmentKey',
    :'environment_name' => :'environmentName',
    :'status' => :'status',
    :'creation_date' => :'creationDate',
    :'_links' => :'_links'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 317

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



80
81
82
83
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 80

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 66

def self.openapi_types
  {
    :'_id' => :'String',
    :'flag_key' => :'String',
    :'flag_name' => :'String',
    :'environment_key' => :'String',
    :'environment_name' => :'String',
    :'status' => :'String',
    :'creation_date' => :'Integer',
    :'_links' => :'Hash<String, Link>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



289
290
291
292
293
294
295
296
297
298
299
300
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 289

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      flag_key == o.flag_key &&
      flag_name == o.flag_name &&
      environment_key == o.environment_key &&
      environment_name == o.environment_name &&
      status == o.status &&
      creation_date == o.creation_date &&
      _links == o._links
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



412
413
414
415
416
417
418
419
420
421
422
423
424
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 412

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


304
305
306
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 304

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



310
311
312
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 310

def hash
  [_id, flag_key, flag_name, environment_key, environment_name, status, creation_date, _links].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 154

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @flag_key.nil?
    invalid_properties.push('invalid value for "flag_key", flag_key cannot be nil.')
  end

  if @flag_name.nil?
    invalid_properties.push('invalid value for "flag_name", flag_name cannot be nil.')
  end

  if @environment_key.nil?
    invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.')
  end

  if @environment_name.nil?
    invalid_properties.push('invalid value for "environment_name", environment_name cannot be nil.')
  end

  if @status.nil?
    invalid_properties.push('invalid value for "status", status cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



388
389
390
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 388

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



394
395
396
397
398
399
400
401
402
403
404
405
406
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 394

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



382
383
384
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 382

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/launchdarkly_api/models/dependent_measured_rollout_rep.rb', line 194

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @flag_key.nil?
  return false if @flag_name.nil?
  return false if @environment_key.nil?
  return false if @environment_name.nil?
  return false if @status.nil?
  return false if @creation_date.nil?
  return false if @_links.nil?
  true
end