Class: LaunchDarklyApi::DependentMetricOrMetricGroupRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::DependentMetricOrMetricGroupRep
- Defined in:
- lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#_version_id ⇒ Object
The version ID of the metric or metric group.
-
#event_key ⇒ Object
The event key sent with the metric.
-
#is_group ⇒ Object
Whether this is a metric group or a metric.
-
#is_numeric ⇒ Object
For custom and trace metrics, whether to track numeric changes in value against a baseline (
true) or to track a conversion when an end user takes an action (false). -
#key ⇒ Object
A unique key to reference the metric or metric group.
-
#kind ⇒ Object
If this is a metric, then it represents the kind of event the metric tracks.
-
#metrics ⇒ Object
An ordered list of the metrics in this metric group.
-
#name ⇒ Object
A human-friendly name for the metric or metric group.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DependentMetricOrMetricGroupRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DependentMetricOrMetricGroupRep
Initializes the object
115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 115 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::DependentMetricOrMetricGroupRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::DependentMetricOrMetricGroupRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'_version_id') self._version_id = attributes[:'_version_id'] else self._version_id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'is_numeric') self.is_numeric = attributes[:'is_numeric'] end if attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'is_group') self.is_group = attributes[:'is_group'] else self.is_group = nil end if attributes.key?(:'metrics') if (value = attributes[:'metrics']).is_a?(Array) self.metrics = value end end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
37 38 39 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 37 def _links @_links end |
#_version_id ⇒ Object
The version ID of the metric or metric group
22 23 24 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 22 def _version_id @_version_id end |
#event_key ⇒ Object
The event key sent with the metric. Only relevant for custom metrics.
34 35 36 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 34 def event_key @event_key end |
#is_group ⇒ Object
Whether this is a metric group or a metric
40 41 42 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 40 def is_group @is_group end |
#is_numeric ⇒ Object
For custom and trace metrics, whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false).
31 32 33 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 31 def is_numeric @is_numeric end |
#key ⇒ Object
A unique key to reference the metric or metric group
19 20 21 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 19 def key @key end |
#kind ⇒ Object
If this is a metric, then it represents the kind of event the metric tracks. If this is a metric group, then it represents the group type
28 29 30 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 28 def kind @kind end |
#metrics ⇒ Object
An ordered list of the metrics in this metric group
43 44 45 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 43 def metrics @metrics end |
#name ⇒ Object
A human-friendly name for the metric or metric group
25 26 27 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 25 def name @name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
83 84 85 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 83 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
88 89 90 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 88 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
68 69 70 71 72 73 74 75 76 77 78 79 80 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 68 def self.attribute_map { :'key' => :'key', :'_version_id' => :'_versionId', :'name' => :'name', :'kind' => :'kind', :'is_numeric' => :'isNumeric', :'event_key' => :'eventKey', :'_links' => :'_links', :'is_group' => :'isGroup', :'metrics' => :'metrics' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 320 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
108 109 110 111 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 108 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
93 94 95 96 97 98 99 100 101 102 103 104 105 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 93 def self.openapi_types { :'key' => :'String', :'_version_id' => :'String', :'name' => :'String', :'kind' => :'String', :'is_numeric' => :'Boolean', :'event_key' => :'String', :'_links' => :'Hash<String, Link>', :'is_group' => :'Boolean', :'metrics' => :'Array<MetricInGroupRep>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && _version_id == o._version_id && name == o.name && kind == o.kind && is_numeric == o.is_numeric && event_key == o.event_key && _links == o._links && is_group == o.is_group && metrics == o.metrics end |
#eql?(o) ⇒ Boolean
307 308 309 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 307 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
313 314 315 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 313 def hash [key, _version_id, name, kind, is_numeric, event_key, _links, is_group, metrics].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @_version_id.nil? invalid_properties.push('invalid value for "_version_id", _version_id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @is_group.nil? invalid_properties.push('invalid value for "is_group", is_group cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 342 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/launchdarkly_api/models/dependent_metric_or_metric_group_rep.rb', line 216 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @_version_id.nil? return false if @name.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom", "trace", "funnel", "standard"]) return false unless kind_validator.valid?(@kind) return false if @_links.nil? return false if @is_group.nil? true end |