Class: LaunchDarklyApi::DeploymentRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::DeploymentRep
- Defined in:
- lib/launchdarkly_api/models/deployment_rep.rb
Instance Attribute Summary collapse
-
#active ⇒ Object
Whether the deployment is active.
-
#application_key ⇒ Object
The application key.
-
#application_version ⇒ Object
The application version.
-
#archived ⇒ Object
Whether the deployment is archived.
-
#duration_ms ⇒ Object
The duration of the deployment in milliseconds.
-
#ended_at ⇒ Object
Returns the value of attribute ended_at.
-
#environment_key ⇒ Object
The environment key.
-
#flag_references ⇒ Object
Returns the value of attribute flag_references.
-
#id ⇒ Object
The deployment ID.
-
#kind ⇒ Object
Returns the value of attribute kind.
-
#lead_time ⇒ Object
The total lead time from first commit to deployment end in milliseconds.
-
#lead_time_stages ⇒ Object
Returns the value of attribute lead_time_stages.
-
#lines_added ⇒ Object
The number of lines added.
-
#lines_deleted ⇒ Object
The number of lines deleted.
-
#metadata ⇒ Object
The metadata associated with the deployment.
-
#number_of_contributors ⇒ Object
The number of contributors.
-
#number_of_pull_requests ⇒ Object
The number of pull requests.
-
#pull_requests ⇒ Object
Returns the value of attribute pull_requests.
-
#started_at ⇒ Object
Returns the value of attribute started_at.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ DeploymentRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ DeploymentRep
Initializes the object
141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 141 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::DeploymentRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::DeploymentRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'application_key') self.application_key = attributes[:'application_key'] else self.application_key = nil end if attributes.key?(:'application_version') self.application_version = attributes[:'application_version'] else self.application_version = nil end if attributes.key?(:'started_at') self.started_at = attributes[:'started_at'] else self.started_at = nil end if attributes.key?(:'ended_at') self.ended_at = attributes[:'ended_at'] end if attributes.key?(:'duration_ms') self.duration_ms = attributes[:'duration_ms'] end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'active') self.active = attributes[:'active'] else self.active = nil end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'archived') self.archived = attributes[:'archived'] else self.archived = nil end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] else self.environment_key = nil end if attributes.key?(:'number_of_contributors') self.number_of_contributors = attributes[:'number_of_contributors'] else self.number_of_contributors = nil end if attributes.key?(:'number_of_pull_requests') self.number_of_pull_requests = attributes[:'number_of_pull_requests'] else self.number_of_pull_requests = nil end if attributes.key?(:'lines_added') self.lines_added = attributes[:'lines_added'] else self.lines_added = nil end if attributes.key?(:'lines_deleted') self.lines_deleted = attributes[:'lines_deleted'] else self.lines_deleted = nil end if attributes.key?(:'lead_time') self.lead_time = attributes[:'lead_time'] else self.lead_time = nil end if attributes.key?(:'pull_requests') self.pull_requests = attributes[:'pull_requests'] end if attributes.key?(:'flag_references') self.flag_references = attributes[:'flag_references'] end if attributes.key?(:'lead_time_stages') self.lead_time_stages = attributes[:'lead_time_stages'] end end |
Instance Attribute Details
#active ⇒ Object
Whether the deployment is active
39 40 41 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 39 def active @active end |
#application_key ⇒ Object
The application key
22 23 24 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 22 def application_key @application_key end |
#application_version ⇒ Object
The application version
25 26 27 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 25 def application_version @application_version end |
#archived ⇒ Object
Whether the deployment is archived
45 46 47 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 45 def archived @archived end |
#duration_ms ⇒ Object
The duration of the deployment in milliseconds
32 33 34 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 32 def duration_ms @duration_ms end |
#ended_at ⇒ Object
Returns the value of attribute ended_at.
29 30 31 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 29 def ended_at @ended_at end |
#environment_key ⇒ Object
The environment key
48 49 50 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 48 def environment_key @environment_key end |
#flag_references ⇒ Object
Returns the value of attribute flag_references.
67 68 69 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 67 def flag_references @flag_references end |
#id ⇒ Object
The deployment ID
19 20 21 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 19 def id @id end |
#kind ⇒ Object
Returns the value of attribute kind.
36 37 38 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 36 def kind @kind end |
#lead_time ⇒ Object
The total lead time from first commit to deployment end in milliseconds
63 64 65 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 63 def lead_time @lead_time end |
#lead_time_stages ⇒ Object
Returns the value of attribute lead_time_stages.
69 70 71 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 69 def lead_time_stages @lead_time_stages end |
#lines_added ⇒ Object
The number of lines added
57 58 59 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 57 def lines_added @lines_added end |
#lines_deleted ⇒ Object
The number of lines deleted
60 61 62 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 60 def lines_deleted @lines_deleted end |
#metadata ⇒ Object
The metadata associated with the deployment
42 43 44 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 42 def @metadata end |
#number_of_contributors ⇒ Object
The number of contributors
51 52 53 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 51 def number_of_contributors @number_of_contributors end |
#number_of_pull_requests ⇒ Object
The number of pull requests
54 55 56 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 54 def number_of_pull_requests @number_of_pull_requests end |
#pull_requests ⇒ Object
Returns the value of attribute pull_requests.
65 66 67 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 65 def pull_requests @pull_requests end |
#started_at ⇒ Object
Returns the value of attribute started_at.
27 28 29 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 27 def started_at @started_at end |
#status ⇒ Object
Returns the value of attribute status.
34 35 36 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 34 def status @status end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
98 99 100 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 98 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
103 104 105 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 103 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 72 def self.attribute_map { :'id' => :'id', :'application_key' => :'applicationKey', :'application_version' => :'applicationVersion', :'started_at' => :'startedAt', :'ended_at' => :'endedAt', :'duration_ms' => :'durationMs', :'status' => :'status', :'kind' => :'kind', :'active' => :'active', :'metadata' => :'metadata', :'archived' => :'archived', :'environment_key' => :'environmentKey', :'number_of_contributors' => :'numberOfContributors', :'number_of_pull_requests' => :'numberOfPullRequests', :'lines_added' => :'linesAdded', :'lines_deleted' => :'linesDeleted', :'lead_time' => :'leadTime', :'pull_requests' => :'pullRequests', :'flag_references' => :'flagReferences', :'lead_time_stages' => :'leadTimeStages' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 533 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
134 135 136 137 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 134 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 108 def self.openapi_types { :'id' => :'String', :'application_key' => :'String', :'application_version' => :'String', :'started_at' => :'Integer', :'ended_at' => :'Integer', :'duration_ms' => :'Integer', :'status' => :'String', :'kind' => :'String', :'active' => :'Boolean', :'metadata' => :'Hash<String, Object>', :'archived' => :'Boolean', :'environment_key' => :'String', :'number_of_contributors' => :'Integer', :'number_of_pull_requests' => :'Integer', :'lines_added' => :'Integer', :'lines_deleted' => :'Integer', :'lead_time' => :'Integer', :'pull_requests' => :'PullRequestCollectionRep', :'flag_references' => :'FlagReferenceCollectionRep', :'lead_time_stages' => :'LeadTimeStagesRep' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
493 494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 493 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && application_key == o.application_key && application_version == o.application_version && started_at == o.started_at && ended_at == o.ended_at && duration_ms == o.duration_ms && status == o.status && kind == o.kind && active == o.active && == o. && archived == o.archived && environment_key == o.environment_key && number_of_contributors == o.number_of_contributors && number_of_pull_requests == o.number_of_pull_requests && lines_added == o.lines_added && lines_deleted == o.lines_deleted && lead_time == o.lead_time && pull_requests == o.pull_requests && flag_references == o.flag_references && lead_time_stages == o.lead_time_stages end |
#eql?(o) ⇒ Boolean
520 521 522 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 520 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
526 527 528 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 526 def hash [id, application_key, application_version, started_at, ended_at, duration_ms, status, kind, active, , archived, environment_key, number_of_contributors, number_of_pull_requests, lines_added, lines_deleted, lead_time, pull_requests, flag_references, lead_time_stages].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 268 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @application_key.nil? invalid_properties.push('invalid value for "application_key", application_key cannot be nil.') end if @application_version.nil? invalid_properties.push('invalid value for "application_version", application_version cannot be nil.') end if @started_at.nil? invalid_properties.push('invalid value for "started_at", started_at cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @active.nil? invalid_properties.push('invalid value for "active", active cannot be nil.') end if @archived.nil? invalid_properties.push('invalid value for "archived", archived cannot be nil.') end if @environment_key.nil? invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.') end if @number_of_contributors.nil? invalid_properties.push('invalid value for "number_of_contributors", number_of_contributors cannot be nil.') end if @number_of_pull_requests.nil? invalid_properties.push('invalid value for "number_of_pull_requests", number_of_pull_requests cannot be nil.') end if @lines_added.nil? invalid_properties.push('invalid value for "lines_added", lines_added cannot be nil.') end if @lines_deleted.nil? invalid_properties.push('invalid value for "lines_deleted", lines_deleted cannot be nil.') end if @lead_time.nil? invalid_properties.push('invalid value for "lead_time", lead_time cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
555 556 557 558 559 560 561 562 563 564 565 566 567 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 555 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 |
# File 'lib/launchdarkly_api/models/deployment_rep.rb', line 332 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @application_key.nil? return false if @application_version.nil? return false if @started_at.nil? return false if @status.nil? return false if @kind.nil? return false if @active.nil? return false if @archived.nil? return false if @environment_key.nil? return false if @number_of_contributors.nil? return false if @number_of_pull_requests.nil? return false if @lines_added.nil? return false if @lines_deleted.nil? return false if @lead_time.nil? true end |