Class: LaunchDarklyApi::Destination

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/destination.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ Destination

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/launchdarkly_api/models/destination.rb', line 113

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Destination` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Destination`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  end

  if attributes.key?(:'config')
    self.config = attributes[:'config']
  end

  if attributes.key?(:'on')
    self.on = attributes[:'on']
  end

  if attributes.key?(:'created_at')
    self.created_at = attributes[:'created_at']
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



40
41
42
# File 'lib/launchdarkly_api/models/destination.rb', line 40

def _access
  @_access
end

#_idObject

The ID of this Data Export destination



19
20
21
# File 'lib/launchdarkly_api/models/destination.rb', line 19

def _id
  @_id
end

The location and content type of related resources



22
23
24
# File 'lib/launchdarkly_api/models/destination.rb', line 22

def _links
  @_links
end

#configObject

An object with the configuration parameters required for the destination type



33
34
35
# File 'lib/launchdarkly_api/models/destination.rb', line 33

def config
  @config
end

#created_atObject

Returns the value of attribute created_at.



38
39
40
# File 'lib/launchdarkly_api/models/destination.rb', line 38

def created_at
  @created_at
end

#kindObject

The type of Data Export destination



28
29
30
# File 'lib/launchdarkly_api/models/destination.rb', line 28

def kind
  @kind
end

#nameObject

A human-readable name for your Data Export destination



25
26
27
# File 'lib/launchdarkly_api/models/destination.rb', line 25

def name
  @name
end

#onObject

Whether the export is on, that is, the status of the integration



36
37
38
# File 'lib/launchdarkly_api/models/destination.rb', line 36

def on
  @on
end

#versionObject

Returns the value of attribute version.



30
31
32
# File 'lib/launchdarkly_api/models/destination.rb', line 30

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



80
81
82
# File 'lib/launchdarkly_api/models/destination.rb', line 80

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



85
86
87
# File 'lib/launchdarkly_api/models/destination.rb', line 85

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



65
66
67
68
69
70
71
72
73
74
75
76
77
# File 'lib/launchdarkly_api/models/destination.rb', line 65

def self.attribute_map
  {
    :'_id' => :'_id',
    :'_links' => :'_links',
    :'name' => :'name',
    :'kind' => :'kind',
    :'version' => :'version',
    :'config' => :'config',
    :'on' => :'on',
    :'created_at' => :'createdAt',
    :'_access' => :'_access'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
# File 'lib/launchdarkly_api/models/destination.rb', line 224

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



105
106
107
108
109
# File 'lib/launchdarkly_api/models/destination.rb', line 105

def self.openapi_nullable
  Set.new([
    :'config',
  ])
end

.openapi_typesObject

Attribute type mapping.



90
91
92
93
94
95
96
97
98
99
100
101
102
# File 'lib/launchdarkly_api/models/destination.rb', line 90

def self.openapi_types
  {
    :'_id' => :'String',
    :'_links' => :'Hash<String, Link>',
    :'name' => :'String',
    :'kind' => :'String',
    :'version' => :'Float',
    :'config' => :'Object',
    :'on' => :'Boolean',
    :'created_at' => :'Integer',
    :'_access' => :'Access'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



195
196
197
198
199
200
201
202
203
204
205
206
207
# File 'lib/launchdarkly_api/models/destination.rb', line 195

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      _links == o._links &&
      name == o.name &&
      kind == o.kind &&
      version == o.version &&
      config == o.config &&
      on == o.on &&
      created_at == o.created_at &&
      _access == o._access
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


211
212
213
# File 'lib/launchdarkly_api/models/destination.rb', line 211

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



217
218
219
# File 'lib/launchdarkly_api/models/destination.rb', line 217

def hash
  [_id, _links, name, kind, version, config, on, created_at, _access].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
# File 'lib/launchdarkly_api/models/destination.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



246
247
248
249
250
251
252
253
254
255
256
257
258
# File 'lib/launchdarkly_api/models/destination.rb', line 246

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



176
177
178
179
180
181
# File 'lib/launchdarkly_api/models/destination.rb', line 176

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  kind_validator = EnumAttributeValidator.new('String', ["google-pubsub", "kinesis", "mparticle", "segment", "azure-event-hubs", "snowflake-v2", "databricks", "bigquery", "redshift"])
  return false unless kind_validator.valid?(@kind)
  true
end