Class: LaunchDarklyApi::Environment

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/environment.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Environment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
# File 'lib/launchdarkly_api/models/environment.rb', line 127

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Environment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Environment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'api_key')
    self.api_key = attributes[:'api_key']
  else
    self.api_key = nil
  end

  if attributes.key?(:'mobile_key')
    self.mobile_key = attributes[:'mobile_key']
  else
    self.mobile_key = nil
  end

  if attributes.key?(:'color')
    self.color = attributes[:'color']
  else
    self.color = nil
  end

  if attributes.key?(:'default_ttl')
    self.default_ttl = attributes[:'default_ttl']
  else
    self.default_ttl = nil
  end

  if attributes.key?(:'secure_mode')
    self.secure_mode = attributes[:'secure_mode']
  else
    self.secure_mode = nil
  end

  if attributes.key?(:'default_track_events')
    self.default_track_events = attributes[:'default_track_events']
  else
    self.default_track_events = nil
  end

  if attributes.key?(:'require_comments')
    self.require_comments = attributes[:'require_comments']
  else
    self.require_comments = nil
  end

  if attributes.key?(:'confirm_changes')
    self.confirm_changes = attributes[:'confirm_changes']
  else
    self.confirm_changes = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'approval_settings')
    self.approval_settings = attributes[:'approval_settings']
  end

  if attributes.key?(:'resource_approval_settings')
    if (value = attributes[:'resource_approval_settings']).is_a?(Hash)
      self.resource_approval_settings = value
    end
  end

  if attributes.key?(:'critical')
    self.critical = attributes[:'critical']
  else
    self.critical = nil
  end
end

Instance Attribute Details

#_idObject

The ID for the environment. Use this as the client-side ID for authorization in some client-side SDKs, and to associate LaunchDarkly environments with CDN integrations in edge SDKs.



22
23
24
# File 'lib/launchdarkly_api/models/environment.rb', line 22

def _id
  @_id
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/environment.rb', line 19

def _links
  @_links
end

#api_keyObject

The SDK key for the environment. Use this for authorization in server-side SDKs.



31
32
33
# File 'lib/launchdarkly_api/models/environment.rb', line 31

def api_key
  @api_key
end

#approval_settingsObject

Returns the value of attribute approval_settings.



57
58
59
# File 'lib/launchdarkly_api/models/environment.rb', line 57

def approval_settings
  @approval_settings
end

#colorObject

The color used to indicate this environment in the UI



37
38
39
# File 'lib/launchdarkly_api/models/environment.rb', line 37

def color
  @color
end

#confirm_changesObject

Whether members who modify flags and segments through the LaunchDarkly user interface are required to confirm those changes



52
53
54
# File 'lib/launchdarkly_api/models/environment.rb', line 52

def confirm_changes
  @confirm_changes
end

#criticalObject

Whether the environment is critical



63
64
65
# File 'lib/launchdarkly_api/models/environment.rb', line 63

def critical
  @critical
end

#default_track_eventsObject

Enables tracking detailed information for new flags by default



46
47
48
# File 'lib/launchdarkly_api/models/environment.rb', line 46

def default_track_events
  @default_track_events
end

#default_ttlObject

The default time (in minutes) that the PHP SDK can cache feature flag rules locally



40
41
42
# File 'lib/launchdarkly_api/models/environment.rb', line 40

def default_ttl
  @default_ttl
end

#keyObject

A project-unique key for the new environment



25
26
27
# File 'lib/launchdarkly_api/models/environment.rb', line 25

def key
  @key
end

#mobile_keyObject

The mobile key for the environment. Use this for authorization in mobile SDKs.



34
35
36
# File 'lib/launchdarkly_api/models/environment.rb', line 34

def mobile_key
  @mobile_key
end

#nameObject

A human-friendly name for the new environment



28
29
30
# File 'lib/launchdarkly_api/models/environment.rb', line 28

def name
  @name
end

#require_commentsObject

Whether members who modify flags and segments through the LaunchDarkly user interface are required to add a comment



49
50
51
# File 'lib/launchdarkly_api/models/environment.rb', line 49

def require_comments
  @require_comments
end

#resource_approval_settingsObject

Details on the approval settings for this environment for each resource kind



60
61
62
# File 'lib/launchdarkly_api/models/environment.rb', line 60

def resource_approval_settings
  @resource_approval_settings
end

#secure_modeObject

Ensures that one end user of the client-side SDK cannot inspect the variations for another end user



43
44
45
# File 'lib/launchdarkly_api/models/environment.rb', line 43

def secure_mode
  @secure_mode
end

#tagsObject

A list of tags for this environment



55
56
57
# File 'lib/launchdarkly_api/models/environment.rb', line 55

def tags
  @tags
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
555
556
557
558
559
560
561
562
563
564
# File 'lib/launchdarkly_api/models/environment.rb', line 527

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



88
89
90
# File 'lib/launchdarkly_api/models/environment.rb', line 88

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



93
94
95
# File 'lib/launchdarkly_api/models/environment.rb', line 93

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/launchdarkly_api/models/environment.rb', line 66

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'key' => :'key',
    :'name' => :'name',
    :'api_key' => :'apiKey',
    :'mobile_key' => :'mobileKey',
    :'color' => :'color',
    :'default_ttl' => :'defaultTtl',
    :'secure_mode' => :'secureMode',
    :'default_track_events' => :'defaultTrackEvents',
    :'require_comments' => :'requireComments',
    :'confirm_changes' => :'confirmChanges',
    :'tags' => :'tags',
    :'approval_settings' => :'approvalSettings',
    :'resource_approval_settings' => :'resourceApprovalSettings',
    :'critical' => :'critical'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



503
504
505
506
507
508
509
510
511
512
513
514
515
516
517
518
519
520
521
# File 'lib/launchdarkly_api/models/environment.rb', line 503

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



120
121
122
123
# File 'lib/launchdarkly_api/models/environment.rb', line 120

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/launchdarkly_api/models/environment.rb', line 98

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'api_key' => :'String',
    :'mobile_key' => :'String',
    :'color' => :'String',
    :'default_ttl' => :'Integer',
    :'secure_mode' => :'Boolean',
    :'default_track_events' => :'Boolean',
    :'require_comments' => :'Boolean',
    :'confirm_changes' => :'Boolean',
    :'tags' => :'Array<String>',
    :'approval_settings' => :'ApprovalSettings',
    :'resource_approval_settings' => :'Hash<String, ApprovalSettings>',
    :'critical' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



467
468
469
470
471
472
473
474
475
476
477
478
479
480
481
482
483
484
485
486
# File 'lib/launchdarkly_api/models/environment.rb', line 467

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      key == o.key &&
      name == o.name &&
      api_key == o.api_key &&
      mobile_key == o.mobile_key &&
      color == o.color &&
      default_ttl == o.default_ttl &&
      secure_mode == o.secure_mode &&
      default_track_events == o.default_track_events &&
      require_comments == o.require_comments &&
      confirm_changes == o.confirm_changes &&
      tags == o.tags &&
      approval_settings == o.approval_settings &&
      resource_approval_settings == o.resource_approval_settings &&
      critical == o.critical
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



598
599
600
601
602
603
604
605
606
607
608
609
610
# File 'lib/launchdarkly_api/models/environment.rb', line 598

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


490
491
492
# File 'lib/launchdarkly_api/models/environment.rb', line 490

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



496
497
498
# File 'lib/launchdarkly_api/models/environment.rb', line 496

def hash
  [_links, _id, key, name, api_key, mobile_key, color, default_ttl, secure_mode, default_track_events, require_comments, confirm_changes, tags, approval_settings, resource_approval_settings, critical].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
# File 'lib/launchdarkly_api/models/environment.rb', line 242

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @api_key.nil?
    invalid_properties.push('invalid value for "api_key", api_key cannot be nil.')
  end

  if @mobile_key.nil?
    invalid_properties.push('invalid value for "mobile_key", mobile_key cannot be nil.')
  end

  if @color.nil?
    invalid_properties.push('invalid value for "color", color cannot be nil.')
  end

  if @default_ttl.nil?
    invalid_properties.push('invalid value for "default_ttl", default_ttl cannot be nil.')
  end

  if @secure_mode.nil?
    invalid_properties.push('invalid value for "secure_mode", secure_mode cannot be nil.')
  end

  if @default_track_events.nil?
    invalid_properties.push('invalid value for "default_track_events", default_track_events cannot be nil.')
  end

  if @require_comments.nil?
    invalid_properties.push('invalid value for "require_comments", require_comments cannot be nil.')
  end

  if @confirm_changes.nil?
    invalid_properties.push('invalid value for "confirm_changes", confirm_changes cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @critical.nil?
    invalid_properties.push('invalid value for "critical", critical cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



574
575
576
# File 'lib/launchdarkly_api/models/environment.rb', line 574

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



580
581
582
583
584
585
586
587
588
589
590
591
592
# File 'lib/launchdarkly_api/models/environment.rb', line 580

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



568
569
570
# File 'lib/launchdarkly_api/models/environment.rb', line 568

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/launchdarkly_api/models/environment.rb', line 306

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @key.nil?
  return false if @name.nil?
  return false if @api_key.nil?
  return false if @mobile_key.nil?
  return false if @color.nil?
  return false if @default_ttl.nil?
  return false if @secure_mode.nil?
  return false if @default_track_events.nil?
  return false if @require_comments.nil?
  return false if @confirm_changes.nil?
  return false if @tags.nil?
  return false if @critical.nil?
  true
end