Class: LaunchDarklyApi::EnvironmentPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::EnvironmentPost
- Defined in:
- lib/launchdarkly_api/models/environment_post.rb
Instance Attribute Summary collapse
-
#color ⇒ Object
A color to indicate this environment in the UI.
-
#confirm_changes ⇒ Object
Requires confirmation for all flag and segment changes via the UI in this environment.
-
#critical ⇒ Object
Whether the environment is critical.
-
#default_track_events ⇒ Object
Enables tracking detailed information for new flags by default.
-
#default_ttl ⇒ Object
The default time (in minutes) that the PHP SDK can cache feature flag rules locally.
-
#key ⇒ Object
A project-unique key for the new environment.
-
#name ⇒ Object
A human-friendly name for the new environment.
-
#require_comments ⇒ Object
Requires comments for all flag and segment changes via the UI in this environment.
-
#secure_mode ⇒ Object
Ensures that one end user of the client-side SDK cannot inspect the variations for another end user.
-
#source ⇒ Object
Returns the value of attribute source.
-
#tags ⇒ Object
Tags to apply to the new environment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ EnvironmentPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ EnvironmentPost
Initializes the object
102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 102 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::EnvironmentPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::EnvironmentPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'color') self.color = attributes[:'color'] else self.color = nil end if attributes.key?(:'default_ttl') self.default_ttl = attributes[:'default_ttl'] end if attributes.key?(:'secure_mode') self.secure_mode = attributes[:'secure_mode'] end if attributes.key?(:'default_track_events') self.default_track_events = attributes[:'default_track_events'] end if attributes.key?(:'confirm_changes') self.confirm_changes = attributes[:'confirm_changes'] end if attributes.key?(:'require_comments') self.require_comments = attributes[:'require_comments'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'source') self.source = attributes[:'source'] end if attributes.key?(:'critical') self.critical = attributes[:'critical'] end end |
Instance Attribute Details
#color ⇒ Object
A color to indicate this environment in the UI
25 26 27 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 25 def color @color end |
#confirm_changes ⇒ Object
Requires confirmation for all flag and segment changes via the UI in this environment
37 38 39 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 37 def confirm_changes @confirm_changes end |
#critical ⇒ Object
Whether the environment is critical
48 49 50 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 48 def critical @critical end |
#default_track_events ⇒ Object
Enables tracking detailed information for new flags by default
34 35 36 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 34 def default_track_events @default_track_events end |
#default_ttl ⇒ Object
The default time (in minutes) that the PHP SDK can cache feature flag rules locally
28 29 30 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 28 def default_ttl @default_ttl end |
#key ⇒ Object
A project-unique key for the new environment
22 23 24 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 22 def key @key end |
#name ⇒ Object
A human-friendly name for the new environment
19 20 21 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 19 def name @name end |
#require_comments ⇒ Object
Requires comments for all flag and segment changes via the UI in this environment
40 41 42 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 40 def require_comments @require_comments end |
#secure_mode ⇒ Object
Ensures that one end user of the client-side SDK cannot inspect the variations for another end user
31 32 33 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 31 def secure_mode @secure_mode end |
#source ⇒ Object
Returns the value of attribute source.
45 46 47 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 45 def source @source end |
#tags ⇒ Object
Tags to apply to the new environment
43 44 45 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 43 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
68 69 70 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 68 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
73 74 75 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 73 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 51 def self.attribute_map { :'name' => :'name', :'key' => :'key', :'color' => :'color', :'default_ttl' => :'defaultTtl', :'secure_mode' => :'secureMode', :'default_track_events' => :'defaultTrackEvents', :'confirm_changes' => :'confirmChanges', :'require_comments' => :'requireComments', :'tags' => :'tags', :'source' => :'source', :'critical' => :'critical' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 262 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
95 96 97 98 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 95 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 78 def self.openapi_types { :'name' => :'String', :'key' => :'String', :'color' => :'String', :'default_ttl' => :'Integer', :'secure_mode' => :'Boolean', :'default_track_events' => :'Boolean', :'confirm_changes' => :'Boolean', :'require_comments' => :'Boolean', :'tags' => :'Array<String>', :'source' => :'SourceEnv', :'critical' => :'Boolean' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 231 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && key == o.key && color == o.color && default_ttl == o.default_ttl && secure_mode == o.secure_mode && default_track_events == o.default_track_events && confirm_changes == o.confirm_changes && require_comments == o.require_comments && == o. && source == o.source && critical == o.critical end |
#eql?(o) ⇒ Boolean
249 250 251 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 249 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
255 256 257 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 255 def hash [name, key, color, default_ttl, secure_mode, default_track_events, confirm_changes, require_comments, , source, critical].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 171 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @color.nil? invalid_properties.push('invalid value for "color", color cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 284 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
191 192 193 194 195 196 197 |
# File 'lib/launchdarkly_api/models/environment_post.rb', line 191 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @key.nil? return false if @color.nil? true end |