Class: LaunchDarklyApi::ExpandedFlagRep

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/expanded_flag_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ ExpandedFlagRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 154

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandedFlagRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandedFlagRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  else
    self._version = nil
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  else
    self.creation_date = nil
  end

  if attributes.key?(:'include_in_snippet')
    self.include_in_snippet = attributes[:'include_in_snippet']
  end

  if attributes.key?(:'client_side_availability')
    self.client_side_availability = attributes[:'client_side_availability']
  end

  if attributes.key?(:'variations')
    if (value = attributes[:'variations']).is_a?(Array)
      self.variations = value
    end
  else
    self.variations = nil
  end

  if attributes.key?(:'temporary')
    self.temporary = attributes[:'temporary']
  else
    self.temporary = nil
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'_maintainer')
    self._maintainer = attributes[:'_maintainer']
  end

  if attributes.key?(:'custom_properties')
    if (value = attributes[:'custom_properties']).is_a?(Hash)
      self.custom_properties = value
    end
  else
    self.custom_properties = nil
  end

  if attributes.key?(:'archived')
    self.archived = attributes[:'archived']
  else
    self.archived = nil
  end

  if attributes.key?(:'archived_date')
    self.archived_date = attributes[:'archived_date']
  end

  if attributes.key?(:'defaults')
    self.defaults = attributes[:'defaults']
  end
end

Instance Attribute Details

The location and content type of related resources



50
51
52
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 50

def _links
  @_links
end

#_maintainerObject

Returns the value of attribute _maintainer.



55
56
57
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 55

def _maintainer
  @_maintainer
end

#_versionObject

Version of the feature flag



31
32
33
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 31

def _version
  @_version
end

#archivedObject

Boolean indicating if the feature flag is archived



60
61
62
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 60

def archived
  @archived
end

#archived_dateObject

Returns the value of attribute archived_date.



62
63
64
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 62

def archived_date
  @archived_date
end

#client_side_availabilityObject

Returns the value of attribute client_side_availability.



38
39
40
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 38

def client_side_availability
  @client_side_availability
end

#creation_dateObject

Returns the value of attribute creation_date.



33
34
35
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 33

def creation_date
  @creation_date
end

#custom_propertiesObject

Returns the value of attribute custom_properties.



57
58
59
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 57

def custom_properties
  @custom_properties
end

#defaultsObject

Returns the value of attribute defaults.



64
65
66
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 64

def defaults
  @defaults
end

#descriptionObject

Description of the feature flag



25
26
27
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 25

def description
  @description
end

#include_in_snippetObject

Deprecated, use clientSideAvailability. Whether this flag should be made available to the client-side JavaScript SDK



36
37
38
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 36

def include_in_snippet
  @include_in_snippet
end

#keyObject

A unique key used to reference the flag in your code



28
29
30
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 28

def key
  @key
end

#kindObject

Kind of feature flag



22
23
24
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 22

def kind
  @kind
end

#maintainer_idObject

The ID of the member who maintains the flag



53
54
55
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 53

def maintainer_id
  @maintainer_id
end

#nameObject

A human-friendly name for the feature flag



19
20
21
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 19

def name
  @name
end

#tagsObject

Tags for the feature flag



47
48
49
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 47

def tags
  @tags
end

#temporaryObject

Whether the flag is a temporary flag



44
45
46
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 44

def temporary
  @temporary
end

#variationsObject

An array of possible variations for the flag



41
42
43
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 41

def variations
  @variations
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



517
518
519
520
521
522
523
524
525
526
527
528
529
530
531
532
533
534
535
536
537
538
539
540
541
542
543
544
545
546
547
548
549
550
551
552
553
554
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 517

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



113
114
115
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 113

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



118
119
120
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 118

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 89

def self.attribute_map
  {
    :'name' => :'name',
    :'kind' => :'kind',
    :'description' => :'description',
    :'key' => :'key',
    :'_version' => :'_version',
    :'creation_date' => :'creationDate',
    :'include_in_snippet' => :'includeInSnippet',
    :'client_side_availability' => :'clientSideAvailability',
    :'variations' => :'variations',
    :'temporary' => :'temporary',
    :'tags' => :'tags',
    :'_links' => :'_links',
    :'maintainer_id' => :'maintainerId',
    :'_maintainer' => :'_maintainer',
    :'custom_properties' => :'customProperties',
    :'archived' => :'archived',
    :'archived_date' => :'archivedDate',
    :'defaults' => :'defaults'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



493
494
495
496
497
498
499
500
501
502
503
504
505
506
507
508
509
510
511
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 493

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



147
148
149
150
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 147

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 123

def self.openapi_types
  {
    :'name' => :'String',
    :'kind' => :'String',
    :'description' => :'String',
    :'key' => :'String',
    :'_version' => :'Integer',
    :'creation_date' => :'Integer',
    :'include_in_snippet' => :'Boolean',
    :'client_side_availability' => :'ClientSideAvailability',
    :'variations' => :'Array<Variation>',
    :'temporary' => :'Boolean',
    :'tags' => :'Array<String>',
    :'_links' => :'Hash<String, Link>',
    :'maintainer_id' => :'String',
    :'_maintainer' => :'MemberSummary',
    :'custom_properties' => :'Hash<String, CustomProperty>',
    :'archived' => :'Boolean',
    :'archived_date' => :'Integer',
    :'defaults' => :'Defaults'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



455
456
457
458
459
460
461
462
463
464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 455

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      kind == o.kind &&
      description == o.description &&
      key == o.key &&
      _version == o._version &&
      creation_date == o.creation_date &&
      include_in_snippet == o.include_in_snippet &&
      client_side_availability == o.client_side_availability &&
      variations == o.variations &&
      temporary == o.temporary &&
      tags == o.tags &&
      _links == o._links &&
      maintainer_id == o.maintainer_id &&
      _maintainer == o._maintainer &&
      custom_properties == o.custom_properties &&
      archived == o.archived &&
      archived_date == o.archived_date &&
      defaults == o.defaults
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



588
589
590
591
592
593
594
595
596
597
598
599
600
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 588

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


480
481
482
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 480

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



486
487
488
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 486

def hash
  [name, kind, description, key, _version, creation_date, include_in_snippet, client_side_availability, variations, temporary, tags, _links, maintainer_id, _maintainer, custom_properties, archived, archived_date, defaults].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 273

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  if @variations.nil?
    invalid_properties.push('invalid value for "variations", variations cannot be nil.')
  end

  if @temporary.nil?
    invalid_properties.push('invalid value for "temporary", temporary cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @custom_properties.nil?
    invalid_properties.push('invalid value for "custom_properties", custom_properties cannot be nil.')
  end

  if @archived.nil?
    invalid_properties.push('invalid value for "archived", archived cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



564
565
566
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 564

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



570
571
572
573
574
575
576
577
578
579
580
581
582
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 570

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



558
559
560
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 558

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/launchdarkly_api/models/expanded_flag_rep.rb', line 325

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["boolean", "multivariate"])
  return false unless kind_validator.valid?(@kind)
  return false if @key.nil?
  return false if @_version.nil?
  return false if @creation_date.nil?
  return false if @variations.nil?
  return false if @temporary.nil?
  return false if @tags.nil?
  return false if @_links.nil?
  return false if @custom_properties.nil?
  return false if @archived.nil?
  true
end