Class: LaunchDarklyApi::ExpandedMetric
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ExpandedMetric
- Defined in:
- lib/launchdarkly_api/models/expanded_metric.rb
Overview
Metric representation for Views API - contains only fields actually used by the Views service
Instance Attribute Summary collapse
-
#_id ⇒ Object
ID of the metric.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_version_id ⇒ Object
Version ID of the metric.
-
#category ⇒ Object
Category of the Metric.
-
#creation_date ⇒ Object
Creation date in milliseconds.
-
#description ⇒ Object
Description of the Metric.
-
#event_key ⇒ Object
Event key for the metric.
-
#is_active ⇒ Object
Whether the metric is active.
-
#is_numeric ⇒ Object
Returns the value of attribute is_numeric.
-
#key ⇒ Object
A unique key used to reference the metric.
-
#kind ⇒ Object
Kind of the Metric.
-
#last_modified ⇒ Object
Last modification date in milliseconds.
-
#last_seen ⇒ Object
Last seen date in milliseconds.
-
#name ⇒ Object
A human-friendly name for the metric.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpandedMetric
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ExpandedMetric
Initializes the object
112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 112 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandedMetric` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandedMetric`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'last_modified') self.last_modified = attributes[:'last_modified'] end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] end if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'_version_id') self._version_id = attributes[:'_version_id'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'is_numeric') self.is_numeric = attributes[:'is_numeric'] end if attributes.key?(:'last_seen') self.last_seen = attributes[:'last_seen'] end if attributes.key?(:'_links') self._links = attributes[:'_links'] end end |
Instance Attribute Details
#_id ⇒ Object
ID of the metric
38 39 40 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 38 def _id @_id end |
#_links ⇒ Object
Returns the value of attribute _links.
57 58 59 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 57 def _links @_links end |
#_version_id ⇒ Object
Version ID of the metric
41 42 43 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 41 def _version_id @_version_id end |
#category ⇒ Object
Category of the Metric
47 48 49 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 47 def category @category end |
#creation_date ⇒ Object
Creation date in milliseconds
26 27 28 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 26 def creation_date @creation_date end |
#description ⇒ Object
Description of the Metric
50 51 52 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 50 def description @description end |
#event_key ⇒ Object
Event key for the metric
35 36 37 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 35 def event_key @event_key end |
#is_active ⇒ Object
Whether the metric is active
32 33 34 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 32 def is_active @is_active end |
#is_numeric ⇒ Object
Returns the value of attribute is_numeric.
52 53 54 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 52 def is_numeric @is_numeric end |
#key ⇒ Object
A unique key used to reference the metric
20 21 22 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 20 def key @key end |
#kind ⇒ Object
Kind of the Metric
44 45 46 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 44 def kind @kind end |
#last_modified ⇒ Object
Last modification date in milliseconds
29 30 31 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 29 def last_modified @last_modified end |
#last_seen ⇒ Object
Last seen date in milliseconds
55 56 57 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 55 def last_seen @last_seen end |
#name ⇒ Object
A human-friendly name for the metric
23 24 25 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 23 def name @name end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 257 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
80 81 82 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 80 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 60 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'creation_date' => :'creationDate', :'last_modified' => :'lastModified', :'is_active' => :'isActive', :'event_key' => :'eventKey', :'_id' => :'_id', :'_version_id' => :'_versionId', :'kind' => :'kind', :'category' => :'category', :'description' => :'description', :'is_numeric' => :'isNumeric', :'last_seen' => :'lastSeen', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 233 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
105 106 107 108 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 105 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 85 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'creation_date' => :'Integer', :'last_modified' => :'Integer', :'is_active' => :'Boolean', :'event_key' => :'String', :'_id' => :'String', :'_version_id' => :'String', :'kind' => :'String', :'category' => :'String', :'description' => :'String', :'is_numeric' => :'Boolean', :'last_seen' => :'Integer', :'_links' => :'ParentAndSelfLinks' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 199 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && creation_date == o.creation_date && last_modified == o.last_modified && is_active == o.is_active && event_key == o.event_key && _id == o._id && _version_id == o._version_id && kind == o.kind && category == o.category && description == o.description && is_numeric == o.is_numeric && last_seen == o.last_seen && _links == o._links end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 328 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
220 221 222 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 220 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
226 227 228 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 226 def hash [key, name, creation_date, last_modified, is_active, event_key, _id, _version_id, kind, category, description, is_numeric, last_seen, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 184 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
304 305 306 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 304 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
310 311 312 313 314 315 316 317 318 319 320 321 322 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 310 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
298 299 300 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 298 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 |
# File 'lib/launchdarkly_api/models/expanded_metric.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |