Class: LaunchDarklyApi::ExpandedSegment
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ExpandedSegment
- Defined in:
- lib/launchdarkly_api/models/expanded_segment.rb
Overview
Segment representation for Views API - contains only fields actually used by the Views service
Instance Attribute Summary collapse
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#creation_date ⇒ Object
Creation date in milliseconds.
-
#deleted ⇒ Object
Whether the segment is deleted.
-
#description ⇒ Object
Description of the segment.
-
#environment_id ⇒ Object
Environment ID of the segment.
-
#environment_key ⇒ Object
Environment key of the segment.
-
#generation ⇒ Object
Generation of the segment.
-
#key ⇒ Object
A unique key used to reference the segment.
-
#last_modified_date ⇒ Object
Last modification date in milliseconds.
-
#name ⇒ Object
A human-friendly name for the segment.
-
#tags ⇒ Object
Tags for the segment.
-
#unbounded ⇒ Object
Whether the segment is unbounded.
-
#version ⇒ Object
Version of the segment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExpandedSegment
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExpandedSegment
Initializes the object
113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 113 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExpandedSegment` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExpandedSegment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'environment_id') self.environment_id = attributes[:'environment_id'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end if attributes.key?(:'last_modified_date') self.last_modified_date = attributes[:'last_modified_date'] end if attributes.key?(:'deleted') self.deleted = attributes[:'deleted'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'unbounded') self.unbounded = attributes[:'unbounded'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'generation') self.generation = attributes[:'generation'] end if attributes.key?(:'_links') self._links = attributes[:'_links'] end end |
Instance Attribute Details
#_links ⇒ Object
Returns the value of attribute _links.
55 56 57 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 55 def _links @_links end |
#creation_date ⇒ Object
Creation date in milliseconds
35 36 37 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 35 def creation_date @creation_date end |
#deleted ⇒ Object
Whether the segment is deleted
41 42 43 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 41 def deleted @deleted end |
#description ⇒ Object
Description of the segment
32 33 34 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 32 def description @description end |
#environment_id ⇒ Object
Environment ID of the segment
26 27 28 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 26 def environment_id @environment_id end |
#environment_key ⇒ Object
Environment key of the segment
29 30 31 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 29 def environment_key @environment_key end |
#generation ⇒ Object
Generation of the segment
53 54 55 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 53 def generation @generation end |
#key ⇒ Object
A unique key used to reference the segment
20 21 22 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 20 def key @key end |
#last_modified_date ⇒ Object
Last modification date in milliseconds
38 39 40 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 38 def last_modified_date @last_modified_date end |
#name ⇒ Object
A human-friendly name for the segment
23 24 25 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 23 def name @name end |
#tags ⇒ Object
Tags for the segment
44 45 46 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 44 def @tags end |
#unbounded ⇒ Object
Whether the segment is unbounded
47 48 49 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 47 def unbounded @unbounded end |
#version ⇒ Object
Version of the segment
50 51 52 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 50 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
77 78 79 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 77 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
82 83 84 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 82 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 58 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'environment_id' => :'environmentId', :'environment_key' => :'environmentKey', :'description' => :'description', :'creation_date' => :'creationDate', :'last_modified_date' => :'lastModifiedDate', :'deleted' => :'deleted', :'tags' => :'tags', :'unbounded' => :'unbounded', :'version' => :'version', :'generation' => :'generation', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 266 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
106 107 108 109 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 106 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 87 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'environment_id' => :'String', :'environment_key' => :'String', :'description' => :'String', :'creation_date' => :'Integer', :'last_modified_date' => :'Integer', :'deleted' => :'Boolean', :'tags' => :'Array<String>', :'unbounded' => :'Boolean', :'version' => :'Integer', :'generation' => :'Integer', :'_links' => :'ParentAndSelfLinks' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 233 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && environment_id == o.environment_id && environment_key == o.environment_key && description == o.description && creation_date == o.creation_date && last_modified_date == o.last_modified_date && deleted == o.deleted && == o. && unbounded == o.unbounded && version == o.version && generation == o.generation && _links == o._links end |
#eql?(o) ⇒ Boolean
253 254 255 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 253 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
259 260 261 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 259 def hash [key, name, environment_id, environment_key, description, creation_date, last_modified_date, deleted, , unbounded, version, generation, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
188 189 190 191 192 193 194 195 196 197 198 199 200 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 188 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
288 289 290 291 292 293 294 295 296 297 298 299 300 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 288 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
204 205 206 207 208 209 |
# File 'lib/launchdarkly_api/models/expanded_segment.rb', line 204 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? true end |