Class: LaunchDarklyApi::Experiment

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/experiment.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Experiment

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
# File 'lib/launchdarkly_api/models/experiment.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Experiment` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Experiment`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'_maintainer_id')
    self._maintainer_id = attributes[:'_maintainer_id']
  else
    self._maintainer_id = nil
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  else
    self._creation_date = nil
  end

  if attributes.key?(:'environment_key')
    self.environment_key = attributes[:'environment_key']
  else
    self.environment_key = nil
  end

  if attributes.key?(:'archived_date')
    self.archived_date = attributes[:'archived_date']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'holdout_id')
    self.holdout_id = attributes[:'holdout_id']
  end

  if attributes.key?(:'current_iteration')
    self.current_iteration = attributes[:'current_iteration']
  end

  if attributes.key?(:'draft_iteration')
    self.draft_iteration = attributes[:'draft_iteration']
  end

  if attributes.key?(:'previous_iterations')
    if (value = attributes[:'previous_iterations']).is_a?(Array)
      self.previous_iterations = value
    end
  end
end

Instance Attribute Details

#_creation_dateObject

Returns the value of attribute _creation_date.



33
34
35
# File 'lib/launchdarkly_api/models/experiment.rb', line 33

def _creation_date
  @_creation_date
end

#_idObject

The experiment ID



19
20
21
# File 'lib/launchdarkly_api/models/experiment.rb', line 19

def _id
  @_id
end

The location and content type of related resources



40
41
42
# File 'lib/launchdarkly_api/models/experiment.rb', line 40

def _links
  @_links
end

#_maintainer_idObject

The ID of the member who maintains this experiment.



31
32
33
# File 'lib/launchdarkly_api/models/experiment.rb', line 31

def _maintainer_id
  @_maintainer_id
end

#archived_dateObject

Returns the value of attribute archived_date.



37
38
39
# File 'lib/launchdarkly_api/models/experiment.rb', line 37

def archived_date
  @archived_date
end

#current_iterationObject

Returns the value of attribute current_iteration.



45
46
47
# File 'lib/launchdarkly_api/models/experiment.rb', line 45

def current_iteration
  @current_iteration
end

#descriptionObject

The experiment description



28
29
30
# File 'lib/launchdarkly_api/models/experiment.rb', line 28

def description
  @description
end

#draft_iterationObject

Returns the value of attribute draft_iteration.



47
48
49
# File 'lib/launchdarkly_api/models/experiment.rb', line 47

def draft_iteration
  @draft_iteration
end

#environment_keyObject

Returns the value of attribute environment_key.



35
36
37
# File 'lib/launchdarkly_api/models/experiment.rb', line 35

def environment_key
  @environment_key
end

#holdout_idObject

The holdout ID



43
44
45
# File 'lib/launchdarkly_api/models/experiment.rb', line 43

def holdout_id
  @holdout_id
end

#keyObject

The experiment key



22
23
24
# File 'lib/launchdarkly_api/models/experiment.rb', line 22

def key
  @key
end

#nameObject

The experiment name



25
26
27
# File 'lib/launchdarkly_api/models/experiment.rb', line 25

def name
  @name
end

#previous_iterationsObject

Details on the previous iterations for this experiment.



50
51
52
# File 'lib/launchdarkly_api/models/experiment.rb', line 50

def previous_iterations
  @previous_iterations
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



355
356
357
358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/launchdarkly_api/models/experiment.rb', line 355

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/experiment.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/launchdarkly_api/models/experiment.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/launchdarkly_api/models/experiment.rb', line 53

def self.attribute_map
  {
    :'_id' => :'_id',
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'_maintainer_id' => :'_maintainerId',
    :'_creation_date' => :'_creationDate',
    :'environment_key' => :'environmentKey',
    :'archived_date' => :'archivedDate',
    :'_links' => :'_links',
    :'holdout_id' => :'holdoutId',
    :'current_iteration' => :'currentIteration',
    :'draft_iteration' => :'draftIteration',
    :'previous_iterations' => :'previousIterations'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
347
348
349
# File 'lib/launchdarkly_api/models/experiment.rb', line 331

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/launchdarkly_api/models/experiment.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/launchdarkly_api/models/experiment.rb', line 82

def self.openapi_types
  {
    :'_id' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'_maintainer_id' => :'String',
    :'_creation_date' => :'Integer',
    :'environment_key' => :'String',
    :'archived_date' => :'Integer',
    :'_links' => :'Hash<String, Link>',
    :'holdout_id' => :'String',
    :'current_iteration' => :'IterationRep',
    :'draft_iteration' => :'IterationRep',
    :'previous_iterations' => :'Array<IterationRep>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
# File 'lib/launchdarkly_api/models/experiment.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      _maintainer_id == o._maintainer_id &&
      _creation_date == o._creation_date &&
      environment_key == o.environment_key &&
      archived_date == o.archived_date &&
      _links == o._links &&
      holdout_id == o.holdout_id &&
      current_iteration == o.current_iteration &&
      draft_iteration == o.draft_iteration &&
      previous_iterations == o.previous_iterations
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



426
427
428
429
430
431
432
433
434
435
436
437
438
# File 'lib/launchdarkly_api/models/experiment.rb', line 426

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


318
319
320
# File 'lib/launchdarkly_api/models/experiment.rb', line 318

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



324
325
326
# File 'lib/launchdarkly_api/models/experiment.rb', line 324

def hash
  [_id, key, name, description, _maintainer_id, _creation_date, environment_key, archived_date, _links, holdout_id, current_iteration, draft_iteration, previous_iterations].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
# File 'lib/launchdarkly_api/models/experiment.rb', line 193

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @_maintainer_id.nil?
    invalid_properties.push('invalid value for "_maintainer_id", _maintainer_id cannot be nil.')
  end

  if @_creation_date.nil?
    invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.')
  end

  if @environment_key.nil?
    invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



402
403
404
# File 'lib/launchdarkly_api/models/experiment.rb', line 402

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/launchdarkly_api/models/experiment.rb', line 408

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



396
397
398
# File 'lib/launchdarkly_api/models/experiment.rb', line 396

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



225
226
227
228
229
230
231
232
233
234
# File 'lib/launchdarkly_api/models/experiment.rb', line 225

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @_maintainer_id.nil?
  return false if @_creation_date.nil?
  return false if @environment_key.nil?
  return false if @_links.nil?
  true
end