Class: LaunchDarklyApi::ExperimentPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ExperimentPost
- Defined in:
- lib/launchdarkly_api/models/experiment_post.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#analysis_config ⇒ Object
Returns the value of attribute analysis_config.
-
#data_source ⇒ Object
The source of metric data in order to analyze results.
-
#description ⇒ Object
The experiment description.
-
#holdout_id ⇒ Object
The ID of the holdout.
-
#iteration ⇒ Object
Returns the value of attribute iteration.
-
#key ⇒ Object
The experiment key.
-
#maintainer_id ⇒ Object
The ID of the member who maintains this experiment.
-
#methodology ⇒ Object
The results analysis approach.
-
#name ⇒ Object
The experiment name.
-
#tags ⇒ Object
Tags for the experiment.
-
#type ⇒ Object
The type of experiment.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ExperimentPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ExperimentPost
Initializes the object
123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 123 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ExperimentPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ExperimentPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'iteration') self.iteration = attributes[:'iteration'] else self.iteration = nil end if attributes.key?(:'holdout_id') self.holdout_id = attributes[:'holdout_id'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'methodology') self.methodology = attributes[:'methodology'] end if attributes.key?(:'analysis_config') self.analysis_config = attributes[:'analysis_config'] end if attributes.key?(:'data_source') self.data_source = attributes[:'data_source'] end if attributes.key?(:'type') self.type = attributes[:'type'] end end |
Instance Attribute Details
#analysis_config ⇒ Object
Returns the value of attribute analysis_config.
41 42 43 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 41 def analysis_config @analysis_config end |
#data_source ⇒ Object
The source of metric data in order to analyze results. Defaults to "launchdarkly" when not provided.
44 45 46 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 44 def data_source @data_source end |
#description ⇒ Object
The experiment description
22 23 24 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 22 def description @description end |
#holdout_id ⇒ Object
The ID of the holdout
33 34 35 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 33 def holdout_id @holdout_id end |
#iteration ⇒ Object
Returns the value of attribute iteration.
30 31 32 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 30 def iteration @iteration end |
#key ⇒ Object
The experiment key
28 29 30 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 28 def key @key end |
#maintainer_id ⇒ Object
The ID of the member who maintains this experiment
25 26 27 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 25 def maintainer_id @maintainer_id end |
#methodology ⇒ Object
The results analysis approach.
39 40 41 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 39 def methodology @methodology end |
#name ⇒ Object
The experiment name
19 20 21 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 19 def name @name end |
#tags ⇒ Object
Tags for the experiment
36 37 38 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 36 def @tags end |
#type ⇒ Object
The type of experiment.
47 48 49 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 47 def type @type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
89 90 91 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 89 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
94 95 96 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 94 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 72 def self.attribute_map { :'name' => :'name', :'description' => :'description', :'maintainer_id' => :'maintainerId', :'key' => :'key', :'iteration' => :'iteration', :'holdout_id' => :'holdoutId', :'tags' => :'tags', :'methodology' => :'methodology', :'analysis_config' => :'analysisConfig', :'data_source' => :'dataSource', :'type' => :'type' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 319 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
116 117 118 119 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 116 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 99 def self.openapi_types { :'name' => :'String', :'description' => :'String', :'maintainer_id' => :'String', :'key' => :'String', :'iteration' => :'IterationInput', :'holdout_id' => :'String', :'tags' => :'Array<String>', :'methodology' => :'String', :'analysis_config' => :'AnalysisConfigInput', :'data_source' => :'String', :'type' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 288 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && description == o.description && maintainer_id == o.maintainer_id && key == o.key && iteration == o.iteration && holdout_id == o.holdout_id && == o. && methodology == o.methodology && analysis_config == o.analysis_config && data_source == o.data_source && type == o.type end |
#eql?(o) ⇒ Boolean
306 307 308 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 306 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
312 313 314 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 312 def hash [name, description, maintainer_id, key, iteration, holdout_id, , methodology, analysis_config, data_source, type].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 192 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @iteration.nil? invalid_properties.push('invalid value for "iteration", iteration cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 341 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
212 213 214 215 216 217 218 219 220 221 222 223 224 |
# File 'lib/launchdarkly_api/models/experiment_post.rb', line 212 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @key.nil? return false if @iteration.nil? methodology_validator = EnumAttributeValidator.new('String', ["bayesian", "frequentist", "export_only"]) return false unless methodology_validator.valid?(@methodology) data_source_validator = EnumAttributeValidator.new('String', ["launchdarkly", "snowflake"]) return false unless data_source_validator.valid?(@data_source) type_validator = EnumAttributeValidator.new('String', ["experiment", "mab", "holdout"]) return false unless type_validator.valid?(@type) true end |