Class: LaunchDarklyApi::ExperimentsBetaApi

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/api/experiments_beta_api.rb

Instance Attribute Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(api_client = ApiClient.default) ⇒ ExperimentsBetaApi

Returns a new instance of ExperimentsBetaApi.



19
20
21
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 19

def initialize(api_client = ApiClient.default)
  @api_client = api_client
end

Instance Attribute Details

#api_clientObject

Returns the value of attribute api_client.



17
18
19
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 17

def api_client
  @api_client
end

Instance Method Details

#get_experiment(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ ExperimentResultsRep

Get experiment results Get detailed experiment result data

Parameters:

  • project_key (String)

    The project key

  • feature_flag_key (String)

    The feature flag key

  • environment_key (String)

    The environment key

  • metric_key (String)

    The metric key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :from (Integer)

    A timestamp denoting the start of the data collection period, expressed as a Unix epoch time in milliseconds.

  • :to (Integer)

    A timestamp denoting the end of the data collection period, expressed as a Unix epoch time in milliseconds.

Returns:



32
33
34
35
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 32

def get_experiment(project_key, feature_flag_key, environment_key, metric_key, opts = {})
  data, _status_code, _headers = get_experiment_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts)
  data
end

#get_experiment_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ Array<(ExperimentResultsRep, Integer, Hash)>

Get experiment results Get detailed experiment result data

Parameters:

  • project_key (String)

    The project key

  • feature_flag_key (String)

    The feature flag key

  • environment_key (String)

    The environment key

  • metric_key (String)

    The metric key

  • opts (Hash) (defaults to: {})

    the optional parameters

Options Hash (opts):

  • :from (Integer)

    A timestamp denoting the start of the data collection period, expressed as a Unix epoch time in milliseconds.

  • :to (Integer)

    A timestamp denoting the end of the data collection period, expressed as a Unix epoch time in milliseconds.

Returns:

  • (Array<(ExperimentResultsRep, Integer, Hash)>)

    ExperimentResultsRep data, response status code and response headers



47
48
49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 47

def get_experiment_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.get_experiment ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.get_experiment"
  end
  # verify the required parameter 'feature_flag_key' is set
  if @api_client.config.client_side_validation && feature_flag_key.nil?
    fail ArgumentError, "Missing the required parameter 'feature_flag_key' when calling ExperimentsBetaApi.get_experiment"
  end
  # verify the required parameter 'environment_key' is set
  if @api_client.config.client_side_validation && environment_key.nil?
    fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.get_experiment"
  end
  # verify the required parameter 'metric_key' is set
  if @api_client.config.client_side_validation && metric_key.nil?
    fail ArgumentError, "Missing the required parameter 'metric_key' when calling ExperimentsBetaApi.get_experiment"
  end
  # resource path
  local_var_path = '/api/v2/flags/{projectKey}/{featureFlagKey}/experiments/{environmentKey}/{metricKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'featureFlagKey' + '}', CGI.escape(feature_flag_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'metricKey' + '}', CGI.escape(metric_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}
  query_params[:'from'] = opts[:'from'] if !opts[:'from'].nil?
  query_params[:'to'] = opts[:'to'] if !opts[:'to'].nil?

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type] || 'ExperimentResultsRep'

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ExperimentsBetaApi.get_experiment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:GET, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ExperimentsBetaApi#get_experiment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end

#reset_experiment(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ nil

Reset experiment results Reset all experiment results by deleting all existing data for an experiment

Parameters:

  • project_key (String)

    The project key

  • feature_flag_key (String)

    The feature flag key

  • environment_key (String)

    The environment key

  • metric_key (String)

    The metric&#39;s key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (nil)


117
118
119
120
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 117

def reset_experiment(project_key, feature_flag_key, environment_key, metric_key, opts = {})
  reset_experiment_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts)
  nil
end

#reset_experiment_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {}) ⇒ Array<(nil, Integer, Hash)>

Reset experiment results Reset all experiment results by deleting all existing data for an experiment

Parameters:

  • project_key (String)

    The project key

  • feature_flag_key (String)

    The feature flag key

  • environment_key (String)

    The environment key

  • metric_key (String)

    The metric&#39;s key

  • opts (Hash) (defaults to: {})

    the optional parameters

Returns:

  • (Array<(nil, Integer, Hash)>)

    nil, response status code and response headers



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/launchdarkly_api/api/experiments_beta_api.rb', line 130

def reset_experiment_with_http_info(project_key, feature_flag_key, environment_key, metric_key, opts = {})
  if @api_client.config.debugging
    @api_client.config.logger.debug 'Calling API: ExperimentsBetaApi.reset_experiment ...'
  end
  # verify the required parameter 'project_key' is set
  if @api_client.config.client_side_validation && project_key.nil?
    fail ArgumentError, "Missing the required parameter 'project_key' when calling ExperimentsBetaApi.reset_experiment"
  end
  # verify the required parameter 'feature_flag_key' is set
  if @api_client.config.client_side_validation && feature_flag_key.nil?
    fail ArgumentError, "Missing the required parameter 'feature_flag_key' when calling ExperimentsBetaApi.reset_experiment"
  end
  # verify the required parameter 'environment_key' is set
  if @api_client.config.client_side_validation && environment_key.nil?
    fail ArgumentError, "Missing the required parameter 'environment_key' when calling ExperimentsBetaApi.reset_experiment"
  end
  # verify the required parameter 'metric_key' is set
  if @api_client.config.client_side_validation && metric_key.nil?
    fail ArgumentError, "Missing the required parameter 'metric_key' when calling ExperimentsBetaApi.reset_experiment"
  end
  # resource path
  local_var_path = '/api/v2/flags/{projectKey}/{featureFlagKey}/experiments/{environmentKey}/{metricKey}/results'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'featureFlagKey' + '}', CGI.escape(feature_flag_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'metricKey' + '}', CGI.escape(metric_key.to_s))

  # query parameters
  query_params = opts[:query_params] || {}

  # header parameters
  header_params = opts[:header_params] || {}
  # HTTP header 'Accept' (if needed)
  header_params['Accept'] = @api_client.select_header_accept(['application/json'])

  # form parameters
  form_params = opts[:form_params] || {}

  # http body (model)
  post_body = opts[:debug_body]

  # return_type
  return_type = opts[:debug_return_type]

  # auth_names
  auth_names = opts[:debug_auth_names] || ['ApiKey']

  new_options = opts.merge(
    :operation => :"ExperimentsBetaApi.reset_experiment",
    :header_params => header_params,
    :query_params => query_params,
    :form_params => form_params,
    :body => post_body,
    :auth_names => auth_names,
    :return_type => return_type
  )

  data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, new_options)
  if @api_client.config.debugging
    @api_client.config.logger.debug "API called: ExperimentsBetaApi#reset_experiment\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}"
  end
  return data, status_code, headers
end