Class: LaunchDarklyApi::FeatureFlagBody

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/feature_flag_body.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ FeatureFlagBody

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 131

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FeatureFlagBody` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FeatureFlagBody`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'include_in_snippet')
    self.include_in_snippet = attributes[:'include_in_snippet']
  end

  if attributes.key?(:'client_side_availability')
    self.client_side_availability = attributes[:'client_side_availability']
  end

  if attributes.key?(:'variations')
    if (value = attributes[:'variations']).is_a?(Array)
      self.variations = value
    end
  end

  if attributes.key?(:'temporary')
    self.temporary = attributes[:'temporary']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'custom_properties')
    if (value = attributes[:'custom_properties']).is_a?(Hash)
      self.custom_properties = value
    end
  end

  if attributes.key?(:'defaults')
    self.defaults = attributes[:'defaults']
  end

  if attributes.key?(:'purpose')
    self.purpose = attributes[:'purpose']
  end

  if attributes.key?(:'migration_settings')
    self.migration_settings = attributes[:'migration_settings']
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end
end

Instance Attribute Details

#client_side_availabilityObject

Returns the value of attribute client_side_availability.



30
31
32
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 30

def client_side_availability
  @client_side_availability
end

#custom_propertiesObject

Returns the value of attribute custom_properties.



41
42
43
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 41

def custom_properties
  @custom_properties
end

#defaultsObject

Returns the value of attribute defaults.



43
44
45
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 43

def defaults
  @defaults
end

#descriptionObject

Description of the feature flag. Defaults to an empty string.



25
26
27
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 25

def description
  @description
end

#include_in_snippetObject

Deprecated, use clientSideAvailability. Whether this flag should be made available to the client-side JavaScript SDK. Defaults to false.



28
29
30
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 28

def include_in_snippet
  @include_in_snippet
end

#keyObject

A unique key used to reference the flag in your code



22
23
24
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 22

def key
  @key
end

#maintainer_idObject

The ID of the member who maintains this feature flag



51
52
53
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 51

def maintainer_id
  @maintainer_id
end

#maintainer_team_keyObject

The key of the team that maintains this feature flag



54
55
56
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 54

def maintainer_team_key
  @maintainer_team_key
end

#migration_settingsObject

Returns the value of attribute migration_settings.



48
49
50
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 48

def migration_settings
  @migration_settings
end

#nameObject

A human-friendly name for the feature flag



19
20
21
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 19

def name
  @name
end

#purposeObject

Purpose of the flag



46
47
48
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 46

def purpose
  @purpose
end

#tagsObject

Tags for the feature flag. Defaults to an empty array.



39
40
41
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 39

def tags
  @tags
end

#temporaryObject

Whether the flag is a temporary flag. Defaults to true.



36
37
38
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 36

def temporary
  @temporary
end

#variationsObject

An array of possible variations for the flag. The variation values must be unique. If omitted, two boolean variations of true and false will be used.



33
34
35
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 33

def variations
  @variations
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



99
100
101
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 99

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 79

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'description' => :'description',
    :'include_in_snippet' => :'includeInSnippet',
    :'client_side_availability' => :'clientSideAvailability',
    :'variations' => :'variations',
    :'temporary' => :'temporary',
    :'tags' => :'tags',
    :'custom_properties' => :'customProperties',
    :'defaults' => :'defaults',
    :'purpose' => :'purpose',
    :'migration_settings' => :'migrationSettings',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 278

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



124
125
126
127
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 124

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 104

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'description' => :'String',
    :'include_in_snippet' => :'Boolean',
    :'client_side_availability' => :'ClientSideAvailabilityPost',
    :'variations' => :'Array<Variation>',
    :'temporary' => :'Boolean',
    :'tags' => :'Array<String>',
    :'custom_properties' => :'Hash<String, CustomProperty>',
    :'defaults' => :'Defaults',
    :'purpose' => :'String',
    :'migration_settings' => :'MigrationSettingsPost',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 244

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      description == o.description &&
      include_in_snippet == o.include_in_snippet &&
      client_side_availability == o.client_side_availability &&
      variations == o.variations &&
      temporary == o.temporary &&
      tags == o.tags &&
      custom_properties == o.custom_properties &&
      defaults == o.defaults &&
      purpose == o.purpose &&
      migration_settings == o.migration_settings &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
343
344
345
346
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 309

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



380
381
382
383
384
385
386
387
388
389
390
391
392
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 380

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



285
286
287
288
289
290
291
292
293
294
295
296
297
298
299
300
301
302
303
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 285

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 271

def hash
  [name, key, description, include_in_snippet, client_side_availability, variations, temporary, tags, custom_properties, defaults, purpose, migration_settings, maintainer_id, maintainer_team_key].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 209

def list_invalid_properties
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



356
357
358
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 356

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



362
363
364
365
366
367
368
369
370
371
372
373
374
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 362

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



350
351
352
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 350

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



224
225
226
227
228
229
230
# File 'lib/launchdarkly_api/models/feature_flag_body.rb', line 224

def valid?
  return false if @name.nil?
  return false if @key.nil?
  purpose_validator = EnumAttributeValidator.new('String', ["migration"])
  return false unless purpose_validator.valid?(@purpose)
  true
end