Class: LaunchDarklyApi::FlagEventRep
- Inherits:
-
Object
- Object
- LaunchDarklyApi::FlagEventRep
- Defined in:
- lib/launchdarkly_api/models/flag_event_rep.rb
Instance Attribute Summary collapse
-
#actions ⇒ Object
The resource actions.
-
#audit_log_entry_id ⇒ Object
The audit log entry ID.
-
#description ⇒ Object
The event description.
-
#environment_id ⇒ Object
The environment ID.
-
#environment_key ⇒ Object
The environment key.
-
#event_time ⇒ Object
Returns the value of attribute event_time.
-
#event_type ⇒ Object
Returns the value of attribute event_type.
-
#experiments ⇒ Object
Returns the value of attribute experiments.
-
#flag_key ⇒ Object
The flag key.
-
#id ⇒ Object
The flag event ID.
-
#impact ⇒ Object
Returns the value of attribute impact.
-
#member ⇒ Object
Returns the value of attribute member.
-
#project_id ⇒ Object
The project ID.
-
#project_key ⇒ Object
The project key.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlagEventRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ FlagEventRep
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagEventRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagEventRep`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'project_key') self.project_key = attributes[:'project_key'] end if attributes.key?(:'environment_id') self.environment_id = attributes[:'environment_id'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] end if attributes.key?(:'flag_key') self.flag_key = attributes[:'flag_key'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] end if attributes.key?(:'event_time') self.event_time = attributes[:'event_time'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'audit_log_entry_id') self.audit_log_entry_id = attributes[:'audit_log_entry_id'] end if attributes.key?(:'member') self.member = attributes[:'member'] end if attributes.key?(:'actions') if (value = attributes[:'actions']).is_a?(Array) self.actions = value end end if attributes.key?(:'impact') self.impact = attributes[:'impact'] end if attributes.key?(:'experiments') self.experiments = attributes[:'experiments'] end end |
Instance Attribute Details
#actions ⇒ Object
The resource actions
49 50 51 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 49 def actions @actions end |
#audit_log_entry_id ⇒ Object
The audit log entry ID
44 45 46 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 44 def audit_log_entry_id @audit_log_entry_id end |
#description ⇒ Object
The event description
41 42 43 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 41 def description @description end |
#environment_id ⇒ Object
The environment ID
28 29 30 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 28 def environment_id @environment_id end |
#environment_key ⇒ Object
The environment key
31 32 33 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 31 def environment_key @environment_key end |
#event_time ⇒ Object
Returns the value of attribute event_time.
38 39 40 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 38 def event_time @event_time end |
#event_type ⇒ Object
Returns the value of attribute event_type.
36 37 38 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 36 def event_type @event_type end |
#experiments ⇒ Object
Returns the value of attribute experiments.
53 54 55 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 53 def experiments @experiments end |
#flag_key ⇒ Object
The flag key
34 35 36 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 34 def flag_key @flag_key end |
#id ⇒ Object
The flag event ID
19 20 21 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 19 def id @id end |
#impact ⇒ Object
Returns the value of attribute impact.
51 52 53 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 51 def impact @impact end |
#member ⇒ Object
Returns the value of attribute member.
46 47 48 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 46 def member @member end |
#project_id ⇒ Object
The project ID
22 23 24 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 22 def project_id @project_id end |
#project_key ⇒ Object
The project key
25 26 27 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 25 def project_key @project_key end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 76 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 56 def self.attribute_map { :'id' => :'id', :'project_id' => :'projectId', :'project_key' => :'projectKey', :'environment_id' => :'environmentId', :'environment_key' => :'environmentKey', :'flag_key' => :'flagKey', :'event_type' => :'eventType', :'event_time' => :'eventTime', :'description' => :'description', :'audit_log_entry_id' => :'auditLogEntryId', :'member' => :'member', :'actions' => :'actions', :'impact' => :'impact', :'experiments' => :'experiments' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
269 270 271 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 269 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 81 def self.openapi_types { :'id' => :'String', :'project_id' => :'String', :'project_key' => :'String', :'environment_id' => :'String', :'environment_key' => :'String', :'flag_key' => :'String', :'event_type' => :'String', :'event_time' => :'Integer', :'description' => :'String', :'audit_log_entry_id' => :'String', :'member' => :'FlagEventMemberRep', :'actions' => :'Array<String>', :'impact' => :'FlagEventImpactRep', :'experiments' => :'FlagEventExperimentCollection' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 235 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && project_id == o.project_id && project_key == o.project_key && environment_id == o.environment_id && environment_key == o.environment_key && flag_key == o.flag_key && event_type == o.event_type && event_time == o.event_time && description == o.description && audit_log_entry_id == o.audit_log_entry_id && member == o.member && actions == o.actions && impact == o.impact && experiments == o.experiments end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 300 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
371 372 373 374 375 376 377 378 379 380 381 382 383 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 371 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 276 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
256 257 258 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 256 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
262 263 264 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 262 def hash [id, project_id, project_key, environment_id, environment_key, flag_key, event_type, event_time, description, audit_log_entry_id, member, actions, impact, experiments].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 182 def list_invalid_properties invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @project_id.nil? invalid_properties.push('invalid value for "project_id", project_id cannot be nil.') end if @project_key.nil? invalid_properties.push('invalid value for "project_key", project_key cannot be nil.') end if @flag_key.nil? invalid_properties.push('invalid value for "flag_key", flag_key cannot be nil.') end if @event_type.nil? invalid_properties.push('invalid value for "event_type", event_type cannot be nil.') end if @event_time.nil? invalid_properties.push('invalid value for "event_time", event_time cannot be nil.') end if @description.nil? invalid_properties.push('invalid value for "description", description cannot be nil.') end if @impact.nil? invalid_properties.push('invalid value for "impact", impact cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
347 348 349 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 347 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
353 354 355 356 357 358 359 360 361 362 363 364 365 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 353 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
341 342 343 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 341 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
221 222 223 224 225 226 227 228 229 230 231 |
# File 'lib/launchdarkly_api/models/flag_event_rep.rb', line 221 def valid? return false if @id.nil? return false if @project_id.nil? return false if @project_key.nil? return false if @flag_key.nil? return false if @event_type.nil? return false if @event_time.nil? return false if @description.nil? return false if @impact.nil? true end |