Class: LaunchDarklyApi::FlagLinkPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::FlagLinkPost
- Defined in:
- lib/launchdarkly_api/models/flag_link_post.rb
Instance Attribute Summary collapse
-
#deep_link ⇒ Object
The URL for the external resource you are linking the flag to.
-
#description ⇒ Object
The description of the flag link.
-
#integration_key ⇒ Object
The integration key for an integration whose
manifest.jsonincludes theflagLinkcapability, if this is a flag link for an existing integration. -
#key ⇒ Object
The flag link key.
-
#metadata ⇒ Object
The metadata required by this integration in order to create a flag link, if this is a flag link for an existing integration.
-
#timestamp ⇒ Object
Returns the value of attribute timestamp.
-
#title ⇒ Object
The title of the flag link.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlagLinkPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FlagLinkPost
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagLinkPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagLinkPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'integration_key') self.integration_key = attributes[:'integration_key'] end if attributes.key?(:'timestamp') self. = attributes[:'timestamp'] end if attributes.key?(:'deep_link') self.deep_link = attributes[:'deep_link'] end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'metadata') if (value = attributes[:'metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#deep_link ⇒ Object
The URL for the external resource you are linking the flag to
27 28 29 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 27 def deep_link @deep_link end |
#description ⇒ Object
The description of the flag link
33 34 35 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 33 def description @description end |
#integration_key ⇒ Object
The integration key for an integration whose manifest.json includes the flagLink capability, if this is a flag link for an existing integration. Do not include for URL flag links.
22 23 24 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 22 def integration_key @integration_key end |
#key ⇒ Object
The flag link key
19 20 21 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 19 def key @key end |
#metadata ⇒ Object
The metadata required by this integration in order to create a flag link, if this is a flag link for an existing integration. Defined in the integration's manifest.json file under flagLink.
36 37 38 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 36 def @metadata end |
#timestamp ⇒ Object
Returns the value of attribute timestamp.
24 25 26 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 24 def @timestamp end |
#title ⇒ Object
The title of the flag link
30 31 32 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 30 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 39 def self.attribute_map { :'key' => :'key', :'integration_key' => :'integrationKey', :'timestamp' => :'timestamp', :'deep_link' => :'deepLink', :'title' => :'title', :'description' => :'description', :'metadata' => :'metadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 171 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 62 def self.openapi_types { :'key' => :'String', :'integration_key' => :'String', :'timestamp' => :'Integer', :'deep_link' => :'String', :'title' => :'String', :'description' => :'String', :'metadata' => :'Hash<String, String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
144 145 146 147 148 149 150 151 152 153 154 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 144 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && integration_key == o.integration_key && == o. && deep_link == o.deep_link && title == o.title && description == o.description && == o. end |
#eql?(o) ⇒ Boolean
158 159 160 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 158 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
164 165 166 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 164 def hash [key, integration_key, , deep_link, title, description, ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
129 130 131 132 133 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 129 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
193 194 195 196 197 198 199 200 201 202 203 204 205 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 193 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
137 138 139 140 |
# File 'lib/launchdarkly_api/models/flag_link_post.rb', line 137 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |