Class: LaunchDarklyApi::FlagLinkRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::FlagLinkRep
- Defined in:
- lib/launchdarkly_api/models/flag_link_rep.rb
Instance Attribute Summary collapse
-
#_created_at ⇒ Object
Returns the value of attribute _created_at.
-
#_deep_link ⇒ Object
The URL for the external resource the flag is linked to.
-
#_id ⇒ Object
The ID of this flag link.
-
#_integration_key ⇒ Object
The integration key for an integration whose
manifest.jsonincludes theflagLinkcapability, if this is a flag link for an existing integration. -
#_key ⇒ Object
The flag link key.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_member ⇒ Object
Returns the value of attribute _member.
-
#_metadata ⇒ Object
The metadata required by this integration in order to create a flag link, if this is a flag link for an existing integration.
-
#_timestamp ⇒ Object
Returns the value of attribute _timestamp.
-
#description ⇒ Object
The description of the flag link.
-
#title ⇒ Object
The title of the flag link.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ FlagLinkRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ FlagLinkRep
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::FlagLinkRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::FlagLinkRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'_key') self._key = attributes[:'_key'] end if attributes.key?(:'_integration_key') self._integration_key = attributes[:'_integration_key'] end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_deep_link') self._deep_link = attributes[:'_deep_link'] else self._deep_link = nil end if attributes.key?(:'_timestamp') self. = attributes[:'_timestamp'] else self. = nil end if attributes.key?(:'title') self.title = attributes[:'title'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'_metadata') if (value = attributes[:'_metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'_created_at') self._created_at = attributes[:'_created_at'] else self._created_at = nil end if attributes.key?(:'_member') self._member = attributes[:'_member'] end end |
Instance Attribute Details
#_created_at ⇒ Object
Returns the value of attribute _created_at.
44 45 46 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 44 def _created_at @_created_at end |
#_deep_link ⇒ Object
The URL for the external resource the flag is linked to
31 32 33 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 31 def _deep_link @_deep_link end |
#_id ⇒ Object
The ID of this flag link
28 29 30 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 28 def _id @_id end |
#_integration_key ⇒ Object
The integration key for an integration whose manifest.json includes the flagLink capability, if this is a flag link for an existing integration
25 26 27 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 25 def _integration_key @_integration_key end |
#_key ⇒ Object
The flag link key
22 23 24 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 22 def _key @_key end |
#_links ⇒ Object
The location and content type of related resources
19 20 21 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 19 def _links @_links end |
#_member ⇒ Object
Returns the value of attribute _member.
46 47 48 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 46 def _member @_member end |
#_metadata ⇒ Object
The metadata required by this integration in order to create a flag link, if this is a flag link for an existing integration. Defined in the integration's manifest.json file under flagLink.
42 43 44 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 42 def @_metadata end |
#_timestamp ⇒ Object
Returns the value of attribute _timestamp.
33 34 35 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 33 def @_timestamp end |
#description ⇒ Object
The description of the flag link
39 40 41 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 39 def description @description end |
#title ⇒ Object
The title of the flag link
36 37 38 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 36 def title @title end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
66 67 68 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 66 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 71 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 49 def self.attribute_map { :'_links' => :'_links', :'_key' => :'_key', :'_integration_key' => :'_integrationKey', :'_id' => :'_id', :'_deep_link' => :'_deepLink', :'_timestamp' => :'_timestamp', :'title' => :'title', :'description' => :'description', :'_metadata' => :'_metadata', :'_created_at' => :'_createdAt', :'_member' => :'_member' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 296 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 76 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_key' => :'String', :'_integration_key' => :'String', :'_id' => :'String', :'_deep_link' => :'String', :'_timestamp' => :'TimestampRep', :'title' => :'String', :'description' => :'String', :'_metadata' => :'Hash<String, String>', :'_created_at' => :'Integer', :'_member' => :'FlagLinkMember' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 265 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _key == o._key && _integration_key == o._integration_key && _id == o._id && _deep_link == o._deep_link && == o. && title == o.title && description == o.description && == o. && _created_at == o._created_at && _member == o._member end |
#eql?(o) ⇒ Boolean
283 284 285 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 283 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
289 290 291 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 289 def hash [_links, _key, _integration_key, _id, _deep_link, , title, description, , _created_at, _member].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 175 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_deep_link.nil? invalid_properties.push('invalid value for "_deep_link", _deep_link cannot be nil.') end if @_timestamp.nil? invalid_properties.push('invalid value for "_timestamp", _timestamp cannot be nil.') end if @_created_at.nil? invalid_properties.push('invalid value for "_created_at", _created_at cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
318 319 320 321 322 323 324 325 326 327 328 329 330 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 318 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
203 204 205 206 207 208 209 210 211 |
# File 'lib/launchdarkly_api/models/flag_link_rep.rb', line 203 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_links.nil? return false if @_id.nil? return false if @_deep_link.nil? return false if @_timestamp.nil? return false if @_created_at.nil? true end |