Class: LaunchDarklyApi::InsightGroupCollection
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::InsightGroupCollection
- Defined in:
- lib/launchdarkly_api/models/insight_group_collection.rb
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#items ⇒ Object
A list of insight groups.
-
#metadata ⇒ Object
Returns the value of attribute metadata.
-
#score_metadata ⇒ Object
Returns the value of attribute score_metadata.
-
#total_count ⇒ Object
The total number of insight groups.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ InsightGroupCollection
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ InsightGroupCollection
Initializes the object
71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 71 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightGroupCollection` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightGroupCollection`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'total_count') self.total_count = attributes[:'total_count'] else self.total_count = nil end if attributes.key?(:'items') if (value = attributes[:'items']).is_a?(Array) self.items = value end else self.items = nil end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'metadata') self. = attributes[:'metadata'] end if attributes.key?(:'score_metadata') self. = attributes[:'score_metadata'] end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
25 26 27 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 25 def _links @_links end |
#items ⇒ Object
A list of insight groups
22 23 24 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 22 def items @items end |
#metadata ⇒ Object
Returns the value of attribute metadata.
27 28 29 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 27 def @metadata end |
#score_metadata ⇒ Object
Returns the value of attribute score_metadata.
29 30 31 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 29 def @score_metadata end |
#total_count ⇒ Object
The total number of insight groups
19 20 21 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 19 def total_count @total_count end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
43 44 45 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 43 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
48 49 50 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 48 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
32 33 34 35 36 37 38 39 40 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 32 def self.attribute_map { :'total_count' => :'totalCount', :'items' => :'items', :'_links' => :'_links', :'metadata' => :'metadata', :'score_metadata' => :'scoreMetadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 186 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
64 65 66 67 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 64 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
53 54 55 56 57 58 59 60 61 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 53 def self.openapi_types { :'total_count' => :'Integer', :'items' => :'Array<InsightGroup>', :'_links' => :'Hash<String, Link>', :'metadata' => :'InsightGroupCollectionMetadata', :'score_metadata' => :'InsightGroupCollectionScoreMetadata' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
161 162 163 164 165 166 167 168 169 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 161 def ==(o) return true if self.equal?(o) self.class == o.class && total_count == o.total_count && items == o.items && _links == o._links && == o. && == o. end |
#eql?(o) ⇒ Boolean
173 174 175 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 173 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
179 180 181 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 179 def hash [total_count, items, _links, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
116 117 118 119 120 121 122 123 124 125 126 127 128 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 116 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @total_count.nil? invalid_properties.push('invalid value for "total_count", total_count cannot be nil.') end if @items.nil? invalid_properties.push('invalid value for "items", items cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
208 209 210 211 212 213 214 215 216 217 218 219 220 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 208 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
132 133 134 135 136 137 |
# File 'lib/launchdarkly_api/models/insight_group_collection.rb', line 132 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @total_count.nil? return false if @items.nil? true end |