Class: LaunchDarklyApi::InsightGroupScores

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/insight_group_scores.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ InsightGroupScores

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 92

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::InsightGroupScores` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::InsightGroupScores`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'overall')
    self.overall = attributes[:'overall']
  else
    self.overall = nil
  end

  if attributes.key?(:'deployment_frequency')
    self.deployment_frequency = attributes[:'deployment_frequency']
  else
    self.deployment_frequency = nil
  end

  if attributes.key?(:'deployment_failure_rate')
    self.deployment_failure_rate = attributes[:'deployment_failure_rate']
  else
    self.deployment_failure_rate = nil
  end

  if attributes.key?(:'lead_time')
    self.lead_time = attributes[:'lead_time']
  else
    self.lead_time = nil
  end

  if attributes.key?(:'impact_size')
    self.impact_size = attributes[:'impact_size']
  else
    self.impact_size = nil
  end

  if attributes.key?(:'experimentation_coverage')
    self.experimentation_coverage = attributes[:'experimentation_coverage']
  else
    self.experimentation_coverage = nil
  end

  if attributes.key?(:'flag_health')
    self.flag_health = attributes[:'flag_health']
  else
    self.flag_health = nil
  end

  if attributes.key?(:'velocity')
    self.velocity = attributes[:'velocity']
  else
    self.velocity = nil
  end

  if attributes.key?(:'risk')
    self.risk = attributes[:'risk']
  else
    self.risk = nil
  end

  if attributes.key?(:'efficiency')
    self.efficiency = attributes[:'efficiency']
  else
    self.efficiency = nil
  end

  if attributes.key?(:'creation_ratio')
    self.creation_ratio = attributes[:'creation_ratio']
  end
end

Instance Attribute Details

#creation_ratioObject

Returns the value of attribute creation_ratio.



38
39
40
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 38

def creation_ratio
  @creation_ratio
end

#deployment_failure_rateObject

Returns the value of attribute deployment_failure_rate.



22
23
24
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 22

def deployment_failure_rate
  @deployment_failure_rate
end

#deployment_frequencyObject

Returns the value of attribute deployment_frequency.



20
21
22
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 20

def deployment_frequency
  @deployment_frequency
end

#efficiencyObject

Returns the value of attribute efficiency.



36
37
38
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 36

def efficiency
  @efficiency
end

#experimentation_coverageObject

Returns the value of attribute experimentation_coverage.



28
29
30
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 28

def experimentation_coverage
  @experimentation_coverage
end

#flag_healthObject

Returns the value of attribute flag_health.



30
31
32
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 30

def flag_health
  @flag_health
end

#impact_sizeObject

Returns the value of attribute impact_size.



26
27
28
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 26

def impact_size
  @impact_size
end

#lead_timeObject

Returns the value of attribute lead_time.



24
25
26
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 24

def lead_time
  @lead_time
end

#overallObject

Returns the value of attribute overall.



18
19
20
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 18

def overall
  @overall
end

#riskObject

Returns the value of attribute risk.



34
35
36
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 34

def risk
  @risk
end

#velocityObject

Returns the value of attribute velocity.



32
33
34
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 32

def velocity
  @velocity
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
421
422
423
424
425
426
427
428
429
430
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 393

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



58
59
60
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 58

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



63
64
65
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 63

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



41
42
43
44
45
46
47
48
49
50
51
52
53
54
55
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 41

def self.attribute_map
  {
    :'overall' => :'overall',
    :'deployment_frequency' => :'deploymentFrequency',
    :'deployment_failure_rate' => :'deploymentFailureRate',
    :'lead_time' => :'leadTime',
    :'impact_size' => :'impactSize',
    :'experimentation_coverage' => :'experimentationCoverage',
    :'flag_health' => :'flagHealth',
    :'velocity' => :'velocity',
    :'risk' => :'risk',
    :'efficiency' => :'efficiency',
    :'creation_ratio' => :'creationRatio'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 369

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



85
86
87
88
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 85

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



68
69
70
71
72
73
74
75
76
77
78
79
80
81
82
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 68

def self.openapi_types
  {
    :'overall' => :'InsightsMetricScore',
    :'deployment_frequency' => :'InsightsMetricScore',
    :'deployment_failure_rate' => :'InsightsMetricScore',
    :'lead_time' => :'InsightsMetricScore',
    :'impact_size' => :'InsightsMetricScore',
    :'experimentation_coverage' => :'InsightsMetricScore',
    :'flag_health' => :'InsightsMetricScore',
    :'velocity' => :'InsightsMetricScore',
    :'risk' => :'InsightsMetricScore',
    :'efficiency' => :'InsightsMetricScore',
    :'creation_ratio' => :'InsightsMetricScore'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



338
339
340
341
342
343
344
345
346
347
348
349
350
351
352
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 338

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      overall == o.overall &&
      deployment_frequency == o.deployment_frequency &&
      deployment_failure_rate == o.deployment_failure_rate &&
      lead_time == o.lead_time &&
      impact_size == o.impact_size &&
      experimentation_coverage == o.experimentation_coverage &&
      flag_health == o.flag_health &&
      velocity == o.velocity &&
      risk == o.risk &&
      efficiency == o.efficiency &&
      creation_ratio == o.creation_ratio
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



464
465
466
467
468
469
470
471
472
473
474
475
476
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 464

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


356
357
358
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 356

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



362
363
364
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 362

def hash
  [overall, deployment_frequency, deployment_failure_rate, lead_time, impact_size, experimentation_coverage, flag_health, velocity, risk, efficiency, creation_ratio].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 173

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @overall.nil?
    invalid_properties.push('invalid value for "overall", overall cannot be nil.')
  end

  if @deployment_frequency.nil?
    invalid_properties.push('invalid value for "deployment_frequency", deployment_frequency cannot be nil.')
  end

  if @deployment_failure_rate.nil?
    invalid_properties.push('invalid value for "deployment_failure_rate", deployment_failure_rate cannot be nil.')
  end

  if @lead_time.nil?
    invalid_properties.push('invalid value for "lead_time", lead_time cannot be nil.')
  end

  if @impact_size.nil?
    invalid_properties.push('invalid value for "impact_size", impact_size cannot be nil.')
  end

  if @experimentation_coverage.nil?
    invalid_properties.push('invalid value for "experimentation_coverage", experimentation_coverage cannot be nil.')
  end

  if @flag_health.nil?
    invalid_properties.push('invalid value for "flag_health", flag_health cannot be nil.')
  end

  if @velocity.nil?
    invalid_properties.push('invalid value for "velocity", velocity cannot be nil.')
  end

  if @risk.nil?
    invalid_properties.push('invalid value for "risk", risk cannot be nil.')
  end

  if @efficiency.nil?
    invalid_properties.push('invalid value for "efficiency", efficiency cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



440
441
442
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 440

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



446
447
448
449
450
451
452
453
454
455
456
457
458
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 446

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



434
435
436
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 434

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/launchdarkly_api/models/insight_group_scores.rb', line 221

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @overall.nil?
  return false if @deployment_frequency.nil?
  return false if @deployment_failure_rate.nil?
  return false if @lead_time.nil?
  return false if @impact_size.nil?
  return false if @experimentation_coverage.nil?
  return false if @flag_health.nil?
  return false if @velocity.nil?
  return false if @risk.nil?
  return false if @efficiency.nil?
  true
end