Class: LaunchDarklyApi::Integration
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::Integration
- Defined in:
- lib/launchdarkly_api/models/integration.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_id ⇒ Object
The ID for this integration audit log subscription.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_status ⇒ Object
Returns the value of attribute _status.
-
#api_key ⇒ Object
Datadog API key.
-
#config ⇒ Object
Details on configuration for an integration of this type.
-
#kind ⇒ Object
The type of integration.
-
#name ⇒ Object
A human-friendly name for the integration.
-
#on ⇒ Object
Whether the integration is currently active.
-
#statements ⇒ Object
Represents a Custom role policy, defining a resource kinds filter the integration audit log subscription responds to.
-
#tags ⇒ Object
An array of tags for this integration.
-
#url ⇒ Object
Slack webhook receiver URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Integration
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Integration
Initializes the object
106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 |
# File 'lib/launchdarkly_api/models/integration.rb', line 106 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Integration` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Integration`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'config') if (value = attributes[:'config']).is_a?(Hash) self.config = value end end if attributes.key?(:'statements') if (value = attributes[:'statements']).is_a?(Array) self.statements = value end end if attributes.key?(:'on') self.on = attributes[:'on'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_status') self._status = attributes[:'_status'] end if attributes.key?(:'url') self.url = attributes[:'url'] end if attributes.key?(:'api_key') self.api_key = attributes[:'api_key'] end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
42 43 44 |
# File 'lib/launchdarkly_api/models/integration.rb', line 42 def _access @_access end |
#_id ⇒ Object
The ID for this integration audit log subscription
22 23 24 |
# File 'lib/launchdarkly_api/models/integration.rb', line 22 def _id @_id end |
#_links ⇒ Object
The location and content type of related resources
19 20 21 |
# File 'lib/launchdarkly_api/models/integration.rb', line 19 def _links @_links end |
#_status ⇒ Object
Returns the value of attribute _status.
44 45 46 |
# File 'lib/launchdarkly_api/models/integration.rb', line 44 def _status @_status end |
#api_key ⇒ Object
Datadog API key. Only used for legacy Datadog webhook integrations.
50 51 52 |
# File 'lib/launchdarkly_api/models/integration.rb', line 50 def api_key @api_key end |
#config ⇒ Object
Details on configuration for an integration of this type. Refer to the formVariables field in the corresponding manifest.json for a full list of fields for each integration.
31 32 33 |
# File 'lib/launchdarkly_api/models/integration.rb', line 31 def config @config end |
#kind ⇒ Object
The type of integration
25 26 27 |
# File 'lib/launchdarkly_api/models/integration.rb', line 25 def kind @kind end |
#name ⇒ Object
A human-friendly name for the integration
28 29 30 |
# File 'lib/launchdarkly_api/models/integration.rb', line 28 def name @name end |
#on ⇒ Object
Whether the integration is currently active
37 38 39 |
# File 'lib/launchdarkly_api/models/integration.rb', line 37 def on @on end |
#statements ⇒ Object
Represents a Custom role policy, defining a resource kinds filter the integration audit log subscription responds to.
34 35 36 |
# File 'lib/launchdarkly_api/models/integration.rb', line 34 def statements @statements end |
#tags ⇒ Object
An array of tags for this integration
40 41 42 |
# File 'lib/launchdarkly_api/models/integration.rb', line 40 def @tags end |
#url ⇒ Object
Slack webhook receiver URL. Only used for legacy Slack webhook integrations.
47 48 49 |
# File 'lib/launchdarkly_api/models/integration.rb', line 47 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/integration.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/integration.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/integration.rb', line 53 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'kind' => :'kind', :'name' => :'name', :'config' => :'config', :'statements' => :'statements', :'on' => :'on', :'tags' => :'tags', :'_access' => :'_access', :'_status' => :'_status', :'url' => :'url', :'api_key' => :'apiKey' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 |
# File 'lib/launchdarkly_api/models/integration.rb', line 226 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
99 100 101 102 |
# File 'lib/launchdarkly_api/models/integration.rb', line 99 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 |
# File 'lib/launchdarkly_api/models/integration.rb', line 81 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_id' => :'String', :'kind' => :'String', :'name' => :'String', :'config' => :'Hash<String, Object>', :'statements' => :'Array<Statement>', :'on' => :'Boolean', :'tags' => :'Array<String>', :'_access' => :'Access', :'_status' => :'IntegrationSubscriptionStatusRep', :'url' => :'String', :'api_key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 |
# File 'lib/launchdarkly_api/models/integration.rb', line 194 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && kind == o.kind && name == o.name && config == o.config && statements == o.statements && on == o.on && == o. && _access == o._access && _status == o._status && url == o.url && api_key == o.api_key end |
#eql?(o) ⇒ Boolean
213 214 215 |
# File 'lib/launchdarkly_api/models/integration.rb', line 213 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
219 220 221 |
# File 'lib/launchdarkly_api/models/integration.rb', line 219 def hash [_links, _id, kind, name, config, statements, on, , _access, _status, url, api_key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
179 180 181 182 183 |
# File 'lib/launchdarkly_api/models/integration.rb', line 179 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
248 249 250 251 252 253 254 255 256 257 258 259 260 |
# File 'lib/launchdarkly_api/models/integration.rb', line 248 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 |
# File 'lib/launchdarkly_api/models/integration.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |