Class: LaunchDarklyApi::IntegrationConfigurationsRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::IntegrationConfigurationsRep
- Defined in:
- lib/launchdarkly_api/models/integration_configurations_rep.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_created_at ⇒ Object
Returns the value of attribute _created_at.
-
#_id ⇒ Object
The unique identifier for this integration configuration.
-
#_integration_key ⇒ Object
The type of integration.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_maintainer_id ⇒ Object
The ID of the member who maintains this integration configuration.
-
#capability_config ⇒ Object
Returns the value of attribute capability_config.
-
#config_values ⇒ Object
Details on configuration for an integration of this type.
-
#enabled ⇒ Object
Whether the integration is currently active.
-
#name ⇒ Object
A human-friendly name for the integration.
-
#redshift_iam_permissions_policy ⇒ Object
IAM permissions policy JSON for the customer's Redshift IAM role.
-
#redshift_iam_trust_policy ⇒ Object
IAM trust policy JSON for the customer's Redshift IAM role.
-
#redshift_setup_scripts ⇒ Object
SQL setup scripts (4 parts) for Redshift Native Experimentation setup.
-
#snowflake_setup_script ⇒ Object
Consolidated SQL script for Snowflake Warehouse Native Experimentation setup.
-
#tags ⇒ Object
An array of tags for this integration.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ IntegrationConfigurationsRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ IntegrationConfigurationsRep
Initializes the object
120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 120 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::IntegrationConfigurationsRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::IntegrationConfigurationsRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'_created_at') self._created_at = attributes[:'_created_at'] end if attributes.key?(:'_integration_key') self._integration_key = attributes[:'_integration_key'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'config_values') if (value = attributes[:'config_values']).is_a?(Hash) self.config_values = value end end if attributes.key?(:'capability_config') self.capability_config = attributes[:'capability_config'] end if attributes.key?(:'snowflake_setup_script') self.snowflake_setup_script = attributes[:'snowflake_setup_script'] end if attributes.key?(:'redshift_setup_scripts') if (value = attributes[:'redshift_setup_scripts']).is_a?(Array) self.redshift_setup_scripts = value end end if attributes.key?(:'redshift_iam_permissions_policy') self. = attributes[:'redshift_iam_permissions_policy'] end if attributes.key?(:'redshift_iam_trust_policy') self.redshift_iam_trust_policy = attributes[:'redshift_iam_trust_policy'] end if attributes.key?(:'_maintainer_id') self._maintainer_id = attributes[:'_maintainer_id'] end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
38 39 40 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 38 def _access @_access end |
#_created_at ⇒ Object
Returns the value of attribute _created_at.
27 28 29 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 27 def _created_at @_created_at end |
#_id ⇒ Object
The unique identifier for this integration configuration
22 23 24 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 22 def _id @_id end |
#_integration_key ⇒ Object
The type of integration
30 31 32 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 30 def _integration_key @_integration_key end |
#_links ⇒ Object
The location and content type of related resources
19 20 21 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 19 def _links @_links end |
#_maintainer_id ⇒ Object
The ID of the member who maintains this integration configuration. Defaults to the member who created it.
58 59 60 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 58 def _maintainer_id @_maintainer_id end |
#capability_config ⇒ Object
Returns the value of attribute capability_config.
43 44 45 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 43 def capability_config @capability_config end |
#config_values ⇒ Object
Details on configuration for an integration of this type. Refer to the formVariables field in the corresponding manifest.json for a full list of fields for each integration.
41 42 43 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 41 def config_values @config_values end |
#enabled ⇒ Object
Whether the integration is currently active
36 37 38 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 36 def enabled @enabled end |
#name ⇒ Object
A human-friendly name for the integration
25 26 27 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 25 def name @name end |
#redshift_iam_permissions_policy ⇒ Object
IAM permissions policy JSON for the customer's Redshift IAM role. Present only for setup endpoint responses.
52 53 54 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 52 def @redshift_iam_permissions_policy end |
#redshift_iam_trust_policy ⇒ Object
IAM trust policy JSON for the customer's Redshift IAM role. Present only for setup endpoint responses.
55 56 57 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 55 def redshift_iam_trust_policy @redshift_iam_trust_policy end |
#redshift_setup_scripts ⇒ Object
SQL setup scripts (4 parts) for Redshift Native Experimentation setup. Present only for setup endpoint responses.
49 50 51 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 49 def redshift_setup_scripts @redshift_setup_scripts end |
#snowflake_setup_script ⇒ Object
Consolidated SQL script for Snowflake Warehouse Native Experimentation setup. Present only for setup endpoint responses.
46 47 48 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 46 def snowflake_setup_script @snowflake_setup_script end |
#tags ⇒ Object
An array of tags for this integration
33 34 35 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 33 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
82 83 84 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 82 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
87 88 89 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 87 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 61 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'name' => :'name', :'_created_at' => :'_createdAt', :'_integration_key' => :'_integrationKey', :'tags' => :'tags', :'enabled' => :'enabled', :'_access' => :'_access', :'config_values' => :'configValues', :'capability_config' => :'capabilityConfig', :'snowflake_setup_script' => :'snowflakeSetupScript', :'redshift_setup_scripts' => :'redshiftSetupScripts', :'redshift_iam_permissions_policy' => :'redshiftIAMPermissionsPolicy', :'redshift_iam_trust_policy' => :'redshiftIAMTrustPolicy', :'_maintainer_id' => :'_maintainerId' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 306 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
113 114 115 116 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 113 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 92 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_id' => :'String', :'name' => :'String', :'_created_at' => :'Integer', :'_integration_key' => :'String', :'tags' => :'Array<String>', :'enabled' => :'Boolean', :'_access' => :'Access', :'config_values' => :'Hash<String, Object>', :'capability_config' => :'CapabilityConfigRep', :'snowflake_setup_script' => :'String', :'redshift_setup_scripts' => :'Array<String>', :'redshift_iam_permissions_policy' => :'String', :'redshift_iam_trust_policy' => :'String', :'_maintainer_id' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 271 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && name == o.name && _created_at == o._created_at && _integration_key == o._integration_key && == o. && enabled == o.enabled && _access == o._access && config_values == o.config_values && capability_config == o.capability_config && snowflake_setup_script == o.snowflake_setup_script && redshift_setup_scripts == o.redshift_setup_scripts && == o. && redshift_iam_trust_policy == o.redshift_iam_trust_policy && _maintainer_id == o._maintainer_id end |
#eql?(o) ⇒ Boolean
293 294 295 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 293 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
299 300 301 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 299 def hash [_links, _id, name, _created_at, _integration_key, , enabled, _access, config_values, capability_config, snowflake_setup_script, redshift_setup_scripts, , redshift_iam_trust_policy, _maintainer_id].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 211 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
328 329 330 331 332 333 334 335 336 337 338 339 340 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 328 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
231 232 233 234 235 236 237 |
# File 'lib/launchdarkly_api/models/integration_configurations_rep.rb', line 231 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_links.nil? return false if @_id.nil? return false if @name.nil? true end |