Class: LaunchDarklyApi::IntegrationsBetaApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::IntegrationsBetaApi
- Defined in:
- lib/launchdarkly_api/api/integrations_beta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_big_segment_store_integration(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ BigSegmentStoreIntegration
Create big segment store integration Create a persistent store integration.
-
#create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Create big segment store integration Create a persistent store integration.
-
#create_flag_import_configuration(project_key, integration_key, flag_import_configuration_post, opts = {}) ⇒ FlagImportIntegration
Create a flag import configuration Create a new flag import configuration.
-
#create_flag_import_configuration_with_http_info(project_key, integration_key, flag_import_configuration_post, opts = {}) ⇒ Array<(FlagImportIntegration, Integer, Hash)>
Create a flag import configuration Create a new flag import configuration.
-
#delete_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ nil
Delete big segment store integration Delete a persistent store integration.
-
#delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete big segment store integration Delete a persistent store integration.
-
#delete_flag_import_configuration(project_key, integration_key, integration_id, opts = {}) ⇒ nil
Delete a flag import configuration Delete a flag import configuration by ID.
-
#delete_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a flag import configuration Delete a flag import configuration by ID.
-
#get_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ BigSegmentStoreIntegration
Get big segment store integration by ID Get a big segment store integration by ID.
-
#get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Get big segment store integration by ID Get a big segment store integration by ID.
-
#get_big_segment_store_integrations(opts = {}) ⇒ BigSegmentStoreIntegrationCollection
List all big segment store integrations List all big segment store integrations.
-
#get_big_segment_store_integrations_with_http_info(opts = {}) ⇒ Array<(BigSegmentStoreIntegrationCollection, Integer, Hash)>
List all big segment store integrations List all big segment store integrations.
-
#get_flag_import_configuration(project_key, integration_key, integration_id, opts = {}) ⇒ FlagImportIntegration
Get a single flag import configuration Get a single flag import configuration by ID.
-
#get_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts = {}) ⇒ Array<(FlagImportIntegration, Integer, Hash)>
Get a single flag import configuration Get a single flag import configuration by ID.
-
#get_flag_import_configurations(opts = {}) ⇒ FlagImportIntegrationCollection
List all flag import configurations List all flag import configurations.
-
#get_flag_import_configurations_with_http_info(opts = {}) ⇒ Array<(FlagImportIntegrationCollection, Integer, Hash)>
List all flag import configurations List all flag import configurations.
-
#initialize(api_client = ApiClient.default) ⇒ IntegrationsBetaApi
constructor
A new instance of IntegrationsBetaApi.
-
#patch_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ BigSegmentStoreIntegration
Update big segment store integration Update a big segment store integration.
-
#patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Update big segment store integration Update a big segment store integration.
-
#patch_flag_import_configuration(project_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ FlagImportIntegration
Update a flag import configuration Updating a flag import configuration uses a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes.
-
#patch_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ Array<(FlagImportIntegration, Integer, Hash)>
Update a flag import configuration Updating a flag import configuration uses a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes.
-
#trigger_flag_import_job(project_key, integration_key, integration_id, opts = {}) ⇒ Object
Trigger a single flag import run Trigger a single flag import run for an existing flag import configuration.
-
#trigger_flag_import_job_with_http_info(project_key, integration_key, integration_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Trigger a single flag import run Trigger a single flag import run for an existing flag import configuration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ IntegrationsBetaApi
Returns a new instance of IntegrationsBetaApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_big_segment_store_integration(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ BigSegmentStoreIntegration
Create big segment store integration
Create a persistent store integration. If you are using server-side SDKs, segments synced from external tools and larger list-based segments require a persistent store within your infrastructure. LaunchDarkly keeps the persistent store up to date and consults it during flag evaluation. You can use either Redis or DynamoDB as your persistent store. When you create a persistent store integration, the fields in the `config` object in the request vary depending on which persistent store you use. If you are using Redis to create your persistent store integration, you will need to know: * Your Redis host * Your Redis port * Your Redis username * Your Redis password * Whether or not LaunchDarkly should connect using TLS If you are using DynamoDB to create your persistent store integration, you will need to know: * Your DynamoDB table name. The table must have the following schema: * Partition key: `namespace` (string) * Sort key: `key` (string) * Your DynamoDB Amazon Web Services (AWS) region. * Your AWS role Amazon Resource Name (ARN). This is the role that LaunchDarkly will assume to manage your DynamoDB table. * The External ID you specified when creating your Amazon Resource Name (ARN). To learn more, read [Segment configuration](https://docs.launchdarkly.com/home/flags/segment-config).
30 31 32 33 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 30 def create_big_segment_store_integration(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) data, _status_code, _headers = create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts) data end |
#create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Create big segment store integration
Create a persistent store integration. If you are using server-side SDKs, segments synced from external tools and larger list-based segments require a persistent store within your infrastructure. LaunchDarkly keeps the persistent store up to date and consults it during flag evaluation. You can use either Redis or DynamoDB as your persistent store. When you create a persistent store integration, the fields in the `config` object in the request vary depending on which persistent store you use. If you are using Redis to create your persistent store integration, you will need to know: * Your Redis host * Your Redis port * Your Redis username * Your Redis password * Whether or not LaunchDarkly should connect using TLS If you are using DynamoDB to create your persistent store integration, you will need to know: * Your DynamoDB table name. The table must have the following schema: * Partition key: `namespace` (string) * Sort key: `key` (string) * Your DynamoDB Amazon Web Services (AWS) region. * Your AWS role Amazon Resource Name (ARN). This is the role that LaunchDarkly will assume to manage your DynamoDB table. * The External ID you specified when creating your Amazon Resource Name (ARN). To learn more, read [Segment configuration](https://docs.launchdarkly.com/home/flags/segment-config).
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 43 def create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.create_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.create_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling IntegrationsBetaApi.create_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.create_big_segment_store_integration" end # verify the required parameter 'integration_delivery_configuration_post' is set if @api_client.config.client_side_validation && integration_delivery_configuration_post.nil? fail ArgumentError, "Missing the required parameter 'integration_delivery_configuration_post' when calling IntegrationsBetaApi.create_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(integration_delivery_configuration_post) # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.create_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#create_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#create_flag_import_configuration(project_key, integration_key, flag_import_configuration_post, opts = {}) ⇒ FlagImportIntegration
Create a flag import configuration Create a new flag import configuration. The ‘integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`. The `config` object in the request body schema is described by the global integration settings, as specified by the formVariables in the manifest.json for this integration. It varies slightly based on the `integrationKey`.
115 116 117 118 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 115 def create_flag_import_configuration(project_key, integration_key, flag_import_configuration_post, opts = {}) data, _status_code, _headers = create_flag_import_configuration_with_http_info(project_key, integration_key, flag_import_configuration_post, opts) data end |
#create_flag_import_configuration_with_http_info(project_key, integration_key, flag_import_configuration_post, opts = {}) ⇒ Array<(FlagImportIntegration, Integer, Hash)>
Create a flag import configuration Create a new flag import configuration. The `integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`. The `config` object in the request body schema is described by the global integration settings, as specified by the <code>formVariables</code> in the <code>manifest.json</code> for this integration. It varies slightly based on the `integrationKey`.
127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 127 def create_flag_import_configuration_with_http_info(project_key, integration_key, flag_import_configuration_post, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.create_flag_import_configuration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.create_flag_import_configuration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.create_flag_import_configuration" end # verify the required parameter 'flag_import_configuration_post' is set if @api_client.config.client_side_validation && flag_import_configuration_post.nil? fail ArgumentError, "Missing the required parameter 'flag_import_configuration_post' when calling IntegrationsBetaApi.create_flag_import_configuration" end # resource path local_var_path = '/api/v2/integration-capabilities/flag-import/{projectKey}/{integrationKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(flag_import_configuration_post) # return_type return_type = opts[:debug_return_type] || 'FlagImportIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.create_flag_import_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#create_flag_import_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ nil
Delete big segment store integration Delete a persistent store integration. Each integration uses either Redis or DynamoDB.
196 197 198 199 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 196 def delete_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts) nil end |
#delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete big segment store integration Delete a persistent store integration. Each integration uses either Redis or DynamoDB.
209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 209 def delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.delete_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.delete_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling IntegrationsBetaApi.delete_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.delete_big_segment_store_integration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.delete_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.delete_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#delete_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_flag_import_configuration(project_key, integration_key, integration_id, opts = {}) ⇒ nil
Delete a flag import configuration Delete a flag import configuration by ID. The ‘integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`.
276 277 278 279 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 276 def delete_flag_import_configuration(project_key, integration_key, integration_id, opts = {}) delete_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts) nil end |
#delete_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete a flag import configuration Delete a flag import configuration by ID. The `integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`.
288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 288 def delete_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.delete_flag_import_configuration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.delete_flag_import_configuration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.delete_flag_import_configuration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.delete_flag_import_configuration" end # resource path local_var_path = '/api/v2/integration-capabilities/flag-import/{projectKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.delete_flag_import_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#delete_flag_import_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ BigSegmentStoreIntegration
Get big segment store integration by ID Get a big segment store integration by ID.
352 353 354 355 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 352 def get_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) data, _status_code, _headers = get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts) data end |
#get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Get big segment store integration by ID Get a big segment store integration by ID.
365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 365 def get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.get_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.get_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling IntegrationsBetaApi.get_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.get_big_segment_store_integration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.get_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.get_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#get_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_big_segment_store_integrations(opts = {}) ⇒ BigSegmentStoreIntegrationCollection
List all big segment store integrations List all big segment store integrations.
429 430 431 432 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 429 def get_big_segment_store_integrations(opts = {}) data, _status_code, _headers = get_big_segment_store_integrations_with_http_info(opts) data end |
#get_big_segment_store_integrations_with_http_info(opts = {}) ⇒ Array<(BigSegmentStoreIntegrationCollection, Integer, Hash)>
List all big segment store integrations List all big segment store integrations.
438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 453 454 455 456 457 458 459 460 461 462 463 464 465 466 467 468 469 470 471 472 473 474 475 476 477 478 479 480 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 438 def get_big_segment_store_integrations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.get_big_segment_store_integrations ...' end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegrationCollection' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.get_big_segment_store_integrations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#get_big_segment_store_integrations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_flag_import_configuration(project_key, integration_key, integration_id, opts = {}) ⇒ FlagImportIntegration
Get a single flag import configuration Get a single flag import configuration by ID. The ‘integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`.
489 490 491 492 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 489 def get_flag_import_configuration(project_key, integration_key, integration_id, opts = {}) data, _status_code, _headers = get_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts) data end |
#get_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts = {}) ⇒ Array<(FlagImportIntegration, Integer, Hash)>
Get a single flag import configuration Get a single flag import configuration by ID. The `integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`.
501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 532 533 534 535 536 537 538 539 540 541 542 543 544 545 546 547 548 549 550 551 552 553 554 555 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 501 def get_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.get_flag_import_configuration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.get_flag_import_configuration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.get_flag_import_configuration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.get_flag_import_configuration" end # resource path local_var_path = '/api/v2/integration-capabilities/flag-import/{projectKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FlagImportIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.get_flag_import_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#get_flag_import_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_flag_import_configurations(opts = {}) ⇒ FlagImportIntegrationCollection
List all flag import configurations List all flag import configurations.
561 562 563 564 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 561 def get_flag_import_configurations(opts = {}) data, _status_code, _headers = get_flag_import_configurations_with_http_info(opts) data end |
#get_flag_import_configurations_with_http_info(opts = {}) ⇒ Array<(FlagImportIntegrationCollection, Integer, Hash)>
List all flag import configurations List all flag import configurations.
570 571 572 573 574 575 576 577 578 579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 570 def get_flag_import_configurations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.get_flag_import_configurations ...' end # resource path local_var_path = '/api/v2/integration-capabilities/flag-import' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'FlagImportIntegrationCollection' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.get_flag_import_configurations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#get_flag_import_configurations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ BigSegmentStoreIntegration
Update big segment store integration Update a big segment store integration. Updating a big segment store requires a [JSON Patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](/#section/Overview/Updates).
623 624 625 626 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 623 def patch_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) data, _status_code, _headers = patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts) data end |
#patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Update big segment store integration Update a big segment store integration. Updating a big segment store requires a [JSON Patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](/#section/Overview/Updates).
637 638 639 640 641 642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 662 663 664 665 666 667 668 669 670 671 672 673 674 675 676 677 678 679 680 681 682 683 684 685 686 687 688 689 690 691 692 693 694 695 696 697 698 699 700 701 702 703 704 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 637 def patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.patch_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling IntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'patch_operation' is set if @api_client.config.client_side_validation && patch_operation.nil? fail ArgumentError, "Missing the required parameter 'patch_operation' when calling IntegrationsBetaApi.patch_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_operation) # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.patch_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#patch_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_flag_import_configuration(project_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ FlagImportIntegration
Update a flag import configuration Updating a flag import configuration uses a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](/#section/Overview/Updates).<br/><br/>To add an element to the import configuration fields that are arrays, set the ‘path` to the name of the field and then append `/<array index>`. Use `/0` to add to the beginning of the array. Use `/-` to add to the end of the array.<br/><br/>You can update the `config`, `tags`, and `name` of the flag import configuration.
714 715 716 717 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 714 def patch_flag_import_configuration(project_key, integration_key, integration_id, patch_operation, opts = {}) data, _status_code, _headers = patch_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, patch_operation, opts) data end |
#patch_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ Array<(FlagImportIntegration, Integer, Hash)>
Update a flag import configuration Updating a flag import configuration uses a [JSON patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](/#section/Overview/Updates).<br/><br/>To add an element to the import configuration fields that are arrays, set the `path` to the name of the field and then append `/<array index>`. Use `/0` to add to the beginning of the array. Use `/-` to add to the end of the array.<br/><br/>You can update the `config`, `tags`, and `name` of the flag import configuration.
727 728 729 730 731 732 733 734 735 736 737 738 739 740 741 742 743 744 745 746 747 748 749 750 751 752 753 754 755 756 757 758 759 760 761 762 763 764 765 766 767 768 769 770 771 772 773 774 775 776 777 778 779 780 781 782 783 784 785 786 787 788 789 790 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 727 def patch_flag_import_configuration_with_http_info(project_key, integration_key, integration_id, patch_operation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.patch_flag_import_configuration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.patch_flag_import_configuration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.patch_flag_import_configuration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.patch_flag_import_configuration" end # verify the required parameter 'patch_operation' is set if @api_client.config.client_side_validation && patch_operation.nil? fail ArgumentError, "Missing the required parameter 'patch_operation' when calling IntegrationsBetaApi.patch_flag_import_configuration" end # resource path local_var_path = '/api/v2/integration-capabilities/flag-import/{projectKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_operation) # return_type return_type = opts[:debug_return_type] || 'FlagImportIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.patch_flag_import_configuration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#patch_flag_import_configuration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#trigger_flag_import_job(project_key, integration_key, integration_id, opts = {}) ⇒ Object
Trigger a single flag import run Trigger a single flag import run for an existing flag import configuration. The ‘integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`.
799 800 801 802 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 799 def trigger_flag_import_job(project_key, integration_key, integration_id, opts = {}) data, _status_code, _headers = trigger_flag_import_job_with_http_info(project_key, integration_key, integration_id, opts) data end |
#trigger_flag_import_job_with_http_info(project_key, integration_key, integration_id, opts = {}) ⇒ Array<(Object, Integer, Hash)>
Trigger a single flag import run Trigger a single flag import run for an existing flag import configuration. The `integrationKey` path parameter identifies the feature management system from which the import occurs, for example, `split`.
811 812 813 814 815 816 817 818 819 820 821 822 823 824 825 826 827 828 829 830 831 832 833 834 835 836 837 838 839 840 841 842 843 844 845 846 847 848 849 850 851 852 853 854 855 856 857 858 859 860 861 862 863 864 865 |
# File 'lib/launchdarkly_api/api/integrations_beta_api.rb', line 811 def trigger_flag_import_job_with_http_info(project_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: IntegrationsBetaApi.trigger_flag_import_job ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling IntegrationsBetaApi.trigger_flag_import_job" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling IntegrationsBetaApi.trigger_flag_import_job" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling IntegrationsBetaApi.trigger_flag_import_job" end # resource path local_var_path = '/api/v2/integration-capabilities/flag-import/{projectKey}/{integrationKey}/{integrationId}/trigger'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'Object' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"IntegrationsBetaApi.trigger_flag_import_job", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: IntegrationsBetaApi#trigger_flag_import_job\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |