Class: LaunchDarklyApi::IterationInput

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/iteration_input.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ IterationInput

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 95

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::IterationInput` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::IterationInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'hypothesis')
    self.hypothesis = attributes[:'hypothesis']
  else
    self.hypothesis = nil
  end

  if attributes.key?(:'can_reshuffle_traffic')
    self.can_reshuffle_traffic = attributes[:'can_reshuffle_traffic']
  end

  if attributes.key?(:'metrics')
    if (value = attributes[:'metrics']).is_a?(Array)
      self.metrics = value
    end
  else
    self.metrics = nil
  end

  if attributes.key?(:'primary_single_metric_key')
    self.primary_single_metric_key = attributes[:'primary_single_metric_key']
  end

  if attributes.key?(:'primary_funnel_key')
    self.primary_funnel_key = attributes[:'primary_funnel_key']
  end

  if attributes.key?(:'treatments')
    if (value = attributes[:'treatments']).is_a?(Array)
      self.treatments = value
    end
  else
    self.treatments = nil
  end

  if attributes.key?(:'flags')
    if (value = attributes[:'flags']).is_a?(Hash)
      self.flags = value
    end
  else
    self.flags = nil
  end

  if attributes.key?(:'randomization_unit')
    self.randomization_unit = attributes[:'randomization_unit']
  end

  if attributes.key?(:'covariance_id')
    self.covariance_id = attributes[:'covariance_id']
  end

  if attributes.key?(:'attributes')
    if (value = attributes[:'attributes']).is_a?(Array)
      self.attributes = value
    end
  end
end

Instance Attribute Details

#attributesObject

The attributes that this iteration’s results can be sliced by



43
44
45
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 43

def attributes
  @attributes
end

#can_reshuffle_trafficObject

Whether to allow the experiment to reassign traffic to different variations when you increase or decrease the traffic in your experiment audience (true) or keep all traffic assigned to its initial variation (false). Defaults to true.



22
23
24
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 22

def can_reshuffle_traffic
  @can_reshuffle_traffic
end

#covariance_idObject

The ID of the covariance CSV



40
41
42
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 40

def covariance_id
  @covariance_id
end

#flagsObject

Returns the value of attribute flags.



34
35
36
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 34

def flags
  @flags
end

#hypothesisObject

The expected outcome of this experiment



19
20
21
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 19

def hypothesis
  @hypothesis
end

#metricsObject

Returns the value of attribute metrics.



24
25
26
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 24

def metrics
  @metrics
end

#primary_funnel_keyObject

The key of the primary funnel group for this experiment. Either primarySingleMetricKey or primaryFunnelKey must be present.



30
31
32
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 30

def primary_funnel_key
  @primary_funnel_key
end

#primary_single_metric_keyObject

The key of the primary metric for this experiment. Either primarySingleMetricKey or primaryFunnelKey must be present.



27
28
29
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 27

def primary_single_metric_key
  @primary_single_metric_key
end

#randomization_unitObject

The unit of randomization for this iteration. Defaults to user.



37
38
39
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 37

def randomization_unit
  @randomization_unit
end

#treatmentsObject

Returns the value of attribute treatments.



32
33
34
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 32

def treatments
  @treatments
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



297
298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 297

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



62
63
64
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 62

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



67
68
69
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 67

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



46
47
48
49
50
51
52
53
54
55
56
57
58
59
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 46

def self.attribute_map
  {
    :'hypothesis' => :'hypothesis',
    :'can_reshuffle_traffic' => :'canReshuffleTraffic',
    :'metrics' => :'metrics',
    :'primary_single_metric_key' => :'primarySingleMetricKey',
    :'primary_funnel_key' => :'primaryFunnelKey',
    :'treatments' => :'treatments',
    :'flags' => :'flags',
    :'randomization_unit' => :'randomizationUnit',
    :'covariance_id' => :'covarianceId',
    :'attributes' => :'attributes'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
290
291
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 273

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



88
89
90
91
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 88

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 72

def self.openapi_types
  {
    :'hypothesis' => :'String',
    :'can_reshuffle_traffic' => :'Boolean',
    :'metrics' => :'Array<MetricInput>',
    :'primary_single_metric_key' => :'String',
    :'primary_funnel_key' => :'String',
    :'treatments' => :'Array<TreatmentInput>',
    :'flags' => :'Hash<String, FlagInput>',
    :'randomization_unit' => :'String',
    :'covariance_id' => :'String',
    :'attributes' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



243
244
245
246
247
248
249
250
251
252
253
254
255
256
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 243

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      hypothesis == o.hypothesis &&
      can_reshuffle_traffic == o.can_reshuffle_traffic &&
      metrics == o.metrics &&
      primary_single_metric_key == o.primary_single_metric_key &&
      primary_funnel_key == o.primary_funnel_key &&
      treatments == o.treatments &&
      flags == o.flags &&
      randomization_unit == o.randomization_unit &&
      covariance_id == o.covariance_id &&
      attributes == o.attributes
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



368
369
370
371
372
373
374
375
376
377
378
379
380
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 368

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


260
261
262
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 260

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



266
267
268
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 266

def hash
  [hypothesis, can_reshuffle_traffic, metrics, primary_single_metric_key, primary_funnel_key, treatments, flags, randomization_unit, covariance_id, attributes].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 168

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @hypothesis.nil?
    invalid_properties.push('invalid value for "hypothesis", hypothesis cannot be nil.')
  end

  if @metrics.nil?
    invalid_properties.push('invalid value for "metrics", metrics cannot be nil.')
  end

  if @treatments.nil?
    invalid_properties.push('invalid value for "treatments", treatments cannot be nil.')
  end

  if @flags.nil?
    invalid_properties.push('invalid value for "flags", flags cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



344
345
346
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 344

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



350
351
352
353
354
355
356
357
358
359
360
361
362
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 350

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



338
339
340
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 338

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



192
193
194
195
196
197
198
199
# File 'lib/launchdarkly_api/models/iteration_input.rb', line 192

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @hypothesis.nil?
  return false if @metrics.nil?
  return false if @treatments.nil?
  return false if @flags.nil?
  true
end