Class: LaunchDarklyApi::Member
- Inherits:
-
Object
- Object
- LaunchDarklyApi::Member
- Defined in:
- lib/launchdarkly_api/models/member.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
The member’s ID.
-
#_integration_metadata ⇒ Object
Returns the value of attribute _integration_metadata.
-
#_last_seen ⇒ Object
Returns the value of attribute _last_seen.
-
#_last_seen_metadata ⇒ Object
Returns the value of attribute _last_seen_metadata.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_pending_email ⇒ Object
The member’s email address before it has been verified, for accounts where email verification is required.
-
#_pending_invite ⇒ Object
Whether the member has a pending invitation.
-
#_verified ⇒ Object
Whether the member’s email address has been verified.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#custom_roles ⇒ Object
The set of additional roles, besides the base role, assigned to the member.
-
#email ⇒ Object
The member’s email address.
-
#excluded_dashboards ⇒ Object
Default dashboards that the member has chosen to ignore.
-
#first_name ⇒ Object
The member’s first name.
-
#last_name ⇒ Object
The member’s last name.
-
#mfa ⇒ Object
Whether multi-factor authentication is enabled for this member.
-
#oauth_providers ⇒ Object
A list of OAuth providers.
-
#permission_grants ⇒ Object
A list of permission grants.
-
#role ⇒ Object
The member’s base role.
-
#role_attributes ⇒ Object
Returns the value of attribute role_attributes.
-
#teams ⇒ Object
Details on the teams this member is assigned to.
-
#version ⇒ Object
Version of the current configuration.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Member
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Member
Initializes the object
143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 |
# File 'lib/launchdarkly_api/models/member.rb', line 143 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Member` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Member`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'role') self.role = attributes[:'role'] else self.role = nil end if attributes.key?(:'email') self.email = attributes[:'email'] else self.email = nil end if attributes.key?(:'_pending_invite') self._pending_invite = attributes[:'_pending_invite'] else self._pending_invite = nil end if attributes.key?(:'_verified') self._verified = attributes[:'_verified'] else self._verified = nil end if attributes.key?(:'_pending_email') self._pending_email = attributes[:'_pending_email'] end if attributes.key?(:'custom_roles') if (value = attributes[:'custom_roles']).is_a?(Array) self.custom_roles = value end else self.custom_roles = nil end if attributes.key?(:'mfa') self.mfa = attributes[:'mfa'] else self.mfa = nil end if attributes.key?(:'excluded_dashboards') if (value = attributes[:'excluded_dashboards']).is_a?(Array) self.excluded_dashboards = value end end if attributes.key?(:'_last_seen') self._last_seen = attributes[:'_last_seen'] else self._last_seen = nil end if attributes.key?(:'_last_seen_metadata') self. = attributes[:'_last_seen_metadata'] end if attributes.key?(:'_integration_metadata') self. = attributes[:'_integration_metadata'] end if attributes.key?(:'teams') if (value = attributes[:'teams']).is_a?(Array) self.teams = value end end if attributes.key?(:'permission_grants') if (value = attributes[:'permission_grants']).is_a?(Array) self. = value end end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'oauth_providers') if (value = attributes[:'oauth_providers']).is_a?(Array) self.oauth_providers = value end end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'role_attributes') if (value = attributes[:'role_attributes']).is_a?(Hash) self.role_attributes = value end end end |
Instance Attribute Details
#_id ⇒ Object
The member’s ID
22 23 24 |
# File 'lib/launchdarkly_api/models/member.rb', line 22 def _id @_id end |
#_integration_metadata ⇒ Object
Returns the value of attribute _integration_metadata.
58 59 60 |
# File 'lib/launchdarkly_api/models/member.rb', line 58 def @_integration_metadata end |
#_last_seen ⇒ Object
Returns the value of attribute _last_seen.
54 55 56 |
# File 'lib/launchdarkly_api/models/member.rb', line 54 def _last_seen @_last_seen end |
#_last_seen_metadata ⇒ Object
Returns the value of attribute _last_seen_metadata.
56 57 58 |
# File 'lib/launchdarkly_api/models/member.rb', line 56 def @_last_seen_metadata end |
#_links ⇒ Object
The location and content type of related resources
19 20 21 |
# File 'lib/launchdarkly_api/models/member.rb', line 19 def _links @_links end |
#_pending_email ⇒ Object
The member’s email address before it has been verified, for accounts where email verification is required
43 44 45 |
# File 'lib/launchdarkly_api/models/member.rb', line 43 def _pending_email @_pending_email end |
#_pending_invite ⇒ Object
Whether the member has a pending invitation
37 38 39 |
# File 'lib/launchdarkly_api/models/member.rb', line 37 def _pending_invite @_pending_invite end |
#_verified ⇒ Object
Whether the member’s email address has been verified
40 41 42 |
# File 'lib/launchdarkly_api/models/member.rb', line 40 def _verified @_verified end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
66 67 68 |
# File 'lib/launchdarkly_api/models/member.rb', line 66 def creation_date @creation_date end |
#custom_roles ⇒ Object
The set of additional roles, besides the base role, assigned to the member
46 47 48 |
# File 'lib/launchdarkly_api/models/member.rb', line 46 def custom_roles @custom_roles end |
#email ⇒ Object
The member’s email address
34 35 36 |
# File 'lib/launchdarkly_api/models/member.rb', line 34 def email @email end |
#excluded_dashboards ⇒ Object
Default dashboards that the member has chosen to ignore
52 53 54 |
# File 'lib/launchdarkly_api/models/member.rb', line 52 def excluded_dashboards @excluded_dashboards end |
#first_name ⇒ Object
The member’s first name
25 26 27 |
# File 'lib/launchdarkly_api/models/member.rb', line 25 def first_name @first_name end |
#last_name ⇒ Object
The member’s last name
28 29 30 |
# File 'lib/launchdarkly_api/models/member.rb', line 28 def last_name @last_name end |
#mfa ⇒ Object
Whether multi-factor authentication is enabled for this member
49 50 51 |
# File 'lib/launchdarkly_api/models/member.rb', line 49 def mfa @mfa end |
#oauth_providers ⇒ Object
A list of OAuth providers
69 70 71 |
# File 'lib/launchdarkly_api/models/member.rb', line 69 def oauth_providers @oauth_providers end |
#permission_grants ⇒ Object
A list of permission grants. Permission grants allow a member to have access to a specific action, without having to create or update a custom role.
64 65 66 |
# File 'lib/launchdarkly_api/models/member.rb', line 64 def @permission_grants end |
#role ⇒ Object
The member’s base role. If the member has no additional roles, this role will be in effect.
31 32 33 |
# File 'lib/launchdarkly_api/models/member.rb', line 31 def role @role end |
#role_attributes ⇒ Object
Returns the value of attribute role_attributes.
74 75 76 |
# File 'lib/launchdarkly_api/models/member.rb', line 74 def role_attributes @role_attributes end |
#teams ⇒ Object
Details on the teams this member is assigned to
61 62 63 |
# File 'lib/launchdarkly_api/models/member.rb', line 61 def teams @teams end |
#version ⇒ Object
Version of the current configuration
72 73 74 |
# File 'lib/launchdarkly_api/models/member.rb', line 72 def version @version end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 429 430 431 432 433 434 435 436 437 438 439 440 441 442 443 444 |
# File 'lib/launchdarkly_api/models/member.rb', line 407 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
104 105 106 |
# File 'lib/launchdarkly_api/models/member.rb', line 104 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 |
# File 'lib/launchdarkly_api/models/member.rb', line 77 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'first_name' => :'firstName', :'last_name' => :'lastName', :'role' => :'role', :'email' => :'email', :'_pending_invite' => :'_pendingInvite', :'_verified' => :'_verified', :'_pending_email' => :'_pendingEmail', :'custom_roles' => :'customRoles', :'mfa' => :'mfa', :'excluded_dashboards' => :'excludedDashboards', :'_last_seen' => :'_lastSeen', :'_last_seen_metadata' => :'_lastSeenMetadata', :'_integration_metadata' => :'_integrationMetadata', :'teams' => :'teams', :'permission_grants' => :'permissionGrants', :'creation_date' => :'creationDate', :'oauth_providers' => :'oauthProviders', :'version' => :'version', :'role_attributes' => :'roleAttributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 |
# File 'lib/launchdarkly_api/models/member.rb', line 383 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
136 137 138 139 |
# File 'lib/launchdarkly_api/models/member.rb', line 136 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 |
# File 'lib/launchdarkly_api/models/member.rb', line 109 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_id' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'role' => :'String', :'email' => :'String', :'_pending_invite' => :'Boolean', :'_verified' => :'Boolean', :'_pending_email' => :'String', :'custom_roles' => :'Array<String>', :'mfa' => :'String', :'excluded_dashboards' => :'Array<String>', :'_last_seen' => :'Integer', :'_last_seen_metadata' => :'LastSeenMetadata', :'_integration_metadata' => :'IntegrationMetadata', :'teams' => :'Array<MemberTeamSummaryRep>', :'permission_grants' => :'Array<MemberPermissionGrantSummaryRep>', :'creation_date' => :'Integer', :'oauth_providers' => :'Array<String>', :'version' => :'Integer', :'role_attributes' => :'Hash<String, Array>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 |
# File 'lib/launchdarkly_api/models/member.rb', line 342 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && first_name == o.first_name && last_name == o.last_name && role == o.role && email == o.email && _pending_invite == o._pending_invite && _verified == o._verified && _pending_email == o._pending_email && custom_roles == o.custom_roles && mfa == o.mfa && excluded_dashboards == o.excluded_dashboards && _last_seen == o._last_seen && == o. && == o. && teams == o.teams && == o. && creation_date == o.creation_date && oauth_providers == o.oauth_providers && version == o.version && role_attributes == o.role_attributes end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
478 479 480 481 482 483 484 485 486 487 488 489 490 |
# File 'lib/launchdarkly_api/models/member.rb', line 478 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
370 371 372 |
# File 'lib/launchdarkly_api/models/member.rb', line 370 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
376 377 378 |
# File 'lib/launchdarkly_api/models/member.rb', line 376 def hash [_links, _id, first_name, last_name, role, email, _pending_invite, _verified, _pending_email, custom_roles, mfa, excluded_dashboards, _last_seen, , , teams, , creation_date, oauth_providers, version, role_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 |
# File 'lib/launchdarkly_api/models/member.rb', line 277 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @role.nil? invalid_properties.push('invalid value for "role", role cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @_pending_invite.nil? invalid_properties.push('invalid value for "_pending_invite", _pending_invite cannot be nil.') end if @_verified.nil? invalid_properties.push('invalid value for "_verified", _verified cannot be nil.') end if @custom_roles.nil? invalid_properties.push('invalid value for "custom_roles", custom_roles cannot be nil.') end if @mfa.nil? invalid_properties.push('invalid value for "mfa", mfa cannot be nil.') end if @_last_seen.nil? invalid_properties.push('invalid value for "_last_seen", _last_seen cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
454 455 456 |
# File 'lib/launchdarkly_api/models/member.rb', line 454 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
460 461 462 463 464 465 466 467 468 469 470 471 472 |
# File 'lib/launchdarkly_api/models/member.rb', line 460 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
448 449 450 |
# File 'lib/launchdarkly_api/models/member.rb', line 448 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
325 326 327 328 329 330 331 332 333 334 335 336 337 338 |
# File 'lib/launchdarkly_api/models/member.rb', line 325 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_links.nil? return false if @_id.nil? return false if @role.nil? return false if @email.nil? return false if @_pending_invite.nil? return false if @_verified.nil? return false if @custom_roles.nil? return false if @mfa.nil? return false if @_last_seen.nil? return false if @creation_date.nil? true end |