Class: LaunchDarklyApi::Member

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/member.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Member

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
# File 'lib/launchdarkly_api/models/member.rb', line 134

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Member` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Member`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'first_name')
    self.first_name = attributes[:'first_name']
  end

  if attributes.key?(:'last_name')
    self.last_name = attributes[:'last_name']
  end

  if attributes.key?(:'role')
    self.role = attributes[:'role']
  end

  if attributes.key?(:'email')
    self.email = attributes[:'email']
  end

  if attributes.key?(:'_pending_invite')
    self._pending_invite = attributes[:'_pending_invite']
  end

  if attributes.key?(:'_verified')
    self._verified = attributes[:'_verified']
  end

  if attributes.key?(:'_pending_email')
    self._pending_email = attributes[:'_pending_email']
  end

  if attributes.key?(:'custom_roles')
    if (value = attributes[:'custom_roles']).is_a?(Array)
      self.custom_roles = value
    end
  end

  if attributes.key?(:'mfa')
    self.mfa = attributes[:'mfa']
  end

  if attributes.key?(:'excluded_dashboards')
    if (value = attributes[:'excluded_dashboards']).is_a?(Array)
      self.excluded_dashboards = value
    end
  end

  if attributes.key?(:'_last_seen')
    self._last_seen = attributes[:'_last_seen']
  end

  if attributes.key?(:'_last_seen_metadata')
    self. = attributes[:'_last_seen_metadata']
  end

  if attributes.key?(:'_integration_metadata')
    self. = attributes[:'_integration_metadata']
  end

  if attributes.key?(:'teams')
    if (value = attributes[:'teams']).is_a?(Array)
      self.teams = value
    end
  end

  if attributes.key?(:'permission_grants')
    if (value = attributes[:'permission_grants']).is_a?(Array)
      self.permission_grants = value
    end
  end

  if attributes.key?(:'creation_date')
    self.creation_date = attributes[:'creation_date']
  end

  if attributes.key?(:'oauth_providers')
    if (value = attributes[:'oauth_providers']).is_a?(Array)
      self.oauth_providers = value
    end
  end
end

Instance Attribute Details

#_idObject

The member’s ID



22
23
24
# File 'lib/launchdarkly_api/models/member.rb', line 22

def _id
  @_id
end

#_integration_metadataObject

Returns the value of attribute _integration_metadata.



58
59
60
# File 'lib/launchdarkly_api/models/member.rb', line 58

def 
  @_integration_metadata
end

#_last_seenObject

Returns the value of attribute _last_seen.



54
55
56
# File 'lib/launchdarkly_api/models/member.rb', line 54

def _last_seen
  @_last_seen
end

#_last_seen_metadataObject

Returns the value of attribute _last_seen_metadata.



56
57
58
# File 'lib/launchdarkly_api/models/member.rb', line 56

def 
  @_last_seen_metadata
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/member.rb', line 19

def _links
  @_links
end

#_pending_emailObject

The member’s email address before it has been verified, for accounts where email verification is required



43
44
45
# File 'lib/launchdarkly_api/models/member.rb', line 43

def _pending_email
  @_pending_email
end

#_pending_inviteObject

Whether the member has a pending invitation



37
38
39
# File 'lib/launchdarkly_api/models/member.rb', line 37

def _pending_invite
  @_pending_invite
end

#_verifiedObject

Whether the member’s email address has been verified



40
41
42
# File 'lib/launchdarkly_api/models/member.rb', line 40

def _verified
  @_verified
end

#creation_dateObject

Returns the value of attribute creation_date.



66
67
68
# File 'lib/launchdarkly_api/models/member.rb', line 66

def creation_date
  @creation_date
end

#custom_rolesObject

The set of custom roles (as keys) assigned to the member



46
47
48
# File 'lib/launchdarkly_api/models/member.rb', line 46

def custom_roles
  @custom_roles
end

#emailObject

The member’s email address



34
35
36
# File 'lib/launchdarkly_api/models/member.rb', line 34

def email
  @email
end

#excluded_dashboardsObject

Default dashboards that the member has chosen to ignore



52
53
54
# File 'lib/launchdarkly_api/models/member.rb', line 52

def excluded_dashboards
  @excluded_dashboards
end

#first_nameObject

The member’s first name



25
26
27
# File 'lib/launchdarkly_api/models/member.rb', line 25

def first_name
  @first_name
end

#last_nameObject

The member’s last name



28
29
30
# File 'lib/launchdarkly_api/models/member.rb', line 28

def last_name
  @last_name
end

#mfaObject

Whether multi-factor authentication is enabled for this member



49
50
51
# File 'lib/launchdarkly_api/models/member.rb', line 49

def mfa
  @mfa
end

#oauth_providersObject

A list of OAuth providers



69
70
71
# File 'lib/launchdarkly_api/models/member.rb', line 69

def oauth_providers
  @oauth_providers
end

#permission_grantsObject

A list of permission grants. Permission grants allow a member to have access to a specific action, without having to create or update a custom role.



64
65
66
# File 'lib/launchdarkly_api/models/member.rb', line 64

def permission_grants
  @permission_grants
end

#roleObject

The member’s built-in role. If the member has no custom roles, this role will be in effect.



31
32
33
# File 'lib/launchdarkly_api/models/member.rb', line 31

def role
  @role
end

#teamsObject

Details on the teams this member is assigned to



61
62
63
# File 'lib/launchdarkly_api/models/member.rb', line 61

def teams
  @teams
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



97
98
99
# File 'lib/launchdarkly_api/models/member.rb', line 97

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



72
73
74
75
76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
93
94
# File 'lib/launchdarkly_api/models/member.rb', line 72

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'first_name' => :'firstName',
    :'last_name' => :'lastName',
    :'role' => :'role',
    :'email' => :'email',
    :'_pending_invite' => :'_pendingInvite',
    :'_verified' => :'_verified',
    :'_pending_email' => :'_pendingEmail',
    :'custom_roles' => :'customRoles',
    :'mfa' => :'mfa',
    :'excluded_dashboards' => :'excludedDashboards',
    :'_last_seen' => :'_lastSeen',
    :'_last_seen_metadata' => :'_lastSeenMetadata',
    :'_integration_metadata' => :'_integrationMetadata',
    :'teams' => :'teams',
    :'permission_grants' => :'permissionGrants',
    :'creation_date' => :'creationDate',
    :'oauth_providers' => :'oauthProviders'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



340
341
342
# File 'lib/launchdarkly_api/models/member.rb', line 340

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



127
128
129
130
# File 'lib/launchdarkly_api/models/member.rb', line 127

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
# File 'lib/launchdarkly_api/models/member.rb', line 102

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'first_name' => :'String',
    :'last_name' => :'String',
    :'role' => :'String',
    :'email' => :'String',
    :'_pending_invite' => :'Boolean',
    :'_verified' => :'Boolean',
    :'_pending_email' => :'String',
    :'custom_roles' => :'Array<String>',
    :'mfa' => :'String',
    :'excluded_dashboards' => :'Array<String>',
    :'_last_seen' => :'Integer',
    :'_last_seen_metadata' => :'LastSeenMetadata',
    :'_integration_metadata' => :'IntegrationMetadata',
    :'teams' => :'Array<MemberTeamSummaryRep>',
    :'permission_grants' => :'Array<MemberPermissionGrantSummaryRep>',
    :'creation_date' => :'Integer',
    :'oauth_providers' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
319
320
321
322
323
# File 'lib/launchdarkly_api/models/member.rb', line 301

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      first_name == o.first_name &&
      last_name == o.last_name &&
      role == o.role &&
      email == o.email &&
      _pending_invite == o._pending_invite &&
      _verified == o._verified &&
      _pending_email == o._pending_email &&
      custom_roles == o.custom_roles &&
      mfa == o.mfa &&
      excluded_dashboards == o.excluded_dashboards &&
      _last_seen == o._last_seen &&
       == o. &&
       == o. &&
      teams == o.teams &&
      permission_grants == o.permission_grants &&
      creation_date == o.creation_date &&
      oauth_providers == o.oauth_providers
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
# File 'lib/launchdarkly_api/models/member.rb', line 371

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



442
443
444
445
446
447
448
449
450
451
452
453
454
# File 'lib/launchdarkly_api/models/member.rb', line 442

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



347
348
349
350
351
352
353
354
355
356
357
358
359
360
361
362
363
364
365
# File 'lib/launchdarkly_api/models/member.rb', line 347

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


327
328
329
# File 'lib/launchdarkly_api/models/member.rb', line 327

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



333
334
335
# File 'lib/launchdarkly_api/models/member.rb', line 333

def hash
  [_links, _id, first_name, last_name, role, email, _pending_invite, _verified, _pending_email, custom_roles, mfa, excluded_dashboards, _last_seen, , , teams, permission_grants, creation_date, oauth_providers].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
# File 'lib/launchdarkly_api/models/member.rb', line 238

def list_invalid_properties
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @role.nil?
    invalid_properties.push('invalid value for "role", role cannot be nil.')
  end

  if @email.nil?
    invalid_properties.push('invalid value for "email", email cannot be nil.')
  end

  if @_pending_invite.nil?
    invalid_properties.push('invalid value for "_pending_invite", _pending_invite cannot be nil.')
  end

  if @_verified.nil?
    invalid_properties.push('invalid value for "_verified", _verified cannot be nil.')
  end

  if @custom_roles.nil?
    invalid_properties.push('invalid value for "custom_roles", custom_roles cannot be nil.')
  end

  if @mfa.nil?
    invalid_properties.push('invalid value for "mfa", mfa cannot be nil.')
  end

  if @_last_seen.nil?
    invalid_properties.push('invalid value for "_last_seen", _last_seen cannot be nil.')
  end

  if @creation_date.nil?
    invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



418
419
420
# File 'lib/launchdarkly_api/models/member.rb', line 418

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



424
425
426
427
428
429
430
431
432
433
434
435
436
# File 'lib/launchdarkly_api/models/member.rb', line 424

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



412
413
414
# File 'lib/launchdarkly_api/models/member.rb', line 412

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



285
286
287
288
289
290
291
292
293
294
295
296
297
# File 'lib/launchdarkly_api/models/member.rb', line 285

def valid?
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @role.nil?
  return false if @email.nil?
  return false if @_pending_invite.nil?
  return false if @_verified.nil?
  return false if @custom_roles.nil?
  return false if @mfa.nil?
  return false if @_last_seen.nil?
  return false if @creation_date.nil?
  true
end