Class: LaunchDarklyApi::Member
- Inherits:
-
Object
- Object
- LaunchDarklyApi::Member
- Defined in:
- lib/launchdarkly_api/models/member.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
The member's ID.
-
#_integration_metadata ⇒ Object
Returns the value of attribute _integration_metadata.
-
#_last_seen ⇒ Object
Returns the value of attribute _last_seen.
-
#_last_seen_metadata ⇒ Object
Returns the value of attribute _last_seen_metadata.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_pending_email ⇒ Object
Returns the value of attribute _pending_email.
-
#_pending_invite ⇒ Object
Whether or not the member has a pending invitation.
-
#_verified ⇒ Object
Whether or not the member's email address has been verified.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#custom_roles ⇒ Object
The set of custom roles (as keys) assigned to the member.
-
#email ⇒ Object
The member's email address.
-
#excluded_dashboards ⇒ Object
Default dashboards that the member has chosen to ignore.
-
#first_name ⇒ Object
The member's first name.
-
#last_name ⇒ Object
The member's last name.
-
#mfa ⇒ Object
Whether or not multi-factor authentication is enabled for this member.
-
#permission_grants ⇒ Object
Returns the value of attribute permission_grants.
-
#role ⇒ Object
The member's built-in role.
-
#teams ⇒ Object
Returns the value of attribute teams.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Member
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ Member
Initializes the object
125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 |
# File 'lib/launchdarkly_api/models/member.rb', line 125 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Member` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Member`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'role') self.role = attributes[:'role'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'_pending_invite') self._pending_invite = attributes[:'_pending_invite'] end if attributes.key?(:'_verified') self._verified = attributes[:'_verified'] end if attributes.key?(:'_pending_email') self._pending_email = attributes[:'_pending_email'] end if attributes.key?(:'custom_roles') if (value = attributes[:'custom_roles']).is_a?(Array) self.custom_roles = value end end if attributes.key?(:'mfa') self.mfa = attributes[:'mfa'] end if attributes.key?(:'excluded_dashboards') if (value = attributes[:'excluded_dashboards']).is_a?(Array) self.excluded_dashboards = value end end if attributes.key?(:'_last_seen') self._last_seen = attributes[:'_last_seen'] end if attributes.key?(:'_last_seen_metadata') self. = attributes[:'_last_seen_metadata'] end if attributes.key?(:'_integration_metadata') self. = attributes[:'_integration_metadata'] end if attributes.key?(:'teams') if (value = attributes[:'teams']).is_a?(Array) self.teams = value end end if attributes.key?(:'permission_grants') if (value = attributes[:'permission_grants']).is_a?(Array) self. = value end end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] end end |
Instance Attribute Details
#_id ⇒ Object
The member's ID
21 22 23 |
# File 'lib/launchdarkly_api/models/member.rb', line 21 def _id @_id end |
#_integration_metadata ⇒ Object
Returns the value of attribute _integration_metadata.
56 57 58 |
# File 'lib/launchdarkly_api/models/member.rb', line 56 def @_integration_metadata end |
#_last_seen ⇒ Object
Returns the value of attribute _last_seen.
52 53 54 |
# File 'lib/launchdarkly_api/models/member.rb', line 52 def _last_seen @_last_seen end |
#_last_seen_metadata ⇒ Object
Returns the value of attribute _last_seen_metadata.
54 55 56 |
# File 'lib/launchdarkly_api/models/member.rb', line 54 def @_last_seen_metadata end |
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/member.rb', line 18 def _links @_links end |
#_pending_email ⇒ Object
Returns the value of attribute _pending_email.
41 42 43 |
# File 'lib/launchdarkly_api/models/member.rb', line 41 def _pending_email @_pending_email end |
#_pending_invite ⇒ Object
Whether or not the member has a pending invitation
36 37 38 |
# File 'lib/launchdarkly_api/models/member.rb', line 36 def _pending_invite @_pending_invite end |
#_verified ⇒ Object
Whether or not the member's email address has been verified
39 40 41 |
# File 'lib/launchdarkly_api/models/member.rb', line 39 def _verified @_verified end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
62 63 64 |
# File 'lib/launchdarkly_api/models/member.rb', line 62 def creation_date @creation_date end |
#custom_roles ⇒ Object
The set of custom roles (as keys) assigned to the member
44 45 46 |
# File 'lib/launchdarkly_api/models/member.rb', line 44 def custom_roles @custom_roles end |
#email ⇒ Object
The member's email address
33 34 35 |
# File 'lib/launchdarkly_api/models/member.rb', line 33 def email @email end |
#excluded_dashboards ⇒ Object
Default dashboards that the member has chosen to ignore
50 51 52 |
# File 'lib/launchdarkly_api/models/member.rb', line 50 def excluded_dashboards @excluded_dashboards end |
#first_name ⇒ Object
The member's first name
24 25 26 |
# File 'lib/launchdarkly_api/models/member.rb', line 24 def first_name @first_name end |
#last_name ⇒ Object
The member's last name
27 28 29 |
# File 'lib/launchdarkly_api/models/member.rb', line 27 def last_name @last_name end |
#mfa ⇒ Object
Whether or not multi-factor authentication is enabled for this member
47 48 49 |
# File 'lib/launchdarkly_api/models/member.rb', line 47 def mfa @mfa end |
#permission_grants ⇒ Object
Returns the value of attribute permission_grants.
60 61 62 |
# File 'lib/launchdarkly_api/models/member.rb', line 60 def @permission_grants end |
#role ⇒ Object
The member's built-in role. If the member has no custom roles, this role will be in effect.
30 31 32 |
# File 'lib/launchdarkly_api/models/member.rb', line 30 def role @role end |
#teams ⇒ Object
Returns the value of attribute teams.
58 59 60 |
# File 'lib/launchdarkly_api/models/member.rb', line 58 def teams @teams end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
89 90 91 |
# File 'lib/launchdarkly_api/models/member.rb', line 89 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 |
# File 'lib/launchdarkly_api/models/member.rb', line 65 def self.attribute_map { :'_links' => :'_links', :'_id' => :'_id', :'first_name' => :'firstName', :'last_name' => :'lastName', :'role' => :'role', :'email' => :'email', :'_pending_invite' => :'_pendingInvite', :'_verified' => :'_verified', :'_pending_email' => :'_pendingEmail', :'custom_roles' => :'customRoles', :'mfa' => :'mfa', :'excluded_dashboards' => :'excludedDashboards', :'_last_seen' => :'_lastSeen', :'_last_seen_metadata' => :'_lastSeenMetadata', :'_integration_metadata' => :'_integrationMetadata', :'teams' => :'teams', :'permission_grants' => :'permissionGrants', :'creation_date' => :'creationDate' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
329 330 331 |
# File 'lib/launchdarkly_api/models/member.rb', line 329 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
118 119 120 121 |
# File 'lib/launchdarkly_api/models/member.rb', line 118 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 |
# File 'lib/launchdarkly_api/models/member.rb', line 94 def self.openapi_types { :'_links' => :'Hash<String, Link>', :'_id' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'role' => :'String', :'email' => :'String', :'_pending_invite' => :'Boolean', :'_verified' => :'Boolean', :'_pending_email' => :'String', :'custom_roles' => :'Array<String>', :'mfa' => :'String', :'excluded_dashboards' => :'Array<String>', :'_last_seen' => :'Integer', :'_last_seen_metadata' => :'LastSeenMetadata', :'_integration_metadata' => :'IntegrationMetadata', :'teams' => :'Array<MemberTeamSummaryRep>', :'permission_grants' => :'Array<MemberPermissionGrantSummaryRep>', :'creation_date' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 |
# File 'lib/launchdarkly_api/models/member.rb', line 291 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && _id == o._id && first_name == o.first_name && last_name == o.last_name && role == o.role && email == o.email && _pending_invite == o._pending_invite && _verified == o._verified && _pending_email == o._pending_email && custom_roles == o.custom_roles && mfa == o.mfa && excluded_dashboards == o.excluded_dashboards && _last_seen == o._last_seen && == o. && == o. && teams == o.teams && == o. && creation_date == o.creation_date end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 |
# File 'lib/launchdarkly_api/models/member.rb', line 359 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
430 431 432 433 434 435 436 437 438 439 440 441 442 |
# File 'lib/launchdarkly_api/models/member.rb', line 430 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 |
# File 'lib/launchdarkly_api/models/member.rb', line 336 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
316 317 318 |
# File 'lib/launchdarkly_api/models/member.rb', line 316 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
322 323 324 |
# File 'lib/launchdarkly_api/models/member.rb', line 322 def hash [_links, _id, first_name, last_name, role, email, _pending_invite, _verified, _pending_email, custom_roles, mfa, excluded_dashboards, _last_seen, , , teams, , creation_date].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 |
# File 'lib/launchdarkly_api/models/member.rb', line 223 def list_invalid_properties invalid_properties = Array.new if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @role.nil? invalid_properties.push('invalid value for "role", role cannot be nil.') end if @email.nil? invalid_properties.push('invalid value for "email", email cannot be nil.') end if @_pending_invite.nil? invalid_properties.push('invalid value for "_pending_invite", _pending_invite cannot be nil.') end if @_verified.nil? invalid_properties.push('invalid value for "_verified", _verified cannot be nil.') end if @custom_roles.nil? invalid_properties.push('invalid value for "custom_roles", custom_roles cannot be nil.') end if @mfa.nil? invalid_properties.push('invalid value for "mfa", mfa cannot be nil.') end if @excluded_dashboards.nil? invalid_properties.push('invalid value for "excluded_dashboards", excluded_dashboards cannot be nil.') end if @_last_seen.nil? invalid_properties.push('invalid value for "_last_seen", _last_seen cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
406 407 408 |
# File 'lib/launchdarkly_api/models/member.rb', line 406 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
412 413 414 415 416 417 418 419 420 421 422 423 424 |
# File 'lib/launchdarkly_api/models/member.rb', line 412 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
400 401 402 |
# File 'lib/launchdarkly_api/models/member.rb', line 400 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
274 275 276 277 278 279 280 281 282 283 284 285 286 287 |
# File 'lib/launchdarkly_api/models/member.rb', line 274 def valid? return false if @_links.nil? return false if @_id.nil? return false if @role.nil? return false if @email.nil? return false if @_pending_invite.nil? return false if @_verified.nil? return false if @custom_roles.nil? return false if @mfa.nil? return false if @excluded_dashboards.nil? return false if @_last_seen.nil? return false if @creation_date.nil? true end |