Class: LaunchDarklyApi::MetricGroupRep

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/metric_group_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MetricGroupRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 135

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricGroupRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricGroupRep`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  else
    self._id = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'_creation_date')
    self._creation_date = attributes[:'_creation_date']
  else
    self._creation_date = nil
  end

  if attributes.key?(:'_last_modified')
    self._last_modified = attributes[:'_last_modified']
  else
    self._last_modified = nil
  end

  if attributes.key?(:'maintainer')
    self.maintainer = attributes[:'maintainer']
  else
    self.maintainer = nil
  end

  if attributes.key?(:'metrics')
    if (value = attributes[:'metrics']).is_a?(Array)
      self.metrics = value
    end
  else
    self.metrics = nil
  end

  if attributes.key?(:'_version')
    self._version = attributes[:'_version']
  else
    self._version = nil
  end

  if attributes.key?(:'experiments')
    if (value = attributes[:'experiments']).is_a?(Array)
      self.experiments = value
    end
  end

  if attributes.key?(:'experiment_count')
    self.experiment_count = attributes[:'experiment_count']
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



36
37
38
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 36

def _access
  @_access
end

#_creation_dateObject

Returns the value of attribute _creation_date.



41
42
43
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 41

def _creation_date
  @_creation_date
end

#_idObject

The ID of this metric group



19
20
21
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 19

def _id
  @_id
end

#_last_modifiedObject

Returns the value of attribute _last_modified.



43
44
45
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 43

def _last_modified
  @_last_modified
end

The location and content type of related resources



34
35
36
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 34

def _links
  @_links
end

#_versionObject

The version of this metric group



51
52
53
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 51

def _version
  @_version
end

#descriptionObject

Description of the metric group



31
32
33
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 31

def description
  @description
end

#experiment_countObject

The number of experiments using this metric group



56
57
58
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 56

def experiment_count
  @experiment_count
end

#experimentsObject

Returns the value of attribute experiments.



53
54
55
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 53

def experiments
  @experiments
end

#keyObject

A unique key to reference the metric group



22
23
24
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 22

def key
  @key
end

#kindObject

The type of the metric group



28
29
30
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 28

def kind
  @kind
end

#maintainerObject

Returns the value of attribute maintainer.



45
46
47
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 45

def maintainer
  @maintainer
end

#metricsObject

An ordered list of the metrics in this metric group



48
49
50
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 48

def metrics
  @metrics
end

#nameObject

A human-friendly name for the metric group



25
26
27
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 25

def name
  @name
end

#tagsObject

Tags for the metric group



39
40
41
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 39

def tags
  @tags
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 382

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



102
103
104
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 102

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



81
82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
99
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 81

def self.attribute_map
  {
    :'_id' => :'_id',
    :'key' => :'key',
    :'name' => :'name',
    :'kind' => :'kind',
    :'description' => :'description',
    :'_links' => :'_links',
    :'_access' => :'_access',
    :'tags' => :'tags',
    :'_creation_date' => :'_creationDate',
    :'_last_modified' => :'_lastModified',
    :'maintainer' => :'maintainer',
    :'metrics' => :'metrics',
    :'_version' => :'_version',
    :'experiments' => :'experiments',
    :'experiment_count' => :'experimentCount'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



358
359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 358

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



128
129
130
131
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 128

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 107

def self.openapi_types
  {
    :'_id' => :'String',
    :'key' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'description' => :'String',
    :'_links' => :'Hash<String, Link>',
    :'_access' => :'Access',
    :'tags' => :'Array<String>',
    :'_creation_date' => :'Integer',
    :'_last_modified' => :'Integer',
    :'maintainer' => :'MaintainerRep',
    :'metrics' => :'Array<MetricInGroupRep>',
    :'_version' => :'Integer',
    :'experiments' => :'Array<DependentExperimentRep>',
    :'experiment_count' => :'Integer'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 323

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _id == o._id &&
      key == o.key &&
      name == o.name &&
      kind == o.kind &&
      description == o.description &&
      _links == o._links &&
      _access == o._access &&
      tags == o.tags &&
      _creation_date == o._creation_date &&
      _last_modified == o._last_modified &&
      maintainer == o.maintainer &&
      metrics == o.metrics &&
      _version == o._version &&
      experiments == o.experiments &&
      experiment_count == o.experiment_count
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



453
454
455
456
457
458
459
460
461
462
463
464
465
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 453

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


345
346
347
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 345

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



351
352
353
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 351

def hash
  [_id, key, name, kind, description, _links, _access, tags, _creation_date, _last_modified, maintainer, metrics, _version, experiments, experiment_count].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
283
284
285
286
287
288
289
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 241

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @_creation_date.nil?
    invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.')
  end

  if @_last_modified.nil?
    invalid_properties.push('invalid value for "_last_modified", _last_modified cannot be nil.')
  end

  if @maintainer.nil?
    invalid_properties.push('invalid value for "maintainer", maintainer cannot be nil.')
  end

  if @metrics.nil?
    invalid_properties.push('invalid value for "metrics", metrics cannot be nil.')
  end

  if @_version.nil?
    invalid_properties.push('invalid value for "_version", _version cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



429
430
431
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 429

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



435
436
437
438
439
440
441
442
443
444
445
446
447
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 435

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



423
424
425
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 423

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



293
294
295
296
297
298
299
300
301
302
303
304
305
306
307
308
309
# File 'lib/launchdarkly_api/models/metric_group_rep.rb', line 293

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @_id.nil?
  return false if @key.nil?
  return false if @name.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["funnel", "standard", "guardrail"])
  return false unless kind_validator.valid?(@kind)
  return false if @_links.nil?
  return false if @tags.nil?
  return false if @_creation_date.nil?
  return false if @_last_modified.nil?
  return false if @maintainer.nil?
  return false if @metrics.nil?
  return false if @_version.nil?
  true
end