Class: LaunchDarklyApi::MetricInGroupRep

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/metric_in_group_rep.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ MetricInGroupRep

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 130

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricInGroupRep` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricInGroupRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'_version_id')
    self._version_id = attributes[:'_version_id']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'is_numeric')
    self.is_numeric = attributes[:'is_numeric']
  end

  if attributes.key?(:'unit_aggregation_type')
    self.unit_aggregation_type = attributes[:'unit_aggregation_type']
  end

  if attributes.key?(:'analysis_type')
    self.analysis_type = attributes[:'analysis_type']
  end

  if attributes.key?(:'event_key')
    self.event_key = attributes[:'event_key']
  end

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  else
    self._links = nil
  end

  if attributes.key?(:'name_in_group')
    self.name_in_group = attributes[:'name_in_group']
  end

  if attributes.key?(:'randomization_units')
    if (value = attributes[:'randomization_units']).is_a?(Array)
      self.randomization_units = value
    end
  end

  if attributes.key?(:'analysis_units')
    if (value = attributes[:'analysis_units']).is_a?(Array)
      self.analysis_units = value
    end
  end
end

Instance Attribute Details

The location and content type of related resources



43
44
45
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 43

def _links
  @_links
end

#_version_idObject

The version ID of the metric



22
23
24
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 22

def _version_id
  @_version_id
end

#analysis_typeObject

The method for analyzing metric events



37
38
39
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 37

def analysis_type
  @analysis_type
end

#analysis_unitsObject

An array of analysis units allowed for this metric.



52
53
54
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 52

def analysis_units
  @analysis_units
end

#event_keyObject

The event key sent with the metric. Only relevant for custom metrics.



40
41
42
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 40

def event_key
  @event_key
end

#is_numericObject

For custom metrics, whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false).



31
32
33
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 31

def is_numeric
  @is_numeric
end

#keyObject

The metric key



19
20
21
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 19

def key
  @key
end

#kindObject

The kind of event the metric tracks



28
29
30
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 28

def kind
  @kind
end

#nameObject

The metric name



25
26
27
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 25

def name
  @name
end

#name_in_groupObject

Name of the metric when used within the associated metric group. Can be different from the original name of the metric. Required if and only if the metric group is a funnel.



46
47
48
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 46

def name_in_group
  @name_in_group
end

#randomization_unitsObject

Deprecated, use analysisUnits instead.



49
50
51
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 49

def randomization_units
  @randomization_units
end

#unit_aggregation_typeObject

The type of unit aggregation to use for the metric



34
35
36
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 34

def unit_aggregation_type
  @unit_aggregation_type
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



95
96
97
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 95

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



100
101
102
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 100

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



77
78
79
80
81
82
83
84
85
86
87
88
89
90
91
92
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 77

def self.attribute_map
  {
    :'key' => :'key',
    :'_version_id' => :'_versionId',
    :'name' => :'name',
    :'kind' => :'kind',
    :'is_numeric' => :'isNumeric',
    :'unit_aggregation_type' => :'unitAggregationType',
    :'analysis_type' => :'analysisType',
    :'event_key' => :'eventKey',
    :'_links' => :'_links',
    :'name_in_group' => :'nameInGroup',
    :'randomization_units' => :'randomizationUnits',
    :'analysis_units' => :'analysisUnits'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 342

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



123
124
125
126
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 123

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 105

def self.openapi_types
  {
    :'key' => :'String',
    :'_version_id' => :'String',
    :'name' => :'String',
    :'kind' => :'String',
    :'is_numeric' => :'Boolean',
    :'unit_aggregation_type' => :'String',
    :'analysis_type' => :'String',
    :'event_key' => :'String',
    :'_links' => :'Hash<String, Link>',
    :'name_in_group' => :'String',
    :'randomization_units' => :'Array<String>',
    :'analysis_units' => :'Array<String>'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



310
311
312
313
314
315
316
317
318
319
320
321
322
323
324
325
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 310

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      _version_id == o._version_id &&
      name == o.name &&
      kind == o.kind &&
      is_numeric == o.is_numeric &&
      unit_aggregation_type == o.unit_aggregation_type &&
      analysis_type == o.analysis_type &&
      event_key == o.event_key &&
      _links == o._links &&
      name_in_group == o.name_in_group &&
      randomization_units == o.randomization_units &&
      analysis_units == o.analysis_units
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


329
330
331
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 329

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



335
336
337
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 335

def hash
  [key, _version_id, name, kind, is_numeric, unit_aggregation_type, analysis_type, event_key, _links, name_in_group, randomization_units, analysis_units].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 209

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



364
365
366
367
368
369
370
371
372
373
374
375
376
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 364

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



233
234
235
236
237
238
239
240
241
242
243
244
245
246
# File 'lib/launchdarkly_api/models/metric_in_group_rep.rb', line 233

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @name.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom", "trace"])
  return false unless kind_validator.valid?(@kind)
  unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["sum", "average", "count_distinct"])
  return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type)
  analysis_type_validator = EnumAttributeValidator.new('String', ["mean", "percentile"])
  return false unless analysis_type_validator.valid?(@analysis_type)
  return false if @_links.nil?
  true
end