Class: LaunchDarklyApi::MetricPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::MetricPost
- Defined in:
- lib/launchdarkly_api/models/metric_post.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#analysis_type ⇒ Object
The method for analyzing metric events.
-
#data_source ⇒ Object
Returns the value of attribute data_source.
-
#description ⇒ Object
Description of the metric.
-
#event_default ⇒ Object
Returns the value of attribute event_default.
-
#event_key ⇒ Object
The event key to use in your code.
-
#filters ⇒ Object
Returns the value of attribute filters.
-
#is_numeric ⇒ Object
Whether to track numeric changes in value against a baseline (
true) or to track a conversion when an end user takes an action (false). -
#key ⇒ Object
A unique key to reference the metric.
-
#kind ⇒ Object
The kind of event your metric will track.
-
#maintainer_id ⇒ Object
The ID of the member who maintains this metric.
-
#name ⇒ Object
A human-friendly name for the metric.
-
#percentile_value ⇒ Object
The percentile for the analysis method.
-
#randomization_units ⇒ Object
An array of randomization units allowed for this metric.
-
#selector ⇒ Object
One or more CSS selectors.
-
#success_criteria ⇒ Object
Success criteria.
-
#tags ⇒ Object
Tags for the metric.
-
#unit ⇒ Object
The unit of measure.
-
#unit_aggregation_type ⇒ Object
The method by which multiple unit event values are aggregated.
-
#urls ⇒ Object
One or more target URLs.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MetricPost
Initializes the object
162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 162 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'selector') self.selector = attributes[:'selector'] end if attributes.key?(:'urls') if (value = attributes[:'urls']).is_a?(Array) self.urls = value end end if attributes.key?(:'is_numeric') self.is_numeric = attributes[:'is_numeric'] end if attributes.key?(:'unit') self.unit = attributes[:'unit'] end if attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] end if attributes.key?(:'success_criteria') self.success_criteria = attributes[:'success_criteria'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'randomization_units') if (value = attributes[:'randomization_units']).is_a?(Array) self.randomization_units = value end end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'unit_aggregation_type') self.unit_aggregation_type = attributes[:'unit_aggregation_type'] end if attributes.key?(:'analysis_type') self.analysis_type = attributes[:'analysis_type'] end if attributes.key?(:'percentile_value') self.percentile_value = attributes[:'percentile_value'] end if attributes.key?(:'event_default') self.event_default = attributes[:'event_default'] end if attributes.key?(:'data_source') self.data_source = attributes[:'data_source'] end if attributes.key?(:'filters') self.filters = attributes[:'filters'] end end |
Instance Attribute Details
#analysis_type ⇒ Object
The method for analyzing metric events
61 62 63 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 61 def analysis_type @analysis_type end |
#data_source ⇒ Object
Returns the value of attribute data_source.
68 69 70 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 68 def data_source @data_source end |
#description ⇒ Object
Description of the metric
25 26 27 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 25 def description @description end |
#event_default ⇒ Object
Returns the value of attribute event_default.
66 67 68 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 66 def event_default @event_default end |
#event_key ⇒ Object
The event key to use in your code. Required for custom conversion/binary and custom numeric metrics only.
43 44 45 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 43 def event_key @event_key end |
#filters ⇒ Object
Returns the value of attribute filters.
70 71 72 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 70 def filters @filters end |
#is_numeric ⇒ Object
Whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false). Required for custom metrics only.
37 38 39 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 37 def is_numeric @is_numeric end |
#key ⇒ Object
A unique key to reference the metric
19 20 21 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 19 def key @key end |
#kind ⇒ Object
The kind of event your metric will track
28 29 30 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 28 def kind @kind end |
#maintainer_id ⇒ Object
The ID of the member who maintains this metric
55 56 57 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 55 def maintainer_id @maintainer_id end |
#name ⇒ Object
A human-friendly name for the metric
22 23 24 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 22 def name @name end |
#percentile_value ⇒ Object
The percentile for the analysis method. An integer denoting the target percentile between 0 and 100. Required when analysisType is percentile.
64 65 66 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 64 def percentile_value @percentile_value end |
#randomization_units ⇒ Object
An array of randomization units allowed for this metric
52 53 54 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 52 def randomization_units @randomization_units end |
#selector ⇒ Object
One or more CSS selectors. Required for click metrics only.
31 32 33 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 31 def selector @selector end |
#success_criteria ⇒ Object
Success criteria. Required for custom numeric metrics, optional for custom conversion metrics.
46 47 48 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 46 def success_criteria @success_criteria end |
#tags ⇒ Object
Tags for the metric
49 50 51 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 49 def @tags end |
#unit ⇒ Object
The unit of measure. Applicable for numeric custom metrics only.
40 41 42 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 40 def unit @unit end |
#unit_aggregation_type ⇒ Object
The method by which multiple unit event values are aggregated
58 59 60 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 58 def unit_aggregation_type @unit_aggregation_type end |
#urls ⇒ Object
One or more target URLs. Required for click and pageview metrics only.
34 35 36 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 34 def urls @urls end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
120 121 122 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 120 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
125 126 127 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 125 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 95 def self.attribute_map { :'key' => :'key', :'name' => :'name', :'description' => :'description', :'kind' => :'kind', :'selector' => :'selector', :'urls' => :'urls', :'is_numeric' => :'isNumeric', :'unit' => :'unit', :'event_key' => :'eventKey', :'success_criteria' => :'successCriteria', :'tags' => :'tags', :'randomization_units' => :'randomizationUnits', :'maintainer_id' => :'maintainerId', :'unit_aggregation_type' => :'unitAggregationType', :'analysis_type' => :'analysisType', :'percentile_value' => :'percentileValue', :'event_default' => :'eventDefault', :'data_source' => :'dataSource', :'filters' => :'filters' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 375 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
155 156 157 158 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 155 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 130 def self.openapi_types { :'key' => :'String', :'name' => :'String', :'description' => :'String', :'kind' => :'String', :'selector' => :'String', :'urls' => :'Array<UrlPost>', :'is_numeric' => :'Boolean', :'unit' => :'String', :'event_key' => :'String', :'success_criteria' => :'String', :'tags' => :'Array<String>', :'randomization_units' => :'Array<String>', :'maintainer_id' => :'String', :'unit_aggregation_type' => :'String', :'analysis_type' => :'String', :'percentile_value' => :'Integer', :'event_default' => :'MetricEventDefaultRep', :'data_source' => :'MetricDataSourceRefRep', :'filters' => :'EventFilter' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 336 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && name == o.name && description == o.description && kind == o.kind && selector == o.selector && urls == o.urls && is_numeric == o.is_numeric && unit == o.unit && event_key == o.event_key && success_criteria == o.success_criteria && == o. && randomization_units == o.randomization_units && maintainer_id == o.maintainer_id && unit_aggregation_type == o.unit_aggregation_type && analysis_type == o.analysis_type && percentile_value == o.percentile_value && event_default == o.event_default && data_source == o.data_source && filters == o.filters end |
#eql?(o) ⇒ Boolean
362 363 364 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 362 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
368 369 370 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 368 def hash [key, name, description, kind, selector, urls, is_numeric, unit, event_key, success_criteria, , randomization_units, maintainer_id, unit_aggregation_type, analysis_type, percentile_value, event_default, data_source, filters].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
265 266 267 268 269 270 271 272 273 274 275 276 277 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 265 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
397 398 399 400 401 402 403 404 405 406 407 408 409 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 397 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
281 282 283 284 285 286 287 288 289 290 291 292 |
# File 'lib/launchdarkly_api/models/metric_post.rb', line 281 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom"]) return false unless kind_validator.valid?(@kind) success_criteria_validator = EnumAttributeValidator.new('String', ["HigherThanBaseline", "LowerThanBaseline"]) return false unless success_criteria_validator.valid?(@success_criteria) unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["average", "sum"]) return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type) true end |