Class: LaunchDarklyApi::MetricPost

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/metric_post.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MetricPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
252
253
254
255
# File 'lib/launchdarkly_api/models/metric_post.rb', line 157

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricPost`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  else
    self.kind = nil
  end

  if attributes.key?(:'selector')
    self.selector = attributes[:'selector']
  end

  if attributes.key?(:'urls')
    if (value = attributes[:'urls']).is_a?(Array)
      self.urls = value
    end
  end

  if attributes.key?(:'is_numeric')
    self.is_numeric = attributes[:'is_numeric']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'event_key')
    self.event_key = attributes[:'event_key']
  end

  if attributes.key?(:'success_criteria')
    self.success_criteria = attributes[:'success_criteria']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'randomization_units')
    if (value = attributes[:'randomization_units']).is_a?(Array)
      self.randomization_units = value
    end
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'unit_aggregation_type')
    self.unit_aggregation_type = attributes[:'unit_aggregation_type']
  end

  if attributes.key?(:'analysis_type')
    self.analysis_type = attributes[:'analysis_type']
  end

  if attributes.key?(:'percentile_value')
    self.percentile_value = attributes[:'percentile_value']
  end

  if attributes.key?(:'event_default')
    self.event_default = attributes[:'event_default']
  end

  if attributes.key?(:'data_source')
    self.data_source = attributes[:'data_source']
  end

  if attributes.key?(:'filters')
    self.filters = attributes[:'filters']
  end
end

Instance Attribute Details

#analysis_typeObject

The method for analyzing metric events



61
62
63
# File 'lib/launchdarkly_api/models/metric_post.rb', line 61

def analysis_type
  @analysis_type
end

#data_sourceObject

Returns the value of attribute data_source.



68
69
70
# File 'lib/launchdarkly_api/models/metric_post.rb', line 68

def data_source
  @data_source
end

#descriptionObject

Description of the metric



25
26
27
# File 'lib/launchdarkly_api/models/metric_post.rb', line 25

def description
  @description
end

#event_defaultObject

Returns the value of attribute event_default.



66
67
68
# File 'lib/launchdarkly_api/models/metric_post.rb', line 66

def event_default
  @event_default
end

#event_keyObject

The event key to use in your code. Required for custom conversion/binary and custom numeric metrics only.



43
44
45
# File 'lib/launchdarkly_api/models/metric_post.rb', line 43

def event_key
  @event_key
end

#filtersObject

Returns the value of attribute filters.



70
71
72
# File 'lib/launchdarkly_api/models/metric_post.rb', line 70

def filters
  @filters
end

#is_numericObject

Whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false). Required for custom metrics only.



37
38
39
# File 'lib/launchdarkly_api/models/metric_post.rb', line 37

def is_numeric
  @is_numeric
end

#keyObject

A unique key to reference the metric



19
20
21
# File 'lib/launchdarkly_api/models/metric_post.rb', line 19

def key
  @key
end

#kindObject

The kind of event your metric will track



28
29
30
# File 'lib/launchdarkly_api/models/metric_post.rb', line 28

def kind
  @kind
end

#maintainer_idObject

The ID of the member who maintains this metric



55
56
57
# File 'lib/launchdarkly_api/models/metric_post.rb', line 55

def maintainer_id
  @maintainer_id
end

#nameObject

A human-friendly name for the metric



22
23
24
# File 'lib/launchdarkly_api/models/metric_post.rb', line 22

def name
  @name
end

#percentile_valueObject

The percentile for the analysis method. An integer denoting the target percentile between 0 and 100. Required when analysisType is percentile.



64
65
66
# File 'lib/launchdarkly_api/models/metric_post.rb', line 64

def percentile_value
  @percentile_value
end

#randomization_unitsObject

An array of randomization units allowed for this metric



52
53
54
# File 'lib/launchdarkly_api/models/metric_post.rb', line 52

def randomization_units
  @randomization_units
end

#selectorObject

One or more CSS selectors. Required for click metrics only.



31
32
33
# File 'lib/launchdarkly_api/models/metric_post.rb', line 31

def selector
  @selector
end

#success_criteriaObject

Success criteria. Required for custom numeric metrics, optional for custom conversion metrics.



46
47
48
# File 'lib/launchdarkly_api/models/metric_post.rb', line 46

def success_criteria
  @success_criteria
end

#tagsObject

Tags for the metric



49
50
51
# File 'lib/launchdarkly_api/models/metric_post.rb', line 49

def tags
  @tags
end

#unitObject

The unit of measure. Applicable for numeric custom metrics only.



40
41
42
# File 'lib/launchdarkly_api/models/metric_post.rb', line 40

def unit
  @unit
end

#unit_aggregation_typeObject

The method by which multiple unit event values are aggregated



58
59
60
# File 'lib/launchdarkly_api/models/metric_post.rb', line 58

def unit_aggregation_type
  @unit_aggregation_type
end

#urlsObject

One or more target URLs. Required for click and pageview metrics only.



34
35
36
# File 'lib/launchdarkly_api/models/metric_post.rb', line 34

def urls
  @urls
end

Class Method Details

._deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
404
405
406
407
408
409
410
411
412
413
414
415
416
417
418
419
420
# File 'lib/launchdarkly_api/models/metric_post.rb', line 383

def self._deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



120
121
122
# File 'lib/launchdarkly_api/models/metric_post.rb', line 120

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
# File 'lib/launchdarkly_api/models/metric_post.rb', line 95

def self.attribute_map
  {
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'kind' => :'kind',
    :'selector' => :'selector',
    :'urls' => :'urls',
    :'is_numeric' => :'isNumeric',
    :'unit' => :'unit',
    :'event_key' => :'eventKey',
    :'success_criteria' => :'successCriteria',
    :'tags' => :'tags',
    :'randomization_units' => :'randomizationUnits',
    :'maintainer_id' => :'maintainerId',
    :'unit_aggregation_type' => :'unitAggregationType',
    :'analysis_type' => :'analysisType',
    :'percentile_value' => :'percentileValue',
    :'event_default' => :'eventDefault',
    :'data_source' => :'dataSource',
    :'filters' => :'filters'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



359
360
361
362
363
364
365
366
367
368
369
370
371
372
373
374
375
376
377
# File 'lib/launchdarkly_api/models/metric_post.rb', line 359

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



150
151
152
153
# File 'lib/launchdarkly_api/models/metric_post.rb', line 150

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
# File 'lib/launchdarkly_api/models/metric_post.rb', line 125

def self.openapi_types
  {
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'kind' => :'String',
    :'selector' => :'String',
    :'urls' => :'Array<UrlPost>',
    :'is_numeric' => :'Boolean',
    :'unit' => :'String',
    :'event_key' => :'String',
    :'success_criteria' => :'String',
    :'tags' => :'Array<String>',
    :'randomization_units' => :'Array<String>',
    :'maintainer_id' => :'String',
    :'unit_aggregation_type' => :'String',
    :'analysis_type' => :'String',
    :'percentile_value' => :'Integer',
    :'event_default' => :'MetricEventDefaultRep',
    :'data_source' => :'MetricDataSourceRefRep',
    :'filters' => :'EventFilter'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



320
321
322
323
324
325
326
327
328
329
330
331
332
333
334
335
336
337
338
339
340
341
342
# File 'lib/launchdarkly_api/models/metric_post.rb', line 320

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      kind == o.kind &&
      selector == o.selector &&
      urls == o.urls &&
      is_numeric == o.is_numeric &&
      unit == o.unit &&
      event_key == o.event_key &&
      success_criteria == o.success_criteria &&
      tags == o.tags &&
      randomization_units == o.randomization_units &&
      maintainer_id == o.maintainer_id &&
      unit_aggregation_type == o.unit_aggregation_type &&
      analysis_type == o.analysis_type &&
      percentile_value == o.percentile_value &&
      event_default == o.event_default &&
      data_source == o.data_source &&
      filters == o.filters
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



454
455
456
457
458
459
460
461
462
463
464
465
466
# File 'lib/launchdarkly_api/models/metric_post.rb', line 454

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


346
347
348
# File 'lib/launchdarkly_api/models/metric_post.rb', line 346

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



352
353
354
# File 'lib/launchdarkly_api/models/metric_post.rb', line 352

def hash
  [key, name, description, kind, selector, urls, is_numeric, unit, event_key, success_criteria, tags, randomization_units, maintainer_id, unit_aggregation_type, analysis_type, percentile_value, event_default, data_source, filters].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



259
260
261
262
263
264
265
266
267
268
269
270
271
# File 'lib/launchdarkly_api/models/metric_post.rb', line 259

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



430
431
432
# File 'lib/launchdarkly_api/models/metric_post.rb', line 430

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



436
437
438
439
440
441
442
443
444
445
446
447
448
# File 'lib/launchdarkly_api/models/metric_post.rb', line 436

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



424
425
426
# File 'lib/launchdarkly_api/models/metric_post.rb', line 424

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



275
276
277
278
279
280
281
282
283
284
285
286
# File 'lib/launchdarkly_api/models/metric_post.rb', line 275

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @key.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom"])
  return false unless kind_validator.valid?(@kind)
  success_criteria_validator = EnumAttributeValidator.new('String', ["HigherThanBaseline", "LowerThanBaseline"])
  return false unless success_criteria_validator.valid?(@success_criteria)
  unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["average", "sum"])
  return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type)
  true
end