Class: LaunchDarklyApi::MetricPost

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/metric_post.rb

Defined Under Namespace

Classes: EnumAttributeValidator

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ MetricPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
216
217
218
219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
# File 'lib/launchdarkly_api/models/metric_post.rb', line 149

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricPost`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'description')
    self.description = attributes[:'description']
  end

  if attributes.key?(:'kind')
    self.kind = attributes[:'kind']
  end

  if attributes.key?(:'selector')
    self.selector = attributes[:'selector']
  end

  if attributes.key?(:'urls')
    if (value = attributes[:'urls']).is_a?(Array)
      self.urls = value
    end
  end

  if attributes.key?(:'is_active')
    self.is_active = attributes[:'is_active']
  end

  if attributes.key?(:'is_numeric')
    self.is_numeric = attributes[:'is_numeric']
  end

  if attributes.key?(:'unit')
    self.unit = attributes[:'unit']
  end

  if attributes.key?(:'event_key')
    self.event_key = attributes[:'event_key']
  end

  if attributes.key?(:'success_criteria')
    self.success_criteria = attributes[:'success_criteria']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'randomization_units')
    if (value = attributes[:'randomization_units']).is_a?(Array)
      self.randomization_units = value
    end
  end

  if attributes.key?(:'unit_aggregation_type')
    self.unit_aggregation_type = attributes[:'unit_aggregation_type']
  end

  if attributes.key?(:'analysis_type')
    self.analysis_type = attributes[:'analysis_type']
  end

  if attributes.key?(:'percentile_value')
    self.percentile_value = attributes[:'percentile_value']
  end

  if attributes.key?(:'event_default')
    self.event_default = attributes[:'event_default']
  end
end

Instance Attribute Details

#analysis_typeObject

The method for analyzing metric events



61
62
63
# File 'lib/launchdarkly_api/models/metric_post.rb', line 61

def analysis_type
  @analysis_type
end

#descriptionObject

Description of the metric



25
26
27
# File 'lib/launchdarkly_api/models/metric_post.rb', line 25

def description
  @description
end

#event_defaultObject

Returns the value of attribute event_default.



66
67
68
# File 'lib/launchdarkly_api/models/metric_post.rb', line 66

def event_default
  @event_default
end

#event_keyObject

The event key to use in your code. Required for custom conversion/binary and custom numeric metrics only.



46
47
48
# File 'lib/launchdarkly_api/models/metric_post.rb', line 46

def event_key
  @event_key
end

#is_activeObject

Whether the metric is active. Set to true to record click or pageview metrics. Not applicable for custom metrics.



37
38
39
# File 'lib/launchdarkly_api/models/metric_post.rb', line 37

def is_active
  @is_active
end

#is_numericObject

Whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false). Required for custom metrics only.



40
41
42
# File 'lib/launchdarkly_api/models/metric_post.rb', line 40

def is_numeric
  @is_numeric
end

#keyObject

A unique key to reference the metric



19
20
21
# File 'lib/launchdarkly_api/models/metric_post.rb', line 19

def key
  @key
end

#kindObject

The kind of event your metric will track



28
29
30
# File 'lib/launchdarkly_api/models/metric_post.rb', line 28

def kind
  @kind
end

#nameObject

A human-friendly name for the metric



22
23
24
# File 'lib/launchdarkly_api/models/metric_post.rb', line 22

def name
  @name
end

#percentile_valueObject

The percentile for the analysis method. An integer denoting the target percentile between 0 and 100. Required when analysisType is percentile.



64
65
66
# File 'lib/launchdarkly_api/models/metric_post.rb', line 64

def percentile_value
  @percentile_value
end

#randomization_unitsObject

An array of randomization units allowed for this metric



55
56
57
# File 'lib/launchdarkly_api/models/metric_post.rb', line 55

def randomization_units
  @randomization_units
end

#selectorObject

One or more CSS selectors. Required for click metrics only.



31
32
33
# File 'lib/launchdarkly_api/models/metric_post.rb', line 31

def selector
  @selector
end

#success_criteriaObject

Success criteria. Required for custom numeric metrics, optional for custom conversion metrics.



49
50
51
# File 'lib/launchdarkly_api/models/metric_post.rb', line 49

def success_criteria
  @success_criteria
end

#tagsObject

Tags for the metric



52
53
54
# File 'lib/launchdarkly_api/models/metric_post.rb', line 52

def tags
  @tags
end

#unitObject

The unit of measure. Applicable for numeric custom metrics only.



43
44
45
# File 'lib/launchdarkly_api/models/metric_post.rb', line 43

def unit
  @unit
end

#unit_aggregation_typeObject

The method by which multiple unit event values are aggregated



58
59
60
# File 'lib/launchdarkly_api/models/metric_post.rb', line 58

def unit_aggregation_type
  @unit_aggregation_type
end

#urlsObject

One or more target URLs. Required for click and pageview metrics only.



34
35
36
# File 'lib/launchdarkly_api/models/metric_post.rb', line 34

def urls
  @urls
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



114
115
116
# File 'lib/launchdarkly_api/models/metric_post.rb', line 114

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
# File 'lib/launchdarkly_api/models/metric_post.rb', line 91

def self.attribute_map
  {
    :'key' => :'key',
    :'name' => :'name',
    :'description' => :'description',
    :'kind' => :'kind',
    :'selector' => :'selector',
    :'urls' => :'urls',
    :'is_active' => :'isActive',
    :'is_numeric' => :'isNumeric',
    :'unit' => :'unit',
    :'event_key' => :'eventKey',
    :'success_criteria' => :'successCriteria',
    :'tags' => :'tags',
    :'randomization_units' => :'randomizationUnits',
    :'unit_aggregation_type' => :'unitAggregationType',
    :'analysis_type' => :'analysisType',
    :'percentile_value' => :'percentileValue',
    :'event_default' => :'eventDefault'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



335
336
337
# File 'lib/launchdarkly_api/models/metric_post.rb', line 335

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



142
143
144
145
# File 'lib/launchdarkly_api/models/metric_post.rb', line 142

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
# File 'lib/launchdarkly_api/models/metric_post.rb', line 119

def self.openapi_types
  {
    :'key' => :'String',
    :'name' => :'String',
    :'description' => :'String',
    :'kind' => :'String',
    :'selector' => :'String',
    :'urls' => :'Array<UrlPost>',
    :'is_active' => :'Boolean',
    :'is_numeric' => :'Boolean',
    :'unit' => :'String',
    :'event_key' => :'String',
    :'success_criteria' => :'String',
    :'tags' => :'Array<String>',
    :'randomization_units' => :'Array<String>',
    :'unit_aggregation_type' => :'String',
    :'analysis_type' => :'String',
    :'percentile_value' => :'Integer',
    :'event_default' => :'MetricEventDefaultRep'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



298
299
300
301
302
303
304
305
306
307
308
309
310
311
312
313
314
315
316
317
318
# File 'lib/launchdarkly_api/models/metric_post.rb', line 298

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      key == o.key &&
      name == o.name &&
      description == o.description &&
      kind == o.kind &&
      selector == o.selector &&
      urls == o.urls &&
      is_active == o.is_active &&
      is_numeric == o.is_numeric &&
      unit == o.unit &&
      event_key == o.event_key &&
      success_criteria == o.success_criteria &&
      tags == o.tags &&
      randomization_units == o.randomization_units &&
      unit_aggregation_type == o.unit_aggregation_type &&
      analysis_type == o.analysis_type &&
      percentile_value == o.percentile_value &&
      event_default == o.event_default
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



366
367
368
369
370
371
372
373
374
375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
394
395
396
397
398
399
400
401
402
403
# File 'lib/launchdarkly_api/models/metric_post.rb', line 366

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



437
438
439
440
441
442
443
444
445
446
447
448
449
# File 'lib/launchdarkly_api/models/metric_post.rb', line 437

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
359
360
# File 'lib/launchdarkly_api/models/metric_post.rb', line 342

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


322
323
324
# File 'lib/launchdarkly_api/models/metric_post.rb', line 322

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



328
329
330
# File 'lib/launchdarkly_api/models/metric_post.rb', line 328

def hash
  [key, name, description, kind, selector, urls, is_active, is_numeric, unit, event_key, success_criteria, tags, randomization_units, unit_aggregation_type, analysis_type, percentile_value, event_default].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



239
240
241
242
243
244
245
246
247
248
249
250
# File 'lib/launchdarkly_api/models/metric_post.rb', line 239

def list_invalid_properties
  invalid_properties = Array.new
  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @kind.nil?
    invalid_properties.push('invalid value for "kind", kind cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



413
414
415
# File 'lib/launchdarkly_api/models/metric_post.rb', line 413

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



419
420
421
422
423
424
425
426
427
428
429
430
431
# File 'lib/launchdarkly_api/models/metric_post.rb', line 419

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



407
408
409
# File 'lib/launchdarkly_api/models/metric_post.rb', line 407

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



254
255
256
257
258
259
260
261
262
263
264
# File 'lib/launchdarkly_api/models/metric_post.rb', line 254

def valid?
  return false if @key.nil?
  return false if @kind.nil?
  kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom"])
  return false unless kind_validator.valid?(@kind)
  success_criteria_validator = EnumAttributeValidator.new('String', ["HigherThanBaseline", "LowerThanBaseline"])
  return false unless success_criteria_validator.valid?(@success_criteria)
  unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["average", "sum"])
  return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type)
  true
end