Class: LaunchDarklyApi::MetricRep
- Inherits:
-
Object
- Object
- LaunchDarklyApi::MetricRep
- Defined in:
- lib/launchdarkly_api/models/metric_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_attached_features ⇒ Object
Details on the flags attached to this metric.
-
#_attached_flag_count ⇒ Object
The number of feature flags currently attached to this metric.
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_id ⇒ Object
The ID of this metric.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
-
#_site ⇒ Object
Returns the value of attribute _site.
-
#_version ⇒ Object
Version of the metric.
-
#_version_id ⇒ Object
The version ID of the metric.
-
#analysis_type ⇒ Object
The method for analyzing metric events.
-
#category ⇒ Object
The category of the metric.
-
#description ⇒ Object
Description of the metric.
-
#event_default ⇒ Object
Returns the value of attribute event_default.
-
#event_key ⇒ Object
For custom metrics, the event key to use in your code.
-
#experiment_count ⇒ Object
The number of experiments using this metric.
-
#experiments ⇒ Object
Returns the value of attribute experiments.
-
#is_active ⇒ Object
Whether the metric is active.
-
#is_numeric ⇒ Object
For custom metrics, whether to track numeric changes in value against a baseline (
true) or to track a conversion when an end user takes an action (false). -
#key ⇒ Object
A unique key to reference the metric.
-
#kind ⇒ Object
The kind of event the metric tracks.
-
#last_modified ⇒ Object
Returns the value of attribute last_modified.
-
#maintainer_id ⇒ Object
The ID of the member who maintains this metric.
-
#metric_group_count ⇒ Object
The number of metric groups using this metric.
-
#metric_groups ⇒ Object
Metric groups that use this metric.
-
#name ⇒ Object
A human-friendly name for the metric.
-
#percentile_value ⇒ Object
The percentile for the analysis method.
-
#randomization_units ⇒ Object
An array of randomization units allowed for this metric.
-
#selector ⇒ Object
For click metrics, the CSS selectors.
-
#success_criteria ⇒ Object
For custom metrics, the success criteria.
-
#tags ⇒ Object
Tags for the metric.
-
#unit ⇒ Object
For numeric custom metrics, the unit of measure.
-
#unit_aggregation_type ⇒ Object
The method by which multiple unit event values are aggregated.
-
#urls ⇒ Object
Returns the value of attribute urls.
Class Method Summary collapse
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
-
#build_from_hash(attributes) ⇒ Object
Builds the object from hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ MetricRep
Initializes the object
227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 227 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricRep`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'experiment_count') self.experiment_count = attributes[:'experiment_count'] end if attributes.key?(:'metric_group_count') self.metric_group_count = attributes[:'metric_group_count'] end if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'_version_id') self._version_id = attributes[:'_version_id'] end if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] end if attributes.key?(:'_attached_flag_count') self._attached_flag_count = attributes[:'_attached_flag_count'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end if attributes.key?(:'_site') self._site = attributes[:'_site'] end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] end if attributes.key?(:'last_modified') self.last_modified = attributes[:'last_modified'] end if attributes.key?(:'maintainer_id') self.maintainer_id = attributes[:'maintainer_id'] end if attributes.key?(:'_maintainer') self._maintainer = attributes[:'_maintainer'] end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'category') self.category = attributes[:'category'] end if attributes.key?(:'is_numeric') self.is_numeric = attributes[:'is_numeric'] end if attributes.key?(:'success_criteria') self.success_criteria = attributes[:'success_criteria'] end if attributes.key?(:'unit') self.unit = attributes[:'unit'] end if attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] end if attributes.key?(:'randomization_units') if (value = attributes[:'randomization_units']).is_a?(Array) self.randomization_units = value end end if attributes.key?(:'unit_aggregation_type') self.unit_aggregation_type = attributes[:'unit_aggregation_type'] end if attributes.key?(:'analysis_type') self.analysis_type = attributes[:'analysis_type'] end if attributes.key?(:'percentile_value') self.percentile_value = attributes[:'percentile_value'] end if attributes.key?(:'event_default') self.event_default = attributes[:'event_default'] end if attributes.key?(:'experiments') if (value = attributes[:'experiments']).is_a?(Array) self.experiments = value end end if attributes.key?(:'metric_groups') if (value = attributes[:'metric_groups']).is_a?(Array) self.metric_groups = value end end if attributes.key?(:'is_active') self.is_active = attributes[:'is_active'] end if attributes.key?(:'_attached_features') if (value = attributes[:'_attached_features']).is_a?(Array) self._attached_features = value end end if attributes.key?(:'_version') self._version = attributes[:'_version'] end if attributes.key?(:'selector') self.selector = attributes[:'selector'] end if attributes.key?(:'urls') if (value = attributes[:'urls']).is_a?(Array) self.urls = value end end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
47 48 49 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 47 def _access @_access end |
#_attached_features ⇒ Object
Details on the flags attached to this metric
102 103 104 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 102 def _attached_features @_attached_features end |
#_attached_flag_count ⇒ Object
The number of feature flags currently attached to this metric
40 41 42 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 40 def _attached_flag_count @_attached_flag_count end |
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
52 53 54 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 52 def _creation_date @_creation_date end |
#_id ⇒ Object
The ID of this metric
25 26 27 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 25 def _id @_id end |
#_links ⇒ Object
The location and content type of related resources
43 44 45 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 43 def _links @_links end |
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
59 60 61 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 59 def _maintainer @_maintainer end |
#_site ⇒ Object
Returns the value of attribute _site.
45 46 47 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 45 def _site @_site end |
#_version ⇒ Object
Version of the metric
105 106 107 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 105 def _version @_version end |
#_version_id ⇒ Object
The version ID of the metric
28 29 30 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 28 def _version_id @_version_id end |
#analysis_type ⇒ Object
The method for analyzing metric events
86 87 88 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 86 def analysis_type @analysis_type end |
#category ⇒ Object
The category of the metric
65 66 67 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 65 def category @category end |
#description ⇒ Object
Description of the metric
62 63 64 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 62 def description @description end |
#event_default ⇒ Object
Returns the value of attribute event_default.
91 92 93 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 91 def event_default @event_default end |
#event_key ⇒ Object
For custom metrics, the event key to use in your code
77 78 79 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 77 def event_key @event_key end |
#experiment_count ⇒ Object
The number of experiments using this metric
19 20 21 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 19 def experiment_count @experiment_count end |
#experiments ⇒ Object
Returns the value of attribute experiments.
93 94 95 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 93 def experiments @experiments end |
#is_active ⇒ Object
Whether the metric is active
99 100 101 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 99 def is_active @is_active end |
#is_numeric ⇒ Object
For custom metrics, whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false).
68 69 70 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 68 def is_numeric @is_numeric end |
#key ⇒ Object
A unique key to reference the metric
31 32 33 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 31 def key @key end |
#kind ⇒ Object
The kind of event the metric tracks
37 38 39 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 37 def kind @kind end |
#last_modified ⇒ Object
Returns the value of attribute last_modified.
54 55 56 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 54 def last_modified @last_modified end |
#maintainer_id ⇒ Object
The ID of the member who maintains this metric
57 58 59 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 57 def maintainer_id @maintainer_id end |
#metric_group_count ⇒ Object
The number of metric groups using this metric
22 23 24 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 22 def metric_group_count @metric_group_count end |
#metric_groups ⇒ Object
Metric groups that use this metric
96 97 98 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 96 def metric_groups @metric_groups end |
#name ⇒ Object
A human-friendly name for the metric
34 35 36 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 34 def name @name end |
#percentile_value ⇒ Object
The percentile for the analysis method. An integer denoting the target percentile between 0 and 100. Required when analysisType is percentile.
89 90 91 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 89 def percentile_value @percentile_value end |
#randomization_units ⇒ Object
An array of randomization units allowed for this metric
80 81 82 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 80 def randomization_units @randomization_units end |
#selector ⇒ Object
For click metrics, the CSS selectors
108 109 110 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 108 def selector @selector end |
#success_criteria ⇒ Object
For custom metrics, the success criteria
71 72 73 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 71 def success_criteria @success_criteria end |
#tags ⇒ Object
Tags for the metric
50 51 52 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 50 def @tags end |
#unit ⇒ Object
For numeric custom metrics, the unit of measure
74 75 76 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 74 def unit @unit end |
#unit_aggregation_type ⇒ Object
The method by which multiple unit event values are aggregated
83 84 85 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 83 def unit_aggregation_type @unit_aggregation_type end |
#urls ⇒ Object
Returns the value of attribute urls.
110 111 112 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 110 def urls @urls end |
Class Method Details
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
175 176 177 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 175 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 135 def self.attribute_map { :'experiment_count' => :'experimentCount', :'metric_group_count' => :'metricGroupCount', :'_id' => :'_id', :'_version_id' => :'_versionId', :'key' => :'key', :'name' => :'name', :'kind' => :'kind', :'_attached_flag_count' => :'_attachedFlagCount', :'_links' => :'_links', :'_site' => :'_site', :'_access' => :'_access', :'tags' => :'tags', :'_creation_date' => :'_creationDate', :'last_modified' => :'lastModified', :'maintainer_id' => :'maintainerId', :'_maintainer' => :'_maintainer', :'description' => :'description', :'category' => :'category', :'is_numeric' => :'isNumeric', :'success_criteria' => :'successCriteria', :'unit' => :'unit', :'event_key' => :'eventKey', :'randomization_units' => :'randomizationUnits', :'unit_aggregation_type' => :'unitAggregationType', :'analysis_type' => :'analysisType', :'percentile_value' => :'percentileValue', :'event_default' => :'eventDefault', :'experiments' => :'experiments', :'metric_groups' => :'metricGroups', :'is_active' => :'isActive', :'_attached_features' => :'_attachedFeatures', :'_version' => :'_version', :'selector' => :'selector', :'urls' => :'urls' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
548 549 550 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 548 def self.build_from_hash(attributes) new.build_from_hash(attributes) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
220 221 222 223 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 220 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 180 def self.openapi_types { :'experiment_count' => :'Integer', :'metric_group_count' => :'Integer', :'_id' => :'String', :'_version_id' => :'String', :'key' => :'String', :'name' => :'String', :'kind' => :'String', :'_attached_flag_count' => :'Integer', :'_links' => :'Hash<String, Link>', :'_site' => :'Link', :'_access' => :'Access', :'tags' => :'Array<String>', :'_creation_date' => :'Integer', :'last_modified' => :'Modification', :'maintainer_id' => :'String', :'_maintainer' => :'MemberSummary', :'description' => :'String', :'category' => :'String', :'is_numeric' => :'Boolean', :'success_criteria' => :'String', :'unit' => :'String', :'event_key' => :'String', :'randomization_units' => :'Array<String>', :'unit_aggregation_type' => :'String', :'analysis_type' => :'String', :'percentile_value' => :'Integer', :'event_default' => :'MetricEventDefaultRep', :'experiments' => :'Array<DependentExperimentRep>', :'metric_groups' => :'Array<DependentMetricGroupRep>', :'is_active' => :'Boolean', :'_attached_features' => :'Array<FlagListingRep>', :'_version' => :'Integer', :'selector' => :'String', :'urls' => :'Array<Hash>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
494 495 496 497 498 499 500 501 502 503 504 505 506 507 508 509 510 511 512 513 514 515 516 517 518 519 520 521 522 523 524 525 526 527 528 529 530 531 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 494 def ==(o) return true if self.equal?(o) self.class == o.class && experiment_count == o.experiment_count && metric_group_count == o.metric_group_count && _id == o._id && _version_id == o._version_id && key == o.key && name == o.name && kind == o.kind && _attached_flag_count == o._attached_flag_count && _links == o._links && _site == o._site && _access == o._access && == o. && _creation_date == o._creation_date && last_modified == o.last_modified && maintainer_id == o.maintainer_id && _maintainer == o._maintainer && description == o.description && category == o.category && is_numeric == o.is_numeric && success_criteria == o.success_criteria && unit == o.unit && event_key == o.event_key && randomization_units == o.randomization_units && unit_aggregation_type == o.unit_aggregation_type && analysis_type == o.analysis_type && percentile_value == o.percentile_value && event_default == o.event_default && experiments == o.experiments && metric_groups == o.metric_groups && is_active == o.is_active && _attached_features == o._attached_features && _version == o._version && selector == o.selector && urls == o.urls end |
#_deserialize(type, value) ⇒ Object
Deserializes the data based on type
579 580 581 582 583 584 585 586 587 588 589 590 591 592 593 594 595 596 597 598 599 600 601 602 603 604 605 606 607 608 609 610 611 612 613 614 615 616 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 579 def _deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
650 651 652 653 654 655 656 657 658 659 660 661 662 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 650 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#build_from_hash(attributes) ⇒ Object
Builds the object from hash
555 556 557 558 559 560 561 562 563 564 565 566 567 568 569 570 571 572 573 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 555 def build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) self.class.openapi_types.each_pair do |key, type| if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key) self.send("#{key}=", nil) elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[self.class.attribute_map[key]].is_a?(Array) self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) }) end elsif !attributes[self.class.attribute_map[key]].nil? self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]])) end end self end |
#eql?(o) ⇒ Boolean
535 536 537 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 535 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
541 542 543 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 541 def hash [experiment_count, metric_group_count, _id, _version_id, key, name, kind, _attached_flag_count, _links, _site, _access, , _creation_date, last_modified, maintainer_id, _maintainer, description, category, is_numeric, success_criteria, unit, event_key, randomization_units, unit_aggregation_type, analysis_type, percentile_value, event_default, experiments, metric_groups, is_active, _attached_features, _version, selector, urls].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 426 427 428 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 393 def list_invalid_properties invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_version_id.nil? invalid_properties.push('invalid value for "_version_id", _version_id cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end if @tags.nil? invalid_properties.push('invalid value for "tags", tags cannot be nil.') end if @_creation_date.nil? invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
626 627 628 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 626 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
632 633 634 635 636 637 638 639 640 641 642 643 644 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 632 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
620 621 622 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 620 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 |
# File 'lib/launchdarkly_api/models/metric_rep.rb', line 432 def valid? return false if @_id.nil? return false if @_version_id.nil? return false if @key.nil? return false if @name.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom"]) return false unless kind_validator.valid?(@kind) return false if @_links.nil? return false if @tags.nil? return false if @_creation_date.nil? success_criteria_validator = EnumAttributeValidator.new('String', ["HigherThanBaseline", "LowerThanBaseline"]) return false unless success_criteria_validator.valid?(@success_criteria) unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["average", "sum"]) return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type) analysis_type_validator = EnumAttributeValidator.new('String', ["mean", "percentile"]) return false unless analysis_type_validator.valid?(@analysis_type) true end |