Class: LaunchDarklyApi::MetricV2Rep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::MetricV2Rep
- Defined in:
- lib/launchdarkly_api/models/metric_v2_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_links ⇒ Object
The location and content type of related resources.
-
#_version_id ⇒ Object
The version ID of the metric.
-
#event_key ⇒ Object
The event key sent with the metric.
-
#is_numeric ⇒ Object
For custom metrics, whether to track numeric changes in value against a baseline (
true) or to track a conversion when an end user takes an action (false). -
#key ⇒ Object
The metric key.
-
#kind ⇒ Object
The kind of event the metric tracks.
-
#name ⇒ Object
The metric name.
-
#unit_aggregation_type ⇒ Object
The type of unit aggregation to use for the metric.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ MetricV2Rep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ MetricV2Rep
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::MetricV2Rep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::MetricV2Rep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'_version_id') self._version_id = attributes[:'_version_id'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'is_numeric') self.is_numeric = attributes[:'is_numeric'] end if attributes.key?(:'unit_aggregation_type') self.unit_aggregation_type = attributes[:'unit_aggregation_type'] end if attributes.key?(:'event_key') self.event_key = attributes[:'event_key'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end else self._links = nil end end |
Instance Attribute Details
#_links ⇒ Object
The location and content type of related resources
40 41 42 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 40 def _links @_links end |
#_version_id ⇒ Object
The version ID of the metric
22 23 24 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 22 def _version_id @_version_id end |
#event_key ⇒ Object
The event key sent with the metric. Only relevant for custom metrics.
37 38 39 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 37 def event_key @event_key end |
#is_numeric ⇒ Object
For custom metrics, whether to track numeric changes in value against a baseline (true) or to track a conversion when an end user takes an action (false).
31 32 33 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 31 def is_numeric @is_numeric end |
#key ⇒ Object
The metric key
19 20 21 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 19 def key @key end |
#kind ⇒ Object
The kind of event the metric tracks
28 29 30 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 28 def kind @kind end |
#name ⇒ Object
The metric name
25 26 27 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 25 def name @name end |
#unit_aggregation_type ⇒ Object
The type of unit aggregation to use for the metric
34 35 36 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 34 def unit_aggregation_type @unit_aggregation_type end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
79 80 81 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 79 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
84 85 86 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 84 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 65 def self.attribute_map { :'key' => :'key', :'_version_id' => :'_versionId', :'name' => :'name', :'kind' => :'kind', :'is_numeric' => :'isNumeric', :'unit_aggregation_type' => :'unitAggregationType', :'event_key' => :'eventKey', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 286 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 89 def self.openapi_types { :'key' => :'String', :'_version_id' => :'String', :'name' => :'String', :'kind' => :'String', :'is_numeric' => :'Boolean', :'unit_aggregation_type' => :'String', :'event_key' => :'String', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
258 259 260 261 262 263 264 265 266 267 268 269 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 258 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && _version_id == o._version_id && name == o.name && kind == o.kind && is_numeric == o.is_numeric && unit_aggregation_type == o.unit_aggregation_type && event_key == o.event_key && _links == o._links end |
#eql?(o) ⇒ Boolean
273 274 275 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 273 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
279 280 281 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 279 def hash [key, _version_id, name, kind, is_numeric, unit_aggregation_type, event_key, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 169 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @_links.nil? invalid_properties.push('invalid value for "_links", _links cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
308 309 310 311 312 313 314 315 316 317 318 319 320 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 308 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
193 194 195 196 197 198 199 200 201 202 203 204 |
# File 'lib/launchdarkly_api/models/metric_v2_rep.rb', line 193 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["pageview", "click", "custom"]) return false unless kind_validator.valid?(@kind) unit_aggregation_type_validator = EnumAttributeValidator.new('String', ["sum", "average"]) return false unless unit_aggregation_type_validator.valid?(@unit_aggregation_type) return false if @_links.nil? true end |