Class: LaunchDarklyApi::ModelConfig

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/model_config.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelConfig

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
202
203
204
205
206
207
208
209
210
211
212
213
214
215
# File 'lib/launchdarkly_api/models/model_config.rb', line 122

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ModelConfig` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ModelConfig`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_access')
    self._access = attributes[:'_access']
  end

  if attributes.key?(:'_maintainer')
    self._maintainer = attributes[:'_maintainer']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'global')
    self.global = attributes[:'global']
  else
    self.global = nil
  end

  if attributes.key?(:'params')
    self.params = attributes[:'params']
  end

  if attributes.key?(:'custom_params')
    self.custom_params = attributes[:'custom_params']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  else
    self.tags = nil
  end

  if attributes.key?(:'version')
    self.version = attributes[:'version']
  else
    self.version = nil
  end

  if attributes.key?(:'cost_per_input_token')
    self.cost_per_input_token = attributes[:'cost_per_input_token']
  end

  if attributes.key?(:'cost_per_output_token')
    self.cost_per_output_token = attributes[:'cost_per_output_token']
  end

  if attributes.key?(:'cost_per_cached_input_token')
    self.cost_per_cached_input_token = attributes[:'cost_per_cached_input_token']
  end

  if attributes.key?(:'is_restricted')
    self.is_restricted = attributes[:'is_restricted']
  else
    self.is_restricted = nil
  end
end

Instance Attribute Details

#_accessObject

Returns the value of attribute _access.



18
19
20
# File 'lib/launchdarkly_api/models/model_config.rb', line 18

def _access
  @_access
end

#_maintainerObject

Returns the value of attribute _maintainer.



20
21
22
# File 'lib/launchdarkly_api/models/model_config.rb', line 20

def _maintainer
  @_maintainer
end

#cost_per_cached_input_tokenObject

Cost per cached input token in USD



55
56
57
# File 'lib/launchdarkly_api/models/model_config.rb', line 55

def cost_per_cached_input_token
  @cost_per_cached_input_token
end

#cost_per_input_tokenObject

Cost per input token in USD



49
50
51
# File 'lib/launchdarkly_api/models/model_config.rb', line 49

def cost_per_input_token
  @cost_per_input_token
end

#cost_per_output_tokenObject

Cost per output token in USD



52
53
54
# File 'lib/launchdarkly_api/models/model_config.rb', line 52

def cost_per_output_token
  @cost_per_output_token
end

#custom_paramsObject

Returns the value of attribute custom_params.



42
43
44
# File 'lib/launchdarkly_api/models/model_config.rb', line 42

def custom_params
  @custom_params
end

#globalObject

Whether the model is global



38
39
40
# File 'lib/launchdarkly_api/models/model_config.rb', line 38

def global
  @global
end

#iconObject

Icon for the model



32
33
34
# File 'lib/launchdarkly_api/models/model_config.rb', line 32

def icon
  @icon
end

#idObject

Identifier for the model, for use with third party providers



29
30
31
# File 'lib/launchdarkly_api/models/model_config.rb', line 29

def id
  @id
end

#is_restrictedObject

Whether the model is restricted



58
59
60
# File 'lib/launchdarkly_api/models/model_config.rb', line 58

def is_restricted
  @is_restricted
end

#keyObject

Unique key for the model



26
27
28
# File 'lib/launchdarkly_api/models/model_config.rb', line 26

def key
  @key
end

#nameObject

Human-readable name of the model



23
24
25
# File 'lib/launchdarkly_api/models/model_config.rb', line 23

def name
  @name
end

#paramsObject

Returns the value of attribute params.



40
41
42
# File 'lib/launchdarkly_api/models/model_config.rb', line 40

def params
  @params
end

#providerObject

Provider for the model



35
36
37
# File 'lib/launchdarkly_api/models/model_config.rb', line 35

def provider
  @provider
end

#tagsObject

Returns the value of attribute tags.



44
45
46
# File 'lib/launchdarkly_api/models/model_config.rb', line 44

def tags
  @tags
end

#versionObject

Returns the value of attribute version.



46
47
48
# File 'lib/launchdarkly_api/models/model_config.rb', line 46

def version
  @version
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



83
84
85
# File 'lib/launchdarkly_api/models/model_config.rb', line 83

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



88
89
90
# File 'lib/launchdarkly_api/models/model_config.rb', line 88

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



61
62
63
64
65
66
67
68
69
70
71
72
73
74
75
76
77
78
79
80
# File 'lib/launchdarkly_api/models/model_config.rb', line 61

def self.attribute_map
  {
    :'_access' => :'_access',
    :'_maintainer' => :'_maintainer',
    :'name' => :'name',
    :'key' => :'key',
    :'id' => :'id',
    :'icon' => :'icon',
    :'provider' => :'provider',
    :'global' => :'global',
    :'params' => :'params',
    :'custom_params' => :'customParams',
    :'tags' => :'tags',
    :'version' => :'version',
    :'cost_per_input_token' => :'costPerInputToken',
    :'cost_per_output_token' => :'costPerOutputToken',
    :'cost_per_cached_input_token' => :'costPerCachedInputToken',
    :'is_restricted' => :'isRestricted'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



375
376
377
378
379
380
381
382
383
384
385
386
387
388
389
390
391
392
393
# File 'lib/launchdarkly_api/models/model_config.rb', line 375

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



115
116
117
118
# File 'lib/launchdarkly_api/models/model_config.rb', line 115

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
# File 'lib/launchdarkly_api/models/model_config.rb', line 93

def self.openapi_types
  {
    :'_access' => :'AiConfigsAccess',
    :'_maintainer' => :'AIConfigMaintainer',
    :'name' => :'String',
    :'key' => :'String',
    :'id' => :'String',
    :'icon' => :'String',
    :'provider' => :'String',
    :'global' => :'Boolean',
    :'params' => :'Object',
    :'custom_params' => :'Object',
    :'tags' => :'Array<String>',
    :'version' => :'Integer',
    :'cost_per_input_token' => :'Float',
    :'cost_per_output_token' => :'Float',
    :'cost_per_cached_input_token' => :'Float',
    :'is_restricted' => :'Boolean'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



339
340
341
342
343
344
345
346
347
348
349
350
351
352
353
354
355
356
357
358
# File 'lib/launchdarkly_api/models/model_config.rb', line 339

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _access == o._access &&
      _maintainer == o._maintainer &&
      name == o.name &&
      key == o.key &&
      id == o.id &&
      icon == o.icon &&
      provider == o.provider &&
      global == o.global &&
      params == o.params &&
      custom_params == o.custom_params &&
      tags == o.tags &&
      version == o.version &&
      cost_per_input_token == o.cost_per_input_token &&
      cost_per_output_token == o.cost_per_output_token &&
      cost_per_cached_input_token == o.cost_per_cached_input_token &&
      is_restricted == o.is_restricted
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


362
363
364
# File 'lib/launchdarkly_api/models/model_config.rb', line 362

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



368
369
370
# File 'lib/launchdarkly_api/models/model_config.rb', line 368

def hash
  [_access, _maintainer, name, key, id, icon, provider, global, params, custom_params, tags, version, cost_per_input_token, cost_per_output_token, cost_per_cached_input_token, is_restricted].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



219
220
221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
244
245
246
247
248
249
250
251
# File 'lib/launchdarkly_api/models/model_config.rb', line 219

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  if @global.nil?
    invalid_properties.push('invalid value for "global", global cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  if @version.nil?
    invalid_properties.push('invalid value for "version", version cannot be nil.')
  end

  if @is_restricted.nil?
    invalid_properties.push('invalid value for "is_restricted", is_restricted cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



397
398
399
400
401
402
403
404
405
406
407
408
409
# File 'lib/launchdarkly_api/models/model_config.rb', line 397

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



255
256
257
258
259
260
261
262
263
264
265
# File 'lib/launchdarkly_api/models/model_config.rb', line 255

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @key.nil?
  return false if @id.nil?
  return false if @global.nil?
  return false if @tags.nil?
  return false if @version.nil?
  return false if @is_restricted.nil?
  true
end