Class: LaunchDarklyApi::ModelConfigPost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/model_config_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelConfigPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
170
171
172
173
174
175
176
177
178
179
180
181
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 108

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ModelConfigPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ModelConfigPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'maintainer_id')
    self.maintainer_id = attributes[:'maintainer_id']
  end

  if attributes.key?(:'maintainer_team_key')
    self.maintainer_team_key = attributes[:'maintainer_team_key']
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'params')
    self.params = attributes[:'params']
  end

  if attributes.key?(:'custom_params')
    self.custom_params = attributes[:'custom_params']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'cost_per_input_token')
    self.cost_per_input_token = attributes[:'cost_per_input_token']
  end

  if attributes.key?(:'cost_per_output_token')
    self.cost_per_output_token = attributes[:'cost_per_output_token']
  end

  if attributes.key?(:'cost_per_cached_input_token')
    self.cost_per_cached_input_token = attributes[:'cost_per_cached_input_token']
  end
end

Instance Attribute Details

#cost_per_cached_input_tokenObject

Cost per cached input token in USD



50
51
52
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 50

def cost_per_cached_input_token
  @cost_per_cached_input_token
end

#cost_per_input_tokenObject

Cost per input token in USD



44
45
46
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 44

def cost_per_input_token
  @cost_per_input_token
end

#cost_per_output_tokenObject

Cost per output token in USD



47
48
49
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 47

def cost_per_output_token
  @cost_per_output_token
end

#custom_paramsObject

Returns the value of attribute custom_params.



39
40
41
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 39

def custom_params
  @custom_params
end

#iconObject

Icon for the model



32
33
34
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 32

def icon
  @icon
end

#idObject

Identifier for the model, for use with third party providers



25
26
27
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 25

def id
  @id
end

#keyObject

Unique key for the model



22
23
24
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 22

def key
  @key
end

#maintainer_idObject

Returns the value of attribute maintainer_id.



27
28
29
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 27

def maintainer_id
  @maintainer_id
end

#maintainer_team_keyObject

Returns the value of attribute maintainer_team_key.



29
30
31
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 29

def maintainer_team_key
  @maintainer_team_key
end

#nameObject

Human readable name of the model



19
20
21
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 19

def name
  @name
end

#paramsObject

Returns the value of attribute params.



37
38
39
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 37

def params
  @params
end

#providerObject

Provider for the model



35
36
37
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 35

def provider
  @provider
end

#tagsObject

Returns the value of attribute tags.



41
42
43
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 41

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



72
73
74
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 72

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



77
78
79
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 77

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



53
54
55
56
57
58
59
60
61
62
63
64
65
66
67
68
69
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 53

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'id' => :'id',
    :'maintainer_id' => :'maintainerId',
    :'maintainer_team_key' => :'maintainerTeamKey',
    :'icon' => :'icon',
    :'provider' => :'provider',
    :'params' => :'params',
    :'custom_params' => :'customParams',
    :'tags' => :'tags',
    :'cost_per_input_token' => :'costPerInputToken',
    :'cost_per_output_token' => :'costPerOutputToken',
    :'cost_per_cached_input_token' => :'costPerCachedInputToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



278
279
280
281
282
283
284
285
286
287
288
289
290
291
292
293
294
295
296
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 278

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



101
102
103
104
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 101

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



82
83
84
85
86
87
88
89
90
91
92
93
94
95
96
97
98
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 82

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'id' => :'String',
    :'maintainer_id' => :'String',
    :'maintainer_team_key' => :'String',
    :'icon' => :'String',
    :'provider' => :'String',
    :'params' => :'Object',
    :'custom_params' => :'Object',
    :'tags' => :'Array<String>',
    :'cost_per_input_token' => :'Float',
    :'cost_per_output_token' => :'Float',
    :'cost_per_cached_input_token' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 245

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      id == o.id &&
      maintainer_id == o.maintainer_id &&
      maintainer_team_key == o.maintainer_team_key &&
      icon == o.icon &&
      provider == o.provider &&
      params == o.params &&
      custom_params == o.custom_params &&
      tags == o.tags &&
      cost_per_input_token == o.cost_per_input_token &&
      cost_per_output_token == o.cost_per_output_token &&
      cost_per_cached_input_token == o.cost_per_cached_input_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


265
266
267
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 265

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



271
272
273
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 271

def hash
  [name, key, id, maintainer_id, maintainer_team_key, icon, provider, params, custom_params, tags, cost_per_input_token, cost_per_output_token, cost_per_cached_input_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



185
186
187
188
189
190
191
192
193
194
195
196
197
198
199
200
201
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 185

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



300
301
302
303
304
305
306
307
308
309
310
311
312
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 300

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



205
206
207
208
209
210
211
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 205

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @key.nil?
  return false if @id.nil?
  true
end