Class: LaunchDarklyApi::ModelConfigPost

Inherits:
ApiModelBase show all
Defined in:
lib/launchdarkly_api/models/model_config_post.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Methods inherited from ApiModelBase

_deserialize, #_to_hash, #to_body, #to_s

Constructor Details

#initialize(attributes = {}) ⇒ ModelConfigPost

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
139
140
141
142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 100

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ModelConfigPost` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  acceptable_attribute_map = self.class.acceptable_attribute_map
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!acceptable_attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ModelConfigPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  else
    self.name = nil
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  else
    self.key = nil
  end

  if attributes.key?(:'id')
    self.id = attributes[:'id']
  else
    self.id = nil
  end

  if attributes.key?(:'icon')
    self.icon = attributes[:'icon']
  end

  if attributes.key?(:'provider')
    self.provider = attributes[:'provider']
  end

  if attributes.key?(:'params')
    self.params = attributes[:'params']
  end

  if attributes.key?(:'custom_params')
    self.custom_params = attributes[:'custom_params']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'cost_per_input_token')
    self.cost_per_input_token = attributes[:'cost_per_input_token']
  end

  if attributes.key?(:'cost_per_output_token')
    self.cost_per_output_token = attributes[:'cost_per_output_token']
  end

  if attributes.key?(:'cost_per_cached_input_token')
    self.cost_per_cached_input_token = attributes[:'cost_per_cached_input_token']
  end
end

Instance Attribute Details

#cost_per_cached_input_tokenObject

Cost per cached input token in USD



46
47
48
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 46

def cost_per_cached_input_token
  @cost_per_cached_input_token
end

#cost_per_input_tokenObject

Cost per input token in USD



40
41
42
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 40

def cost_per_input_token
  @cost_per_input_token
end

#cost_per_output_tokenObject

Cost per output token in USD



43
44
45
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 43

def cost_per_output_token
  @cost_per_output_token
end

#custom_paramsObject

Returns the value of attribute custom_params.



35
36
37
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 35

def custom_params
  @custom_params
end

#iconObject

Icon for the model



28
29
30
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 28

def icon
  @icon
end

#idObject

Identifier for the model, for use with third party providers



25
26
27
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 25

def id
  @id
end

#keyObject

Unique key for the model



22
23
24
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 22

def key
  @key
end

#nameObject

Human readable name of the model



19
20
21
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 19

def name
  @name
end

#paramsObject

Returns the value of attribute params.



33
34
35
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 33

def params
  @params
end

#providerObject

Provider for the model



31
32
33
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 31

def provider
  @provider
end

#tagsObject

Returns the value of attribute tags.



37
38
39
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 37

def tags
  @tags
end

Class Method Details

.acceptable_attribute_mapObject

Returns attribute mapping this model knows about



66
67
68
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 66

def self.acceptable_attribute_map
  attribute_map
end

.acceptable_attributesObject

Returns all the JSON keys this model knows about



71
72
73
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 71

def self.acceptable_attributes
  acceptable_attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



49
50
51
52
53
54
55
56
57
58
59
60
61
62
63
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 49

def self.attribute_map
  {
    :'name' => :'name',
    :'key' => :'key',
    :'id' => :'id',
    :'icon' => :'icon',
    :'provider' => :'provider',
    :'params' => :'params',
    :'custom_params' => :'customParams',
    :'tags' => :'tags',
    :'cost_per_input_token' => :'costPerInputToken',
    :'cost_per_output_token' => :'costPerOutputToken',
    :'cost_per_cached_input_token' => :'costPerCachedInputToken'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 260

def self.build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  transformed_hash = {}
  openapi_types.each_pair do |key, type|
    if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = nil
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[attribute_map[key]].is_a?(Array)
        transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) }
      end
    elsif !attributes[attribute_map[key]].nil?
      transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]])
    end
  end
  new(transformed_hash)
end

.openapi_nullableObject

List of attributes with nullable: true



93
94
95
96
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 93

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



76
77
78
79
80
81
82
83
84
85
86
87
88
89
90
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 76

def self.openapi_types
  {
    :'name' => :'String',
    :'key' => :'String',
    :'id' => :'String',
    :'icon' => :'String',
    :'provider' => :'String',
    :'params' => :'Object',
    :'custom_params' => :'Object',
    :'tags' => :'Array<String>',
    :'cost_per_input_token' => :'Float',
    :'cost_per_output_token' => :'Float',
    :'cost_per_cached_input_token' => :'Float'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



229
230
231
232
233
234
235
236
237
238
239
240
241
242
243
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 229

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      name == o.name &&
      key == o.key &&
      id == o.id &&
      icon == o.icon &&
      provider == o.provider &&
      params == o.params &&
      custom_params == o.custom_params &&
      tags == o.tags &&
      cost_per_input_token == o.cost_per_input_token &&
      cost_per_output_token == o.cost_per_output_token &&
      cost_per_cached_input_token == o.cost_per_cached_input_token
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


247
248
249
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 247

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



253
254
255
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 253

def hash
  [name, key, id, icon, provider, params, custom_params, tags, cost_per_input_token, cost_per_output_token, cost_per_cached_input_token].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



169
170
171
172
173
174
175
176
177
178
179
180
181
182
183
184
185
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 169

def list_invalid_properties
  warn '[DEPRECATED] the `list_invalid_properties` method is obsolete'
  invalid_properties = Array.new
  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @id.nil?
    invalid_properties.push('invalid value for "id", id cannot be nil.')
  end

  invalid_properties
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



282
283
284
285
286
287
288
289
290
291
292
293
294
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 282

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



189
190
191
192
193
194
195
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 189

def valid?
  warn '[DEPRECATED] the `valid?` method is obsolete'
  return false if @name.nil?
  return false if @key.nil?
  return false if @id.nil?
  true
end