Class: LaunchDarklyApi::ModelConfigPost
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ModelConfigPost
- Defined in:
- lib/launchdarkly_api/models/model_config_post.rb
Instance Attribute Summary collapse
-
#cost_per_input_token ⇒ Object
Cost per input token in USD.
-
#cost_per_output_token ⇒ Object
Cost per output token in USD.
-
#custom_params ⇒ Object
Returns the value of attribute custom_params.
-
#icon ⇒ Object
Icon for the model.
-
#id ⇒ Object
Identifier for the model, for use with third party providers.
-
#key ⇒ Object
Unique key for the model.
-
#name ⇒ Object
Human readable name of the model.
-
#params ⇒ Object
Returns the value of attribute params.
-
#provider ⇒ Object
Provider for the model.
-
#tags ⇒ Object
Returns the value of attribute tags.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ModelConfigPost
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ModelConfigPost
Initializes the object
95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 95 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ModelConfigPost` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ModelConfigPost`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'icon') self.icon = attributes[:'icon'] end if attributes.key?(:'provider') self.provider = attributes[:'provider'] end if attributes.key?(:'params') self.params = attributes[:'params'] end if attributes.key?(:'custom_params') self.custom_params = attributes[:'custom_params'] end if attributes.key?(:'tags') if (value = attributes[:'tags']).is_a?(Array) self. = value end end if attributes.key?(:'cost_per_input_token') self.cost_per_input_token = attributes[:'cost_per_input_token'] end if attributes.key?(:'cost_per_output_token') self.cost_per_output_token = attributes[:'cost_per_output_token'] end end |
Instance Attribute Details
#cost_per_input_token ⇒ Object
Cost per input token in USD
40 41 42 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 40 def cost_per_input_token @cost_per_input_token end |
#cost_per_output_token ⇒ Object
Cost per output token in USD
43 44 45 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 43 def cost_per_output_token @cost_per_output_token end |
#custom_params ⇒ Object
Returns the value of attribute custom_params.
35 36 37 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 35 def custom_params @custom_params end |
#icon ⇒ Object
Icon for the model
28 29 30 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 28 def icon @icon end |
#id ⇒ Object
Identifier for the model, for use with third party providers
25 26 27 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 25 def id @id end |
#key ⇒ Object
Unique key for the model
22 23 24 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 22 def key @key end |
#name ⇒ Object
Human readable name of the model
19 20 21 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 19 def name @name end |
#params ⇒ Object
Returns the value of attribute params.
33 34 35 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 33 def params @params end |
#provider ⇒ Object
Provider for the model
31 32 33 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 31 def provider @provider end |
#tags ⇒ Object
Returns the value of attribute tags.
37 38 39 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 37 def @tags end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
62 63 64 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 62 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
67 68 69 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 67 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 46 def self.attribute_map { :'name' => :'name', :'key' => :'key', :'id' => :'id', :'icon' => :'icon', :'provider' => :'provider', :'params' => :'params', :'custom_params' => :'customParams', :'tags' => :'tags', :'cost_per_input_token' => :'costPerInputToken', :'cost_per_output_token' => :'costPerOutputToken' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 250 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
88 89 90 91 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 88 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 72 def self.openapi_types { :'name' => :'String', :'key' => :'String', :'id' => :'String', :'icon' => :'String', :'provider' => :'String', :'params' => :'Object', :'custom_params' => :'Object', :'tags' => :'Array<String>', :'cost_per_input_token' => :'Float', :'cost_per_output_token' => :'Float' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 220 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && key == o.key && id == o.id && icon == o.icon && provider == o.provider && params == o.params && custom_params == o.custom_params && == o. && cost_per_input_token == o.cost_per_input_token && cost_per_output_token == o.cost_per_output_token end |
#eql?(o) ⇒ Boolean
237 238 239 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 237 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
243 244 245 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 243 def hash [name, key, id, icon, provider, params, custom_params, , cost_per_input_token, cost_per_output_token].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 160 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 272 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
180 181 182 183 184 185 186 |
# File 'lib/launchdarkly_api/models/model_config_post.rb', line 180 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @name.nil? return false if @key.nil? return false if @id.nil? true end |