Class: LaunchDarklyApi::OtherApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::OtherApi
- Defined in:
- lib/launchdarkly_api/api/other_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#get_caller_identity(opts = {}) ⇒ CallerIdentityRep
Identify the caller Get basic information about the identity used (session cookie, API token, SDK keys, etc.) to call the API.
-
#get_caller_identity_with_http_info(opts = {}) ⇒ Array<(CallerIdentityRep, Integer, Hash)>
Identify the caller Get basic information about the identity used (session cookie, API token, SDK keys, etc.) to call the API.
-
#get_ips(opts = {}) ⇒ IpList
Gets the public IP list Get a list of IP ranges the LaunchDarkly service uses.
-
#get_ips_with_http_info(opts = {}) ⇒ Array<(IpList, Integer, Hash)>
Gets the public IP list Get a list of IP ranges the LaunchDarkly service uses.
-
#get_openapi_spec(opts = {}) ⇒ nil
Gets the OpenAPI spec in json Get the latest version of the OpenAPI specification for LaunchDarkly's API in JSON format.
-
#get_openapi_spec_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Gets the OpenAPI spec in json Get the latest version of the OpenAPI specification for LaunchDarkly's API in JSON format.
-
#get_root(opts = {}) ⇒ RootResponse
Root resource Get all of the resource categories the API supports.
-
#get_root_with_http_info(opts = {}) ⇒ Array<(RootResponse, Integer, Hash)>
Root resource Get all of the resource categories the API supports.
-
#get_versions(opts = {}) ⇒ VersionsRep
Get version information Get the latest API version, the list of valid API versions in ascending order, and the version being used for this request.
-
#get_versions_with_http_info(opts = {}) ⇒ Array<(VersionsRep, Integer, Hash)>
Get version information Get the latest API version, the list of valid API versions in ascending order, and the version being used for this request.
-
#initialize(api_client = ApiClient.default) ⇒ OtherApi
constructor
A new instance of OtherApi.
Constructor Details
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#get_caller_identity(opts = {}) ⇒ CallerIdentityRep
Identify the caller Get basic information about the identity used (session cookie, API token, SDK keys, etc.) to call the API
26 27 28 29 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 26 def get_caller_identity(opts = {}) data, _status_code, _headers = get_caller_identity_with_http_info(opts) data end |
#get_caller_identity_with_http_info(opts = {}) ⇒ Array<(CallerIdentityRep, Integer, Hash)>
Identify the caller Get basic information about the identity used (session cookie, API token, SDK keys, etc.) to call the API
35 36 37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 35 def get_caller_identity_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OtherApi.get_caller_identity ...' end # resource path local_var_path = '/api/v2/caller-identity' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'CallerIdentityRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"OtherApi.get_caller_identity", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OtherApi#get_caller_identity\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_ips(opts = {}) ⇒ IpList
Gets the public IP list
Get a list of IP ranges the LaunchDarkly service uses. You can use this list to allow LaunchDarkly through your firewall. We post upcoming changes to this list in advance on our status page.
In the sandbox, click 'Play' and enter any string in the 'Authorization' field to test this endpoint.
83 84 85 86 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 83 def get_ips(opts = {}) data, _status_code, _headers = get_ips_with_http_info(opts) data end |
#get_ips_with_http_info(opts = {}) ⇒ Array<(IpList, Integer, Hash)>
Gets the public IP list Get a list of IP ranges the LaunchDarkly service uses. You can use this list to allow LaunchDarkly through your firewall. We post upcoming changes to this list in advance on our status page. <br /><br />In the sandbox, click 'Play' and enter any string in the 'Authorization' field to test this endpoint.
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 92 def get_ips_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OtherApi.get_ips ...' end # resource path local_var_path = '/api/v2/public-ip-list' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'IpList' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"OtherApi.get_ips", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OtherApi#get_ips\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_openapi_spec(opts = {}) ⇒ nil
Gets the OpenAPI spec in json Get the latest version of the OpenAPI specification for LaunchDarkly's API in JSON format. In the sandbox, click 'Play' and enter any string in the 'Authorization' field to test this endpoint.
140 141 142 143 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 140 def get_openapi_spec(opts = {}) get_openapi_spec_with_http_info(opts) nil end |
#get_openapi_spec_with_http_info(opts = {}) ⇒ Array<(nil, Integer, Hash)>
Gets the OpenAPI spec in json Get the latest version of the OpenAPI specification for LaunchDarkly's API in JSON format. In the sandbox, click 'Play' and enter any string in the 'Authorization' field to test this endpoint.
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 149 def get_openapi_spec_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OtherApi.get_openapi_spec ...' end # resource path local_var_path = '/api/v2/openapi.json' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"OtherApi.get_openapi_spec", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OtherApi#get_openapi_spec\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_root(opts = {}) ⇒ RootResponse
Root resource Get all of the resource categories the API supports. In the sandbox, click 'Play' and enter any string in the 'Authorization' field to test this endpoint.
197 198 199 200 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 197 def get_root(opts = {}) data, _status_code, _headers = get_root_with_http_info(opts) data end |
#get_root_with_http_info(opts = {}) ⇒ Array<(RootResponse, Integer, Hash)>
Root resource Get all of the resource categories the API supports. In the sandbox, click 'Play' and enter any string in the 'Authorization' field to test this endpoint.
206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 206 def get_root_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OtherApi.get_root ...' end # resource path local_var_path = '/api/v2' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'RootResponse' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"OtherApi.get_root", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OtherApi#get_root\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_versions(opts = {}) ⇒ VersionsRep
Get version information Get the latest API version, the list of valid API versions in ascending order, and the version being used for this request. These are all in the external, date-based format.
254 255 256 257 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 254 def get_versions(opts = {}) data, _status_code, _headers = get_versions_with_http_info(opts) data end |
#get_versions_with_http_info(opts = {}) ⇒ Array<(VersionsRep, Integer, Hash)>
Get version information Get the latest API version, the list of valid API versions in ascending order, and the version being used for this request. These are all in the external, date-based format.
263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 |
# File 'lib/launchdarkly_api/api/other_api.rb', line 263 def get_versions_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: OtherApi.get_versions ...' end # resource path local_var_path = '/api/v2/versions' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) unless header_params['Accept'] # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'VersionsRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"OtherApi.get_versions", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: OtherApi#get_versions\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |