Class: LaunchDarklyApi::PatchSegmentExpiringTargetInstruction
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::PatchSegmentExpiringTargetInstruction
- Defined in:
- lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#context_key ⇒ Object
A unique key used to represent the context.
-
#context_kind ⇒ Object
The kind of context.
-
#kind ⇒ Object
The type of change to make to the context's removal date from this segment.
-
#target_type ⇒ Object
The segment's target type.
-
#value ⇒ Object
The time, in Unix milliseconds, when the context should be removed from this segment.
-
#version ⇒ Object
The version of the expiring target to update.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PatchSegmentExpiringTargetInstruction
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PatchSegmentExpiringTargetInstruction
Initializes the object
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 100 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PatchSegmentExpiringTargetInstruction` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PatchSegmentExpiringTargetInstruction`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'context_key') self.context_key = attributes[:'context_key'] else self.context_key = nil end if attributes.key?(:'context_kind') self.context_kind = attributes[:'context_kind'] else self.context_kind = nil end if attributes.key?(:'target_type') self.target_type = attributes[:'target_type'] else self.target_type = nil end if attributes.key?(:'value') self.value = attributes[:'value'] end if attributes.key?(:'version') self.version = attributes[:'version'] end end |
Instance Attribute Details
#context_key ⇒ Object
A unique key used to represent the context
22 23 24 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 22 def context_key @context_key end |
#context_kind ⇒ Object
The kind of context
25 26 27 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 25 def context_kind @context_kind end |
#kind ⇒ Object
The type of change to make to the context's removal date from this segment
19 20 21 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 19 def kind @kind end |
#target_type ⇒ Object
The segment's target type
28 29 30 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 28 def target_type @target_type end |
#value ⇒ Object
The time, in Unix milliseconds, when the context should be removed from this segment. Required if kind is addExpiringTarget or updateExpiringTarget.
31 32 33 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 31 def value @value end |
#version ⇒ Object
The version of the expiring target to update. Optional and only used if kind is updateExpiringTarget. If included, update will fail if version doesn't match current version of the expiring target.
34 35 36 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 34 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
71 72 73 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 71 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
76 77 78 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 76 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
59 60 61 62 63 64 65 66 67 68 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 59 def self.attribute_map { :'kind' => :'kind', :'context_key' => :'contextKey', :'context_kind' => :'contextKind', :'target_type' => :'targetType', :'value' => :'value', :'version' => :'version' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 254 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
93 94 95 96 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 93 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
81 82 83 84 85 86 87 88 89 90 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 81 def self.openapi_types { :'kind' => :'String', :'context_key' => :'String', :'context_kind' => :'String', :'target_type' => :'String', :'value' => :'Integer', :'version' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
228 229 230 231 232 233 234 235 236 237 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 228 def ==(o) return true if self.equal?(o) self.class == o.class && kind == o.kind && context_key == o.context_key && context_kind == o.context_kind && target_type == o.target_type && value == o.value && version == o.version end |
#eql?(o) ⇒ Boolean
241 242 243 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 241 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
247 248 249 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 247 def hash [kind, context_key, context_kind, target_type, value, version].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 149 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @context_key.nil? invalid_properties.push('invalid value for "context_key", context_key cannot be nil.') end if @context_kind.nil? invalid_properties.push('invalid value for "context_kind", context_kind cannot be nil.') end if @target_type.nil? invalid_properties.push('invalid value for "target_type", target_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
276 277 278 279 280 281 282 283 284 285 286 287 288 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 276 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
173 174 175 176 177 178 179 180 181 182 183 184 |
# File 'lib/launchdarkly_api/models/patch_segment_expiring_target_instruction.rb', line 173 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kind.nil? kind_validator = EnumAttributeValidator.new('String', ["addExpiringTarget", "updateExpiringTarget", "removeExpiringTarget"]) return false unless kind_validator.valid?(@kind) return false if @context_key.nil? return false if @context_kind.nil? return false if @target_type.nil? target_type_validator = EnumAttributeValidator.new('String', ["included", "excluded"]) return false unless target_type_validator.valid?(@target_type) true end |