Class: LaunchDarklyApi::PersistentStoreIntegrationsBetaApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::PersistentStoreIntegrationsBetaApi
- Defined in:
- lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#create_big_segment_store_integration(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ BigSegmentStoreIntegration
Create big segment store integration Create a persistent store integration.
-
#create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Create big segment store integration Create a persistent store integration.
-
#delete_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ nil
Delete big segment store integration Delete a persistent store integration.
-
#delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete big segment store integration Delete a persistent store integration.
-
#get_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ BigSegmentStoreIntegration
Get big segment store integration by ID Get a big segment store integration by ID.
-
#get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Get big segment store integration by ID Get a big segment store integration by ID.
-
#get_big_segment_store_integrations(opts = {}) ⇒ BigSegmentStoreIntegrationCollection
List all big segment store integrations List all big segment store integrations.
-
#get_big_segment_store_integrations_with_http_info(opts = {}) ⇒ Array<(BigSegmentStoreIntegrationCollection, Integer, Hash)>
List all big segment store integrations List all big segment store integrations.
-
#initialize(api_client = ApiClient.default) ⇒ PersistentStoreIntegrationsBetaApi
constructor
A new instance of PersistentStoreIntegrationsBetaApi.
-
#patch_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ BigSegmentStoreIntegration
Update big segment store integration Update a big segment store integration.
-
#patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Update big segment store integration Update a big segment store integration.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ PersistentStoreIntegrationsBetaApi
Returns a new instance of PersistentStoreIntegrationsBetaApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#create_big_segment_store_integration(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ BigSegmentStoreIntegration
Create big segment store integration
Create a persistent store integration. If you are using server-side SDKs, segments synced from external tools and larger list-based segments require a persistent store within your infrastructure. LaunchDarkly keeps the persistent store up to date and consults it during flag evaluation. You can use either Redis or DynamoDB as your persistent store. When you create a persistent store integration, the fields in the `config` object in the request vary depending on which persistent store you use. If you are using Redis to create your persistent store integration, you will need to know: * Your Redis host * Your Redis port * Your Redis username * Your Redis password * Whether or not LaunchDarkly should connect using TLS If you are using DynamoDB to create your persistent store integration, you will need to know: * Your DynamoDB table name. The table must have the following schema: * Partition key: `namespace` (string) * Sort key: `key` (string) * Your DynamoDB Amazon Web Services (AWS) region. * Your AWS role Amazon Resource Name (ARN). This is the role that LaunchDarkly will assume to manage your DynamoDB table. * The External ID you specified when creating your Amazon Resource Name (ARN). To learn more, read [Segment configuration](https://launchdarkly.com/docs/home/flags/segment-config).
30 31 32 33 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 30 def create_big_segment_store_integration(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) data, _status_code, _headers = create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts) data end |
#create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Create big segment store integration
Create a persistent store integration. If you are using server-side SDKs, segments synced from external tools and larger list-based segments require a persistent store within your infrastructure. LaunchDarkly keeps the persistent store up to date and consults it during flag evaluation. You can use either Redis or DynamoDB as your persistent store. When you create a persistent store integration, the fields in the `config` object in the request vary depending on which persistent store you use. If you are using Redis to create your persistent store integration, you will need to know: * Your Redis host * Your Redis port * Your Redis username * Your Redis password * Whether or not LaunchDarkly should connect using TLS If you are using DynamoDB to create your persistent store integration, you will need to know: * Your DynamoDB table name. The table must have the following schema: * Partition key: `namespace` (string) * Sort key: `key` (string) * Your DynamoDB Amazon Web Services (AWS) region. * Your AWS role Amazon Resource Name (ARN). This is the role that LaunchDarkly will assume to manage your DynamoDB table. * The External ID you specified when creating your Amazon Resource Name (ARN). To learn more, read [Segment configuration](https://launchdarkly.com/docs/home/flags/segment-config).
43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 43 def create_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_delivery_configuration_post, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PersistentStoreIntegrationsBetaApi.create_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling PersistentStoreIntegrationsBetaApi.create_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling PersistentStoreIntegrationsBetaApi.create_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling PersistentStoreIntegrationsBetaApi.create_big_segment_store_integration" end # verify the required parameter 'integration_delivery_configuration_post' is set if @api_client.config.client_side_validation && integration_delivery_configuration_post.nil? fail ArgumentError, "Missing the required parameter 'integration_delivery_configuration_post' when calling PersistentStoreIntegrationsBetaApi.create_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(integration_delivery_configuration_post) # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"PersistentStoreIntegrationsBetaApi.create_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PersistentStoreIntegrationsBetaApi#create_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#delete_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ nil
Delete big segment store integration Delete a persistent store integration. Each integration uses either Redis or DynamoDB.
116 117 118 119 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 116 def delete_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts) nil end |
#delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete big segment store integration Delete a persistent store integration. Each integration uses either Redis or DynamoDB.
129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 129 def delete_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PersistentStoreIntegrationsBetaApi.delete_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling PersistentStoreIntegrationsBetaApi.delete_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling PersistentStoreIntegrationsBetaApi.delete_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling PersistentStoreIntegrationsBetaApi.delete_big_segment_store_integration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling PersistentStoreIntegrationsBetaApi.delete_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"PersistentStoreIntegrationsBetaApi.delete_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PersistentStoreIntegrationsBetaApi#delete_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ BigSegmentStoreIntegration
Get big segment store integration by ID Get a big segment store integration by ID.
197 198 199 200 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 197 def get_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, opts = {}) data, _status_code, _headers = get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts) data end |
#get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Get big segment store integration by ID Get a big segment store integration by ID.
210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 210 def get_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PersistentStoreIntegrationsBetaApi.get_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling PersistentStoreIntegrationsBetaApi.get_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling PersistentStoreIntegrationsBetaApi.get_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling PersistentStoreIntegrationsBetaApi.get_big_segment_store_integration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling PersistentStoreIntegrationsBetaApi.get_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"PersistentStoreIntegrationsBetaApi.get_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PersistentStoreIntegrationsBetaApi#get_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_big_segment_store_integrations(opts = {}) ⇒ BigSegmentStoreIntegrationCollection
List all big segment store integrations List all big segment store integrations.
274 275 276 277 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 274 def get_big_segment_store_integrations(opts = {}) data, _status_code, _headers = get_big_segment_store_integrations_with_http_info(opts) data end |
#get_big_segment_store_integrations_with_http_info(opts = {}) ⇒ Array<(BigSegmentStoreIntegrationCollection, Integer, Hash)>
List all big segment store integrations List all big segment store integrations.
283 284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 283 def get_big_segment_store_integrations_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PersistentStoreIntegrationsBetaApi.get_big_segment_store_integrations ...' end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegrationCollection' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"PersistentStoreIntegrationsBetaApi.get_big_segment_store_integrations", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PersistentStoreIntegrationsBetaApi#get_big_segment_store_integrations\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ BigSegmentStoreIntegration
Update big segment store integration Update a big segment store integration. Updating a big segment store requires a [JSON Patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](launchdarkly.com/docs/api#updates).
336 337 338 339 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 336 def patch_big_segment_store_integration(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) data, _status_code, _headers = patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts) data end |
#patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) ⇒ Array<(BigSegmentStoreIntegration, Integer, Hash)>
Update big segment store integration Update a big segment store integration. Updating a big segment store requires a [JSON Patch](datatracker.ietf.org/doc/html/rfc6902) representation of the desired changes. To learn more, read [Updates](launchdarkly.com/docs/api#updates).
350 351 352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 369 370 371 372 373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 |
# File 'lib/launchdarkly_api/api/persistent_store_integrations_beta_api.rb', line 350 def patch_big_segment_store_integration_with_http_info(project_key, environment_key, integration_key, integration_id, patch_operation, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration ...' end # verify the required parameter 'project_key' is set if @api_client.config.client_side_validation && project_key.nil? fail ArgumentError, "Missing the required parameter 'project_key' when calling PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'environment_key' is set if @api_client.config.client_side_validation && environment_key.nil? fail ArgumentError, "Missing the required parameter 'environment_key' when calling PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'integration_key' is set if @api_client.config.client_side_validation && integration_key.nil? fail ArgumentError, "Missing the required parameter 'integration_key' when calling PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'integration_id' is set if @api_client.config.client_side_validation && integration_id.nil? fail ArgumentError, "Missing the required parameter 'integration_id' when calling PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration" end # verify the required parameter 'patch_operation' is set if @api_client.config.client_side_validation && patch_operation.nil? fail ArgumentError, "Missing the required parameter 'patch_operation' when calling PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration" end # resource path local_var_path = '/api/v2/integration-capabilities/big-segment-store/{projectKey}/{environmentKey}/{integrationKey}/{integrationId}'.sub('{' + 'projectKey' + '}', CGI.escape(project_key.to_s)).sub('{' + 'environmentKey' + '}', CGI.escape(environment_key.to_s)).sub('{' + 'integrationKey' + '}', CGI.escape(integration_key.to_s)).sub('{' + 'integrationId' + '}', CGI.escape(integration_id.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(patch_operation) # return_type return_type = opts[:debug_return_type] || 'BigSegmentStoreIntegration' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"PersistentStoreIntegrationsBetaApi.patch_big_segment_store_integration", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: PersistentStoreIntegrationsBetaApi#patch_big_segment_store_integration\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |