Class: LaunchDarklyApi::PostDeploymentEventInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::PostDeploymentEventInput
- Defined in:
- lib/launchdarkly_api/models/post_deployment_event_input.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#application_key ⇒ Object
The application key.
-
#application_kind ⇒ Object
The kind of application.
-
#application_name ⇒ Object
The application name.
-
#deployment_metadata ⇒ Object
A JSON object containing metadata about the deployment.
-
#environment_key ⇒ Object
The environment key.
-
#event_metadata ⇒ Object
A JSON object containing metadata about the event.
-
#event_time ⇒ Object
Returns the value of attribute event_time.
-
#event_type ⇒ Object
The event type.
-
#project_key ⇒ Object
The project key.
-
#version ⇒ Object
The application version.
-
#version_name ⇒ Object
The version name.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PostDeploymentEventInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PostDeploymentEventInput
Initializes the object
124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 124 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PostDeploymentEventInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PostDeploymentEventInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'project_key') self.project_key = attributes[:'project_key'] else self.project_key = nil end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] else self.environment_key = nil end if attributes.key?(:'application_key') self.application_key = attributes[:'application_key'] else self.application_key = nil end if attributes.key?(:'application_name') self.application_name = attributes[:'application_name'] end if attributes.key?(:'application_kind') self.application_kind = attributes[:'application_kind'] end if attributes.key?(:'version') self.version = attributes[:'version'] else self.version = nil end if attributes.key?(:'version_name') self.version_name = attributes[:'version_name'] end if attributes.key?(:'event_type') self.event_type = attributes[:'event_type'] else self.event_type = nil end if attributes.key?(:'event_time') self.event_time = attributes[:'event_time'] end if attributes.key?(:'event_metadata') if (value = attributes[:'event_metadata']).is_a?(Hash) self. = value end end if attributes.key?(:'deployment_metadata') if (value = attributes[:'deployment_metadata']).is_a?(Hash) self. = value end end end |
Instance Attribute Details
#application_key ⇒ Object
The application key. This defines the granularity at which you want to view your insights metrics. Typically it is the name of one of the GitHub repositories that you use in this project.
LaunchDarkly automatically creates a new application each time you send a unique application key.
25 26 27 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 25 def application_key @application_key end |
#application_kind ⇒ Object
The kind of application. Default: server
31 32 33 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 31 def application_kind @application_kind end |
#application_name ⇒ Object
The application name. This defines how the application is displayed
28 29 30 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 28 def application_name @application_name end |
#deployment_metadata ⇒ Object
A JSON object containing metadata about the deployment
48 49 50 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 48 def @deployment_metadata end |
#environment_key ⇒ Object
The environment key
22 23 24 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 22 def environment_key @environment_key end |
#event_metadata ⇒ Object
A JSON object containing metadata about the event
45 46 47 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 45 def @event_metadata end |
#event_time ⇒ Object
Returns the value of attribute event_time.
42 43 44 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 42 def event_time @event_time end |
#event_type ⇒ Object
The event type
40 41 42 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 40 def event_type @event_type end |
#project_key ⇒ Object
The project key
19 20 21 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 19 def project_key @project_key end |
#version ⇒ Object
The application version. You can set the application version to any string that includes only letters, numbers, periods (.), hyphens (-), or underscores (_).
We recommend setting the application version to at least the first seven characters of the SHA or to the tag of the GitHub commit for this deployment.
34 35 36 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 34 def version @version end |
#version_name ⇒ Object
The version name. This defines how the version is displayed
37 38 39 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 37 def version_name @version_name end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
90 91 92 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 90 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
95 96 97 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 95 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
73 74 75 76 77 78 79 80 81 82 83 84 85 86 87 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 73 def self.attribute_map { :'project_key' => :'projectKey', :'environment_key' => :'environmentKey', :'application_key' => :'applicationKey', :'application_name' => :'applicationName', :'application_kind' => :'applicationKind', :'version' => :'version', :'version_name' => :'versionName', :'event_type' => :'eventType', :'event_time' => :'eventTime', :'event_metadata' => :'eventMetadata', :'deployment_metadata' => :'deploymentMetadata' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 334 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
117 118 119 120 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 117 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 100 def self.openapi_types { :'project_key' => :'String', :'environment_key' => :'String', :'application_key' => :'String', :'application_name' => :'String', :'application_kind' => :'String', :'version' => :'String', :'version_name' => :'String', :'event_type' => :'String', :'event_time' => :'Integer', :'event_metadata' => :'Hash<String, Object>', :'deployment_metadata' => :'Hash<String, Object>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 303 def ==(o) return true if self.equal?(o) self.class == o.class && project_key == o.project_key && environment_key == o.environment_key && application_key == o.application_key && application_name == o.application_name && application_kind == o.application_kind && version == o.version && version_name == o.version_name && event_type == o.event_type && event_time == o.event_time && == o. && == o. end |
#eql?(o) ⇒ Boolean
321 322 323 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 321 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
327 328 329 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 327 def hash [project_key, environment_key, application_key, application_name, application_kind, version, version_name, event_type, event_time, , ].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 199 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @project_key.nil? invalid_properties.push('invalid value for "project_key", project_key cannot be nil.') end if @environment_key.nil? invalid_properties.push('invalid value for "environment_key", environment_key cannot be nil.') end if @application_key.nil? invalid_properties.push('invalid value for "application_key", application_key cannot be nil.') end if @version.nil? invalid_properties.push('invalid value for "version", version cannot be nil.') end if @event_type.nil? invalid_properties.push('invalid value for "event_type", event_type cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 356 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
227 228 229 230 231 232 233 234 235 236 237 238 239 |
# File 'lib/launchdarkly_api/models/post_deployment_event_input.rb', line 227 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @project_key.nil? return false if @environment_key.nil? return false if @application_key.nil? application_kind_validator = EnumAttributeValidator.new('String', ["server", "browser", "mobile"]) return false unless application_kind_validator.valid?(@application_kind) return false if @version.nil? return false if @event_type.nil? event_type_validator = EnumAttributeValidator.new('String', ["started", "failed", "finished", "custom"]) return false unless event_type_validator.valid?(@event_type) true end |