Class: LaunchDarklyApi::Project

Inherits:
Object
  • Object
show all
Defined in:
lib/launchdarkly_api/models/project.rb

Instance Attribute Summary collapse

Class Method Summary collapse

Instance Method Summary collapse

Constructor Details

#initialize(attributes = {}) ⇒ Project

Initializes the object

Parameters:

  • attributes (Hash) (defaults to: {})

    Model attributes in the form of hash



86
87
88
89
90
91
92
93
94
95
96
97
98
99
100
101
102
103
104
105
106
107
108
109
110
111
112
113
114
115
116
117
118
119
120
121
122
123
124
125
126
127
128
129
130
131
132
133
134
135
136
137
138
# File 'lib/launchdarkly_api/models/project.rb', line 86

def initialize(attributes = {})
  if (!attributes.is_a?(Hash))
    fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Project` initialize method"
  end

  # check to see if the attribute exists and convert string to symbol for hash key
  attributes = attributes.each_with_object({}) { |(k, v), h|
    if (!self.class.attribute_map.key?(k.to_sym))
      fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Project`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect
    end
    h[k.to_sym] = v
  }

  if attributes.key?(:'_links')
    if (value = attributes[:'_links']).is_a?(Hash)
      self._links = value
    end
  end

  if attributes.key?(:'_id')
    self._id = attributes[:'_id']
  end

  if attributes.key?(:'key')
    self.key = attributes[:'key']
  end

  if attributes.key?(:'include_in_snippet_by_default')
    self.include_in_snippet_by_default = attributes[:'include_in_snippet_by_default']
  end

  if attributes.key?(:'default_client_side_availability')
    self.default_client_side_availability = attributes[:'default_client_side_availability']
  end

  if attributes.key?(:'name')
    self.name = attributes[:'name']
  end

  if attributes.key?(:'tags')
    if (value = attributes[:'tags']).is_a?(Array)
      self.tags = value
    end
  end

  if attributes.key?(:'default_release_pipeline_key')
    self.default_release_pipeline_key = attributes[:'default_release_pipeline_key']
  end

  if attributes.key?(:'environments')
    self.environments = attributes[:'environments']
  end
end

Instance Attribute Details

#_idObject

The ID of this project



22
23
24
# File 'lib/launchdarkly_api/models/project.rb', line 22

def _id
  @_id
end

The location and content type of related resources



19
20
21
# File 'lib/launchdarkly_api/models/project.rb', line 19

def _links
  @_links
end

#default_client_side_availabilityObject

Returns the value of attribute default_client_side_availability.



30
31
32
# File 'lib/launchdarkly_api/models/project.rb', line 30

def default_client_side_availability
  @default_client_side_availability
end

#default_release_pipeline_keyObject

The key of the default release pipeline for this project



39
40
41
# File 'lib/launchdarkly_api/models/project.rb', line 39

def default_release_pipeline_key
  @default_release_pipeline_key
end

#environmentsObject

Returns the value of attribute environments.



41
42
43
# File 'lib/launchdarkly_api/models/project.rb', line 41

def environments
  @environments
end

#include_in_snippet_by_defaultObject

Whether or not flags created in this project are made available to the client-side JavaScript SDK by default



28
29
30
# File 'lib/launchdarkly_api/models/project.rb', line 28

def include_in_snippet_by_default
  @include_in_snippet_by_default
end

#keyObject

The key of this project



25
26
27
# File 'lib/launchdarkly_api/models/project.rb', line 25

def key
  @key
end

#nameObject

A human-friendly name for the project



33
34
35
# File 'lib/launchdarkly_api/models/project.rb', line 33

def name
  @name
end

#tagsObject

A list of tags for the project



36
37
38
# File 'lib/launchdarkly_api/models/project.rb', line 36

def tags
  @tags
end

Class Method Details

.acceptable_attributesObject

Returns all the JSON keys this model knows about



59
60
61
# File 'lib/launchdarkly_api/models/project.rb', line 59

def self.acceptable_attributes
  attribute_map.values
end

.attribute_mapObject

Attribute mapping from ruby-style variable name to JSON key.



44
45
46
47
48
49
50
51
52
53
54
55
56
# File 'lib/launchdarkly_api/models/project.rb', line 44

def self.attribute_map
  {
    :'_links' => :'_links',
    :'_id' => :'_id',
    :'key' => :'key',
    :'include_in_snippet_by_default' => :'includeInSnippetByDefault',
    :'default_client_side_availability' => :'defaultClientSideAvailability',
    :'name' => :'name',
    :'tags' => :'tags',
    :'default_release_pipeline_key' => :'defaultReleasePipelineKey',
    :'environments' => :'environments'
  }
end

.build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



214
215
216
# File 'lib/launchdarkly_api/models/project.rb', line 214

def self.build_from_hash(attributes)
  new.build_from_hash(attributes)
end

.openapi_nullableObject

List of attributes with nullable: true



79
80
81
82
# File 'lib/launchdarkly_api/models/project.rb', line 79

def self.openapi_nullable
  Set.new([
  ])
end

.openapi_typesObject

Attribute type mapping.



64
65
66
67
68
69
70
71
72
73
74
75
76
# File 'lib/launchdarkly_api/models/project.rb', line 64

def self.openapi_types
  {
    :'_links' => :'Hash<String, Link>',
    :'_id' => :'String',
    :'key' => :'String',
    :'include_in_snippet_by_default' => :'Boolean',
    :'default_client_side_availability' => :'ClientSideAvailability',
    :'name' => :'String',
    :'tags' => :'Array<String>',
    :'default_release_pipeline_key' => :'String',
    :'environments' => :'Environments'
  }
end

Instance Method Details

#==(o) ⇒ Object

Checks equality by comparing each attribute.

Parameters:

  • Object (Object)

    to be compared



185
186
187
188
189
190
191
192
193
194
195
196
197
# File 'lib/launchdarkly_api/models/project.rb', line 185

def ==(o)
  return true if self.equal?(o)
  self.class == o.class &&
      _links == o._links &&
      _id == o._id &&
      key == o.key &&
      include_in_snippet_by_default == o.include_in_snippet_by_default &&
      default_client_side_availability == o.default_client_side_availability &&
      name == o.name &&
      tags == o.tags &&
      default_release_pipeline_key == o.default_release_pipeline_key &&
      environments == o.environments
end

#_deserialize(type, value) ⇒ Object

Deserializes the data based on type

Parameters:

  • string

    type Data type

  • string

    value Value to be deserialized

Returns:

  • (Object)

    Deserialized data



245
246
247
248
249
250
251
252
253
254
255
256
257
258
259
260
261
262
263
264
265
266
267
268
269
270
271
272
273
274
275
276
277
278
279
280
281
282
# File 'lib/launchdarkly_api/models/project.rb', line 245

def _deserialize(type, value)
  case type.to_sym
  when :Time
    Time.parse(value)
  when :Date
    Date.parse(value)
  when :String
    value.to_s
  when :Integer
    value.to_i
  when :Float
    value.to_f
  when :Boolean
    if value.to_s =~ /\A(true|t|yes|y|1)\z/i
      true
    else
      false
    end
  when :Object
    # generic object (usually a Hash), return directly
    value
  when /\AArray<(?<inner_type>.+)>\z/
    inner_type = Regexp.last_match[:inner_type]
    value.map { |v| _deserialize(inner_type, v) }
  when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/
    k_type = Regexp.last_match[:k_type]
    v_type = Regexp.last_match[:v_type]
    {}.tap do |hash|
      value.each do |k, v|
        hash[_deserialize(k_type, k)] = _deserialize(v_type, v)
      end
    end
  else # model
    # models (e.g. Pet) or oneOf
    klass = LaunchDarklyApi.const_get(type)
    klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value)
  end
end

#_to_hash(value) ⇒ Hash

Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value

Parameters:

  • value (Object)

    Any valid value

Returns:

  • (Hash)

    Returns the value in the form of hash



316
317
318
319
320
321
322
323
324
325
326
327
328
# File 'lib/launchdarkly_api/models/project.rb', line 316

def _to_hash(value)
  if value.is_a?(Array)
    value.compact.map { |v| _to_hash(v) }
  elsif value.is_a?(Hash)
    {}.tap do |hash|
      value.each { |k, v| hash[k] = _to_hash(v) }
    end
  elsif value.respond_to? :to_hash
    value.to_hash
  else
    value
  end
end

#build_from_hash(attributes) ⇒ Object

Builds the object from hash

Parameters:

  • attributes (Hash)

    Model attributes in the form of hash

Returns:

  • (Object)

    Returns the model itself



221
222
223
224
225
226
227
228
229
230
231
232
233
234
235
236
237
238
239
# File 'lib/launchdarkly_api/models/project.rb', line 221

def build_from_hash(attributes)
  return nil unless attributes.is_a?(Hash)
  attributes = attributes.transform_keys(&:to_sym)
  self.class.openapi_types.each_pair do |key, type|
    if attributes[self.class.attribute_map[key]].nil? && self.class.openapi_nullable.include?(key)
      self.send("#{key}=", nil)
    elsif type =~ /\AArray<(.*)>/i
      # check to ensure the input is an array given that the attribute
      # is documented as an array but the input is not
      if attributes[self.class.attribute_map[key]].is_a?(Array)
        self.send("#{key}=", attributes[self.class.attribute_map[key]].map { |v| _deserialize($1, v) })
      end
    elsif !attributes[self.class.attribute_map[key]].nil?
      self.send("#{key}=", _deserialize(type, attributes[self.class.attribute_map[key]]))
    end
  end

  self
end

#eql?(o) ⇒ Boolean

Parameters:

  • Object (Object)

    to be compared

Returns:

  • (Boolean)

See Also:

  • `==` method


201
202
203
# File 'lib/launchdarkly_api/models/project.rb', line 201

def eql?(o)
  self == o
end

#hashInteger

Calculates hash code according to all attributes.

Returns:

  • (Integer)

    Hash code



207
208
209
# File 'lib/launchdarkly_api/models/project.rb', line 207

def hash
  [_links, _id, key, include_in_snippet_by_default, default_client_side_availability, name, tags, default_release_pipeline_key, environments].hash
end

#list_invalid_propertiesObject

Show invalid properties with the reasons. Usually used together with valid?

Returns:

  • Array for valid properties with the reasons



142
143
144
145
146
147
148
149
150
151
152
153
154
155
156
157
158
159
160
161
162
163
164
165
166
167
168
169
# File 'lib/launchdarkly_api/models/project.rb', line 142

def list_invalid_properties
  invalid_properties = Array.new
  if @_links.nil?
    invalid_properties.push('invalid value for "_links", _links cannot be nil.')
  end

  if @_id.nil?
    invalid_properties.push('invalid value for "_id", _id cannot be nil.')
  end

  if @key.nil?
    invalid_properties.push('invalid value for "key", key cannot be nil.')
  end

  if @include_in_snippet_by_default.nil?
    invalid_properties.push('invalid value for "include_in_snippet_by_default", include_in_snippet_by_default cannot be nil.')
  end

  if @name.nil?
    invalid_properties.push('invalid value for "name", name cannot be nil.')
  end

  if @tags.nil?
    invalid_properties.push('invalid value for "tags", tags cannot be nil.')
  end

  invalid_properties
end

#to_bodyHash

to_body is an alias to to_hash (backward compatibility)

Returns:

  • (Hash)

    Returns the object in the form of hash



292
293
294
# File 'lib/launchdarkly_api/models/project.rb', line 292

def to_body
  to_hash
end

#to_hashHash

Returns the object in the form of hash

Returns:

  • (Hash)

    Returns the object in the form of hash



298
299
300
301
302
303
304
305
306
307
308
309
310
# File 'lib/launchdarkly_api/models/project.rb', line 298

def to_hash
  hash = {}
  self.class.attribute_map.each_pair do |attr, param|
    value = self.send(attr)
    if value.nil?
      is_nullable = self.class.openapi_nullable.include?(attr)
      next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}"))
    end

    hash[param] = _to_hash(value)
  end
  hash
end

#to_sString

Returns the string representation of the object

Returns:

  • (String)

    String presentation of the object



286
287
288
# File 'lib/launchdarkly_api/models/project.rb', line 286

def to_s
  to_hash.to_s
end

#valid?Boolean

Check to see if the all the properties in the model are valid

Returns:

  • (Boolean)

    true if the model is valid



173
174
175
176
177
178
179
180
181
# File 'lib/launchdarkly_api/models/project.rb', line 173

def valid?
  return false if @_links.nil?
  return false if @_id.nil?
  return false if @key.nil?
  return false if @include_in_snippet_by_default.nil?
  return false if @name.nil?
  return false if @tags.nil?
  true
end