Class: LaunchDarklyApi::PullRequestRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::PullRequestRep
- Defined in:
- lib/launchdarkly_api/models/pull_request_rep.rb
Instance Attribute Summary collapse
-
#author ⇒ Object
The pull request author.
-
#base_commit_key ⇒ Object
The pull request base commit key.
-
#create_time ⇒ Object
Returns the value of attribute create_time.
-
#deployments ⇒ Object
Returns the value of attribute deployments.
-
#external_id ⇒ Object
The pull request number.
-
#files_changed ⇒ Object
The number of files changed.
-
#flag_references ⇒ Object
Returns the value of attribute flag_references.
-
#head_commit_key ⇒ Object
The pull request head commit key.
-
#id ⇒ Object
The pull request internal ID.
-
#lead_time ⇒ Object
Returns the value of attribute lead_time.
-
#lines_added ⇒ Object
The number of lines added.
-
#lines_deleted ⇒ Object
The number of lines deleted.
-
#merge_commit_key ⇒ Object
The pull request merge commit key.
-
#merge_time ⇒ Object
Returns the value of attribute merge_time.
-
#status ⇒ Object
The pull request status.
-
#title ⇒ Object
The pull request title.
-
#url ⇒ Object
The pull request URL.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ PullRequestRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ PullRequestRep
Initializes the object
128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 128 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::PullRequestRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::PullRequestRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'id') self.id = attributes[:'id'] else self.id = nil end if attributes.key?(:'external_id') self.external_id = attributes[:'external_id'] else self.external_id = nil end if attributes.key?(:'title') self.title = attributes[:'title'] else self.title = nil end if attributes.key?(:'status') self.status = attributes[:'status'] else self.status = nil end if attributes.key?(:'author') self. = attributes[:'author'] else self. = nil end if attributes.key?(:'create_time') self.create_time = attributes[:'create_time'] else self.create_time = nil end if attributes.key?(:'merge_time') self.merge_time = attributes[:'merge_time'] end if attributes.key?(:'merge_commit_key') self.merge_commit_key = attributes[:'merge_commit_key'] end if attributes.key?(:'base_commit_key') self.base_commit_key = attributes[:'base_commit_key'] else self.base_commit_key = nil end if attributes.key?(:'head_commit_key') self.head_commit_key = attributes[:'head_commit_key'] else self.head_commit_key = nil end if attributes.key?(:'files_changed') self.files_changed = attributes[:'files_changed'] else self.files_changed = nil end if attributes.key?(:'lines_added') self.lines_added = attributes[:'lines_added'] else self.lines_added = nil end if attributes.key?(:'lines_deleted') self.lines_deleted = attributes[:'lines_deleted'] else self.lines_deleted = nil end if attributes.key?(:'url') self.url = attributes[:'url'] else self.url = nil end if attributes.key?(:'deployments') self.deployments = attributes[:'deployments'] end if attributes.key?(:'flag_references') self.flag_references = attributes[:'flag_references'] end if attributes.key?(:'lead_time') self.lead_time = attributes[:'lead_time'] end end |
Instance Attribute Details
#author ⇒ Object
The pull request author
31 32 33 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 31 def @author end |
#base_commit_key ⇒ Object
The pull request base commit key
41 42 43 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 41 def base_commit_key @base_commit_key end |
#create_time ⇒ Object
Returns the value of attribute create_time.
33 34 35 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 33 def create_time @create_time end |
#deployments ⇒ Object
Returns the value of attribute deployments.
58 59 60 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 58 def deployments @deployments end |
#external_id ⇒ Object
The pull request number
22 23 24 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 22 def external_id @external_id end |
#files_changed ⇒ Object
The number of files changed
47 48 49 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 47 def files_changed @files_changed end |
#flag_references ⇒ Object
Returns the value of attribute flag_references.
60 61 62 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 60 def flag_references @flag_references end |
#head_commit_key ⇒ Object
The pull request head commit key
44 45 46 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 44 def head_commit_key @head_commit_key end |
#id ⇒ Object
The pull request internal ID
19 20 21 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 19 def id @id end |
#lead_time ⇒ Object
Returns the value of attribute lead_time.
62 63 64 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 62 def lead_time @lead_time end |
#lines_added ⇒ Object
The number of lines added
50 51 52 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 50 def lines_added @lines_added end |
#lines_deleted ⇒ Object
The number of lines deleted
53 54 55 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 53 def lines_deleted @lines_deleted end |
#merge_commit_key ⇒ Object
The pull request merge commit key
38 39 40 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 38 def merge_commit_key @merge_commit_key end |
#merge_time ⇒ Object
Returns the value of attribute merge_time.
35 36 37 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 35 def merge_time @merge_time end |
#status ⇒ Object
The pull request status
28 29 30 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 28 def status @status end |
#title ⇒ Object
The pull request title
25 26 27 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 25 def title @title end |
#url ⇒ Object
The pull request URL
56 57 58 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 56 def url @url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
88 89 90 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 88 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
93 94 95 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 93 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 84 85 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 65 def self.attribute_map { :'id' => :'id', :'external_id' => :'externalId', :'title' => :'title', :'status' => :'status', :'author' => :'author', :'create_time' => :'createTime', :'merge_time' => :'mergeTime', :'merge_commit_key' => :'mergeCommitKey', :'base_commit_key' => :'baseCommitKey', :'head_commit_key' => :'headCommitKey', :'files_changed' => :'filesChanged', :'lines_added' => :'linesAdded', :'lines_deleted' => :'linesDeleted', :'url' => :'url', :'deployments' => :'deployments', :'flag_references' => :'flagReferences', :'lead_time' => :'leadTime' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
469 470 471 472 473 474 475 476 477 478 479 480 481 482 483 484 485 486 487 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 469 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
121 122 123 124 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 121 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 98 def self.openapi_types { :'id' => :'String', :'external_id' => :'String', :'title' => :'String', :'status' => :'String', :'author' => :'String', :'create_time' => :'Integer', :'merge_time' => :'Integer', :'merge_commit_key' => :'String', :'base_commit_key' => :'String', :'head_commit_key' => :'String', :'files_changed' => :'Integer', :'lines_added' => :'Integer', :'lines_deleted' => :'Integer', :'url' => :'String', :'deployments' => :'DeploymentCollectionRep', :'flag_references' => :'FlagReferenceCollectionRep', :'lead_time' => :'PullRequestLeadTimeRep' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
432 433 434 435 436 437 438 439 440 441 442 443 444 445 446 447 448 449 450 451 452 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 432 def ==(o) return true if self.equal?(o) self.class == o.class && id == o.id && external_id == o.external_id && title == o.title && status == o.status && == o. && create_time == o.create_time && merge_time == o.merge_time && merge_commit_key == o.merge_commit_key && base_commit_key == o.base_commit_key && head_commit_key == o.head_commit_key && files_changed == o.files_changed && lines_added == o.lines_added && lines_deleted == o.lines_deleted && url == o.url && deployments == o.deployments && flag_references == o.flag_references && lead_time == o.lead_time end |
#eql?(o) ⇒ Boolean
456 457 458 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 456 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
462 463 464 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 462 def hash [id, external_id, title, status, , create_time, merge_time, merge_commit_key, base_commit_key, head_commit_key, files_changed, lines_added, lines_deleted, url, deployments, flag_references, lead_time].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 237 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @id.nil? invalid_properties.push('invalid value for "id", id cannot be nil.') end if @external_id.nil? invalid_properties.push('invalid value for "external_id", external_id cannot be nil.') end if @title.nil? invalid_properties.push('invalid value for "title", title cannot be nil.') end if @status.nil? invalid_properties.push('invalid value for "status", status cannot be nil.') end if @author.nil? invalid_properties.push('invalid value for "author", author cannot be nil.') end if @create_time.nil? invalid_properties.push('invalid value for "create_time", create_time cannot be nil.') end if @base_commit_key.nil? invalid_properties.push('invalid value for "base_commit_key", base_commit_key cannot be nil.') end if @head_commit_key.nil? invalid_properties.push('invalid value for "head_commit_key", head_commit_key cannot be nil.') end if @files_changed.nil? invalid_properties.push('invalid value for "files_changed", files_changed cannot be nil.') end if @lines_added.nil? invalid_properties.push('invalid value for "lines_added", lines_added cannot be nil.') end if @lines_deleted.nil? invalid_properties.push('invalid value for "lines_deleted", lines_deleted cannot be nil.') end if @url.nil? invalid_properties.push('invalid value for "url", url cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
491 492 493 494 495 496 497 498 499 500 501 502 503 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 491 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 308 |
# File 'lib/launchdarkly_api/models/pull_request_rep.rb', line 293 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @id.nil? return false if @external_id.nil? return false if @title.nil? return false if @status.nil? return false if @author.nil? return false if @create_time.nil? return false if @base_commit_key.nil? return false if @head_commit_key.nil? return false if @files_changed.nil? return false if @lines_added.nil? return false if @lines_deleted.nil? return false if @url.nil? true end |