Class: LaunchDarklyApi::RelayAutoConfigRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::RelayAutoConfigRep
- Defined in:
- lib/launchdarkly_api/models/relay_auto_config_rep.rb
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_creator ⇒ Object
Returns the value of attribute _creator.
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#creation_date ⇒ Object
Returns the value of attribute creation_date.
-
#display_key ⇒ Object
The last few characters of the Relay Proxy configuration key, displayed in the LaunchDarkly UI.
-
#full_key ⇒ Object
The Relay Proxy configuration key.
-
#last_modified ⇒ Object
Returns the value of attribute last_modified.
-
#name ⇒ Object
A human-friendly name for the Relay Proxy configuration.
-
#policy ⇒ Object
A description of what environments and projects the Relay Proxy should include or exclude.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ RelayAutoConfigRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ RelayAutoConfigRep
Initializes the object
88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 88 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::RelayAutoConfigRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::RelayAutoConfigRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_creator') self._creator = attributes[:'_creator'] end if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'policy') if (value = attributes[:'policy']).is_a?(Array) self.policy = value end else self.policy = nil end if attributes.key?(:'full_key') self.full_key = attributes[:'full_key'] end if attributes.key?(:'display_key') self.display_key = attributes[:'display_key'] else self.display_key = nil end if attributes.key?(:'creation_date') self.creation_date = attributes[:'creation_date'] else self.creation_date = nil end if attributes.key?(:'last_modified') self.last_modified = attributes[:'last_modified'] else self.last_modified = nil end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
22 23 24 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 22 def _access @_access end |
#_creator ⇒ Object
Returns the value of attribute _creator.
20 21 22 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 20 def _creator @_creator end |
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 18 def _id @_id end |
#creation_date ⇒ Object
Returns the value of attribute creation_date.
36 37 38 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 36 def creation_date @creation_date end |
#display_key ⇒ Object
The last few characters of the Relay Proxy configuration key, displayed in the LaunchDarkly UI
34 35 36 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 34 def display_key @display_key end |
#full_key ⇒ Object
The Relay Proxy configuration key
31 32 33 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 31 def full_key @full_key end |
#last_modified ⇒ Object
Returns the value of attribute last_modified.
38 39 40 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 38 def last_modified @last_modified end |
#name ⇒ Object
A human-friendly name for the Relay Proxy configuration
25 26 27 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 25 def name @name end |
#policy ⇒ Object
A description of what environments and projects the Relay Proxy should include or exclude
28 29 30 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 28 def policy @policy end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
56 57 58 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 56 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
61 62 63 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 61 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 53 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 41 def self.attribute_map { :'_id' => :'_id', :'_creator' => :'_creator', :'_access' => :'_access', :'name' => :'name', :'policy' => :'policy', :'full_key' => :'fullKey', :'display_key' => :'displayKey', :'creation_date' => :'creationDate', :'last_modified' => :'lastModified' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
289 290 291 292 293 294 295 296 297 298 299 300 301 302 303 304 305 306 307 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 289 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
81 82 83 84 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 81 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 66 def self.openapi_types { :'_id' => :'String', :'_creator' => :'MemberSummary', :'_access' => :'Access', :'name' => :'String', :'policy' => :'Array<Statement>', :'full_key' => :'String', :'display_key' => :'String', :'creation_date' => :'Integer', :'last_modified' => :'Integer' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
260 261 262 263 264 265 266 267 268 269 270 271 272 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 260 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _creator == o._creator && _access == o._access && name == o.name && policy == o.policy && full_key == o.full_key && display_key == o.display_key && creation_date == o.creation_date && last_modified == o.last_modified end |
#eql?(o) ⇒ Boolean
276 277 278 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 276 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
282 283 284 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 282 def hash [_id, _creator, _access, name, policy, full_key, display_key, creation_date, last_modified].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 155 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @policy.nil? invalid_properties.push('invalid value for "policy", policy cannot be nil.') end if @display_key.nil? invalid_properties.push('invalid value for "display_key", display_key cannot be nil.') end if @creation_date.nil? invalid_properties.push('invalid value for "creation_date", creation_date cannot be nil.') end if @last_modified.nil? invalid_properties.push('invalid value for "last_modified", last_modified cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
311 312 313 314 315 316 317 318 319 320 321 322 323 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 311 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
187 188 189 190 191 192 193 194 195 196 |
# File 'lib/launchdarkly_api/models/relay_auto_config_rep.rb', line 187 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @name.nil? return false if @policy.nil? return false if @display_key.nil? return false if @creation_date.nil? return false if @last_modified.nil? true end |