Class: LaunchDarklyApi::ReleasePhase
- Inherits:
-
Object
- Object
- LaunchDarklyApi::ReleasePhase
- Defined in:
- lib/launchdarkly_api/models/release_phase.rb
Instance Attribute Summary collapse
-
#_audiences ⇒ Object
A logical grouping of one or more environments that share attributes for rolling out changes.
-
#_completed_by ⇒ Object
Returns the value of attribute _completed_by.
-
#_completion_date ⇒ Object
Returns the value of attribute _completion_date.
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_id ⇒ Object
The phase ID.
-
#_name ⇒ Object
The release phase name.
-
#_started_date ⇒ Object
Returns the value of attribute _started_date.
-
#complete ⇒ Object
Whether this phase is complete.
-
#configuration ⇒ Object
Returns the value of attribute configuration.
-
#started ⇒ Object
Whether or not this phase has started.
-
#status ⇒ Object
Returns the value of attribute status.
Class Method Summary collapse
-
._deserialize(type, value) ⇒ Object
Deserializes the data based on type.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
-
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReleasePhase
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility).
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#to_s ⇒ String
Returns the string representation of the object.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Constructor Details
#initialize(attributes = {}) ⇒ ReleasePhase
Initializes the object
92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 92 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleasePhase` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key attributes = attributes.each_with_object({}) { |(k, v), h| if (!self.class.attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleasePhase`. Please check the name to make sure it's valid. List of attributes: " + self.class.attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'_name') self._name = attributes[:'_name'] else self._name = nil end if attributes.key?(:'complete') self.complete = attributes[:'complete'] else self.complete = nil end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] else self._creation_date = nil end if attributes.key?(:'_completion_date') self._completion_date = attributes[:'_completion_date'] end if attributes.key?(:'_completed_by') self._completed_by = attributes[:'_completed_by'] end if attributes.key?(:'_audiences') if (value = attributes[:'_audiences']).is_a?(Array) self._audiences = value end else self._audiences = nil end if attributes.key?(:'status') self.status = attributes[:'status'] end if attributes.key?(:'started') self.started = attributes[:'started'] end if attributes.key?(:'_started_date') self._started_date = attributes[:'_started_date'] end if attributes.key?(:'configuration') self.configuration = attributes[:'configuration'] end end |
Instance Attribute Details
#_audiences ⇒ Object
A logical grouping of one or more environments that share attributes for rolling out changes
34 35 36 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 34 def _audiences @_audiences end |
#_completed_by ⇒ Object
Returns the value of attribute _completed_by.
31 32 33 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 31 def _completed_by @_completed_by end |
#_completion_date ⇒ Object
Returns the value of attribute _completion_date.
29 30 31 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 29 def _completion_date @_completion_date end |
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
27 28 29 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 27 def _creation_date @_creation_date end |
#_id ⇒ Object
The phase ID
19 20 21 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 19 def _id @_id end |
#_name ⇒ Object
The release phase name
22 23 24 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 22 def _name @_name end |
#_started_date ⇒ Object
Returns the value of attribute _started_date.
41 42 43 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 41 def _started_date @_started_date end |
#complete ⇒ Object
Whether this phase is complete
25 26 27 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 25 def complete @complete end |
#configuration ⇒ Object
Returns the value of attribute configuration.
43 44 45 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 43 def configuration @configuration end |
#started ⇒ Object
Whether or not this phase has started
39 40 41 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 39 def started @started end |
#status ⇒ Object
Returns the value of attribute status.
36 37 38 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 36 def status @status end |
Class Method Details
._deserialize(type, value) ⇒ Object
Deserializes the data based on type
259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 287 288 289 290 291 292 293 294 295 296 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 259 def self._deserialize(type, value) case type.to_sym when :Time Time.parse(value) when :Date Date.parse(value) when :String value.to_s when :Integer value.to_i when :Float value.to_f when :Boolean if value.to_s =~ /\A(true|t|yes|y|1)\z/i true else false end when :Object # generic object (usually a Hash), return directly value when /\AArray<(?<inner_type>.+)>\z/ inner_type = Regexp.last_match[:inner_type] value.map { |v| _deserialize(inner_type, v) } when /\AHash<(?<k_type>.+?), (?<v_type>.+)>\z/ k_type = Regexp.last_match[:k_type] v_type = Regexp.last_match[:v_type] {}.tap do |hash| value.each do |k, v| hash[_deserialize(k_type, k)] = _deserialize(v_type, v) end end else # model # models (e.g. Pet) or oneOf klass = LaunchDarklyApi.const_get(type) klass.respond_to?(:openapi_any_of) || klass.respond_to?(:openapi_one_of) ? klass.build(value) : klass.build_from_hash(value) end end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
63 64 65 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 63 def self.acceptable_attributes attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 46 def self.attribute_map { :'_id' => :'_id', :'_name' => :'_name', :'complete' => :'complete', :'_creation_date' => :'_creationDate', :'_completion_date' => :'_completionDate', :'_completed_by' => :'_completedBy', :'_audiences' => :'_audiences', :'status' => :'status', :'started' => :'started', :'_started_date' => :'_startedDate', :'configuration' => :'configuration' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 235 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
85 86 87 88 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 85 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 68 def self.openapi_types { :'_id' => :'String', :'_name' => :'String', :'complete' => :'Boolean', :'_creation_date' => :'Integer', :'_completion_date' => :'Integer', :'_completed_by' => :'CompletedBy', :'_audiences' => :'Array<ReleaseAudience>', :'status' => :'String', :'started' => :'Boolean', :'_started_date' => :'Integer', :'configuration' => :'Object' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 204 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _name == o._name && complete == o.complete && _creation_date == o._creation_date && _completion_date == o._completion_date && _completed_by == o._completed_by && _audiences == o._audiences && status == o.status && started == o.started && _started_date == o._started_date && configuration == o.configuration end |
#_to_hash(value) ⇒ Hash
Outputs non-array value in the form of hash For object, use to_hash. Otherwise, just return the value
330 331 332 333 334 335 336 337 338 339 340 341 342 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 330 def _to_hash(value) if value.is_a?(Array) value.compact.map { |v| _to_hash(v) } elsif value.is_a?(Hash) {}.tap do |hash| value.each { |k, v| hash[k] = _to_hash(v) } end elsif value.respond_to? :to_hash value.to_hash else value end end |
#eql?(o) ⇒ Boolean
222 223 224 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 222 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
228 229 230 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 228 def hash [_id, _name, complete, _creation_date, _completion_date, _completed_by, _audiences, status, started, _started_date, configuration].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 164 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @_name.nil? invalid_properties.push('invalid value for "_name", _name cannot be nil.') end if @complete.nil? invalid_properties.push('invalid value for "complete", complete cannot be nil.') end if @_creation_date.nil? invalid_properties.push('invalid value for "_creation_date", _creation_date cannot be nil.') end if @_audiences.nil? invalid_properties.push('invalid value for "_audiences", _audiences cannot be nil.') end invalid_properties end |
#to_body ⇒ Hash
to_body is an alias to to_hash (backward compatibility)
306 307 308 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 306 def to_body to_hash end |
#to_hash ⇒ Hash
Returns the object in the form of hash
312 313 314 315 316 317 318 319 320 321 322 323 324 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 312 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#to_s ⇒ String
Returns the string representation of the object
300 301 302 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 300 def to_s to_hash.to_s end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
192 193 194 195 196 197 198 199 200 |
# File 'lib/launchdarkly_api/models/release_phase.rb', line 192 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @_name.nil? return false if @complete.nil? return false if @_creation_date.nil? return false if @_audiences.nil? true end |