Class: LaunchDarklyApi::ReleasePolicy
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::ReleasePolicy
- Defined in:
- lib/launchdarkly_api/models/release_policy.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_access ⇒ Object
Returns the value of attribute _access.
-
#_id ⇒ Object
The unique identifier of the release policy.
-
#guarded_release_config ⇒ Object
Returns the value of attribute guarded_release_config.
-
#key ⇒ Object
The human-readable key of the release policy.
-
#name ⇒ Object
The name of the release policy.
-
#progressive_release_config ⇒ Object
Returns the value of attribute progressive_release_config.
-
#rank ⇒ Object
The rank/priority of the release policy.
-
#release_method ⇒ Object
Returns the value of attribute release_method.
-
#scope ⇒ Object
Returns the value of attribute scope.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ ReleasePolicy
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ ReleasePolicy
Initializes the object
110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 110 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::ReleasePolicy` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::ReleasePolicy`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_access') self._access = attributes[:'_access'] end if attributes.key?(:'_id') self._id = attributes[:'_id'] else self._id = nil end if attributes.key?(:'scope') self.scope = attributes[:'scope'] end if attributes.key?(:'rank') self.rank = attributes[:'rank'] else self.rank = nil end if attributes.key?(:'release_method') self.release_method = attributes[:'release_method'] else self.release_method = nil end if attributes.key?(:'guarded_release_config') self.guarded_release_config = attributes[:'guarded_release_config'] end if attributes.key?(:'progressive_release_config') self.progressive_release_config = attributes[:'progressive_release_config'] end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end end |
Instance Attribute Details
#_access ⇒ Object
Returns the value of attribute _access.
18 19 20 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 18 def _access @_access end |
#_id ⇒ Object
The unique identifier of the release policy
21 22 23 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 21 def _id @_id end |
#guarded_release_config ⇒ Object
Returns the value of attribute guarded_release_config.
30 31 32 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 30 def guarded_release_config @guarded_release_config end |
#key ⇒ Object
The human-readable key of the release policy
38 39 40 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 38 def key @key end |
#name ⇒ Object
The name of the release policy
35 36 37 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 35 def name @name end |
#progressive_release_config ⇒ Object
Returns the value of attribute progressive_release_config.
32 33 34 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 32 def progressive_release_config @progressive_release_config end |
#rank ⇒ Object
The rank/priority of the release policy
26 27 28 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 26 def rank @rank end |
#release_method ⇒ Object
Returns the value of attribute release_method.
28 29 30 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 28 def release_method @release_method end |
#scope ⇒ Object
Returns the value of attribute scope.
23 24 25 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 23 def scope @scope end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
78 79 80 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 78 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
83 84 85 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 83 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
63 64 65 66 67 68 69 70 71 72 73 74 75 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 63 def self.attribute_map { :'_access' => :'_access', :'_id' => :'_id', :'scope' => :'scope', :'rank' => :'rank', :'release_method' => :'releaseMethod', :'guarded_release_config' => :'guardedReleaseConfig', :'progressive_release_config' => :'progressiveReleaseConfig', :'name' => :'name', :'key' => :'key' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
301 302 303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 301 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
103 104 105 106 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 103 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
88 89 90 91 92 93 94 95 96 97 98 99 100 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 88 def self.openapi_types { :'_access' => :'ReleasePoliciesAccessRep', :'_id' => :'String', :'scope' => :'ReleasePolicyScope', :'rank' => :'Integer', :'release_method' => :'ReleaseMethod', :'guarded_release_config' => :'GuardedReleaseConfig', :'progressive_release_config' => :'ProgressiveReleaseConfig', :'name' => :'String', :'key' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
272 273 274 275 276 277 278 279 280 281 282 283 284 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 272 def ==(o) return true if self.equal?(o) self.class == o.class && _access == o._access && _id == o._id && scope == o.scope && rank == o.rank && release_method == o.release_method && guarded_release_config == o.guarded_release_config && progressive_release_config == o.progressive_release_config && name == o.name && key == o.key end |
#eql?(o) ⇒ Boolean
288 289 290 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 288 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
294 295 296 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 294 def hash [_access, _id, scope, rank, release_method, guarded_release_config, progressive_release_config, name, key].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 173 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @_id.nil? invalid_properties.push('invalid value for "_id", _id cannot be nil.') end if @rank.nil? invalid_properties.push('invalid value for "rank", rank cannot be nil.') end if @release_method.nil? invalid_properties.push('invalid value for "release_method", release_method cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @name.to_s.length > 256 invalid_properties.push('invalid value for "name", the character length must be smaller than or equal to 256.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
323 324 325 326 327 328 329 330 331 332 333 334 335 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 323 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
205 206 207 208 209 210 211 212 213 214 |
# File 'lib/launchdarkly_api/models/release_policy.rb', line 205 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @_id.nil? return false if @rank.nil? return false if @release_method.nil? return false if @name.nil? return false if @name.to_s.length > 256 return false if @key.nil? true end |