Class: LaunchDarklyApi::Rule
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::Rule
- Defined in:
- lib/launchdarkly_api/models/rule.rb
Instance Attribute Summary collapse
-
#_id ⇒ Object
The flag rule ID.
-
#clauses ⇒ Object
An array of clauses used for individual targeting based on attributes.
-
#description ⇒ Object
The rule description.
-
#disabled ⇒ Object
Whether the rule is disabled.
-
#ref ⇒ Object
Returns the value of attribute ref.
-
#rollout ⇒ Object
Returns the value of attribute rollout.
-
#track_events ⇒ Object
Whether LaunchDarkly tracks events for this rule.
-
#variation ⇒ Object
The index of the variation, from the array of variations for this flag.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ Rule
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ Rule
Initializes the object
86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 |
# File 'lib/launchdarkly_api/models/rule.rb', line 86 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::Rule` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::Rule`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'disabled') self.disabled = attributes[:'disabled'] end if attributes.key?(:'variation') self.variation = attributes[:'variation'] end if attributes.key?(:'rollout') self.rollout = attributes[:'rollout'] end if attributes.key?(:'clauses') if (value = attributes[:'clauses']).is_a?(Array) self.clauses = value end else self.clauses = nil end if attributes.key?(:'track_events') self.track_events = attributes[:'track_events'] else self.track_events = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'ref') self.ref = attributes[:'ref'] end end |
Instance Attribute Details
#_id ⇒ Object
The flag rule ID
19 20 21 |
# File 'lib/launchdarkly_api/models/rule.rb', line 19 def _id @_id end |
#clauses ⇒ Object
An array of clauses used for individual targeting based on attributes
30 31 32 |
# File 'lib/launchdarkly_api/models/rule.rb', line 30 def clauses @clauses end |
#description ⇒ Object
The rule description
36 37 38 |
# File 'lib/launchdarkly_api/models/rule.rb', line 36 def description @description end |
#disabled ⇒ Object
Whether the rule is disabled
22 23 24 |
# File 'lib/launchdarkly_api/models/rule.rb', line 22 def disabled @disabled end |
#ref ⇒ Object
Returns the value of attribute ref.
38 39 40 |
# File 'lib/launchdarkly_api/models/rule.rb', line 38 def ref @ref end |
#rollout ⇒ Object
Returns the value of attribute rollout.
27 28 29 |
# File 'lib/launchdarkly_api/models/rule.rb', line 27 def rollout @rollout end |
#track_events ⇒ Object
Whether LaunchDarkly tracks events for this rule
33 34 35 |
# File 'lib/launchdarkly_api/models/rule.rb', line 33 def track_events @track_events end |
#variation ⇒ Object
The index of the variation, from the array of variations for this flag
25 26 27 |
# File 'lib/launchdarkly_api/models/rule.rb', line 25 def variation @variation end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
55 56 57 |
# File 'lib/launchdarkly_api/models/rule.rb', line 55 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
60 61 62 |
# File 'lib/launchdarkly_api/models/rule.rb', line 60 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
41 42 43 44 45 46 47 48 49 50 51 52 |
# File 'lib/launchdarkly_api/models/rule.rb', line 41 def self.attribute_map { :'_id' => :'_id', :'disabled' => :'disabled', :'variation' => :'variation', :'rollout' => :'rollout', :'clauses' => :'clauses', :'track_events' => :'trackEvents', :'description' => :'description', :'ref' => :'ref' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 |
# File 'lib/launchdarkly_api/models/rule.rb', line 214 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
79 80 81 82 |
# File 'lib/launchdarkly_api/models/rule.rb', line 79 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
65 66 67 68 69 70 71 72 73 74 75 76 |
# File 'lib/launchdarkly_api/models/rule.rb', line 65 def self.openapi_types { :'_id' => :'String', :'disabled' => :'Boolean', :'variation' => :'Integer', :'rollout' => :'Rollout', :'clauses' => :'Array<Clause>', :'track_events' => :'Boolean', :'description' => :'String', :'ref' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
186 187 188 189 190 191 192 193 194 195 196 197 |
# File 'lib/launchdarkly_api/models/rule.rb', line 186 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && disabled == o.disabled && variation == o.variation && rollout == o.rollout && clauses == o.clauses && track_events == o.track_events && description == o.description && ref == o.ref end |
#eql?(o) ⇒ Boolean
201 202 203 |
# File 'lib/launchdarkly_api/models/rule.rb', line 201 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
207 208 209 |
# File 'lib/launchdarkly_api/models/rule.rb', line 207 def hash [_id, disabled, variation, rollout, clauses, track_events, description, ref].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
141 142 143 144 145 146 147 148 149 150 151 152 153 |
# File 'lib/launchdarkly_api/models/rule.rb', line 141 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @clauses.nil? invalid_properties.push('invalid value for "clauses", clauses cannot be nil.') end if @track_events.nil? invalid_properties.push('invalid value for "track_events", track_events cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
236 237 238 239 240 241 242 243 244 245 246 247 248 |
# File 'lib/launchdarkly_api/models/rule.rb', line 236 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
157 158 159 160 161 162 |
# File 'lib/launchdarkly_api/models/rule.rb', line 157 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @clauses.nil? return false if @track_events.nil? true end |