Class: LaunchDarklyApi::SdkKey
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::SdkKey
- Defined in:
- lib/launchdarkly_api/models/sdk_key.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_created_at ⇒ Object
Returns the value of attribute _created_at.
-
#_created_by_member_id ⇒ Object
The ID of the member who created the SDK key.
-
#_links ⇒ Object
Returns the value of attribute _links.
-
#_updated_at ⇒ Object
Returns the value of attribute _updated_at.
-
#_version ⇒ Object
The auto-incremented version number of the SDK key.
-
#description ⇒ Object
The optional description of the SDK key.
-
#expiry ⇒ Object
Returns the value of attribute expiry.
-
#is_default ⇒ Object
Indicates if this SDK key is the system-defined default for the environment.
-
#key ⇒ Object
The user-defined identifying key of the SDK key.
-
#kind ⇒ Object
Returns the value of attribute kind.
-
#name ⇒ Object
The human-readable name of the SDK key.
-
#value ⇒ Object
The string value of the SDK key.
-
#view_summaries ⇒ Object
Summaries of views associated with the SDK key.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SdkKey
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SdkKey
Initializes the object
130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 130 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::SdkKey` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::SdkKey`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_links') self._links = attributes[:'_links'] end if attributes.key?(:'kind') self.kind = attributes[:'kind'] else self.kind = nil end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'expiry') self.expiry = attributes[:'expiry'] end if attributes.key?(:'value') self.value = attributes[:'value'] else self.value = nil end if attributes.key?(:'is_default') self.is_default = attributes[:'is_default'] else self.is_default = nil end if attributes.key?(:'_created_by_member_id') self._created_by_member_id = attributes[:'_created_by_member_id'] end if attributes.key?(:'_created_at') self._created_at = attributes[:'_created_at'] else self._created_at = nil end if attributes.key?(:'_updated_at') self._updated_at = attributes[:'_updated_at'] else self._updated_at = nil end if attributes.key?(:'_version') self._version = attributes[:'_version'] else self._version = nil end if attributes.key?(:'view_summaries') if (value = attributes[:'view_summaries']).is_a?(Array) self.view_summaries = value end end end |
Instance Attribute Details
#_created_at ⇒ Object
Returns the value of attribute _created_at.
42 43 44 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 42 def _created_at @_created_at end |
#_created_by_member_id ⇒ Object
The ID of the member who created the SDK key. This field is immutable.
40 41 42 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 40 def _created_by_member_id @_created_by_member_id end |
#_links ⇒ Object
Returns the value of attribute _links.
18 19 20 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 18 def _links @_links end |
#_updated_at ⇒ Object
Returns the value of attribute _updated_at.
44 45 46 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 44 def _updated_at @_updated_at end |
#_version ⇒ Object
The auto-incremented version number of the SDK key.
47 48 49 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 47 def _version @_version end |
#description ⇒ Object
The optional description of the SDK key.
29 30 31 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 29 def description @description end |
#expiry ⇒ Object
Returns the value of attribute expiry.
31 32 33 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 31 def expiry @expiry end |
#is_default ⇒ Object
Indicates if this SDK key is the system-defined default for the environment. There may also be an expiring default SDK key for the environment (not possible with mobile keys).
37 38 39 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 37 def is_default @is_default end |
#key ⇒ Object
The user-defined identifying key of the SDK key. This is used solely to identify an SDK key and is distinct from the value field, which is the actual SDK key value.
23 24 25 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 23 def key @key end |
#kind ⇒ Object
Returns the value of attribute kind.
20 21 22 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 20 def kind @kind end |
#name ⇒ Object
The human-readable name of the SDK key.
26 27 28 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 26 def name @name end |
#value ⇒ Object
The string value of the SDK key. Use this when configuring your SDK.
34 35 36 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 34 def value @value end |
#view_summaries ⇒ Object
Summaries of views associated with the SDK key.
50 51 52 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 50 def view_summaries @view_summaries end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
94 95 96 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 94 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
99 100 101 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 99 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
75 76 77 78 79 80 81 82 83 84 85 86 87 88 89 90 91 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 75 def self.attribute_map { :'_links' => :'_links', :'kind' => :'kind', :'key' => :'key', :'name' => :'name', :'description' => :'description', :'expiry' => :'expiry', :'value' => :'value', :'is_default' => :'isDefault', :'_created_by_member_id' => :'_createdByMemberId', :'_created_at' => :'_createdAt', :'_updated_at' => :'_updatedAt', :'_version' => :'_version', :'view_summaries' => :'viewSummaries' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 385 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
123 124 125 126 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 123 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 104 def self.openapi_types { :'_links' => :'ParentAndSelfLinks', :'kind' => :'SdkKeyKind', :'key' => :'String', :'name' => :'String', :'description' => :'String', :'expiry' => :'Integer', :'value' => :'String', :'is_default' => :'Boolean', :'_created_by_member_id' => :'String', :'_created_at' => :'Integer', :'_updated_at' => :'Integer', :'_version' => :'Integer', :'view_summaries' => :'Array<ViewSummary>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
352 353 354 355 356 357 358 359 360 361 362 363 364 365 366 367 368 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 352 def ==(o) return true if self.equal?(o) self.class == o.class && _links == o._links && kind == o.kind && key == o.key && name == o.name && description == o.description && expiry == o.expiry && value == o.value && is_default == o.is_default && _created_by_member_id == o._created_by_member_id && _created_at == o._created_at && _updated_at == o._updated_at && _version == o._version && view_summaries == o.view_summaries end |
#eql?(o) ⇒ Boolean
372 373 374 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 372 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
378 379 380 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 378 def hash [_links, kind, key, name, description, expiry, value, is_default, _created_by_member_id, _created_at, _updated_at, _version, view_summaries].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
217 218 219 220 221 222 223 224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 217 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @kind.nil? invalid_properties.push('invalid value for "kind", kind cannot be nil.') end if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end if @value.nil? invalid_properties.push('invalid value for "value", value cannot be nil.') end if @is_default.nil? invalid_properties.push('invalid value for "is_default", is_default cannot be nil.') end if @_created_at.nil? invalid_properties.push('invalid value for "_created_at", _created_at cannot be nil.') end if @_updated_at.nil? invalid_properties.push('invalid value for "_updated_at", _updated_at cannot be nil.') end if @_version.nil? invalid_properties.push('invalid value for "_version", _version cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
407 408 409 410 411 412 413 414 415 416 417 418 419 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 407 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
257 258 259 260 261 262 263 264 265 266 267 268 |
# File 'lib/launchdarkly_api/models/sdk_key.rb', line 257 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @kind.nil? return false if @key.nil? return false if @name.nil? return false if @value.nil? return false if @is_default.nil? return false if @_created_at.nil? return false if @_updated_at.nil? return false if @_version.nil? true end |