Class: LaunchDarklyApi::SdkVersionDetailsRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::SdkVersionDetailsRep
- Defined in:
- lib/launchdarkly_api/models/sdk_version_details_rep.rb
Instance Attribute Summary collapse
-
#application_id ⇒ Object
Returns the value of attribute application_id.
-
#connection_type ⇒ Object
Returns the value of attribute connection_type.
-
#environment_id ⇒ Object
Returns the value of attribute environment_id.
-
#environment_key ⇒ Object
Returns the value of attribute environment_key.
-
#environment_name ⇒ Object
Returns the value of attribute environment_name.
-
#eol_status ⇒ Object
The end of life (EOL) status of the SDK version.
-
#latest_release_url ⇒ Object
Returns the value of attribute latest_release_url.
-
#ld_latest_version ⇒ Object
Returns the value of attribute ld_latest_version.
-
#name ⇒ Object
Returns the value of attribute name.
-
#project_id ⇒ Object
Returns the value of attribute project_id.
-
#project_key ⇒ Object
Returns the value of attribute project_key.
-
#project_name ⇒ Object
Returns the value of attribute project_name.
-
#relay_eol_status ⇒ Object
The end of life status of the Relay Proxy version.
-
#relay_latest_release_url ⇒ Object
Returns the value of attribute relay_latest_release_url.
-
#relay_latest_version ⇒ Object
Returns the value of attribute relay_latest_version.
-
#relay_version ⇒ Object
Returns the value of attribute relay_version.
-
#type ⇒ Object
Returns the value of attribute type.
-
#version ⇒ Object
Returns the value of attribute version.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ SdkVersionDetailsRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ SdkVersionDetailsRep
Initializes the object
122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 122 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::SdkVersionDetailsRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::SdkVersionDetailsRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'version') self.version = attributes[:'version'] end if attributes.key?(:'type') self.type = attributes[:'type'] end if attributes.key?(:'project_id') self.project_id = attributes[:'project_id'] end if attributes.key?(:'project_key') self.project_key = attributes[:'project_key'] end if attributes.key?(:'project_name') self.project_name = attributes[:'project_name'] end if attributes.key?(:'environment_id') self.environment_id = attributes[:'environment_id'] end if attributes.key?(:'environment_key') self.environment_key = attributes[:'environment_key'] end if attributes.key?(:'environment_name') self.environment_name = attributes[:'environment_name'] end if attributes.key?(:'application_id') self.application_id = attributes[:'application_id'] end if attributes.key?(:'ld_latest_version') self.ld_latest_version = attributes[:'ld_latest_version'] end if attributes.key?(:'eol_status') self.eol_status = attributes[:'eol_status'] end if attributes.key?(:'latest_release_url') self.latest_release_url = attributes[:'latest_release_url'] end if attributes.key?(:'connection_type') self.connection_type = attributes[:'connection_type'] end if attributes.key?(:'relay_version') self.relay_version = attributes[:'relay_version'] end if attributes.key?(:'relay_eol_status') self.relay_eol_status = attributes[:'relay_eol_status'] end if attributes.key?(:'relay_latest_version') self.relay_latest_version = attributes[:'relay_latest_version'] end if attributes.key?(:'relay_latest_release_url') self.relay_latest_release_url = attributes[:'relay_latest_release_url'] end end |
Instance Attribute Details
#application_id ⇒ Object
Returns the value of attribute application_id.
36 37 38 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 36 def application_id @application_id end |
#connection_type ⇒ Object
Returns the value of attribute connection_type.
45 46 47 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 45 def connection_type @connection_type end |
#environment_id ⇒ Object
Returns the value of attribute environment_id.
30 31 32 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 30 def environment_id @environment_id end |
#environment_key ⇒ Object
Returns the value of attribute environment_key.
32 33 34 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 32 def environment_key @environment_key end |
#environment_name ⇒ Object
Returns the value of attribute environment_name.
34 35 36 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 34 def environment_name @environment_name end |
#eol_status ⇒ Object
The end of life (EOL) status of the SDK version. Possible values are:
- EolAllClear: the SDK version is current
- EolNear: the SDK version is approaching EOL
- EolPast: the SDK version is past EOL
- MajorVersionAvailable: a new major version is available but the current version is not near EOL
- EolUnknown: the EOL status cannot be determined.
41 42 43 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 41 def eol_status @eol_status end |
#latest_release_url ⇒ Object
Returns the value of attribute latest_release_url.
43 44 45 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 43 def latest_release_url @latest_release_url end |
#ld_latest_version ⇒ Object
Returns the value of attribute ld_latest_version.
38 39 40 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 38 def ld_latest_version @ld_latest_version end |
#name ⇒ Object
Returns the value of attribute name.
18 19 20 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 18 def name @name end |
#project_id ⇒ Object
Returns the value of attribute project_id.
24 25 26 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 24 def project_id @project_id end |
#project_key ⇒ Object
Returns the value of attribute project_key.
26 27 28 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 26 def project_key @project_key end |
#project_name ⇒ Object
Returns the value of attribute project_name.
28 29 30 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 28 def project_name @project_name end |
#relay_eol_status ⇒ Object
The end of life status of the Relay Proxy version. Only present when the SDK connects through a Relay Proxy. Uses the same values as eolStatus.
50 51 52 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 50 def relay_eol_status @relay_eol_status end |
#relay_latest_release_url ⇒ Object
Returns the value of attribute relay_latest_release_url.
54 55 56 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 54 def relay_latest_release_url @relay_latest_release_url end |
#relay_latest_version ⇒ Object
Returns the value of attribute relay_latest_version.
52 53 54 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 52 def relay_latest_version @relay_latest_version end |
#relay_version ⇒ Object
Returns the value of attribute relay_version.
47 48 49 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 47 def relay_version @relay_version end |
#type ⇒ Object
Returns the value of attribute type.
22 23 24 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 22 def type @type end |
#version ⇒ Object
Returns the value of attribute version.
20 21 22 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 20 def version @version end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
81 82 83 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 81 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
86 87 88 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 86 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 57 def self.attribute_map { :'name' => :'name', :'version' => :'version', :'type' => :'type', :'project_id' => :'projectId', :'project_key' => :'projectKey', :'project_name' => :'projectName', :'environment_id' => :'environmentId', :'environment_key' => :'environmentKey', :'environment_name' => :'environmentName', :'application_id' => :'applicationId', :'ld_latest_version' => :'ldLatestVersion', :'eol_status' => :'eolStatus', :'latest_release_url' => :'latestReleaseUrl', :'connection_type' => :'connectionType', :'relay_version' => :'relayVersion', :'relay_eol_status' => :'relayEolStatus', :'relay_latest_version' => :'relayLatestVersion', :'relay_latest_release_url' => :'relayLatestReleaseUrl' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 264 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
115 116 117 118 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 115 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 91 def self.openapi_types { :'name' => :'String', :'version' => :'String', :'type' => :'String', :'project_id' => :'String', :'project_key' => :'String', :'project_name' => :'String', :'environment_id' => :'String', :'environment_key' => :'String', :'environment_name' => :'String', :'application_id' => :'String', :'ld_latest_version' => :'String', :'eol_status' => :'String', :'latest_release_url' => :'String', :'connection_type' => :'String', :'relay_version' => :'String', :'relay_eol_status' => :'String', :'relay_latest_version' => :'String', :'relay_latest_release_url' => :'String' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 226 def ==(o) return true if self.equal?(o) self.class == o.class && name == o.name && version == o.version && type == o.type && project_id == o.project_id && project_key == o.project_key && project_name == o.project_name && environment_id == o.environment_id && environment_key == o.environment_key && environment_name == o.environment_name && application_id == o.application_id && ld_latest_version == o.ld_latest_version && eol_status == o.eol_status && latest_release_url == o.latest_release_url && connection_type == o.connection_type && relay_version == o.relay_version && relay_eol_status == o.relay_eol_status && relay_latest_version == o.relay_latest_version && relay_latest_release_url == o.relay_latest_release_url end |
#eql?(o) ⇒ Boolean
251 252 253 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 251 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
257 258 259 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 257 def hash [name, version, type, project_id, project_key, project_name, environment_id, environment_key, environment_name, application_id, ld_latest_version, eol_status, latest_release_url, connection_type, relay_version, relay_eol_status, relay_latest_version, relay_latest_release_url].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
211 212 213 214 215 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 211 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
286 287 288 289 290 291 292 293 294 295 296 297 298 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 286 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
219 220 221 222 |
# File 'lib/launchdarkly_api/models/sdk_version_details_rep.rb', line 219 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |