Class: LaunchDarklyApi::TeamPostInput
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::TeamPostInput
- Defined in:
- lib/launchdarkly_api/models/team_post_input.rb
Instance Attribute Summary collapse
-
#custom_role_keys ⇒ Object
List of custom role keys the team will access.
-
#description ⇒ Object
A description of the team.
-
#key ⇒ Object
The team key.
-
#member_ids ⇒ Object
A list of member IDs who belong to the team.
-
#name ⇒ Object
A human-friendly name for the team.
-
#permission_grants ⇒ Object
A list of permission grants.
-
#role_attributes ⇒ Object
Returns the value of attribute role_attributes.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TeamPostInput
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TeamPostInput
Initializes the object
82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 99 100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 82 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::TeamPostInput` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::TeamPostInput`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'custom_role_keys') if (value = attributes[:'custom_role_keys']).is_a?(Array) self.custom_role_keys = value end end if attributes.key?(:'description') self.description = attributes[:'description'] end if attributes.key?(:'key') self.key = attributes[:'key'] else self.key = nil end if attributes.key?(:'member_ids') if (value = attributes[:'member_ids']).is_a?(Array) self.member_ids = value end end if attributes.key?(:'name') self.name = attributes[:'name'] else self.name = nil end if attributes.key?(:'permission_grants') if (value = attributes[:'permission_grants']).is_a?(Array) self. = value end end if attributes.key?(:'role_attributes') if (value = attributes[:'role_attributes']).is_a?(Hash) self.role_attributes = value end end end |
Instance Attribute Details
#custom_role_keys ⇒ Object
List of custom role keys the team will access
19 20 21 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 19 def custom_role_keys @custom_role_keys end |
#description ⇒ Object
A description of the team
22 23 24 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 22 def description @description end |
#key ⇒ Object
The team key
25 26 27 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 25 def key @key end |
#member_ids ⇒ Object
A list of member IDs who belong to the team
28 29 30 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 28 def member_ids @member_ids end |
#name ⇒ Object
A human-friendly name for the team
31 32 33 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 31 def name @name end |
#permission_grants ⇒ Object
A list of permission grants. Permission grants allow access to a specific action, without having to create or update a custom role.
34 35 36 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 34 def @permission_grants end |
#role_attributes ⇒ Object
Returns the value of attribute role_attributes.
36 37 38 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 36 def role_attributes @role_attributes end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
52 53 54 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 52 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
57 58 59 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 57 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
39 40 41 42 43 44 45 46 47 48 49 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 39 def self.attribute_map { :'custom_role_keys' => :'customRoleKeys', :'description' => :'description', :'key' => :'key', :'member_ids' => :'memberIDs', :'name' => :'name', :'permission_grants' => :'permissionGrants', :'role_attributes' => :'roleAttributes' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
211 212 213 214 215 216 217 218 219 220 221 222 223 224 225 226 227 228 229 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 211 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
75 76 77 78 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 75 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
62 63 64 65 66 67 68 69 70 71 72 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 62 def self.openapi_types { :'custom_role_keys' => :'Array<String>', :'description' => :'String', :'key' => :'String', :'member_ids' => :'Array<String>', :'name' => :'String', :'permission_grants' => :'Array<PermissionGrantInput>', :'role_attributes' => :'Hash<String, Array>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
184 185 186 187 188 189 190 191 192 193 194 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 184 def ==(o) return true if self.equal?(o) self.class == o.class && custom_role_keys == o.custom_role_keys && description == o.description && key == o.key && member_ids == o.member_ids && name == o.name && == o. && role_attributes == o.role_attributes end |
#eql?(o) ⇒ Boolean
198 199 200 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 198 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
204 205 206 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 204 def hash [custom_role_keys, description, key, member_ids, name, , role_attributes].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
139 140 141 142 143 144 145 146 147 148 149 150 151 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 139 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new if @key.nil? invalid_properties.push('invalid value for "key", key cannot be nil.') end if @name.nil? invalid_properties.push('invalid value for "name", name cannot be nil.') end invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
233 234 235 236 237 238 239 240 241 242 243 244 245 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 233 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
155 156 157 158 159 160 |
# File 'lib/launchdarkly_api/models/team_post_input.rb', line 155 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' return false if @key.nil? return false if @name.nil? true end |