Class: LaunchDarklyApi::TeamsBetaApi
- Inherits:
-
Object
- Object
- LaunchDarklyApi::TeamsBetaApi
- Defined in:
- lib/launchdarkly_api/api/teams_beta_api.rb
Instance Attribute Summary collapse
-
#api_client ⇒ Object
Returns the value of attribute api_client.
Instance Method Summary collapse
-
#delete_team(key, opts = {}) ⇒ nil
Delete team Delete a team by key.
-
#delete_team_with_http_info(key, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete team Delete a team by key.
-
#get_team(key, opts = {}) ⇒ ExpandedTeamRep
Get team Fetch a team by key.
-
#get_team_with_http_info(key, opts = {}) ⇒ Array<(ExpandedTeamRep, Integer, Hash)>
Get team Fetch a team by key.
-
#get_teams(opts = {}) ⇒ TeamCollectionRep
List teams Return a list of teams.
-
#get_teams_with_http_info(opts = {}) ⇒ Array<(TeamCollectionRep, Integer, Hash)>
List teams Return a list of teams.
-
#initialize(api_client = ApiClient.default) ⇒ TeamsBetaApi
constructor
A new instance of TeamsBetaApi.
-
#patch_team(key, team_patch_input, opts = {}) ⇒ ExpandedTeamRep
Update team Perform a partial update to a team.
-
#patch_team_with_http_info(key, team_patch_input, opts = {}) ⇒ Array<(ExpandedTeamRep, Integer, Hash)>
Update team Perform a partial update to a team.
-
#post_team(team_post_input, opts = {}) ⇒ TeamRep
Create team Create a team.
-
#post_team_members(key, opts = {}) ⇒ TeamImportsRep
Add members to team Add multiple members to an existing team by uploading a CSV file of member email addresses.
-
#post_team_members_with_http_info(key, opts = {}) ⇒ Array<(TeamImportsRep, Integer, Hash)>
Add members to team Add multiple members to an existing team by uploading a CSV file of member email addresses.
-
#post_team_with_http_info(team_post_input, opts = {}) ⇒ Array<(TeamRep, Integer, Hash)>
Create team Create a team.
Constructor Details
#initialize(api_client = ApiClient.default) ⇒ TeamsBetaApi
Returns a new instance of TeamsBetaApi.
19 20 21 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 19 def initialize(api_client = ApiClient.default) @api_client = api_client end |
Instance Attribute Details
#api_client ⇒ Object
Returns the value of attribute api_client.
17 18 19 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 17 def api_client @api_client end |
Instance Method Details
#delete_team(key, opts = {}) ⇒ nil
Delete team Delete a team by key
27 28 29 30 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 27 def delete_team(key, opts = {}) delete_team_with_http_info(key, opts) nil end |
#delete_team_with_http_info(key, opts = {}) ⇒ Array<(nil, Integer, Hash)>
Delete team Delete a team by key
37 38 39 40 41 42 43 44 45 46 47 48 49 50 51 52 53 54 55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 71 72 73 74 75 76 77 78 79 80 81 82 83 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 37 def delete_team_with_http_info(key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsBetaApi.delete_team ...' end # verify the required parameter 'key' is set if @api_client.config.client_side_validation && key.nil? fail ArgumentError, "Missing the required parameter 'key' when calling TeamsBetaApi.delete_team" end # resource path local_var_path = '/api/v2/teams/{key}'.sub('{' + 'key' + '}', CGI.escape(key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"TeamsBetaApi.delete_team", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:DELETE, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsBetaApi#delete_team\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_team(key, opts = {}) ⇒ ExpandedTeamRep
Get team Fetch a team by key
90 91 92 93 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 90 def get_team(key, opts = {}) data, _status_code, _headers = get_team_with_http_info(key, opts) data end |
#get_team_with_http_info(key, opts = {}) ⇒ Array<(ExpandedTeamRep, Integer, Hash)>
Get team Fetch a team by key
100 101 102 103 104 105 106 107 108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 100 def get_team_with_http_info(key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsBetaApi.get_team ...' end # verify the required parameter 'key' is set if @api_client.config.client_side_validation && key.nil? fail ArgumentError, "Missing the required parameter 'key' when calling TeamsBetaApi.get_team" end # resource path local_var_path = '/api/v2/teams/{key}'.sub('{' + 'key' + '}', CGI.escape(key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'ExpandedTeamRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"TeamsBetaApi.get_team", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsBetaApi#get_team\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#get_teams(opts = {}) ⇒ TeamCollectionRep
List teams Return a list of teams. By default, this returns the first 20 teams. Page through this list with the `limit` parameter and by following the `first`, `prev`, `next`, and `last` links in the returned `_links` field. These links are not present if the pages they refer to don't exist. For example, the `first` and `prev` links will be missing from the response on the first page. ### Filtering teams LaunchDarkly supports the `query` field for filtering. `query` is a string that matches against the teams' names and keys. It is not case sensitive. For example, the filter `query:abc` matches teams with the string `abc` in their name or key.
155 156 157 158 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 155 def get_teams(opts = {}) data, _status_code, _headers = get_teams_with_http_info(opts) data end |
#get_teams_with_http_info(opts = {}) ⇒ Array<(TeamCollectionRep, Integer, Hash)>
List teams Return a list of teams. By default, this returns the first 20 teams. Page through this list with the `limit` parameter and by following the `first`, `prev`, `next`, and `last` links in the returned `_links` field. These links are not present if the pages they refer to don't exist. For example, the `first` and `prev` links will be missing from the response on the first page. ### Filtering teams LaunchDarkly supports the `query` field for filtering. `query` is a string that matches against the teams' names and keys. It is not case sensitive. For example, the filter `query:abc` matches teams with the string `abc` in their name or key.
167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 167 def get_teams_with_http_info(opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsBetaApi.get_teams ...' end # resource path local_var_path = '/api/v2/teams' # query parameters query_params = opts[:query_params] || {} query_params[:'limit'] = opts[:'limit'] if !opts[:'limit'].nil? query_params[:'offset'] = opts[:'offset'] if !opts[:'offset'].nil? query_params[:'filter'] = opts[:'filter'] if !opts[:'filter'].nil? # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TeamCollectionRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"TeamsBetaApi.get_teams", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:GET, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsBetaApi#get_teams\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#patch_team(key, team_patch_input, opts = {}) ⇒ ExpandedTeamRep
Update team Perform a partial update to a team. The body of a semantic patch request takes the following three properties: 1. comment `string`: (Optional) A description of the update. 1. instructions `array`: (Required) The action or list of actions to be performed by the update. Each update action in the list must be an object/hash table with a `kind` property, although depending on the action, other properties may be necessary. Read below for more information on the specific supported semantic patch instructions. If any instruction in the patch encounters an error, the error will be returned and the flag will not be changed. In general, instructions will silently do nothing if the flag is already in the state requested by the patch instruction. They will generally error if a parameter refers to something that does not exist. Other specific error conditions are noted in the instruction descriptions. ### Instructions #### `addCustomRoles` Adds custom roles to the team. Team members will have these custom roles granted to them. ##### Parameters - `values`: list of custom role keys #### `removeCustomRoles` Removes the custom roles on the team. Team members will no longer have these custom roles granted to them. ##### Parameters - `values`: list of custom role keys #### `addMembers` Adds members to the team. ##### Parameters - `values`: list of member IDs #### `removeMembers` Removes members from the team. ##### Parameters - `values`: list of member IDs #### `addPermissionGrants` Adds permission grants to members for the team, allowing them to, for example, act as a team maintainer. A permission grant may have either an `actionSet` or a list of `actions` but not both at the same time. The members do not have to be team members to have a permission grant for the team. ##### Parameters - `actionSet`: name of the action set - `actions`: list of actions - `memberIDs`: list of member IDs #### `removePermissionGrants` Removes permission grants from members for the team. The `actionSet` and `actions` must match an existing permission grant. ##### Parameters - `actionSet`: name of the action set - `actions`: list of actions - `memberIDs`: list of member IDs #### `updateDescription` Updates the team's description. ##### Parameters - `value`: the team's new description #### `updateName` Updates the team's name. ##### Parameters - `value`: the team's new name
220 221 222 223 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 220 def patch_team(key, team_patch_input, opts = {}) data, _status_code, _headers = patch_team_with_http_info(key, team_patch_input, opts) data end |
#patch_team_with_http_info(key, team_patch_input, opts = {}) ⇒ Array<(ExpandedTeamRep, Integer, Hash)>
Update team Perform a partial update to a team. The body of a semantic patch request takes the following three properties: 1. comment `string`: (Optional) A description of the update. 1. instructions `array`: (Required) The action or list of actions to be performed by the update. Each update action in the list must be an object/hash table with a `kind` property, although depending on the action, other properties may be necessary. Read below for more information on the specific supported semantic patch instructions. If any instruction in the patch encounters an error, the error will be returned and the flag will not be changed. In general, instructions will silently do nothing if the flag is already in the state requested by the patch instruction. They will generally error if a parameter refers to something that does not exist. Other specific error conditions are noted in the instruction descriptions. ### Instructions #### `addCustomRoles` Adds custom roles to the team. Team members will have these custom roles granted to them. ##### Parameters - `values`: list of custom role keys #### `removeCustomRoles` Removes the custom roles on the team. Team members will no longer have these custom roles granted to them. ##### Parameters - `values`: list of custom role keys #### `addMembers` Adds members to the team. ##### Parameters - `values`: list of member IDs #### `removeMembers` Removes members from the team. ##### Parameters - `values`: list of member IDs #### `addPermissionGrants` Adds permission grants to members for the team, allowing them to, for example, act as a team maintainer. A permission grant may have either an `actionSet` or a list of `actions` but not both at the same time. The members do not have to be team members to have a permission grant for the team. ##### Parameters - `actionSet`: name of the action set - `actions`: list of actions - `memberIDs`: list of member IDs #### `removePermissionGrants` Removes permission grants from members for the team. The `actionSet` and `actions` must match an existing permission grant. ##### Parameters - `actionSet`: name of the action set - `actions`: list of actions - `memberIDs`: list of member IDs #### `updateDescription` Updates the team's description. ##### Parameters - `value`: the team's new description #### `updateName` Updates the team's name. ##### Parameters - `value`: the team's new name
231 232 233 234 235 236 237 238 239 240 241 242 243 244 245 246 247 248 249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 268 269 270 271 272 273 274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 231 def patch_team_with_http_info(key, team_patch_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsBetaApi.patch_team ...' end # verify the required parameter 'key' is set if @api_client.config.client_side_validation && key.nil? fail ArgumentError, "Missing the required parameter 'key' when calling TeamsBetaApi.patch_team" end # verify the required parameter 'team_patch_input' is set if @api_client.config.client_side_validation && team_patch_input.nil? fail ArgumentError, "Missing the required parameter 'team_patch_input' when calling TeamsBetaApi.patch_team" end # resource path local_var_path = '/api/v2/teams/{key}'.sub('{' + 'key' + '}', CGI.escape(key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(team_patch_input) # return_type return_type = opts[:debug_return_type] || 'ExpandedTeamRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"TeamsBetaApi.patch_team", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:PATCH, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsBetaApi#patch_team\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_team(team_post_input, opts = {}) ⇒ TeamRep
Create team Create a team
293 294 295 296 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 293 def post_team(team_post_input, opts = {}) data, _status_code, _headers = post_team_with_http_info(team_post_input, opts) data end |
#post_team_members(key, opts = {}) ⇒ TeamImportsRep
Add members to team Add multiple members to an existing team by uploading a CSV file of member email addresses. Your CSV file must include email addresses in the first column. You can include data in additional columns, but LaunchDarkly ignores all data outside the first column. Headers are optional. **Members are only added on a `201` response.** A `207` indicates the CSV file contains a combination of valid and invalid entries and will not result in any members being added to the team. On a `207` response, if an entry contains bad user input the `message` field will contain the row number as well as the reason for the error. The `message` field will be omitted if the entry is valid. Example `207` response: “`json { "items": [ { "status": "success", "value": "a-valid-email@launchdarkly.com" }, { "message": "Line 2: empty row", "status": "error", "value": "" }, { "message": "Line 3: email already exists in the specified team", "status": "error", "value": "existing-team-member@launchdarkly.com" }, { "message": "Line 4: invalid email formatting", "status": "error", "value": "invalid email format" } ] } “` Message | Resolution — | — Empty row | This line is blank. Add an email address and try again. Duplicate entry | This email address appears in the file twice. Remove the email from the file and try again. Email already exists in the specified team | This member is already on your team. Remove the email from the file and try again. Invalid formatting | This email address is not formatted correctly. Fix the formatting and try again. Email does not belong to a LaunchDarkly member | The email address doesn't belong to a LaunchDarkly account member. Invite them to LaunchDarkly, then re-add them to the team. On a `400` response, the `message` field may contain errors specific to this endpoint. Example `400` response: “`json { "code": "invalid_request", "message": "Unable to process file" } “` Message | Resolution — | — Unable to process file | LaunchDarkly could not process the file for an unspecified reason. Review your file for errors and try again. File exceeds 25mb | Break up your file into multiple files of less than 25mbs each. All emails have invalid formatting | None of the email addresses in the file are in the correct format. Fix the formatting and try again. All emails belong to existing team members | All listed members are already on this team. Populate the file with member emails that do not belong to the team and try again. File is empty | The CSV file does not contain any email addresses. Populate the file and try again. No emails belong to members of your LaunchDarkly organization | None of the email addresses belong to members of your LaunchDarkly account. Invite these members to LaunchDarkly, then re-add them to the team.
362 363 364 365 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 362 def post_team_members(key, opts = {}) data, _status_code, _headers = post_team_members_with_http_info(key, opts) data end |
#post_team_members_with_http_info(key, opts = {}) ⇒ Array<(TeamImportsRep, Integer, Hash)>
Add members to team Add multiple members to an existing team by uploading a CSV file of member email addresses. Your CSV file must include email addresses in the first column. You can include data in additional columns, but LaunchDarkly ignores all data outside the first column. Headers are optional. **Members are only added on a `201` response.** A `207` indicates the CSV file contains a combination of valid and invalid entries and will not result in any members being added to the team. On a `207` response, if an entry contains bad user input the `message` field will contain the row number as well as the reason for the error. The `message` field will be omitted if the entry is valid. Example `207` response: ```json { "items": [ { "status": "success", "value": "a-valid-email@launchdarkly.com" }, { "message": "Line 2: empty row", "status": "error", "value": "" }, { "message": "Line 3: email already exists in the specified team", "status": "error", "value": "existing-team-member@launchdarkly.com" }, { "message": "Line 4: invalid email formatting", "status": "error", "value": "invalid email format" } ] } ``` Message | Resolution — | — Empty row | This line is blank. Add an email address and try again. Duplicate entry | This email address appears in the file twice. Remove the email from the file and try again. Email already exists in the specified team | This member is already on your team. Remove the email from the file and try again. Invalid formatting | This email address is not formatted correctly. Fix the formatting and try again. Email does not belong to a LaunchDarkly member | The email address doesn't belong to a LaunchDarkly account member. Invite them to LaunchDarkly, then re-add them to the team. On a `400` response, the `message` field may contain errors specific to this endpoint. Example `400` response: ```json { "code": "invalid_request", "message": "Unable to process file" } ``` Message | Resolution — | — Unable to process file | LaunchDarkly could not process the file for an unspecified reason. Review your file for errors and try again. File exceeds 25mb | Break up your file into multiple files of less than 25mbs each. All emails have invalid formatting | None of the email addresses in the file are in the correct format. Fix the formatting and try again. All emails belong to existing team members | All listed members are already on this team. Populate the file with member emails that do not belong to the team and try again. File is empty | The CSV file does not contain any email addresses. Populate the file and try again. No emails belong to members of your LaunchDarkly organization | None of the email addresses belong to members of your LaunchDarkly account. Invite these members to LaunchDarkly, then re-add them to the team.
373 374 375 376 377 378 379 380 381 382 383 384 385 386 387 388 389 390 391 392 393 394 395 396 397 398 399 400 401 402 403 404 405 406 407 408 409 410 411 412 413 414 415 416 417 418 419 420 421 422 423 424 425 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 373 def post_team_members_with_http_info(key, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsBetaApi.post_team_members ...' end # verify the required parameter 'key' is set if @api_client.config.client_side_validation && key.nil? fail ArgumentError, "Missing the required parameter 'key' when calling TeamsBetaApi.post_team_members" end # resource path local_var_path = '/api/v2/teams/{key}/members'.sub('{' + 'key' + '}', CGI.escape(key.to_s)) # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['multipart/form-data']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} form_params['file'] = opts[:'file'] if !opts[:'file'].nil? # http body (model) post_body = opts[:debug_body] # return_type return_type = opts[:debug_return_type] || 'TeamImportsRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"TeamsBetaApi.post_team_members", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsBetaApi#post_team_members\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |
#post_team_with_http_info(team_post_input, opts = {}) ⇒ Array<(TeamRep, Integer, Hash)>
Create team Create a team
303 304 305 306 307 308 309 310 311 312 313 314 315 316 317 318 319 320 321 322 323 324 325 326 327 328 329 330 331 332 333 334 335 336 337 338 339 340 341 342 343 344 345 346 347 348 349 350 351 352 353 354 |
# File 'lib/launchdarkly_api/api/teams_beta_api.rb', line 303 def post_team_with_http_info(team_post_input, opts = {}) if @api_client.config.debugging @api_client.config.logger.debug 'Calling API: TeamsBetaApi.post_team ...' end # verify the required parameter 'team_post_input' is set if @api_client.config.client_side_validation && team_post_input.nil? fail ArgumentError, "Missing the required parameter 'team_post_input' when calling TeamsBetaApi.post_team" end # resource path local_var_path = '/api/v2/teams' # query parameters query_params = opts[:query_params] || {} # header parameters header_params = opts[:header_params] || {} # HTTP header 'Accept' (if needed) header_params['Accept'] = @api_client.select_header_accept(['application/json']) # HTTP header 'Content-Type' content_type = @api_client.select_header_content_type(['application/json']) if !content_type.nil? header_params['Content-Type'] = content_type end # form parameters form_params = opts[:form_params] || {} # http body (model) post_body = opts[:debug_body] || @api_client.object_to_http_body(team_post_input) # return_type return_type = opts[:debug_return_type] || 'TeamRep' # auth_names auth_names = opts[:debug_auth_names] || ['ApiKey'] = opts.merge( :operation => :"TeamsBetaApi.post_team", :header_params => header_params, :query_params => query_params, :form_params => form_params, :body => post_body, :auth_names => auth_names, :return_type => return_type ) data, status_code, headers = @api_client.call_api(:POST, local_var_path, ) if @api_client.config.debugging @api_client.config.logger.debug "API called: TeamsBetaApi#post_team\nData: #{data.inspect}\nStatus code: #{status_code}\nHeaders: #{headers}" end return data, status_code, headers end |