Class: LaunchDarklyApi::TriggerWorkflowRep
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::TriggerWorkflowRep
- Defined in:
- lib/launchdarkly_api/models/trigger_workflow_rep.rb
Defined Under Namespace
Classes: EnumAttributeValidator
Instance Attribute Summary collapse
-
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
-
#_id ⇒ Object
Returns the value of attribute _id.
-
#_integration_key ⇒ Object
The unique identifier of the integration for your trigger.
-
#_last_failed_at ⇒ Object
Returns the value of attribute _last_failed_at.
-
#_last_triggered_at ⇒ Object
Returns the value of attribute _last_triggered_at.
-
#_links ⇒ Object
The location and content type of related resources.
-
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
-
#_maintainer_id ⇒ Object
The ID of the flag trigger maintainer.
-
#_recent_trigger_bodies ⇒ Object
Details on recent flag trigger requests.
-
#_status ⇒ Object
The trigger state: active, inactive, or failed.
-
#_trigger_count ⇒ Object
Number of times the trigger has been executed.
-
#_version ⇒ Object
The flag trigger version.
-
#enabled ⇒ Object
Whether the flag trigger is currently enabled.
-
#instructions ⇒ Object
Returns the value of attribute instructions.
-
#trigger_url ⇒ Object
The unguessable URL for this flag trigger.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ TriggerWorkflowRep
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ TriggerWorkflowRep
Initializes the object
139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 174 175 176 177 178 179 180 181 182 183 184 185 186 187 188 189 190 191 192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 208 209 210 211 212 213 214 215 216 217 218 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 139 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::TriggerWorkflowRep` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::TriggerWorkflowRep`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'_id') self._id = attributes[:'_id'] end if attributes.key?(:'_version') self._version = attributes[:'_version'] end if attributes.key?(:'_creation_date') self._creation_date = attributes[:'_creation_date'] end if attributes.key?(:'_maintainer_id') self._maintainer_id = attributes[:'_maintainer_id'] end if attributes.key?(:'_maintainer') self._maintainer = attributes[:'_maintainer'] end if attributes.key?(:'enabled') self.enabled = attributes[:'enabled'] end if attributes.key?(:'_status') self._status = attributes[:'_status'] end if attributes.key?(:'_last_failed_at') self._last_failed_at = attributes[:'_last_failed_at'] end if attributes.key?(:'_integration_key') self._integration_key = attributes[:'_integration_key'] end if attributes.key?(:'instructions') if (value = attributes[:'instructions']).is_a?(Array) self.instructions = value end end if attributes.key?(:'_last_triggered_at') self._last_triggered_at = attributes[:'_last_triggered_at'] end if attributes.key?(:'_recent_trigger_bodies') if (value = attributes[:'_recent_trigger_bodies']).is_a?(Array) self._recent_trigger_bodies = value end end if attributes.key?(:'_trigger_count') self._trigger_count = attributes[:'_trigger_count'] end if attributes.key?(:'trigger_url') self.trigger_url = attributes[:'trigger_url'] end if attributes.key?(:'_links') if (value = attributes[:'_links']).is_a?(Hash) self._links = value end end end |
Instance Attribute Details
#_creation_date ⇒ Object
Returns the value of attribute _creation_date.
23 24 25 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 23 def _creation_date @_creation_date end |
#_id ⇒ Object
Returns the value of attribute _id.
18 19 20 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 18 def _id @_id end |
#_integration_key ⇒ Object
The unique identifier of the integration for your trigger
39 40 41 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 39 def _integration_key @_integration_key end |
#_last_failed_at ⇒ Object
Returns the value of attribute _last_failed_at.
36 37 38 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 36 def _last_failed_at @_last_failed_at end |
#_last_triggered_at ⇒ Object
Returns the value of attribute _last_triggered_at.
43 44 45 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 43 def _last_triggered_at @_last_triggered_at end |
#_links ⇒ Object
The location and content type of related resources
55 56 57 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 55 def _links @_links end |
#_maintainer ⇒ Object
Returns the value of attribute _maintainer.
28 29 30 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 28 def _maintainer @_maintainer end |
#_maintainer_id ⇒ Object
The ID of the flag trigger maintainer
26 27 28 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 26 def _maintainer_id @_maintainer_id end |
#_recent_trigger_bodies ⇒ Object
Details on recent flag trigger requests.
46 47 48 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 46 def _recent_trigger_bodies @_recent_trigger_bodies end |
#_status ⇒ Object
The trigger state: active, inactive, or failed
34 35 36 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 34 def _status @_status end |
#_trigger_count ⇒ Object
Number of times the trigger has been executed
49 50 51 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 49 def _trigger_count @_trigger_count end |
#_version ⇒ Object
The flag trigger version
21 22 23 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 21 def _version @_version end |
#enabled ⇒ Object
Whether the flag trigger is currently enabled
31 32 33 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 31 def enabled @enabled end |
#instructions ⇒ Object
Returns the value of attribute instructions.
41 42 43 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 41 def instructions @instructions end |
#trigger_url ⇒ Object
The unguessable URL for this flag trigger
52 53 54 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 52 def trigger_url @trigger_url end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
101 102 103 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 101 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
106 107 108 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 106 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
80 81 82 83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 80 def self.attribute_map { :'_id' => :'_id', :'_version' => :'_version', :'_creation_date' => :'_creationDate', :'_maintainer_id' => :'_maintainerId', :'_maintainer' => :'_maintainer', :'enabled' => :'enabled', :'_status' => :'_status', :'_last_failed_at' => :'_lastFailedAt', :'_integration_key' => :'_integrationKey', :'instructions' => :'instructions', :'_last_triggered_at' => :'_lastTriggeredAt', :'_recent_trigger_bodies' => :'_recentTriggerBodies', :'_trigger_count' => :'_triggerCount', :'trigger_url' => :'triggerURL', :'_links' => :'_links' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
284 285 286 287 288 289 290 291 292 293 294 295 296 297 298 299 300 301 302 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 284 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
132 133 134 135 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 132 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 111 def self.openapi_types { :'_id' => :'String', :'_version' => :'Integer', :'_creation_date' => :'Integer', :'_maintainer_id' => :'String', :'_maintainer' => :'MemberSummary', :'enabled' => :'Boolean', :'_status' => :'String', :'_last_failed_at' => :'Integer', :'_integration_key' => :'String', :'instructions' => :'Array<Hash>', :'_last_triggered_at' => :'Integer', :'_recent_trigger_bodies' => :'Array<RecentTriggerBody>', :'_trigger_count' => :'Integer', :'trigger_url' => :'String', :'_links' => :'Hash<String, Link>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
249 250 251 252 253 254 255 256 257 258 259 260 261 262 263 264 265 266 267 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 249 def ==(o) return true if self.equal?(o) self.class == o.class && _id == o._id && _version == o._version && _creation_date == o._creation_date && _maintainer_id == o._maintainer_id && _maintainer == o._maintainer && enabled == o.enabled && _status == o._status && _last_failed_at == o._last_failed_at && _integration_key == o._integration_key && instructions == o.instructions && _last_triggered_at == o._last_triggered_at && _recent_trigger_bodies == o._recent_trigger_bodies && _trigger_count == o._trigger_count && trigger_url == o.trigger_url && _links == o._links end |
#eql?(o) ⇒ Boolean
271 272 273 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 271 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
277 278 279 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 277 def hash [_id, _version, _creation_date, _maintainer_id, _maintainer, enabled, _status, _last_failed_at, _integration_key, instructions, _last_triggered_at, _recent_trigger_bodies, _trigger_count, trigger_url, _links].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
222 223 224 225 226 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 222 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
306 307 308 309 310 311 312 313 314 315 316 317 318 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 306 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
230 231 232 233 234 235 |
# File 'lib/launchdarkly_api/models/trigger_workflow_rep.rb', line 230 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' _status_validator = EnumAttributeValidator.new('String', ["active", "inactive", "failed"]) return false unless _status_validator.valid?(@_status) true end |