Class: LaunchDarklyApi::User
- Inherits:
-
ApiModelBase
- Object
- ApiModelBase
- LaunchDarklyApi::User
- Defined in:
- lib/launchdarkly_api/models/user.rb
Instance Attribute Summary collapse
-
#anonymous ⇒ Object
Whether the user is anonymous.
-
#avatar ⇒ Object
An absolute URL to an avatar image.
-
#country ⇒ Object
The user's country.
-
#custom ⇒ Object
Any other custom attributes for this user.
-
#email ⇒ Object
The user's email.
-
#first_name ⇒ Object
The user's first name.
-
#ip ⇒ Object
The user's IP address.
-
#key ⇒ Object
The user key.
-
#last_name ⇒ Object
The user's last name.
-
#name ⇒ Object
The user's full name.
-
#private_attrs ⇒ Object
A list of attribute names that are marked as private.
-
#secondary ⇒ Object
If provided, used with the user key to generate a variation in percentage rollouts.
Class Method Summary collapse
-
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about.
-
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about.
-
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
-
.build_from_hash(attributes) ⇒ Object
Builds the object from hash.
-
.openapi_nullable ⇒ Object
List of attributes with nullable: true.
-
.openapi_types ⇒ Object
Attribute type mapping.
Instance Method Summary collapse
-
#==(o) ⇒ Object
Checks equality by comparing each attribute.
- #eql?(o) ⇒ Boolean
-
#hash ⇒ Integer
Calculates hash code according to all attributes.
-
#initialize(attributes = {}) ⇒ User
constructor
Initializes the object.
-
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons.
-
#to_hash ⇒ Hash
Returns the object in the form of hash.
-
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid.
Methods inherited from ApiModelBase
_deserialize, #_to_hash, #to_body, #to_s
Constructor Details
#initialize(attributes = {}) ⇒ User
Initializes the object
108 109 110 111 112 113 114 115 116 117 118 119 120 121 122 123 124 125 126 127 128 129 130 131 132 133 134 135 136 137 138 139 140 141 142 143 144 145 146 147 148 149 150 151 152 153 154 155 156 157 158 159 160 161 162 163 164 165 166 167 168 169 170 171 172 173 |
# File 'lib/launchdarkly_api/models/user.rb', line 108 def initialize(attributes = {}) if (!attributes.is_a?(Hash)) fail ArgumentError, "The input argument (attributes) must be a hash in `LaunchDarklyApi::User` initialize method" end # check to see if the attribute exists and convert string to symbol for hash key acceptable_attribute_map = self.class.acceptable_attribute_map attributes = attributes.each_with_object({}) { |(k, v), h| if (!acceptable_attribute_map.key?(k.to_sym)) fail ArgumentError, "`#{k}` is not a valid attribute in `LaunchDarklyApi::User`. Please check the name to make sure it's valid. List of attributes: " + acceptable_attribute_map.keys.inspect end h[k.to_sym] = v } if attributes.key?(:'key') self.key = attributes[:'key'] end if attributes.key?(:'secondary') self.secondary = attributes[:'secondary'] end if attributes.key?(:'ip') self.ip = attributes[:'ip'] end if attributes.key?(:'country') self.country = attributes[:'country'] end if attributes.key?(:'email') self.email = attributes[:'email'] end if attributes.key?(:'first_name') self.first_name = attributes[:'first_name'] end if attributes.key?(:'last_name') self.last_name = attributes[:'last_name'] end if attributes.key?(:'avatar') self.avatar = attributes[:'avatar'] end if attributes.key?(:'name') self.name = attributes[:'name'] end if attributes.key?(:'anonymous') self.anonymous = attributes[:'anonymous'] end if attributes.key?(:'custom') if (value = attributes[:'custom']).is_a?(Hash) self.custom = value end end if attributes.key?(:'private_attrs') if (value = attributes[:'private_attrs']).is_a?(Array) self.private_attrs = value end end end |
Instance Attribute Details
#anonymous ⇒ Object
Whether the user is anonymous. If true, this user does not appear on the Contexts list in the LaunchDarkly user interface.
46 47 48 |
# File 'lib/launchdarkly_api/models/user.rb', line 46 def anonymous @anonymous end |
#avatar ⇒ Object
An absolute URL to an avatar image.
40 41 42 |
# File 'lib/launchdarkly_api/models/user.rb', line 40 def avatar @avatar end |
#country ⇒ Object
The user's country
28 29 30 |
# File 'lib/launchdarkly_api/models/user.rb', line 28 def country @country end |
#custom ⇒ Object
Any other custom attributes for this user. Custom attributes contain any other user data that you would like to use to conditionally target your users.
49 50 51 |
# File 'lib/launchdarkly_api/models/user.rb', line 49 def custom @custom end |
#email ⇒ Object
The user's email
31 32 33 |
# File 'lib/launchdarkly_api/models/user.rb', line 31 def email @email end |
#first_name ⇒ Object
The user's first name
34 35 36 |
# File 'lib/launchdarkly_api/models/user.rb', line 34 def first_name @first_name end |
#ip ⇒ Object
The user's IP address
25 26 27 |
# File 'lib/launchdarkly_api/models/user.rb', line 25 def ip @ip end |
#key ⇒ Object
The user key. This is the only mandatory user attribute.
19 20 21 |
# File 'lib/launchdarkly_api/models/user.rb', line 19 def key @key end |
#last_name ⇒ Object
The user's last name
37 38 39 |
# File 'lib/launchdarkly_api/models/user.rb', line 37 def last_name @last_name end |
#name ⇒ Object
The user's full name
43 44 45 |
# File 'lib/launchdarkly_api/models/user.rb', line 43 def name @name end |
#private_attrs ⇒ Object
A list of attribute names that are marked as private. You can use these attributes in targeting rules and segments. If you are using a server-side SDK, the SDK will not send the private attribute back to LaunchDarkly. If you are using a client-side SDK, the SDK will send the private attribute back to LaunchDarkly for evaluation. However, the SDK won't send the attribute to LaunchDarkly in events data, LaunchDarkly won't store the private attribute, and the private attribute will not appear on the Contexts list.
52 53 54 |
# File 'lib/launchdarkly_api/models/user.rb', line 52 def private_attrs @private_attrs end |
#secondary ⇒ Object
If provided, used with the user key to generate a variation in percentage rollouts
22 23 24 |
# File 'lib/launchdarkly_api/models/user.rb', line 22 def secondary @secondary end |
Class Method Details
.acceptable_attribute_map ⇒ Object
Returns attribute mapping this model knows about
73 74 75 |
# File 'lib/launchdarkly_api/models/user.rb', line 73 def self.acceptable_attribute_map attribute_map end |
.acceptable_attributes ⇒ Object
Returns all the JSON keys this model knows about
78 79 80 |
# File 'lib/launchdarkly_api/models/user.rb', line 78 def self.acceptable_attributes acceptable_attribute_map.values end |
.attribute_map ⇒ Object
Attribute mapping from ruby-style variable name to JSON key.
55 56 57 58 59 60 61 62 63 64 65 66 67 68 69 70 |
# File 'lib/launchdarkly_api/models/user.rb', line 55 def self.attribute_map { :'key' => :'key', :'secondary' => :'secondary', :'ip' => :'ip', :'country' => :'country', :'email' => :'email', :'first_name' => :'firstName', :'last_name' => :'lastName', :'avatar' => :'avatar', :'name' => :'name', :'anonymous' => :'anonymous', :'custom' => :'custom', :'private_attrs' => :'privateAttrs' } end |
.build_from_hash(attributes) ⇒ Object
Builds the object from hash
224 225 226 227 228 229 230 231 232 233 234 235 236 237 238 239 240 241 242 |
# File 'lib/launchdarkly_api/models/user.rb', line 224 def self.build_from_hash(attributes) return nil unless attributes.is_a?(Hash) attributes = attributes.transform_keys(&:to_sym) transformed_hash = {} openapi_types.each_pair do |key, type| if attributes.key?(attribute_map[key]) && attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = nil elsif type =~ /\AArray<(.*)>/i # check to ensure the input is an array given that the attribute # is documented as an array but the input is not if attributes[attribute_map[key]].is_a?(Array) transformed_hash["#{key}"] = attributes[attribute_map[key]].map { |v| _deserialize($1, v) } end elsif !attributes[attribute_map[key]].nil? transformed_hash["#{key}"] = _deserialize(type, attributes[attribute_map[key]]) end end new(transformed_hash) end |
.openapi_nullable ⇒ Object
List of attributes with nullable: true
101 102 103 104 |
# File 'lib/launchdarkly_api/models/user.rb', line 101 def self.openapi_nullable Set.new([ ]) end |
.openapi_types ⇒ Object
Attribute type mapping.
83 84 85 86 87 88 89 90 91 92 93 94 95 96 97 98 |
# File 'lib/launchdarkly_api/models/user.rb', line 83 def self.openapi_types { :'key' => :'String', :'secondary' => :'String', :'ip' => :'String', :'country' => :'String', :'email' => :'String', :'first_name' => :'String', :'last_name' => :'String', :'avatar' => :'String', :'name' => :'String', :'anonymous' => :'Boolean', :'custom' => :'Hash<String, Object>', :'private_attrs' => :'Array<String>' } end |
Instance Method Details
#==(o) ⇒ Object
Checks equality by comparing each attribute.
192 193 194 195 196 197 198 199 200 201 202 203 204 205 206 207 |
# File 'lib/launchdarkly_api/models/user.rb', line 192 def ==(o) return true if self.equal?(o) self.class == o.class && key == o.key && secondary == o.secondary && ip == o.ip && country == o.country && email == o.email && first_name == o.first_name && last_name == o.last_name && avatar == o.avatar && name == o.name && anonymous == o.anonymous && custom == o.custom && private_attrs == o.private_attrs end |
#eql?(o) ⇒ Boolean
211 212 213 |
# File 'lib/launchdarkly_api/models/user.rb', line 211 def eql?(o) self == o end |
#hash ⇒ Integer
Calculates hash code according to all attributes.
217 218 219 |
# File 'lib/launchdarkly_api/models/user.rb', line 217 def hash [key, secondary, ip, country, email, first_name, last_name, avatar, name, anonymous, custom, private_attrs].hash end |
#list_invalid_properties ⇒ Object
Show invalid properties with the reasons. Usually used together with valid?
177 178 179 180 181 |
# File 'lib/launchdarkly_api/models/user.rb', line 177 def list_invalid_properties warn '[DEPRECATED] the `list_invalid_properties` method is obsolete' invalid_properties = Array.new invalid_properties end |
#to_hash ⇒ Hash
Returns the object in the form of hash
246 247 248 249 250 251 252 253 254 255 256 257 258 |
# File 'lib/launchdarkly_api/models/user.rb', line 246 def to_hash hash = {} self.class.attribute_map.each_pair do |attr, param| value = self.send(attr) if value.nil? is_nullable = self.class.openapi_nullable.include?(attr) next if !is_nullable || (is_nullable && !instance_variable_defined?(:"@#{attr}")) end hash[param] = _to_hash(value) end hash end |
#valid? ⇒ Boolean
Check to see if the all the properties in the model are valid
185 186 187 188 |
# File 'lib/launchdarkly_api/models/user.rb', line 185 def valid? warn '[DEPRECATED] the `valid?` method is obsolete' true end |